Class: Google::Apis::BigqueryV2::BatchDeleteRowAccessPoliciesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Request message for the BatchDeleteRowAccessPoliciesRequest method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchDeleteRowAccessPoliciesRequest

Returns a new instance of BatchDeleteRowAccessPoliciesRequest.



692
693
694
# File 'lib/google/apis/bigquery_v2/classes.rb', line 692

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forceBoolean Also known as: force?

If set to true, it deletes the row access policy even if it's the last row access policy on the table and the deletion will widen the access rather narrowing it. Corresponds to the JSON property force

Returns:

  • (Boolean)


684
685
686
# File 'lib/google/apis/bigquery_v2/classes.rb', line 684

def force
  @force
end

#policy_idsArray<String>

Required. Policy IDs of the row access policies. Corresponds to the JSON property policyIds

Returns:

  • (Array<String>)


690
691
692
# File 'lib/google/apis/bigquery_v2/classes.rb', line 690

def policy_ids
  @policy_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



697
698
699
700
# File 'lib/google/apis/bigquery_v2/classes.rb', line 697

def update!(**args)
  @force = args[:force] if args.key?(:force)
  @policy_ids = args[:policy_ids] if args.key?(:policy_ids)
end