Class: Google::Apis::BigqueryV2::BiEngineStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics for a BI Engine specific query. Populated as part of JobStatistics2

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BiEngineStatistics

Returns a new instance of BiEngineStatistics.



752
753
754
# File 'lib/google/apis/bigquery_v2/classes.rb', line 752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleration_modeString

Output only. Specifies which mode of BI Engine acceleration was performed (if any). Corresponds to the JSON property accelerationMode

Returns:

  • (String)


737
738
739
# File 'lib/google/apis/bigquery_v2/classes.rb', line 737

def acceleration_mode
  @acceleration_mode
end

#bi_engine_modeString

Output only. Specifies which mode of BI Engine acceleration was performed (if any). Corresponds to the JSON property biEngineMode

Returns:

  • (String)


743
744
745
# File 'lib/google/apis/bigquery_v2/classes.rb', line 743

def bi_engine_mode
  @bi_engine_mode
end

#bi_engine_reasonsArray<Google::Apis::BigqueryV2::BiEngineReason>

In case of DISABLED or PARTIAL bi_engine_mode, these contain the explanatory reasons as to why BI Engine could not accelerate. In case the full query was accelerated, this field is not populated. Corresponds to the JSON property biEngineReasons



750
751
752
# File 'lib/google/apis/bigquery_v2/classes.rb', line 750

def bi_engine_reasons
  @bi_engine_reasons
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



757
758
759
760
761
# File 'lib/google/apis/bigquery_v2/classes.rb', line 757

def update!(**args)
  @acceleration_mode = args[:acceleration_mode] if args.key?(:acceleration_mode)
  @bi_engine_mode = args[:bi_engine_mode] if args.key?(:bi_engine_mode)
  @bi_engine_reasons = args[:bi_engine_reasons] if args.key?(:bi_engine_reasons)
end