Class: Google::Apis::BigqueryV2::BigLakeConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Configuration for BigQuery tables for Apache Iceberg (formerly BigLake managed tables.)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BigLakeConfiguration

Returns a new instance of BigLakeConfiguration.



800
801
802
# File 'lib/google/apis/bigquery_v2/classes.rb', line 800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_idString

Optional. The connection specifying the credentials to be used to read and write to external storage, such as Cloud Storage. The connection_id can have the form project`.`location`.`connection_id or projects/project/ locations/location/connections/connection_id". Corresponds to the JSON propertyconnectionId`

Returns:

  • (String)


781
782
783
# File 'lib/google/apis/bigquery_v2/classes.rb', line 781

def connection_id
  @connection_id
end

#file_formatString

Optional. The file format the table data is stored in. Corresponds to the JSON property fileFormat

Returns:

  • (String)


786
787
788
# File 'lib/google/apis/bigquery_v2/classes.rb', line 786

def file_format
  @file_format
end

#storage_uriString

Optional. The fully qualified location prefix of the external folder where table data is stored. The '*' wildcard character is not allowed. The URI should be in the format gs://bucket/path_to_table/ Corresponds to the JSON property storageUri

Returns:

  • (String)


793
794
795
# File 'lib/google/apis/bigquery_v2/classes.rb', line 793

def storage_uri
  @storage_uri
end

#table_formatString

Optional. The table format the metadata only snapshots are stored in. Corresponds to the JSON property tableFormat

Returns:

  • (String)


798
799
800
# File 'lib/google/apis/bigquery_v2/classes.rb', line 798

def table_format
  @table_format
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



805
806
807
808
809
810
# File 'lib/google/apis/bigquery_v2/classes.rb', line 805

def update!(**args)
  @connection_id = args[:connection_id] if args.key?(:connection_id)
  @file_format = args[:file_format] if args.key?(:file_format)
  @storage_uri = args[:storage_uri] if args.key?(:storage_uri)
  @table_format = args[:table_format] if args.key?(:table_format)
end