Class: Google::Apis::BigqueryV2::BigtableOptions
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::BigtableOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Options specific to Google Cloud Bigtable data sources.
Instance Attribute Summary collapse
-
#column_families ⇒ Array<Google::Apis::BigqueryV2::BigtableColumnFamily>
Optional.
-
#ignore_unspecified_column_families ⇒ Boolean
(also: #ignore_unspecified_column_families?)
Optional.
-
#output_column_families_as_json ⇒ Boolean
(also: #output_column_families_as_json?)
Optional.
-
#read_rowkey_as_string ⇒ Boolean
(also: #read_rowkey_as_string?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BigtableOptions
constructor
A new instance of BigtableOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BigtableOptions
Returns a new instance of BigtableOptions.
1017 1018 1019 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column_families ⇒ Array<Google::Apis::BigqueryV2::BigtableColumnFamily>
Optional. List of column families to expose in the table schema along with
their types. This list restricts the column families that can be referenced in
queries and specifies their value types. You can use this list to do type
conversions - see the 'type' field for more details. If you leave this list
empty, all column families are present in the table schema and their values
are read as BYTES. During a query only the column families referenced in that
query are read from Bigtable.
Corresponds to the JSON property columnFamilies
991 992 993 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 991 def column_families @column_families end |
#ignore_unspecified_column_families ⇒ Boolean Also known as: ignore_unspecified_column_families?
Optional. If field is true, then the column families that are not specified in
columnFamilies list are not exposed in the table schema. Otherwise, they are
read with BYTES type values. The default value is false.
Corresponds to the JSON property ignoreUnspecifiedColumnFamilies
998 999 1000 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 998 def ignore_unspecified_column_families @ignore_unspecified_column_families end |
#output_column_families_as_json ⇒ Boolean Also known as: output_column_families_as_json?
Optional. If field is true, then each column family will be read as a single
JSON column. Otherwise they are read as a repeated cell structure containing
timestamp/value tuples. The default value is false.
Corresponds to the JSON property outputColumnFamiliesAsJson
1006 1007 1008 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1006 def output_column_families_as_json @output_column_families_as_json end |
#read_rowkey_as_string ⇒ Boolean Also known as: read_rowkey_as_string?
Optional. If field is true, then the rowkey column families will be read and
converted to string. Otherwise they are read with BYTES type values and users
need to manually cast them with CAST if necessary. The default value is false.
Corresponds to the JSON property readRowkeyAsString
1014 1015 1016 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1014 def read_rowkey_as_string @read_rowkey_as_string end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1022 1023 1024 1025 1026 1027 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1022 def update!(**args) @column_families = args[:column_families] if args.key?(:column_families) @ignore_unspecified_column_families = args[:ignore_unspecified_column_families] if args.key?(:ignore_unspecified_column_families) @output_column_families_as_json = args[:output_column_families_as_json] if args.key?(:output_column_families_as_json) @read_rowkey_as_string = args[:read_rowkey_as_string] if args.key?(:read_rowkey_as_string) end |