Class: Google::Apis::BigqueryV2::BigtableProtoConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Information related to a Bigtable protobuf column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BigtableProtoConfig

Returns a new instance of BigtableProtoConfig.



978
979
980
# File 'lib/google/apis/bigquery_v2/classes.rb', line 978

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#proto_message_nameString

Optional. The fully qualified proto message name of the protobuf. In the format of "foo.bar.Message". Corresponds to the JSON property protoMessageName

Returns:

  • (String)


967
968
969
# File 'lib/google/apis/bigquery_v2/classes.rb', line 967

def proto_message_name
  @proto_message_name
end

#schema_bundle_idString

Optional. The ID of the Bigtable SchemaBundle resource associated with this protobuf. The ID should be referred to within the parent table, e.g., foo rather than projects/project/instances/instance/tables/table/ schemaBundles/foo. See more details on Bigtable SchemaBundles. Corresponds to the JSON property schemaBundleId

Returns:

  • (String)


976
977
978
# File 'lib/google/apis/bigquery_v2/classes.rb', line 976

def schema_bundle_id
  @schema_bundle_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



983
984
985
986
# File 'lib/google/apis/bigquery_v2/classes.rb', line 983

def update!(**args)
  @proto_message_name = args[:proto_message_name] if args.key?(:proto_message_name)
  @schema_bundle_id = args[:schema_bundle_id] if args.key?(:schema_bundle_id)
end