Class: Google::Apis::BigqueryV2::BinaryClassificationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Evaluation metrics for binary classification/classifier models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BinaryClassificationMetrics

Returns a new instance of BinaryClassificationMetrics.



1088
1089
1090
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1088

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregate_classification_metricsGoogle::Apis::BigqueryV2::AggregateClassificationMetrics

Aggregate metrics for classification/classifier models. For multi-class models, the metrics are either macro-averaged or micro-averaged. When macro-averaged, the metrics are calculated for each label and then an unweighted average is taken of those values. When micro-averaged, the metric is calculated globally by counting the total number of correctly predicted rows. Corresponds to the JSON property aggregateClassificationMetrics



1071
1072
1073
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1071

def aggregate_classification_metrics
  @aggregate_classification_metrics
end

#binary_confusion_matrix_listArray<Google::Apis::BigqueryV2::BinaryConfusionMatrix>

Binary confusion matrix at multiple thresholds. Corresponds to the JSON property binaryConfusionMatrixList



1076
1077
1078
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1076

def binary_confusion_matrix_list
  @binary_confusion_matrix_list
end

#negative_labelString

Label representing the negative class. Corresponds to the JSON property negativeLabel

Returns:

  • (String)


1081
1082
1083
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1081

def negative_label
  @negative_label
end

#positive_labelString

Label representing the positive class. Corresponds to the JSON property positiveLabel

Returns:

  • (String)


1086
1087
1088
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1086

def positive_label
  @positive_label
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1093
1094
1095
1096
1097
1098
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1093

def update!(**args)
  @aggregate_classification_metrics = args[:aggregate_classification_metrics] if args.key?(:aggregate_classification_metrics)
  @binary_confusion_matrix_list = args[:binary_confusion_matrix_list] if args.key?(:binary_confusion_matrix_list)
  @negative_label = args[:negative_label] if args.key?(:negative_label)
  @positive_label = args[:positive_label] if args.key?(:positive_label)
end