Class: Google::Apis::BigqueryV2::BinaryConfusionMatrix

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Confusion matrix for binary classification models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BinaryConfusionMatrix

Returns a new instance of BinaryConfusionMatrix.



1150
1151
1152
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accuracyFloat

The fraction of predictions given the correct label. Corresponds to the JSON property accuracy

Returns:

  • (Float)


1108
1109
1110
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1108

def accuracy
  @accuracy
end

#f1_scoreFloat

The equally weighted average of recall and precision. Corresponds to the JSON property f1Score

Returns:

  • (Float)


1113
1114
1115
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1113

def f1_score
  @f1_score
end

#false_negativesFixnum

Number of false samples predicted as false. Corresponds to the JSON property falseNegatives

Returns:

  • (Fixnum)


1118
1119
1120
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1118

def false_negatives
  @false_negatives
end

#false_positivesFixnum

Number of false samples predicted as true. Corresponds to the JSON property falsePositives

Returns:

  • (Fixnum)


1123
1124
1125
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1123

def false_positives
  @false_positives
end

#positive_class_thresholdFloat

Threshold value used when computing each of the following metric. Corresponds to the JSON property positiveClassThreshold

Returns:

  • (Float)


1128
1129
1130
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1128

def positive_class_threshold
  @positive_class_threshold
end

#precisionFloat

The fraction of actual positive predictions that had positive actual labels. Corresponds to the JSON property precision

Returns:

  • (Float)


1133
1134
1135
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1133

def precision
  @precision
end

#recallFloat

The fraction of actual positive labels that were given a positive prediction. Corresponds to the JSON property recall

Returns:

  • (Float)


1138
1139
1140
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1138

def recall
  @recall
end

#true_negativesFixnum

Number of true samples predicted as false. Corresponds to the JSON property trueNegatives

Returns:

  • (Fixnum)


1143
1144
1145
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1143

def true_negatives
  @true_negatives
end

#true_positivesFixnum

Number of true samples predicted as true. Corresponds to the JSON property truePositives

Returns:

  • (Fixnum)


1148
1149
1150
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1148

def true_positives
  @true_positives
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1155

def update!(**args)
  @accuracy = args[:accuracy] if args.key?(:accuracy)
  @f1_score = args[:f1_score] if args.key?(:f1_score)
  @false_negatives = args[:false_negatives] if args.key?(:false_negatives)
  @false_positives = args[:false_positives] if args.key?(:false_positives)
  @positive_class_threshold = args[:positive_class_threshold] if args.key?(:positive_class_threshold)
  @precision = args[:precision] if args.key?(:precision)
  @recall = args[:recall] if args.key?(:recall)
  @true_negatives = args[:true_negatives] if args.key?(:true_negatives)
  @true_positives = args[:true_positives] if args.key?(:true_positives)
end