Class: Google::Apis::BigqueryV2::Cluster
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::Cluster
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Message containing the information about one cluster.
Instance Attribute Summary collapse
-
#centroid_id ⇒ Fixnum
Centroid id.
-
#count ⇒ Fixnum
Count of training data rows that were assigned to this cluster.
-
#feature_values ⇒ Array<Google::Apis::BigqueryV2::FeatureValue>
Values of highly variant features for this cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Cluster
constructor
A new instance of Cluster.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Cluster
Returns a new instance of Cluster.
1515 1516 1517 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1515 def initialize(**args) update!(**args) end |
Instance Attribute Details
#centroid_id ⇒ Fixnum
Centroid id.
Corresponds to the JSON property centroidId
1503 1504 1505 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1503 def centroid_id @centroid_id end |
#count ⇒ Fixnum
Count of training data rows that were assigned to this cluster.
Corresponds to the JSON property count
1508 1509 1510 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1508 def count @count end |
#feature_values ⇒ Array<Google::Apis::BigqueryV2::FeatureValue>
Values of highly variant features for this cluster.
Corresponds to the JSON property featureValues
1513 1514 1515 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1513 def feature_values @feature_values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1520 1521 1522 1523 1524 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1520 def update!(**args) @centroid_id = args[:centroid_id] if args.key?(:centroid_id) @count = args[:count] if args.key?(:count) @feature_values = args[:feature_values] if args.key?(:feature_values) end |