Class: Google::Apis::BigqueryV2::ConnectionProperty
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ConnectionProperty
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
A connection-level property to customize query behavior. Under JDBC, these
correspond directly to connection properties passed to the DriverManager.
Under ODBC, these correspond to properties in the connection string. Currently
supported connection properties: * dataset_project_id: represents the
default project for datasets that are used in the query. Setting the system
variable @@dataset_project_id achieves the same behavior. For more
information about system variables, see: https://cloud.google.com/bigquery/
docs/reference/system-variables * time_zone: represents the default
timezone used to run the query. * session_id: associates the query with a
given session. * query_label: associates the query with a given job label.
If set, all subsequent queries in a script or session will have this label.
For the format in which a you can specify a query label, see labels in the
JobConfiguration resource type: https://cloud.google.com/bigquery/docs/
reference/rest/v2/Job#jobconfiguration * service_account: indicates the
service account to use to run a continuous query. If set, the query job uses
the service account to access Google Cloud resources. Service account access
is bounded by the IAM permissions that you have granted to the service account.
Additional properties are allowed, but ignored. Specifying multiple
connection properties with the same key returns an error.
Instance Attribute Summary collapse
-
#key ⇒ String
The key of the property to set.
-
#value ⇒ String
The value of the property to set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectionProperty
constructor
A new instance of ConnectionProperty.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectionProperty
Returns a new instance of ConnectionProperty.
1593 1594 1595 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1593 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
The key of the property to set.
Corresponds to the JSON property key
1586 1587 1588 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1586 def key @key end |
#value ⇒ String
The value of the property to set.
Corresponds to the JSON property value
1591 1592 1593 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1591 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1598 1599 1600 1601 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1598 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |