Class: Google::Apis::BigqueryV2::DataPolicyOption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Data policy option. For more information, see Mask data by applying data policies to a column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataPolicyOption

Returns a new instance of DataPolicyOption.



1793
1794
1795
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Data policy resource name in the form of projects/project_id/locations/ location_id/dataPolicies/data_policy_id. Corresponds to the JSON property name

Returns:

  • (String)


1791
1792
1793
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1791

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1798
1799
1800
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1798

def update!(**args)
  @name = args[:name] if args.key?(:name)
end