Class: Google::Apis::BigqueryV2::DataSplitResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Data split result. This contains references to the training and evaluation data tables that were used to train the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSplitResult

Returns a new instance of DataSplitResult.



1922
1923
1924
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1922

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#evaluation_tableGoogle::Apis::BigqueryV2::TableReference

Table reference of the evaluation data after split. Corresponds to the JSON property evaluationTable



1910
1911
1912
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1910

def evaluation_table
  @evaluation_table
end

#test_tableGoogle::Apis::BigqueryV2::TableReference

Table reference of the test data after split. Corresponds to the JSON property testTable



1915
1916
1917
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1915

def test_table
  @test_table
end

#training_tableGoogle::Apis::BigqueryV2::TableReference

Table reference of the training data after split. Corresponds to the JSON property trainingTable



1920
1921
1922
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1920

def training_table
  @training_table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1927
1928
1929
1930
1931
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1927

def update!(**args)
  @evaluation_table = args[:evaluation_table] if args.key?(:evaluation_table)
  @test_table = args[:test_table] if args.key?(:test_table)
  @training_table = args[:training_table] if args.key?(:training_table)
end