Class: Google::Apis::BigqueryV2::DatasetAccessEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Grants all resources of particular types in a particular dataset read access to the current dataset. Similar to how individually authorized views work, updates to any resource granted through its dataset (including creation of new resources) requires read permission to referenced resources, plus write permission to the authorizing dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatasetAccessEntry

Returns a new instance of DatasetAccessEntry.



2358
2359
2360
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datasetGoogle::Apis::BigqueryV2::DatasetReference

Identifier for a dataset. Corresponds to the JSON property dataset



2350
2351
2352
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2350

def dataset
  @dataset
end

#target_typesArray<String>

Which resources in the dataset this entry applies to. Currently, only views are supported, but additional target types may be added in the future. Corresponds to the JSON property targetTypes

Returns:

  • (Array<String>)


2356
2357
2358
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2356

def target_types
  @target_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2363
2364
2365
2366
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2363

def update!(**args)
  @dataset = args[:dataset] if args.key?(:dataset)
  @target_types = args[:target_types] if args.key?(:target_types)
end