Class: Google::Apis::BigqueryV2::DestinationTableProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Properties for the destination table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DestinationTableProperties

Returns a new instance of DestinationTableProperties.



2560
2561
2562
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The description for the destination table. This will only be used if the destination table is newly created. If the table already exists and a value different than the current description is provided, the job will fail. Corresponds to the JSON property description

Returns:

  • (String)


2539
2540
2541
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2539

def description
  @description
end

#expiration_timeDateTime

Internal use only. Corresponds to the JSON property expirationTime

Returns:

  • (DateTime)


2544
2545
2546
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2544

def expiration_time
  @expiration_time
end

#friendly_nameString

Optional. Friendly name for the destination table. If the table already exists, it should be same as the existing friendly name. Corresponds to the JSON property friendlyName

Returns:

  • (String)


2550
2551
2552
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2550

def friendly_name
  @friendly_name
end

#labelsHash<String,String>

Optional. The labels associated with this table. You can use these to organize and group your tables. This will only be used if the destination table is newly created. If the table already exists and labels are different than the current labels are provided, the job will fail. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2558
2559
2560
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2558

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2565
2566
2567
2568
2569
2570
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2565

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @friendly_name = args[:friendly_name] if args.key?(:friendly_name)
  @labels = args[:labels] if args.key?(:labels)
end