Class: Google::Apis::BigqueryV2::EncryptionConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Configuration for Cloud KMS encryption settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptionConfiguration

Returns a new instance of EncryptionConfiguration.



2719
2720
2721
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_key_nameString

Optional. Describes the Cloud KMS encryption key that will be used to protect destination BigQuery table. The BigQuery Service Account associated with your project requires access to this encryption key. Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


2717
2718
2719
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2717

def kms_key_name
  @kms_key_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2724
2725
2726
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2724

def update!(**args)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
end