Class: Google::Apis::BigqueryV2::ExportDataStatistics
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ExportDataStatistics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Statistics for the EXPORT DATA statement as part of Query Job. EXTRACT JOB statistics are populated in JobStatistics4.
Instance Attribute Summary collapse
-
#file_count ⇒ Fixnum
Number of destination files generated in case of EXPORT DATA statement only.
-
#row_count ⇒ Fixnum
[Alpha] Number of destination rows generated in case of EXPORT DATA statement only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExportDataStatistics
constructor
A new instance of ExportDataStatistics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExportDataStatistics
Returns a new instance of ExportDataStatistics.
3119 3120 3121 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file_count ⇒ Fixnum
Number of destination files generated in case of EXPORT DATA statement only.
Corresponds to the JSON property fileCount
3111 3112 3113 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3111 def file_count @file_count end |
#row_count ⇒ Fixnum
[Alpha] Number of destination rows generated in case of EXPORT DATA statement
only.
Corresponds to the JSON property rowCount
3117 3118 3119 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3117 def row_count @row_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3124 3125 3126 3127 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3124 def update!(**args) @file_count = args[:file_count] if args.key?(:file_count) @row_count = args[:row_count] if args.key?(:row_count) end |