Class: Google::Apis::BigqueryV2::ExternalCatalogDatasetOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Options defining open source compatible datasets living in the BigQuery catalog. Contains metadata of open source database, schema, or namespace represented by the current dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalCatalogDatasetOptions

Returns a new instance of ExternalCatalogDatasetOptions.



3301
3302
3303
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3301

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_storage_location_uriString

Optional. The storage location URI for all tables in the dataset. Equivalent to hive metastore's database locationUri. Maximum length of 1024 characters. Corresponds to the JSON property defaultStorageLocationUri

Returns:

  • (String)


3293
3294
3295
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3293

def default_storage_location_uri
  @default_storage_location_uri
end

#parametersHash<String,String>

Optional. A map of key value pairs defining the parameters and properties of the open source schema. Maximum size of 2MiB. Corresponds to the JSON property parameters

Returns:

  • (Hash<String,String>)


3299
3300
3301
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3299

def parameters
  @parameters
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3306
3307
3308
3309
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3306

def update!(**args)
  @default_storage_location_uri = args[:default_storage_location_uri] if args.key?(:default_storage_location_uri)
  @parameters = args[:parameters] if args.key?(:parameters)
end