Class: Google::Apis::BigqueryV2::ExternalCatalogTableOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Metadata about open source compatible table. The fields contained in these options correspond to Hive metastore's table-level properties.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalCatalogTableOptions

Returns a new instance of ExternalCatalogTableOptions.



3339
3340
3341
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3339

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_idString

Optional. A connection ID that specifies the credentials to be used to read external storage, such as Azure Blob, Cloud Storage, or Amazon S3. This connection is needed to read the open source table from BigQuery. The connection_id format must be either .. or projects//locations//connections/ . Corresponds to the JSON property connectionId

Returns:

  • (String)


3324
3325
3326
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3324

def connection_id
  @connection_id
end

#parametersHash<String,String>

Optional. A map of the key-value pairs defining the parameters and properties of the open source table. Corresponds with Hive metastore table parameters. Maximum size of 4MiB. Corresponds to the JSON property parameters

Returns:

  • (Hash<String,String>)


3331
3332
3333
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3331

def parameters
  @parameters
end

#storage_descriptorGoogle::Apis::BigqueryV2::StorageDescriptor

Contains information about how a table's data is stored and accessed by open source query engines. Corresponds to the JSON property storageDescriptor



3337
3338
3339
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3337

def storage_descriptor
  @storage_descriptor
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3344
3345
3346
3347
3348
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3344

def update!(**args)
  @connection_id = args[:connection_id] if args.key?(:connection_id)
  @parameters = args[:parameters] if args.key?(:parameters)
  @storage_descriptor = args[:storage_descriptor] if args.key?(:storage_descriptor)
end