Class: Google::Apis::BigqueryV2::ExternalDatasetReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Configures the access a dataset defined in an external metadata storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalDatasetReference

Returns a new instance of ExternalDatasetReference.



3517
3518
3519
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectionString

Required. The connection id that is used to access the external_source. Format: projects/project_id/locations/location_id/connections/connection_id Corresponds to the JSON property connection

Returns:

  • (String)


3510
3511
3512
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3510

def connection
  @connection
end

#external_sourceString

Required. External source that backs this dataset. Corresponds to the JSON property externalSource

Returns:

  • (String)


3515
3516
3517
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3515

def external_source
  @external_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3522
3523
3524
3525
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3522

def update!(**args)
  @connection = args[:connection] if args.key?(:connection)
  @external_source = args[:external_source] if args.key?(:external_source)
end