Class: Google::Apis::BigqueryV2::GenAiErrorStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Provides error statistics for the query job across all AI function calls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenAiErrorStats

Returns a new instance of GenAiErrorStats.



3833
3834
3835
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3833

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<String>

A list of unique errors at query level (up to 5, truncated to 100 chars) Corresponds to the JSON property errors

Returns:

  • (Array<String>)


3831
3832
3833
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3831

def errors
  @errors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3838
3839
3840
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3838

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
end