Class: Google::Apis::BigqueryV2::GenAiFunctionErrorStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Provides error statistics for a GenAi function call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenAiFunctionErrorStats

Returns a new instance of GenAiFunctionErrorStats.



3901
3902
3903
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<String>

A list of unique errors at function level (up to 5, truncated to 100 chars). Corresponds to the JSON property errors

Returns:

  • (Array<String>)


3894
3895
3896
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3894

def errors
  @errors
end

#num_failed_rowsFixnum

Number of failed rows processed by the function Corresponds to the JSON property numFailedRows

Returns:

  • (Fixnum)


3899
3900
3901
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3899

def num_failed_rows
  @num_failed_rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3906
3907
3908
3909
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3906

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
  @num_failed_rows = args[:num_failed_rows] if args.key?(:num_failed_rows)
end