Class: Google::Apis::BigqueryV2::GenAiStats
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::GenAiStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
GenAi stats for the query job.
Instance Attribute Summary collapse
-
#error_stats ⇒ Google::Apis::BigqueryV2::GenAiErrorStats
Provides error statistics for the query job across all AI function calls.
-
#function_stats ⇒ Array<Google::Apis::BigqueryV2::GenAiFunctionStats>
Function level stats for GenAi Functions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenAiStats
constructor
A new instance of GenAiStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenAiStats
Returns a new instance of GenAiStats.
3848 3849 3850 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3848 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_stats ⇒ Google::Apis::BigqueryV2::GenAiErrorStats
Provides error statistics for the query job across all AI function calls.
Corresponds to the JSON property errorStats
3840 3841 3842 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3840 def error_stats @error_stats end |
#function_stats ⇒ Array<Google::Apis::BigqueryV2::GenAiFunctionStats>
Function level stats for GenAi Functions. See https://docs.cloud.google.com/
bigquery/docs/generative-ai-overview
Corresponds to the JSON property functionStats
3846 3847 3848 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3846 def function_stats @function_stats end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3853 3854 3855 3856 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3853 def update!(**args) @error_stats = args[:error_stats] if args.key?(:error_stats) @function_stats = args[:function_stats] if args.key?(:function_stats) end |