Class: Google::Apis::BigqueryV2::GeneratedExpressionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Definition of the expression used to generate the field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeneratedExpressionInfo

Returns a new instance of GeneratedExpressionInfo.



4043
4044
4045
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4043

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asynchronousBoolean Also known as: asynchronous?

Optional. Whether the column generation is done asynchronously. Corresponds to the JSON property asynchronous

Returns:

  • (Boolean)


4028
4029
4030
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4028

def asynchronous
  @asynchronous
end

#generation_expressionString

Optional. The generation expression (e.g. AI.EMBED(...)) used to generate the field. Corresponds to the JSON property generationExpression

Returns:

  • (String)


4035
4036
4037
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4035

def generation_expression
  @generation_expression
end

#storedBoolean Also known as: stored?

Optional. Whether the generated column is stored in the table. Corresponds to the JSON property stored

Returns:

  • (Boolean)


4040
4041
4042
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4040

def stored
  @stored
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4048
4049
4050
4051
4052
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4048

def update!(**args)
  @asynchronous = args[:asynchronous] if args.key?(:asynchronous)
  @generation_expression = args[:generation_expression] if args.key?(:generation_expression)
  @stored = args[:stored] if args.key?(:stored)
end