Class: Google::Apis::BigqueryV2::GlobalExplanation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Global explanations containing the top most important features after training.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalExplanation

Returns a new instance of GlobalExplanation.



4244
4245
4246
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#class_labelString

Class label for this set of global explanations. Will be empty/null for binary logistic and linear regression models. Sorted alphabetically in descending order. Corresponds to the JSON property classLabel

Returns:

  • (String)


4236
4237
4238
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4236

def class_label
  @class_label
end

#explanationsArray<Google::Apis::BigqueryV2::Explanation>

A list of the top global explanations. Sorted by absolute value of attribution in descending order. Corresponds to the JSON property explanations



4242
4243
4244
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4242

def explanations
  @explanations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4249
4250
4251
4252
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4249

def update!(**args)
  @class_label = args[:class_label] if args.key?(:class_label)
  @explanations = args[:explanations] if args.key?(:explanations)
end