Class: Google::Apis::BigqueryV2::GoogleSheetsOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Options specific to Google Sheets data sources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleSheetsOptions

Returns a new instance of GoogleSheetsOptions.



4281
4282
4283
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rangeString

Optional. Range of a sheet to query from. Only used when non-empty. Typical format: sheet_name!top_left_cell_id:bottom_right_cell_id For example: sheet1! A1:B20 Corresponds to the JSON property range

Returns:

  • (String)


4264
4265
4266
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4264

def range
  @range
end

#skip_leading_rowsFixnum

Optional. The number of rows at the top of a sheet that BigQuery will skip when reading the data. The default value is 0. This property is useful if you have header rows that should be skipped. When autodetect is on, the behavior is the following: * skipLeadingRows unspecified - Autodetect tries to detect headers in the first row. If they are not detected, the row is read as data. Otherwise data is read starting from the second row. * skipLeadingRows is 0 - Instructs autodetect that there are no headers and data should be read starting from the first row. * skipLeadingRows = N > 0 - Autodetect skips N-1 rows and tries to detect headers in row N. If headers are not detected, row N is just skipped. Otherwise row N is used to extract column names for the detected schema. Corresponds to the JSON property skipLeadingRows

Returns:

  • (Fixnum)


4279
4280
4281
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4279

def skip_leading_rows
  @skip_leading_rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4286
4287
4288
4289
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4286

def update!(**args)
  @range = args[:range] if args.key?(:range)
  @skip_leading_rows = args[:skip_leading_rows] if args.key?(:skip_leading_rows)
end