Class: Google::Apis::BigqueryV2::HparamTuningTrial

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Training info of a trial in hyperparameter tuning models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HparamTuningTrial

Returns a new instance of HparamTuningTrial.



4598
4599
4600
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_time_msFixnum

Ending time of the trial. Corresponds to the JSON property endTimeMs

Returns:

  • (Fixnum)


4547
4548
4549
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4547

def end_time_ms
  @end_time_ms
end

#error_messageString

Error message for FAILED and INFEASIBLE trial. Corresponds to the JSON property errorMessage

Returns:

  • (String)


4552
4553
4554
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4552

def error_message
  @error_message
end

#eval_lossFloat

Loss computed on the eval data at the end of trial. Corresponds to the JSON property evalLoss

Returns:

  • (Float)


4557
4558
4559
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4557

def eval_loss
  @eval_loss
end

#evaluation_metricsGoogle::Apis::BigqueryV2::EvaluationMetrics

Evaluation metrics of a model. These are either computed on all training data or just the eval data based on whether eval data was used during training. These are not present for imported models. Corresponds to the JSON property evaluationMetrics



4564
4565
4566
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4564

def evaluation_metrics
  @evaluation_metrics
end

#hparam_tuning_evaluation_metricsGoogle::Apis::BigqueryV2::EvaluationMetrics

Evaluation metrics of a model. These are either computed on all training data or just the eval data based on whether eval data was used during training. These are not present for imported models. Corresponds to the JSON property hparamTuningEvaluationMetrics



4571
4572
4573
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4571

def hparam_tuning_evaluation_metrics
  @hparam_tuning_evaluation_metrics
end

#hparamsGoogle::Apis::BigqueryV2::TrainingOptions

Options used in model training. Corresponds to the JSON property hparams



4576
4577
4578
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4576

def hparams
  @hparams
end

#start_time_msFixnum

Starting time of the trial. Corresponds to the JSON property startTimeMs

Returns:

  • (Fixnum)


4581
4582
4583
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4581

def start_time_ms
  @start_time_ms
end

#statusString

The status of the trial. Corresponds to the JSON property status

Returns:

  • (String)


4586
4587
4588
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4586

def status
  @status
end

#training_lossFloat

Loss computed on the training data at the end of trial. Corresponds to the JSON property trainingLoss

Returns:

  • (Float)


4591
4592
4593
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4591

def training_loss
  @training_loss
end

#trial_idFixnum

1-based index of the trial. Corresponds to the JSON property trialId

Returns:

  • (Fixnum)


4596
4597
4598
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4596

def trial_id
  @trial_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4603
4604
4605
4606
4607
4608
4609
4610
4611
4612
4613
4614
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4603

def update!(**args)
  @end_time_ms = args[:end_time_ms] if args.key?(:end_time_ms)
  @error_message = args[:error_message] if args.key?(:error_message)
  @eval_loss = args[:eval_loss] if args.key?(:eval_loss)
  @evaluation_metrics = args[:evaluation_metrics] if args.key?(:evaluation_metrics)
  @hparam_tuning_evaluation_metrics = args[:hparam_tuning_evaluation_metrics] if args.key?(:hparam_tuning_evaluation_metrics)
  @hparams = args[:hparams] if args.key?(:hparams)
  @start_time_ms = args[:start_time_ms] if args.key?(:start_time_ms)
  @status = args[:status] if args.key?(:status)
  @training_loss = args[:training_loss] if args.key?(:training_loss)
  @trial_id = args[:trial_id] if args.key?(:trial_id)
end