Class: Google::Apis::BigqueryV2::IndexUnusedReason

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Reason about why no search index was used in the search query (or sub-query).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IndexUnusedReason

Returns a new instance of IndexUnusedReason.



4735
4736
4737
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_tableGoogle::Apis::BigqueryV2::TableReference

Specifies the base table involved in the reason that no search index was used. Corresponds to the JSON property baseTable



4718
4719
4720
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4718

def base_table
  @base_table
end

#codeString

Specifies the high-level reason for the scenario when no search index was used. Corresponds to the JSON property code

Returns:

  • (String)


4723
4724
4725
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4723

def code
  @code
end

#index_nameString

Specifies the name of the unused search index, if available. Corresponds to the JSON property indexName

Returns:

  • (String)


4728
4729
4730
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4728

def index_name
  @index_name
end

#messageString

Free form human-readable reason for the scenario when no search index was used. Corresponds to the JSON property message

Returns:

  • (String)


4733
4734
4735
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4733

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4740
4741
4742
4743
4744
4745
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4740

def update!(**args)
  @base_table = args[:base_table] if args.key?(:base_table)
  @code = args[:code] if args.key?(:code)
  @index_name = args[:index_name] if args.key?(:index_name)
  @message = args[:message] if args.key?(:message)
end