Class: Google::Apis::BigqueryV2::IterationResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Information about a single iteration of the training run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IterationResult

Returns a new instance of IterationResult.



4919
4920
4921
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4919

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arima_resultGoogle::Apis::BigqueryV2::ArimaResult

(Auto-)arima fitting result. Wrap everything in ArimaResult for easier refactoring if we want to use model-specific iteration results. Corresponds to the JSON property arimaResult



4882
4883
4884
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4882

def arima_result
  @arima_result
end

#cluster_infosArray<Google::Apis::BigqueryV2::ClusterInfo>

Information about top clusters for clustering models. Corresponds to the JSON property clusterInfos



4887
4888
4889
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4887

def cluster_infos
  @cluster_infos
end

#duration_msFixnum

Time taken to run the iteration in milliseconds. Corresponds to the JSON property durationMs

Returns:

  • (Fixnum)


4892
4893
4894
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4892

def duration_ms
  @duration_ms
end

#eval_lossFloat

Loss computed on the eval data at the end of iteration. Corresponds to the JSON property evalLoss

Returns:

  • (Float)


4897
4898
4899
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4897

def eval_loss
  @eval_loss
end

#indexFixnum

Index of the iteration, 0 based. Corresponds to the JSON property index

Returns:

  • (Fixnum)


4902
4903
4904
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4902

def index
  @index
end

#learn_rateFloat

Learn rate used for this iteration. Corresponds to the JSON property learnRate

Returns:

  • (Float)


4907
4908
4909
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4907

def learn_rate
  @learn_rate
end

#principal_component_infosArray<Google::Apis::BigqueryV2::PrincipalComponentInfo>

The information of the principal components. Corresponds to the JSON property principalComponentInfos



4912
4913
4914
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4912

def principal_component_infos
  @principal_component_infos
end

#training_lossFloat

Loss computed on the training data at the end of iteration. Corresponds to the JSON property trainingLoss

Returns:

  • (Float)


4917
4918
4919
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4917

def training_loss
  @training_loss
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4924
4925
4926
4927
4928
4929
4930
4931
4932
4933
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4924

def update!(**args)
  @arima_result = args[:arima_result] if args.key?(:arima_result)
  @cluster_infos = args[:cluster_infos] if args.key?(:cluster_infos)
  @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
  @eval_loss = args[:eval_loss] if args.key?(:eval_loss)
  @index = args[:index] if args.key?(:index)
  @learn_rate = args[:learn_rate] if args.key?(:learn_rate)
  @principal_component_infos = args[:principal_component_infos] if args.key?(:principal_component_infos)
  @training_loss = args[:training_loss] if args.key?(:training_loss)
end