Class: Google::Apis::BigqueryV2::JobConfigurationTableCopy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

JobConfigurationTableCopy configures a job that copies data from one table to another. For more information on copying tables, see Copy a table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobConfigurationTableCopy

Returns a new instance of JobConfigurationTableCopy.



6017
6018
6019
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_dispositionString

Optional. Specifies whether the job is allowed to create new tables. The following values are supported: * CREATE_IF_NEEDED: If the table does not exist, BigQuery creates the table. * CREATE_NEVER: The table must already exist. If it does not, a 'notFound' error is returned in the job result. The default value is CREATE_IF_NEEDED. Creation, truncation and append actions occur as one atomic update upon job completion. Corresponds to the JSON property createDisposition

Returns:

  • (String)


5971
5972
5973
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5971

def create_disposition
  @create_disposition
end

#destination_encryption_configurationGoogle::Apis::BigqueryV2::EncryptionConfiguration

Configuration for Cloud KMS encryption settings. Corresponds to the JSON property destinationEncryptionConfiguration



5976
5977
5978
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5976

def destination_encryption_configuration
  @destination_encryption_configuration
end

#destination_expiration_timeString

Optional. The time when the destination table expires. Expired tables will be deleted and their storage reclaimed. Corresponds to the JSON property destinationExpirationTime

Returns:

  • (String)


5982
5983
5984
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5982

def destination_expiration_time
  @destination_expiration_time
end

#destination_tableGoogle::Apis::BigqueryV2::TableReference

[Required] The destination table. Corresponds to the JSON property destinationTable



5987
5988
5989
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5987

def destination_table
  @destination_table
end

#operation_typeString

Optional. Supported operation types in table copy job. Corresponds to the JSON property operationType

Returns:

  • (String)


5992
5993
5994
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5992

def operation_type
  @operation_type
end

#source_tableGoogle::Apis::BigqueryV2::TableReference

[Pick one] Source table to copy. Corresponds to the JSON property sourceTable



5997
5998
5999
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5997

def source_table
  @source_table
end

#source_tablesArray<Google::Apis::BigqueryV2::TableReference>

[Pick one] Source tables to copy. Corresponds to the JSON property sourceTables



6002
6003
6004
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6002

def source_tables
  @source_tables
end

#write_dispositionString

Optional. Specifies the action that occurs if the destination table already exists. The following values are supported: * WRITE_TRUNCATE: If the table already exists, BigQuery overwrites the table data and uses the schema and table constraints from the source table. * WRITE_APPEND: If the table already exists, BigQuery appends the data to the table. * WRITE_EMPTY: If the table already exists and contains data, a 'duplicate' error is returned in the job result. The default value is WRITE_EMPTY. Each action is atomic and only occurs if BigQuery is able to complete the job successfully. Creation, truncation and append actions occur as one atomic update upon job completion. Corresponds to the JSON property writeDisposition

Returns:

  • (String)


6015
6016
6017
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6015

def write_disposition
  @write_disposition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6022
6023
6024
6025
6026
6027
6028
6029
6030
6031
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6022

def update!(**args)
  @create_disposition = args[:create_disposition] if args.key?(:create_disposition)
  @destination_encryption_configuration = args[:destination_encryption_configuration] if args.key?(:destination_encryption_configuration)
  @destination_expiration_time = args[:destination_expiration_time] if args.key?(:destination_expiration_time)
  @destination_table = args[:destination_table] if args.key?(:destination_table)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @source_table = args[:source_table] if args.key?(:source_table)
  @source_tables = args[:source_tables] if args.key?(:source_tables)
  @write_disposition = args[:write_disposition] if args.key?(:write_disposition)
end