Class: Google::Apis::BigqueryV2::JobCreationReason

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Reason about why a Job was created from a jobs.query method when used with JOB_CREATION_OPTIONAL Job creation mode. For jobs.insert method calls it will always be REQUESTED.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobCreationReason

Returns a new instance of JobCreationReason.



6038
6039
6040
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Output only. Specifies the high level reason why a Job was created. Corresponds to the JSON property code

Returns:

  • (String)


6036
6037
6038
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6036

def code
  @code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6043
6044
6045
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6043

def update!(**args)
  @code = args[:code] if args.key?(:code)
end