Class: Google::Apis::BigqueryV2::JobList
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
JobList is the response format for a jobs.list call.
Defined Under Namespace
Classes: Job
Instance Attribute Summary collapse
-
#etag ⇒ String
A hash of this page of results.
-
#jobs ⇒ Array<Google::Apis::BigqueryV2::JobList::Job>
List of jobs that were requested.
-
#kind ⇒ String
The resource type of the response.
-
#next_page_token ⇒ String
A token to request the next page of results.
-
#unreachable ⇒ Array<String>
A list of skipped locations that were unreachable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobList
constructor
A new instance of JobList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobList
Returns a new instance of JobList.
6003 6004 6005 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
A hash of this page of results.
Corresponds to the JSON property etag
5979 5980 5981 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5979 def etag @etag end |
#jobs ⇒ Array<Google::Apis::BigqueryV2::JobList::Job>
List of jobs that were requested.
Corresponds to the JSON property jobs
5984 5985 5986 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5984 def jobs @jobs end |
#kind ⇒ String
The resource type of the response.
Corresponds to the JSON property kind
5989 5990 5991 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5989 def kind @kind end |
#next_page_token ⇒ String
A token to request the next page of results.
Corresponds to the JSON property nextPageToken
5994 5995 5996 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5994 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
A list of skipped locations that were unreachable. For more information about
BigQuery locations, see: https://cloud.google.com/bigquery/docs/locations.
Example: "europe-west5"
Corresponds to the JSON property unreachable
6001 6002 6003 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6001 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6008 6009 6010 6011 6012 6013 6014 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6008 def update!(**args) @etag = args[:etag] if args.key?(:etag) @jobs = args[:jobs] if args.key?(:jobs) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |