Class: Google::Apis::BigqueryV2::JobList::Job
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobList::Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
ListFormatJob is a partial projection of job information returned as part of a jobs.list response.
Instance Attribute Summary collapse
-
#configuration ⇒ Google::Apis::BigqueryV2::JobConfiguration
Required.
-
#error_result ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
-
#id ⇒ String
Unique opaque ID of the job.
-
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
-
#kind ⇒ String
The resource type.
-
#principal_subject ⇒ String
[Full-projection-only] String representation of identity of requesting party.
-
#state ⇒ String
Running state of the job.
-
#statistics ⇒ Google::Apis::BigqueryV2::JobStatistics
Statistics for a single job execution.
-
#status ⇒ Google::Apis::BigqueryV2::JobStatus
[Full-projection-only] Describes the status of this job.
-
#user_email ⇒ String
[Full-projection-only] Email address of the user who ran the job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Job
constructor
A new instance of Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Job
Returns a new instance of Job.
6160 6161 6162 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration ⇒ Google::Apis::BigqueryV2::JobConfiguration
Required. Describes the job configuration.
Corresponds to the JSON property configuration
6110 6111 6112 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6110 def configuration @configuration end |
#error_result ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
Corresponds to the JSON property errorResult
6115 6116 6117 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6115 def error_result @error_result end |
#id ⇒ String
Unique opaque ID of the job.
Corresponds to the JSON property id
6120 6121 6122 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6120 def id @id end |
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
Corresponds to the JSON property jobReference
6125 6126 6127 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6125 def job_reference @job_reference end |
#kind ⇒ String
The resource type.
Corresponds to the JSON property kind
6130 6131 6132 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6130 def kind @kind end |
#principal_subject ⇒ String
[Full-projection-only] String representation of identity of requesting party.
Populated for both first- and third-party identities. Only present for APIs
that support third-party identities.
Corresponds to the JSON property principal_subject
6137 6138 6139 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6137 def principal_subject @principal_subject end |
#state ⇒ String
Running state of the job. When the state is DONE, errorResult can be checked
to determine whether the job succeeded or failed.
Corresponds to the JSON property state
6143 6144 6145 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6143 def state @state end |
#statistics ⇒ Google::Apis::BigqueryV2::JobStatistics
Statistics for a single job execution.
Corresponds to the JSON property statistics
6148 6149 6150 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6148 def statistics @statistics end |
#status ⇒ Google::Apis::BigqueryV2::JobStatus
[Full-projection-only] Describes the status of this job.
Corresponds to the JSON property status
6153 6154 6155 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6153 def status @status end |
#user_email ⇒ String
[Full-projection-only] Email address of the user who ran the job.
Corresponds to the JSON property user_email
6158 6159 6160 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6158 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6165 6166 6167 6168 6169 6170 6171 6172 6173 6174 6175 6176 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6165 def update!(**args) @configuration = args[:configuration] if args.key?(:configuration) @error_result = args[:error_result] if args.key?(:error_result) @id = args[:id] if args.key?(:id) @job_reference = args[:job_reference] if args.key?(:job_reference) @kind = args[:kind] if args.key?(:kind) @principal_subject = args[:principal_subject] if args.key?(:principal_subject) @state = args[:state] if args.key?(:state) @statistics = args[:statistics] if args.key?(:statistics) @status = args[:status] if args.key?(:status) @user_email = args[:user_email] if args.key?(:user_email) end |