Class: Google::Apis::BigqueryV2::JobStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics for a single job execution.

Defined Under Namespace

Classes: ReservationUsage

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobStatistics

Returns a new instance of JobStatistics.



6358
6359
6360
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_ratioFloat

Output only. [TrustedTester] Job progress (0.0 -> 1.0) for LOAD and EXTRACT jobs. Corresponds to the JSON property completionRatio

Returns:

  • (Float)


6223
6224
6225
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6223

def completion_ratio
  @completion_ratio
end

#copyGoogle::Apis::BigqueryV2::JobStatistics5

Statistics for a copy job. Corresponds to the JSON property copy



6228
6229
6230
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6228

def copy
  @copy
end

#creation_timeFixnum

Output only. Creation time of this job, in milliseconds since the epoch. This field will be present on all jobs. Corresponds to the JSON property creationTime

Returns:

  • (Fixnum)


6234
6235
6236
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6234

def creation_time
  @creation_time
end

#data_masking_statisticsGoogle::Apis::BigqueryV2::DataMaskingStatistics

Statistics for data-masking. Corresponds to the JSON property dataMaskingStatistics



6239
6240
6241
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6239

def data_masking_statistics
  @data_masking_statistics
end

#editionString

Output only. Name of edition corresponding to the reservation for this job at the time of this update. Corresponds to the JSON property edition

Returns:

  • (String)


6245
6246
6247
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6245

def edition
  @edition
end

#end_timeFixnum

Output only. End time of this job, in milliseconds since the epoch. This field will be present whenever a job is in the DONE state. Corresponds to the JSON property endTime

Returns:

  • (Fixnum)


6251
6252
6253
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6251

def end_time
  @end_time
end

#extractGoogle::Apis::BigqueryV2::JobStatistics4

Statistics for an extract job. Corresponds to the JSON property extract



6256
6257
6258
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6256

def extract
  @extract
end

#final_execution_duration_msFixnum

Output only. The duration in milliseconds of the execution of the final attempt of this job, as BigQuery may internally re-attempt to execute the job. Corresponds to the JSON property finalExecutionDurationMs

Returns:

  • (Fixnum)


6262
6263
6264
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6262

def final_execution_duration_ms
  @final_execution_duration_ms
end

#global_query_remote_regionsArray<String>

Output only. Regions where the global query accesses data. Corresponds to the JSON property globalQueryRemoteRegions

Returns:

  • (Array<String>)


6267
6268
6269
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6267

def global_query_remote_regions
  @global_query_remote_regions
end

#loadGoogle::Apis::BigqueryV2::JobStatistics3

Statistics for a load job. Corresponds to the JSON property load



6272
6273
6274
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6272

def load
  @load
end

#num_child_jobsFixnum

Output only. Number of child jobs executed. Corresponds to the JSON property numChildJobs

Returns:

  • (Fixnum)


6277
6278
6279
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6277

def num_child_jobs
  @num_child_jobs
end

#parent_global_query_jobGoogle::Apis::BigqueryV2::JobReference

A job reference is a fully qualified identifier for referring to a job. Corresponds to the JSON property parentGlobalQueryJob



6282
6283
6284
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6282

def parent_global_query_job
  @parent_global_query_job
end

#parent_job_idString

Output only. If this is a child job, specifies the job ID of the parent. Corresponds to the JSON property parentJobId

Returns:

  • (String)


6287
6288
6289
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6287

def parent_job_id
  @parent_job_id
end

#queryGoogle::Apis::BigqueryV2::JobStatistics2

Statistics for a query job. Corresponds to the JSON property query



6292
6293
6294
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6292

def query
  @query
end

#quota_defermentsArray<String>

Output only. Quotas which delayed this job's start time. Corresponds to the JSON property quotaDeferments

Returns:

  • (Array<String>)


6297
6298
6299
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6297

def quota_deferments
  @quota_deferments
end

#reservation_group_pathArray<String>

Output only. The reservation group path of the reservation assigned to this job. This field has a limit of 10 nested reservation groups. This is to maintain consistency between reservatins info schema and jobs info schema. The first reservation group is the root reservation group and the last is the leaf or lowest level reservation group. Corresponds to the JSON property reservationGroupPath

Returns:

  • (Array<String>)


6306
6307
6308
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6306

def reservation_group_path
  @reservation_group_path
end

#reservation_idString

Output only. Name of the primary reservation assigned to this job. Note that this could be different than reservations reported in the reservation usage field if parent reservations were used to execute this job. Corresponds to the JSON property reservation_id

Returns:

  • (String)


6319
6320
6321
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6319

def reservation_id
  @reservation_id
end

#reservation_usageArray<Google::Apis::BigqueryV2::JobStatistics::ReservationUsage>

Output only. Job resource usage breakdown by reservation. This field reported misleading information and will no longer be populated. Corresponds to the JSON property reservationUsage



6312
6313
6314
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6312

def reservation_usage
  @reservation_usage
end

#row_level_security_statisticsGoogle::Apis::BigqueryV2::RowLevelSecurityStatistics

Statistics for row-level security. Corresponds to the JSON property rowLevelSecurityStatistics



6324
6325
6326
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6324

def row_level_security_statistics
  @row_level_security_statistics
end

#script_statisticsGoogle::Apis::BigqueryV2::ScriptStatistics

Job statistics specific to the child job of a script. Corresponds to the JSON property scriptStatistics



6329
6330
6331
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6329

def script_statistics
  @script_statistics
end

#session_infoGoogle::Apis::BigqueryV2::SessionInfo

[Preview] Information related to sessions. Corresponds to the JSON property sessionInfo



6334
6335
6336
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6334

def session_info
  @session_info
end

#start_timeFixnum

Output only. Start time of this job, in milliseconds since the epoch. This field will be present when the job transitions from the PENDING state to either RUNNING or DONE. Corresponds to the JSON property startTime

Returns:

  • (Fixnum)


6341
6342
6343
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6341

def start_time
  @start_time
end

#total_bytes_processedFixnum

Output only. Total bytes processed for the job. Corresponds to the JSON property totalBytesProcessed

Returns:

  • (Fixnum)


6346
6347
6348
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6346

def total_bytes_processed
  @total_bytes_processed
end

#total_slot_msFixnum

Output only. Slot-milliseconds for the job. Corresponds to the JSON property totalSlotMs

Returns:

  • (Fixnum)


6351
6352
6353
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6351

def total_slot_ms
  @total_slot_ms
end

#transaction_infoGoogle::Apis::BigqueryV2::TransactionInfo

[Alpha] Information of a multi-statement transaction. Corresponds to the JSON property transactionInfo



6356
6357
6358
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6356

def transaction_info
  @transaction_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
6387
6388
6389
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6363

def update!(**args)
  @completion_ratio = args[:completion_ratio] if args.key?(:completion_ratio)
  @copy = args[:copy] if args.key?(:copy)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @data_masking_statistics = args[:data_masking_statistics] if args.key?(:data_masking_statistics)
  @edition = args[:edition] if args.key?(:edition)
  @end_time = args[:end_time] if args.key?(:end_time)
  @extract = args[:extract] if args.key?(:extract)
  @final_execution_duration_ms = args[:final_execution_duration_ms] if args.key?(:final_execution_duration_ms)
  @global_query_remote_regions = args[:global_query_remote_regions] if args.key?(:global_query_remote_regions)
  @load = args[:load] if args.key?(:load)
  @num_child_jobs = args[:num_child_jobs] if args.key?(:num_child_jobs)
  @parent_global_query_job = args[:parent_global_query_job] if args.key?(:parent_global_query_job)
  @parent_job_id = args[:parent_job_id] if args.key?(:parent_job_id)
  @query = args[:query] if args.key?(:query)
  @quota_deferments = args[:quota_deferments] if args.key?(:quota_deferments)
  @reservation_group_path = args[:reservation_group_path] if args.key?(:reservation_group_path)
  @reservation_usage = args[:reservation_usage] if args.key?(:reservation_usage)
  @reservation_id = args[:reservation_id] if args.key?(:reservation_id)
  @row_level_security_statistics = args[:row_level_security_statistics] if args.key?(:row_level_security_statistics)
  @script_statistics = args[:script_statistics] if args.key?(:script_statistics)
  @session_info = args[:session_info] if args.key?(:session_info)
  @start_time = args[:start_time] if args.key?(:start_time)
  @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed)
  @total_slot_ms = args[:total_slot_ms] if args.key?(:total_slot_ms)
  @transaction_info = args[:transaction_info] if args.key?(:transaction_info)
end