Class: Google::Apis::BigqueryV2::JobStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobStatus

Returns a new instance of JobStatus.



7017
7018
7019
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_resultGoogle::Apis::BigqueryV2::ErrorProto

Error details. Corresponds to the JSON property errorResult



7001
7002
7003
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7001

def error_result
  @error_result
end

#errorsArray<Google::Apis::BigqueryV2::ErrorProto>

Output only. The first errors encountered during the running of the job. The final message includes the number of errors that caused the process to stop. Errors here do not necessarily mean that the job has not completed or was unsuccessful. Corresponds to the JSON property errors



7009
7010
7011
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7009

def errors
  @errors
end

#stateString

Output only. Running state of the job. Valid states include 'PENDING', ' RUNNING', and 'DONE'. Corresponds to the JSON property state

Returns:

  • (String)


7015
7016
7017
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7015

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7022
7023
7024
7025
7026
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7022

def update!(**args)
  @error_result = args[:error_result] if args.key?(:error_result)
  @errors = args[:errors] if args.key?(:errors)
  @state = args[:state] if args.key?(:state)
end