Class: Google::Apis::BigqueryV2::JoinRestrictionPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Represents privacy policy associated with "join restrictions". Join restriction gives data providers the ability to enforce joins on the ' join_allowed_columns' when data is queried from a privacy protected view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JoinRestrictionPolicy

Returns a new instance of JoinRestrictionPolicy.



6933
6934
6935
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6933

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#join_allowed_columnsArray<String>

Optional. The only columns that joins are allowed on. This field is must be specified for join_conditions JOIN_ANY and JOIN_ALL and it cannot be set for JOIN_BLOCKED. Corresponds to the JSON property joinAllowedColumns

Returns:

  • (Array<String>)


6925
6926
6927
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6925

def join_allowed_columns
  @join_allowed_columns
end

#join_conditionString

Optional. Specifies if a join is required or not on queries for the view. Default is JOIN_CONDITION_UNSPECIFIED. Corresponds to the JSON property joinCondition

Returns:

  • (String)


6931
6932
6933
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6931

def join_condition
  @join_condition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6938
6939
6940
6941
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6938

def update!(**args)
  @join_allowed_columns = args[:join_allowed_columns] if args.key?(:join_allowed_columns)
  @join_condition = args[:join_condition] if args.key?(:join_condition)
end