Class: Google::Apis::BigqueryV2::ListModelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Response format for a single page when listing BigQuery ML models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListModelsResponse

Returns a new instance of ListModelsResponse.



7132
7133
7134
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7132

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modelsArray<Google::Apis::BigqueryV2::Model>

Models in the requested dataset. Only the following fields are populated: model_reference, model_type, creation_time, last_modified_time and labels. Corresponds to the JSON property models



7125
7126
7127
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7125

def models
  @models
end

#next_page_tokenString

A token to request the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7130
7131
7132
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7130

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7137
7138
7139
7140
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7137

def update!(**args)
  @models = args[:models] if args.key?(:models)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end