Class: Google::Apis::BigqueryV2::ListRoutinesResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ListRoutinesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Describes the format of a single result page when listing routines.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of results.
-
#routines ⇒ Array<Google::Apis::BigqueryV2::Routine>
Routines in the requested dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRoutinesResponse
constructor
A new instance of ListRoutinesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRoutinesResponse
Returns a new instance of ListRoutinesResponse.
7160 7161 7162 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7160 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of results.
Corresponds to the JSON property nextPageToken
7150 7151 7152 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7150 def next_page_token @next_page_token end |
#routines ⇒ Array<Google::Apis::BigqueryV2::Routine>
Routines in the requested dataset. Unless read_mask is set in the request,
only the following fields are populated: etag, project_id, dataset_id,
routine_id, routine_type, creation_time, last_modified_time, language, and
remote_function_options.
Corresponds to the JSON property routines
7158 7159 7160 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7158 def routines @routines end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7165 7166 7167 7168 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7165 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @routines = args[:routines] if args.key?(:routines) end |