Class: Google::Apis::BigqueryV2::ListRowAccessPoliciesResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ListRowAccessPoliciesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Response message for the ListRowAccessPolicies method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of results.
-
#row_access_policies ⇒ Array<Google::Apis::BigqueryV2::RowAccessPolicy>
Row access policies on the requested table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRowAccessPoliciesResponse
constructor
A new instance of ListRowAccessPoliciesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRowAccessPoliciesResponse
Returns a new instance of ListRowAccessPoliciesResponse.
7185 7186 7187 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of results.
Corresponds to the JSON property nextPageToken
7178 7179 7180 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7178 def next_page_token @next_page_token end |
#row_access_policies ⇒ Array<Google::Apis::BigqueryV2::RowAccessPolicy>
Row access policies on the requested table.
Corresponds to the JSON property rowAccessPolicies
7183 7184 7185 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7183 def row_access_policies @row_access_policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7190 7191 7192 7193 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7190 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @row_access_policies = args[:row_access_policies] if args.key?(:row_access_policies) end |