Class: Google::Apis::BigqueryV2::MaterializedView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

A materialized view considered for a query job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaterializedView

Returns a new instance of MaterializedView.



7305
7306
7307
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chosenBoolean Also known as: chosen?

Whether the materialized view is chosen for the query. A materialized view can be chosen to rewrite multiple parts of the same query. If a materialized view is chosen to rewrite any part of the query, then this field is true, even if the materialized view was not chosen to rewrite others parts. Corresponds to the JSON property chosen

Returns:

  • (Boolean)


7285
7286
7287
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7285

def chosen
  @chosen
end

#estimated_bytes_savedFixnum

If present, specifies a best-effort estimation of the bytes saved by using the materialized view rather than its base tables. Corresponds to the JSON property estimatedBytesSaved

Returns:

  • (Fixnum)


7292
7293
7294
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7292

def estimated_bytes_saved
  @estimated_bytes_saved
end

#rejected_reasonString

If present, specifies the reason why the materialized view was not chosen for the query. Corresponds to the JSON property rejectedReason

Returns:

  • (String)


7298
7299
7300
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7298

def rejected_reason
  @rejected_reason
end

#table_referenceGoogle::Apis::BigqueryV2::TableReference

The candidate materialized view. Corresponds to the JSON property tableReference



7303
7304
7305
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7303

def table_reference
  @table_reference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7310
7311
7312
7313
7314
7315
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7310

def update!(**args)
  @chosen = args[:chosen] if args.key?(:chosen)
  @estimated_bytes_saved = args[:estimated_bytes_saved] if args.key?(:estimated_bytes_saved)
  @rejected_reason = args[:rejected_reason] if args.key?(:rejected_reason)
  @table_reference = args[:table_reference] if args.key?(:table_reference)
end