Class: Google::Apis::BigqueryV2::MaterializedViewStatus
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::MaterializedViewStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Status of a materialized view. The last refresh timestamp status is omitted here, but is present in the MaterializedViewDefinition message.
Instance Attribute Summary collapse
-
#last_refresh_status ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
-
#refresh_watermark ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MaterializedViewStatus
constructor
A new instance of MaterializedViewStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MaterializedViewStatus
Returns a new instance of MaterializedViewStatus.
7414 7415 7416 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7414 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_refresh_status ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
Corresponds to the JSON property lastRefreshStatus
7406 7407 7408 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7406 def last_refresh_status @last_refresh_status end |
#refresh_watermark ⇒ String
Output only. Refresh watermark of materialized view. The base tables' data
were collected into the materialized view cache until this time.
Corresponds to the JSON property refreshWatermark
7412 7413 7414 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7412 def refresh_watermark @refresh_watermark end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7419 7420 7421 7422 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7419 def update!(**args) @last_refresh_status = args[:last_refresh_status] if args.key?(:last_refresh_status) @refresh_watermark = args[:refresh_watermark] if args.key?(:refresh_watermark) end |