Class: Google::Apis::BigqueryV2::MetadataCacheStalenessInsight

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Column Metadata Index staleness detailed infnormation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetadataCacheStalenessInsight

Returns a new instance of MetadataCacheStalenessInsight.



7441
7442
7443
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7441

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avg_previous_staleness_msString

Output only. Average column metadata index staleness of previous runs with the same query hash. Corresponds to the JSON property avgPreviousStalenessMs

Returns:

  • (String)


7433
7434
7435
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7433

def avg_previous_staleness_ms
  @avg_previous_staleness_ms
end

#staleness_percentage_increaseFloat

Output only. The percent increase in staleness between the current job and the average staleness of previous jobs with the same query hash. Corresponds to the JSON property stalenessPercentageIncrease

Returns:

  • (Float)


7439
7440
7441
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7439

def staleness_percentage_increase
  @staleness_percentage_increase
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7446
7447
7448
7449
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7446

def update!(**args)
  @avg_previous_staleness_ms = args[:avg_previous_staleness_ms] if args.key?(:avg_previous_staleness_ms)
  @staleness_percentage_increase = args[:staleness_percentage_increase] if args.key?(:staleness_percentage_increase)
end