Class: Google::Apis::BigqueryV2::ParquetOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Parquet Options for load and make external tables.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ParquetOptions

Returns a new instance of ParquetOptions.



7371
7372
7373
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_list_inferenceBoolean Also known as: enable_list_inference?

Optional. Indicates whether to use schema inference specifically for Parquet LIST logical type. Corresponds to the JSON property enableListInference

Returns:

  • (Boolean)


7356
7357
7358
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7356

def enable_list_inference
  @enable_list_inference
end

#enum_as_stringBoolean Also known as: enum_as_string?

Optional. Indicates whether to infer Parquet ENUM logical type as STRING instead of BYTES by default. Corresponds to the JSON property enumAsString

Returns:

  • (Boolean)


7363
7364
7365
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7363

def enum_as_string
  @enum_as_string
end

#map_target_typeString

Optional. Indicates how to represent a Parquet map if present. Corresponds to the JSON property mapTargetType

Returns:

  • (String)


7369
7370
7371
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7369

def map_target_type
  @map_target_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7376
7377
7378
7379
7380
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7376

def update!(**args)
  @enable_list_inference = args[:enable_list_inference] if args.key?(:enable_list_inference)
  @enum_as_string = args[:enum_as_string] if args.key?(:enum_as_string)
  @map_target_type = args[:map_target_type] if args.key?(:map_target_type)
end