Class: Google::Apis::BigqueryV2::PartitioningDefinition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

The partitioning information, which includes managed table, external table and metastore partitioned table partition information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartitioningDefinition

Returns a new instance of PartitioningDefinition.



7948
7949
7950
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#partitioned_columnArray<Google::Apis::BigqueryV2::PartitionedColumn>

Optional. Details about each partitioning column. This field is output only for all partitioning types other than metastore partitioned tables. BigQuery native tables only support 1 partitioning column. Other table types may support 0, 1 or more partitioning columns. For metastore partitioned tables, the order must match the definition order in the Hive Metastore, where it must match the physical layout of the table. For example, CREATE TABLE a_table(id BIGINT, name STRING) PARTITIONED BY (city STRING, state STRING). In this case the values must be ['city', 'state'] in that order. Corresponds to the JSON property partitionedColumn



7946
7947
7948
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7946

def partitioned_column
  @partitioned_column
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7953
7954
7955
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7953

def update!(**args)
  @partitioned_column = args[:partitioned_column] if args.key?(:partitioned_column)
end