Class: Google::Apis::BigqueryV2::ProjectList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Response object of ListProjects

Defined Under Namespace

Classes: Project

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectList

Returns a new instance of ProjectList.



8053
8054
8055
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

A hash of the page of results. Corresponds to the JSON property etag

Returns:

  • (String)


8029
8030
8031
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8029

def etag
  @etag
end

#kindString

The resource type of the response. Corresponds to the JSON property kind

Returns:

  • (String)


8034
8035
8036
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8034

def kind
  @kind
end

#next_page_tokenString

Use this token to request the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8039
8040
8041
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8039

def next_page_token
  @next_page_token
end

#projectsArray<Google::Apis::BigqueryV2::ProjectList::Project>

Projects to which the user has at least READ access. This field can be omitted if totalItems is 0. Corresponds to the JSON property projects



8045
8046
8047
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8045

def projects
  @projects
end

#total_itemsFixnum

The total number of projects in the page. A wrapper is used here because the field should still be in the response when the value is 0. Corresponds to the JSON property totalItems

Returns:

  • (Fixnum)


8051
8052
8053
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8051

def total_items
  @total_items
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8058
8059
8060
8061
8062
8063
8064
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8058

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @projects = args[:projects] if args.key?(:projects)
  @total_items = args[:total_items] if args.key?(:total_items)
end