Class: Google::Apis::BigqueryV2::RankingMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Evaluation metrics used by weighted-ALS models specified by feedback_type= implicit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RankingMetrics

Returns a new instance of RankingMetrics.



8881
8882
8883
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8881

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#average_rankFloat

Determines the goodness of a ranking by computing the percentile rank from the predicted confidence and dividing it by the original rank. Corresponds to the JSON property averageRank

Returns:

  • (Float)


8859
8860
8861
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8859

def average_rank
  @average_rank
end

#mean_average_precisionFloat

Calculates a precision per user for all the items by ranking them and then averages all the precisions across all the users. Corresponds to the JSON property meanAveragePrecision

Returns:

  • (Float)


8865
8866
8867
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8865

def mean_average_precision
  @mean_average_precision
end

#mean_squared_errorFloat

Similar to the mean squared error computed in regression and explicit recommendation models except instead of computing the rating directly, the output from evaluate is computed against a preference which is 1 or 0 depending on if the rating exists or not. Corresponds to the JSON property meanSquaredError

Returns:

  • (Float)


8873
8874
8875
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8873

def mean_squared_error
  @mean_squared_error
end

#normalized_discounted_cumulative_gainFloat

A metric to determine the goodness of a ranking calculated from the predicted confidence by comparing it to an ideal rank measured by the original ratings. Corresponds to the JSON property normalizedDiscountedCumulativeGain

Returns:

  • (Float)


8879
8880
8881
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8879

def normalized_discounted_cumulative_gain
  @normalized_discounted_cumulative_gain
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8886
8887
8888
8889
8890
8891
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8886

def update!(**args)
  @average_rank = args[:average_rank] if args.key?(:average_rank)
  @mean_average_precision = args[:mean_average_precision] if args.key?(:mean_average_precision)
  @mean_squared_error = args[:mean_squared_error] if args.key?(:mean_squared_error)
  @normalized_discounted_cumulative_gain = args[:normalized_discounted_cumulative_gain] if args.key?(:normalized_discounted_cumulative_gain)
end