Class: Google::Apis::BigqueryV2::RemoteFunctionOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Options for a remote user-defined function.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoteFunctionOptions

Returns a new instance of RemoteFunctionOptions.



9342
9343
9344
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9342

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectionString

Fully qualified name of the user-provided connection object which holds the authentication information to send requests to the remote service. Format: " projects/`projectId`/locations/`locationId`/connections/`connectionId`" Corresponds to the JSON property connection

Returns:

  • (String)


9320
9321
9322
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9320

def connection
  @connection
end

#endpointString

Endpoint of the user-provided remote service, e.g. https://us-east1- my_gcf_project.cloudfunctions.net/remote_add Corresponds to the JSON property endpoint

Returns:

  • (String)


9326
9327
9328
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9326

def endpoint
  @endpoint
end

#max_batching_rowsFixnum

Max number of rows in each batch sent to the remote service. If absent or if 0, BigQuery dynamically decides the number of rows in a batch. Corresponds to the JSON property maxBatchingRows

Returns:

  • (Fixnum)


9332
9333
9334
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9332

def max_batching_rows
  @max_batching_rows
end

#user_defined_contextHash<String,String>

User-defined context as a set of key/value pairs, which will be sent as function invocation context together with batched arguments in the requests to the remote service. The total number of bytes of keys and values must be less than 8KB. Corresponds to the JSON property userDefinedContext

Returns:

  • (Hash<String,String>)


9340
9341
9342
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9340

def user_defined_context
  @user_defined_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9347
9348
9349
9350
9351
9352
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9347

def update!(**args)
  @connection = args[:connection] if args.key?(:connection)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @max_batching_rows = args[:max_batching_rows] if args.key?(:max_batching_rows)
  @user_defined_context = args[:user_defined_context] if args.key?(:user_defined_context)
end