Class: Google::Apis::BigqueryV2::RowAccessPolicyReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Id path of a row access policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RowAccessPolicyReference

Returns a new instance of RowAccessPolicyReference.



9804
9805
9806
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_idString

Required. The ID of the dataset containing this row access policy. Corresponds to the JSON property datasetId

Returns:

  • (String)


9785
9786
9787
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9785

def dataset_id
  @dataset_id
end

#policy_idString

Required. The ID of the row access policy. The ID must contain only letters (a- z, A-Z), numbers (0-9), or underscores (_). The maximum length is 256 characters. Corresponds to the JSON property policyId

Returns:

  • (String)


9792
9793
9794
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9792

def policy_id
  @policy_id
end

#project_idString

Required. The ID of the project containing this row access policy. Corresponds to the JSON property projectId

Returns:

  • (String)


9797
9798
9799
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9797

def project_id
  @project_id
end

#table_idString

Required. The ID of the table containing this row access policy. Corresponds to the JSON property tableId

Returns:

  • (String)


9802
9803
9804
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9802

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9809
9810
9811
9812
9813
9814
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9809

def update!(**args)
  @dataset_id = args[:dataset_id] if args.key?(:dataset_id)
  @policy_id = args[:policy_id] if args.key?(:policy_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @table_id = args[:table_id] if args.key?(:table_id)
end