Class: Google::Apis::BigqueryV2::StorageDescriptor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Contains information about how a table's data is stored and accessed by open source query engines.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDescriptor

Returns a new instance of StorageDescriptor.



10578
10579
10580
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10578

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#input_formatString

Optional. Specifies the fully qualified class name of the InputFormat (e.g. " org.apache.hadoop.hive.ql.io.orc.OrcInputFormat"). The maximum length is 128 characters. Corresponds to the JSON property inputFormat

Returns:

  • (String)


10557
10558
10559
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10557

def input_format
  @input_format
end

#location_uriString

Optional. The physical location of the table (e.g. gs://spark-dataproc-data/ pangea-data/case_sensitive/ or gs://spark-dataproc-data/pangea-data/*). The maximum length is 2056 bytes. Corresponds to the JSON property locationUri

Returns:

  • (String)


10564
10565
10566
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10564

def location_uri
  @location_uri
end

#output_formatString

Optional. Specifies the fully qualified class name of the OutputFormat (e.g. " org.apache.hadoop.hive.ql.io.orc.OrcOutputFormat"). The maximum length is 128 characters. Corresponds to the JSON property outputFormat

Returns:

  • (String)


10571
10572
10573
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10571

def output_format
  @output_format
end

#serde_infoGoogle::Apis::BigqueryV2::SerDeInfo

Serializer and deserializer information. Corresponds to the JSON property serdeInfo



10576
10577
10578
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10576

def serde_info
  @serde_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10583
10584
10585
10586
10587
10588
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10583

def update!(**args)
  @input_format = args[:input_format] if args.key?(:input_format)
  @location_uri = args[:location_uri] if args.key?(:location_uri)
  @output_format = args[:output_format] if args.key?(:output_format)
  @serde_info = args[:serde_info] if args.key?(:serde_info)
end