Class: Google::Apis::BigqueryV2::StoredColumnsUsage
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::StoredColumnsUsage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Indicates the stored columns usage in the query.
Instance Attribute Summary collapse
-
#base_table ⇒ Google::Apis::BigqueryV2::TableReference
Specifies the base table.
-
#is_query_accelerated ⇒ Boolean
(also: #is_query_accelerated?)
Specifies whether the query was accelerated with stored columns.
-
#stored_columns_unused_reasons ⇒ Array<Google::Apis::BigqueryV2::StoredColumnsUnusedReason>
If stored columns were not used, explain why.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoredColumnsUsage
constructor
A new instance of StoredColumnsUsage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoredColumnsUsage
Returns a new instance of StoredColumnsUsage.
10462 10463 10464 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10462 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_table ⇒ Google::Apis::BigqueryV2::TableReference
Specifies the base table.
Corresponds to the JSON property baseTable
10449 10450 10451 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10449 def base_table @base_table end |
#is_query_accelerated ⇒ Boolean Also known as: is_query_accelerated?
Specifies whether the query was accelerated with stored columns.
Corresponds to the JSON property isQueryAccelerated
10454 10455 10456 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10454 def is_query_accelerated @is_query_accelerated end |
#stored_columns_unused_reasons ⇒ Array<Google::Apis::BigqueryV2::StoredColumnsUnusedReason>
If stored columns were not used, explain why.
Corresponds to the JSON property storedColumnsUnusedReasons
10460 10461 10462 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10460 def stored_columns_unused_reasons @stored_columns_unused_reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10467 10468 10469 10470 10471 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10467 def update!(**args) @base_table = args[:base_table] if args.key?(:base_table) @is_query_accelerated = args[:is_query_accelerated] if args.key?(:is_query_accelerated) @stored_columns_unused_reasons = args[:stored_columns_unused_reasons] if args.key?(:stored_columns_unused_reasons) end |