Class: Google::Apis::BigqueryV2::TableList
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::TableList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Partial projection of the metadata for a given table in a list response.
Defined Under Namespace
Classes: Table
Instance Attribute Summary collapse
-
#etag ⇒ String
A hash of this page of results.
-
#kind ⇒ String
The type of list.
-
#next_page_token ⇒ String
A token to request the next page of results.
-
#tables ⇒ Array<Google::Apis::BigqueryV2::TableList::Table>
Tables in the requested dataset.
-
#total_items ⇒ Fixnum
The total number of tables in the dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TableList
constructor
A new instance of TableList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TableList
Returns a new instance of TableList.
11501 11502 11503 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11501 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
A hash of this page of results.
Corresponds to the JSON property etag
11479 11480 11481 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11479 def etag @etag end |
#kind ⇒ String
The type of list.
Corresponds to the JSON property kind
11484 11485 11486 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11484 def kind @kind end |
#next_page_token ⇒ String
A token to request the next page of results.
Corresponds to the JSON property nextPageToken
11489 11490 11491 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11489 def next_page_token @next_page_token end |
#tables ⇒ Array<Google::Apis::BigqueryV2::TableList::Table>
Tables in the requested dataset.
Corresponds to the JSON property tables
11494 11495 11496 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11494 def tables @tables end |
#total_items ⇒ Fixnum
The total number of tables in the dataset.
Corresponds to the JSON property totalItems
11499 11500 11501 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11499 def total_items @total_items end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11506 11507 11508 11509 11510 11511 11512 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11506 def update!(**args) @etag = args[:etag] if args.key?(:etag) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @tables = args[:tables] if args.key?(:tables) @total_items = args[:total_items] if args.key?(:total_items) end |