Class: Google::Apis::BigqueryV2::TableList::Table

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Defined Under Namespace

Classes: View

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Table

Returns a new instance of Table.



11895
11896
11897
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11895

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusteringGoogle::Apis::BigqueryV2::Clustering

Configures table clustering. Corresponds to the JSON property clustering



11827
11828
11829
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11827

def clustering
  @clustering
end

#creation_timeFixnum

Output only. The time when this table was created, in milliseconds since the epoch. Corresponds to the JSON property creationTime

Returns:

  • (Fixnum)


11833
11834
11835
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11833

def creation_time
  @creation_time
end

#expiration_timeFixnum

The time when this table expires, in milliseconds since the epoch. If not present, the table will persist indefinitely. Expired tables will be deleted and their storage reclaimed. Corresponds to the JSON property expirationTime

Returns:

  • (Fixnum)


11840
11841
11842
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11840

def expiration_time
  @expiration_time
end

#friendly_nameString

The user-friendly name for this table. Corresponds to the JSON property friendlyName

Returns:

  • (String)


11845
11846
11847
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11845

def friendly_name
  @friendly_name
end

#idString

An opaque ID of the table. Corresponds to the JSON property id

Returns:

  • (String)


11850
11851
11852
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11850

def id
  @id
end

#kindString

The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


11855
11856
11857
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11855

def kind
  @kind
end

#labelsHash<String,String>

The labels associated with this table. You can use these to organize and group your tables. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


11861
11862
11863
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11861

def labels
  @labels
end

#range_partitioningGoogle::Apis::BigqueryV2::RangePartitioning

The range partitioning for this table. Corresponds to the JSON property rangePartitioning



11866
11867
11868
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11866

def range_partitioning
  @range_partitioning
end

#require_partition_filterBoolean Also known as: require_partition_filter?

Optional. If set to true, queries including this table must specify a partition filter. This filter is used for partition elimination. Corresponds to the JSON property requirePartitionFilter

Returns:

  • (Boolean)


11872
11873
11874
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11872

def require_partition_filter
  @require_partition_filter
end

#table_referenceGoogle::Apis::BigqueryV2::TableReference

A reference uniquely identifying table. Corresponds to the JSON property tableReference



11878
11879
11880
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11878

def table_reference
  @table_reference
end

#time_partitioningGoogle::Apis::BigqueryV2::TimePartitioning

The time-based partitioning for this table. Corresponds to the JSON property timePartitioning



11883
11884
11885
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11883

def time_partitioning
  @time_partitioning
end

#typeString

The type of table. Corresponds to the JSON property type

Returns:

  • (String)


11888
11889
11890
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11888

def type
  @type
end

#viewGoogle::Apis::BigqueryV2::TableList::Table::View

Information about a logical view. Corresponds to the JSON property view



11893
11894
11895
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11893

def view
  @view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11900
11901
11902
11903
11904
11905
11906
11907
11908
11909
11910
11911
11912
11913
11914
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11900

def update!(**args)
  @clustering = args[:clustering] if args.key?(:clustering)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @friendly_name = args[:friendly_name] if args.key?(:friendly_name)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @labels = args[:labels] if args.key?(:labels)
  @range_partitioning = args[:range_partitioning] if args.key?(:range_partitioning)
  @require_partition_filter = args[:require_partition_filter] if args.key?(:require_partition_filter)
  @table_reference = args[:table_reference] if args.key?(:table_reference)
  @time_partitioning = args[:time_partitioning] if args.key?(:time_partitioning)
  @type = args[:type] if args.key?(:type)
  @view = args[:view] if args.key?(:view)
end