Class: Google::Apis::BigqueryV2::TableMetadataCacheUsage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Table level detail on the usage of metadata caching. Only set for Metadata caching eligible tables referenced in the query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TableMetadataCacheUsage

Returns a new instance of TableMetadataCacheUsage.



11982
11983
11984
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11982

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explanationString

Free form human-readable reason metadata caching was unused for the job. Corresponds to the JSON property explanation

Returns:

  • (String)


11953
11954
11955
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11953

def explanation
  @explanation
end

#pruning_statsGoogle::Apis::BigqueryV2::PruningStats

The column metadata index pruning statistics. Corresponds to the JSON property pruningStats



11958
11959
11960
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11958

def pruning_stats
  @pruning_stats
end

#stalenessString

Duration since last refresh as of this job for managed tables (indicates metadata cache staleness as seen by this job). Corresponds to the JSON property staleness

Returns:

  • (String)


11964
11965
11966
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11964

def staleness
  @staleness
end

#table_referenceGoogle::Apis::BigqueryV2::TableReference

Metadata caching eligible table referenced in the query. Corresponds to the JSON property tableReference



11969
11970
11971
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11969

def table_reference
  @table_reference
end

#table_typeString

Table type. Corresponds to the JSON property tableType

Returns:

  • (String)


11975
11976
11977
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11975

def table_type
  @table_type
end

#unused_reasonString

Reason for not using metadata caching for the table. Corresponds to the JSON property unusedReason

Returns:

  • (String)


11980
11981
11982
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11980

def unused_reason
  @unused_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11987
11988
11989
11990
11991
11992
11993
11994
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11987

def update!(**args)
  @explanation = args[:explanation] if args.key?(:explanation)
  @pruning_stats = args[:pruning_stats] if args.key?(:pruning_stats)
  @staleness = args[:staleness] if args.key?(:staleness)
  @table_reference = args[:table_reference] if args.key?(:table_reference)
  @table_type = args[:table_type] if args.key?(:table_type)
  @unused_reason = args[:unused_reason] if args.key?(:unused_reason)
end