Class: Google::Apis::BigqueryV2::TableSchema
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::TableSchema
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Schema of a table
Instance Attribute Summary collapse
-
#fields ⇒ Array<Google::Apis::BigqueryV2::TableFieldSchema>
Describes the fields in a table.
-
#foreign_type_info ⇒ Google::Apis::BigqueryV2::ForeignTypeInfo
Metadata about the foreign data type definition such as the system in which the type is defined.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TableSchema
constructor
A new instance of TableSchema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TableSchema
Returns a new instance of TableSchema.
11251 11252 11253 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11251 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fields ⇒ Array<Google::Apis::BigqueryV2::TableFieldSchema>
Describes the fields in a table.
Corresponds to the JSON property fields
11243 11244 11245 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11243 def fields @fields end |
#foreign_type_info ⇒ Google::Apis::BigqueryV2::ForeignTypeInfo
Metadata about the foreign data type definition such as the system in which
the type is defined.
Corresponds to the JSON property foreignTypeInfo
11249 11250 11251 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11249 def foreign_type_info @foreign_type_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11256 11257 11258 11259 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11256 def update!(**args) @fields = args[:fields] if args.key?(:fields) @foreign_type_info = args[:foreign_type_info] if args.key?(:foreign_type_info) end |