Class: Google::Apis::BigqueryV2::UndeleteDatasetRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Request format for undeleting a dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UndeleteDatasetRequest

Returns a new instance of UndeleteDatasetRequest.



12193
12194
12195
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deletion_timeString

Optional. The exact time when the dataset was deleted. If not specified, the most recently deleted version is undeleted. Undeleting a dataset using deletion time is not supported. Corresponds to the JSON property deletionTime

Returns:

  • (String)


12191
12192
12193
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12191

def deletion_time
  @deletion_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12198
12199
12200
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12198

def update!(**args)
  @deletion_time = args[:deletion_time] if args.key?(:deletion_time)
end