Class: Google::Apis::BigqueryV2::ArrowSerializationOptions
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ArrowSerializationOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Contains options specific to Arrow Serialization. This feature is not yet available.
Instance Attribute Summary collapse
-
#buffer_compression ⇒ String
The compression codec to use for Arrow buffers in serialized record batches.
-
#picos_timestamp_precision ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ArrowSerializationOptions
constructor
A new instance of ArrowSerializationOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ArrowSerializationOptions
Returns a new instance of ArrowSerializationOptions.
571 572 573 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 571 def initialize(**args) update!(**args) end |
Instance Attribute Details
#buffer_compression ⇒ String
The compression codec to use for Arrow buffers in serialized record batches.
Corresponds to the JSON property bufferCompression
563 564 565 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 563 def buffer_compression @buffer_compression end |
#picos_timestamp_precision ⇒ String
Optional. Set timestamp precision option. If not set, the default precision is
microseconds.
Corresponds to the JSON property picosTimestampPrecision
569 570 571 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 569 def @picos_timestamp_precision end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
576 577 578 579 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 576 def update!(**args) @buffer_compression = args[:buffer_compression] if args.key?(:buffer_compression) @picos_timestamp_precision = args[:picos_timestamp_precision] if args.key?(:picos_timestamp_precision) end |