Class: Google::Apis::BigqueryV2::BatchDeleteRowAccessPoliciesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Request message for the BatchDeleteRowAccessPoliciesRequest method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchDeleteRowAccessPoliciesRequest

Returns a new instance of BatchDeleteRowAccessPoliciesRequest.



621
622
623
# File 'lib/google/apis/bigquery_v2/classes.rb', line 621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forceBoolean Also known as: force?

If set to true, it deletes the row access policy even if it's the last row access policy on the table and the deletion will widen the access rather narrowing it. Corresponds to the JSON property force

Returns:

  • (Boolean)


613
614
615
# File 'lib/google/apis/bigquery_v2/classes.rb', line 613

def force
  @force
end

#policy_idsArray<String>

Required. Policy IDs of the row access policies. Corresponds to the JSON property policyIds

Returns:

  • (Array<String>)


619
620
621
# File 'lib/google/apis/bigquery_v2/classes.rb', line 619

def policy_ids
  @policy_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



626
627
628
629
# File 'lib/google/apis/bigquery_v2/classes.rb', line 626

def update!(**args)
  @force = args[:force] if args.key?(:force)
  @policy_ids = args[:policy_ids] if args.key?(:policy_ids)
end