Class: Google::Apis::BigqueryV2::BigtableColumn
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::BigtableColumn
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Information related to a Bigtable column.
Instance Attribute Summary collapse
-
#encoding ⇒ String
Optional.
-
#field_name ⇒ String
Optional.
-
#only_read_latest ⇒ Boolean
(also: #only_read_latest?)
Optional.
-
#proto_config ⇒ Google::Apis::BigqueryV2::BigtableProtoConfig
Information related to a Bigtable protobuf column.
-
#qualifier_encoded ⇒ String
[Required] Qualifier of the column.
-
#qualifier_string ⇒ String
Qualifier string.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BigtableColumn
constructor
A new instance of BigtableColumn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BigtableColumn
Returns a new instance of BigtableColumn.
901 902 903 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encoding ⇒ String
Optional. The encoding of the values when the type is not STRING. Acceptable
encoding values are: TEXT - indicates values are alphanumeric text strings.
BINARY - indicates values are encoded using HBase Bytes.toBytes family of
functions. PROTO_BINARY - indicates values are encoded using serialized proto
messages. This can only be used in combination with JSON type. 'encoding' can
also be set at the column family level. However, the setting at this level
takes precedence if 'encoding' is set at both levels.
Corresponds to the JSON property encoding
851 852 853 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 851 def encoding @encoding end |
#field_name ⇒ String
Optional. If the qualifier is not a valid BigQuery field identifier i.e. does
not match a-zA-Z*, a valid identifier must be provided as the column field
name and is used as field name in queries.
Corresponds to the JSON property fieldName
858 859 860 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 858 def field_name @field_name end |
#only_read_latest ⇒ Boolean Also known as: only_read_latest?
Optional. If this is set, only the latest version of value in this column are
exposed. 'onlyReadLatest' can also be set at the column family level. However,
the setting at this level takes precedence if 'onlyReadLatest' is set at both
levels.
Corresponds to the JSON property onlyReadLatest
866 867 868 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 866 def only_read_latest @only_read_latest end |
#proto_config ⇒ Google::Apis::BigqueryV2::BigtableProtoConfig
Information related to a Bigtable protobuf column.
Corresponds to the JSON property protoConfig
872 873 874 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 872 def proto_config @proto_config end |
#qualifier_encoded ⇒ String
[Required] Qualifier of the column. Columns in the parent column family that
has this exact qualifier are exposed as . field. If the qualifier is valid
UTF-8 string, it can be specified in the qualifier_string field. Otherwise, a
base-64 encoded value must be set to qualifier_encoded. The column field name
is the same as the column qualifier. However, if the qualifier is not a valid
BigQuery field identifier i.e. does not match a-zA-Z*, a valid identifier must
be provided as field_name.
Corresponds to the JSON property qualifierEncoded
NOTE: Values are automatically base64 encoded/decoded in the client library.
884 885 886 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 884 def qualifier_encoded @qualifier_encoded end |
#qualifier_string ⇒ String
Qualifier string.
Corresponds to the JSON property qualifierString
889 890 891 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 889 def qualifier_string @qualifier_string end |
#type ⇒ String
Optional. The type to convert the value in cells of this column. The values
are expected to be encoded using HBase Bytes.toBytes function when using the
BINARY encoding value. Following BigQuery types are allowed (case-sensitive): *
BYTES * STRING * INTEGER * FLOAT * BOOLEAN * JSON Default type is BYTES. '
type' can also be set at the column family level. However, the setting at this
level takes precedence if 'type' is set at both levels.
Corresponds to the JSON property type
899 900 901 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 899 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
906 907 908 909 910 911 912 913 914 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 906 def update!(**args) @encoding = args[:encoding] if args.key?(:encoding) @field_name = args[:field_name] if args.key?(:field_name) @only_read_latest = args[:only_read_latest] if args.key?(:only_read_latest) @proto_config = args[:proto_config] if args.key?(:proto_config) @qualifier_encoded = args[:qualifier_encoded] if args.key?(:qualifier_encoded) @qualifier_string = args[:qualifier_string] if args.key?(:qualifier_string) @type = args[:type] if args.key?(:type) end |