Class: Google::Apis::BigqueryV2::BigtableColumn

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Information related to a Bigtable column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BigtableColumn

Returns a new instance of BigtableColumn.



824
825
826
# File 'lib/google/apis/bigquery_v2/classes.rb', line 824

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encodingString

Optional. The encoding of the values when the type is not STRING. Acceptable encoding values are: TEXT - indicates values are alphanumeric text strings. BINARY - indicates values are encoded using HBase Bytes.toBytes family of functions. PROTO_BINARY - indicates values are encoded using serialized proto messages. This can only be used in combination with JSON type. 'encoding' can also be set at the column family level. However, the setting at this level takes precedence if 'encoding' is set at both levels. Corresponds to the JSON property encoding

Returns:

  • (String)


774
775
776
# File 'lib/google/apis/bigquery_v2/classes.rb', line 774

def encoding
  @encoding
end

#field_nameString

Optional. If the qualifier is not a valid BigQuery field identifier i.e. does not match a-zA-Z*, a valid identifier must be provided as the column field name and is used as field name in queries. Corresponds to the JSON property fieldName

Returns:

  • (String)


781
782
783
# File 'lib/google/apis/bigquery_v2/classes.rb', line 781

def field_name
  @field_name
end

#only_read_latestBoolean Also known as: only_read_latest?

Optional. If this is set, only the latest version of value in this column are exposed. 'onlyReadLatest' can also be set at the column family level. However, the setting at this level takes precedence if 'onlyReadLatest' is set at both levels. Corresponds to the JSON property onlyReadLatest

Returns:

  • (Boolean)


789
790
791
# File 'lib/google/apis/bigquery_v2/classes.rb', line 789

def only_read_latest
  @only_read_latest
end

#proto_configGoogle::Apis::BigqueryV2::BigtableProtoConfig

Information related to a Bigtable protobuf column. Corresponds to the JSON property protoConfig



795
796
797
# File 'lib/google/apis/bigquery_v2/classes.rb', line 795

def proto_config
  @proto_config
end

#qualifier_encodedString

[Required] Qualifier of the column. Columns in the parent column family that has this exact qualifier are exposed as . field. If the qualifier is valid UTF-8 string, it can be specified in the qualifier_string field. Otherwise, a base-64 encoded value must be set to qualifier_encoded. The column field name is the same as the column qualifier. However, if the qualifier is not a valid BigQuery field identifier i.e. does not match a-zA-Z*, a valid identifier must be provided as field_name. Corresponds to the JSON property qualifierEncoded NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


807
808
809
# File 'lib/google/apis/bigquery_v2/classes.rb', line 807

def qualifier_encoded
  @qualifier_encoded
end

#qualifier_stringString

Qualifier string. Corresponds to the JSON property qualifierString

Returns:

  • (String)


812
813
814
# File 'lib/google/apis/bigquery_v2/classes.rb', line 812

def qualifier_string
  @qualifier_string
end

#typeString

Optional. The type to convert the value in cells of this column. The values are expected to be encoded using HBase Bytes.toBytes function when using the BINARY encoding value. Following BigQuery types are allowed (case-sensitive): * BYTES * STRING * INTEGER * FLOAT * BOOLEAN * JSON Default type is BYTES. ' type' can also be set at the column family level. However, the setting at this level takes precedence if 'type' is set at both levels. Corresponds to the JSON property type

Returns:

  • (String)


822
823
824
# File 'lib/google/apis/bigquery_v2/classes.rb', line 822

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



829
830
831
832
833
834
835
836
837
# File 'lib/google/apis/bigquery_v2/classes.rb', line 829

def update!(**args)
  @encoding = args[:encoding] if args.key?(:encoding)
  @field_name = args[:field_name] if args.key?(:field_name)
  @only_read_latest = args[:only_read_latest] if args.key?(:only_read_latest)
  @proto_config = args[:proto_config] if args.key?(:proto_config)
  @qualifier_encoded = args[:qualifier_encoded] if args.key?(:qualifier_encoded)
  @qualifier_string = args[:qualifier_string] if args.key?(:qualifier_string)
  @type = args[:type] if args.key?(:type)
end