Class: Google::Apis::BigqueryV2::BigtableColumnFamily
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::BigtableColumnFamily
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Information related to a Bigtable column family.
Instance Attribute Summary collapse
-
#columns ⇒ Array<Google::Apis::BigqueryV2::BigtableColumn>
Optional.
-
#encoding ⇒ String
Optional.
-
#family_id ⇒ String
Identifier of the column family.
-
#only_read_latest ⇒ Boolean
(also: #only_read_latest?)
Optional.
-
#proto_config ⇒ Google::Apis::BigqueryV2::BigtableProtoConfig
Information related to a Bigtable protobuf column.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BigtableColumnFamily
constructor
A new instance of BigtableColumnFamily.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BigtableColumnFamily
Returns a new instance of BigtableColumnFamily.
892 893 894 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 892 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<Google::Apis::BigqueryV2::BigtableColumn>
Optional. Lists of columns that should be exposed as individual fields as
opposed to a list of (column name, value) pairs. All columns whose qualifier
matches a qualifier in this list can be accessed as .. Other columns can be
accessed as a list through the .Column field.
Corresponds to the JSON property columns
850 851 852 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 850 def columns @columns end |
#encoding ⇒ String
Optional. The encoding of the values when the type is not STRING. Acceptable
encoding values are: TEXT - indicates values are alphanumeric text strings.
BINARY - indicates values are encoded using HBase Bytes.toBytes family of
functions. PROTO_BINARY - indicates values are encoded using serialized proto
messages. This can only be used in combination with JSON type. This can be
overridden for a specific column by listing that column in 'columns' and
specifying an encoding for it.
Corresponds to the JSON property encoding
861 862 863 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 861 def encoding @encoding end |
#family_id ⇒ String
Identifier of the column family.
Corresponds to the JSON property familyId
866 867 868 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 866 def family_id @family_id end |
#only_read_latest ⇒ Boolean Also known as: only_read_latest?
Optional. If this is set only the latest version of value are exposed for all
columns in this column family. This can be overridden for a specific column by
listing that column in 'columns' and specifying a different setting for that
column.
Corresponds to the JSON property onlyReadLatest
874 875 876 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 874 def only_read_latest @only_read_latest end |
#proto_config ⇒ Google::Apis::BigqueryV2::BigtableProtoConfig
Information related to a Bigtable protobuf column.
Corresponds to the JSON property protoConfig
880 881 882 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 880 def proto_config @proto_config end |
#type ⇒ String
Optional. The type to convert the value in cells of this column family. The
values are expected to be encoded using HBase Bytes.toBytes function when
using the BINARY encoding value. Following BigQuery types are allowed (case-
sensitive): * BYTES * STRING * INTEGER * FLOAT * BOOLEAN * JSON Default type
is BYTES. This can be overridden for a specific column by listing that column
in 'columns' and specifying a type for it.
Corresponds to the JSON property type
890 891 892 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 890 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
897 898 899 900 901 902 903 904 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 897 def update!(**args) @columns = args[:columns] if args.key?(:columns) @encoding = args[:encoding] if args.key?(:encoding) @family_id = args[:family_id] if args.key?(:family_id) @only_read_latest = args[:only_read_latest] if args.key?(:only_read_latest) @proto_config = args[:proto_config] if args.key?(:proto_config) @type = args[:type] if args.key?(:type) end |