Class: Google::Apis::BigqueryV2::CloneDefinition
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::CloneDefinition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Information about base table and clone time of a table clone.
Instance Attribute Summary collapse
-
#base_table_reference ⇒ Google::Apis::BigqueryV2::TableReference
Required.
-
#clone_time ⇒ DateTime
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloneDefinition
constructor
A new instance of CloneDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloneDefinition
Returns a new instance of CloneDefinition.
1479 1480 1481 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1479 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_table_reference ⇒ Google::Apis::BigqueryV2::TableReference
Required. Reference describing the ID of the table that was cloned.
Corresponds to the JSON property baseTableReference
1471 1472 1473 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1471 def base_table_reference @base_table_reference end |
#clone_time ⇒ DateTime
Required. The time at which the base table was cloned. This value is reported
in the JSON response using RFC3339 format.
Corresponds to the JSON property cloneTime
1477 1478 1479 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1477 def clone_time @clone_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1484 1485 1486 1487 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1484 def update!(**args) @base_table_reference = args[:base_table_reference] if args.key?(:base_table_reference) @clone_time = args[:clone_time] if args.key?(:clone_time) end |