Class: Google::Apis::BigqueryV2::CloneDefinition
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::CloneDefinition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Information about base table and clone time of a table clone.
Instance Attribute Summary collapse
-
#base_table_reference ⇒ Google::Apis::BigqueryV2::TableReference
Required.
-
#clone_time ⇒ DateTime
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloneDefinition
constructor
A new instance of CloneDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloneDefinition
Returns a new instance of CloneDefinition.
1408 1409 1410 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1408 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_table_reference ⇒ Google::Apis::BigqueryV2::TableReference
Required. Reference describing the ID of the table that was cloned.
Corresponds to the JSON property baseTableReference
1400 1401 1402 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1400 def base_table_reference @base_table_reference end |
#clone_time ⇒ DateTime
Required. The time at which the base table was cloned. This value is reported
in the JSON response using RFC3339 format.
Corresponds to the JSON property cloneTime
1406 1407 1408 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1406 def clone_time @clone_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1413 1414 1415 1416 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1413 def update!(**args) @base_table_reference = args[:base_table_reference] if args.key?(:base_table_reference) @clone_time = args[:clone_time] if args.key?(:clone_time) end |