Class: Google::Apis::BigqueryV2::Clustering
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::Clustering
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Configures table clustering.
Instance Attribute Summary collapse
-
#fields ⇒ Array<String>
One or more fields on which data should be clustered.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Clustering
constructor
A new instance of Clustering.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Clustering
Returns a new instance of Clustering.
1572 1573 1574 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1572 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fields ⇒ Array<String>
One or more fields on which data should be clustered. Only top-level, non-
repeated, simple-type fields are supported. The ordering of the clustering
fields should be prioritized from most to least important for filtering
purposes. For additional information, see Introduction to clustered tables.
Corresponds to the JSON property fields
1570 1571 1572 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1570 def fields @fields end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1577 1578 1579 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1577 def update!(**args) @fields = args[:fields] if args.key?(:fields) end |