Class: Google::Apis::BigqueryV2::Clustering

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Configures table clustering.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Clustering

Returns a new instance of Clustering.



1566
1567
1568
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsArray<String>

One or more fields on which data should be clustered. Only top-level, non- repeated, simple-type fields are supported. The ordering of the clustering fields should be prioritized from most to least important for filtering purposes. For additional information, see Introduction to clustered tables. Corresponds to the JSON property fields

Returns:

  • (Array<String>)


1564
1565
1566
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1564

def fields
  @fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1571
1572
1573
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1571

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
end