Class: Google::Apis::BigqueryV2::DataSplitResult
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::DataSplitResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Data split result. This contains references to the training and evaluation data tables that were used to train the model.
Instance Attribute Summary collapse
-
#evaluation_table ⇒ Google::Apis::BigqueryV2::TableReference
Table reference of the evaluation data after split.
-
#test_table ⇒ Google::Apis::BigqueryV2::TableReference
Table reference of the test data after split.
-
#training_table ⇒ Google::Apis::BigqueryV2::TableReference
Table reference of the training data after split.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataSplitResult
constructor
A new instance of DataSplitResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataSplitResult
Returns a new instance of DataSplitResult.
1823 1824 1825 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1823 def initialize(**args) update!(**args) end |
Instance Attribute Details
#evaluation_table ⇒ Google::Apis::BigqueryV2::TableReference
Table reference of the evaluation data after split.
Corresponds to the JSON property evaluationTable
1811 1812 1813 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1811 def evaluation_table @evaluation_table end |
#test_table ⇒ Google::Apis::BigqueryV2::TableReference
Table reference of the test data after split.
Corresponds to the JSON property testTable
1816 1817 1818 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1816 def test_table @test_table end |
#training_table ⇒ Google::Apis::BigqueryV2::TableReference
Table reference of the training data after split.
Corresponds to the JSON property trainingTable
1821 1822 1823 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1821 def training_table @training_table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1828 1829 1830 1831 1832 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1828 def update!(**args) @evaluation_table = args[:evaluation_table] if args.key?(:evaluation_table) @test_table = args[:test_table] if args.key?(:test_table) @training_table = args[:training_table] if args.key?(:training_table) end |