Class: Google::Apis::BigqueryV2::Dataset
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::Dataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Represents a BigQuery dataset.
Defined Under Namespace
Instance Attribute Summary collapse
-
#access ⇒ Array<Google::Apis::BigqueryV2::Dataset::Access>
Optional.
-
#creation_time ⇒ Fixnum
Output only.
-
#dataset_reference ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
-
#default_collation ⇒ String
Optional.
-
#default_encryption_configuration ⇒ Google::Apis::BigqueryV2::EncryptionConfiguration
Configuration for Cloud KMS encryption settings.
-
#default_partition_expiration_ms ⇒ Fixnum
This default partition expiration, expressed in milliseconds.
-
#default_rounding_mode ⇒ String
Optional.
-
#default_table_expiration_ms ⇒ Fixnum
Optional.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#external_catalog_dataset_options ⇒ Google::Apis::BigqueryV2::ExternalCatalogDatasetOptions
Options defining open source compatible datasets living in the BigQuery catalog.
-
#external_dataset_reference ⇒ Google::Apis::BigqueryV2::ExternalDatasetReference
Configures the access a dataset defined in an external metadata storage.
-
#friendly_name ⇒ String
Optional.
-
#id ⇒ String
Output only.
-
#is_case_insensitive ⇒ Boolean
(also: #is_case_insensitive?)
Optional.
-
#kind ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
The labels associated with this dataset.
-
#last_modified_time ⇒ Fixnum
Output only.
-
#linked_dataset_metadata ⇒ Google::Apis::BigqueryV2::LinkedDatasetMetadata
Metadata about the Linked Dataset.
-
#linked_dataset_source ⇒ Google::Apis::BigqueryV2::LinkedDatasetSource
A dataset source type which refers to another BigQuery dataset.
-
#location ⇒ String
The geographic location where the dataset should reside.
-
#max_time_travel_hours ⇒ Fixnum
Optional.
-
#resource_tags ⇒ Hash<String,String>
Optional.
-
#restrictions ⇒ Google::Apis::BigqueryV2::RestrictionConfig
Optional.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#storage_billing_model ⇒ String
Optional.
-
#tags ⇒ Array<Google::Apis::BigqueryV2::Dataset::Tag>
Output only.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Dataset
constructor
A new instance of Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Dataset
Returns a new instance of Dataset.
2061 2062 2063 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2061 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access ⇒ Array<Google::Apis::BigqueryV2::Dataset::Access>
Optional. An array of objects that define dataset access for one or more
entities. You can set this property when inserting or updating a dataset in
order to control who is allowed to access the data. If unspecified at dataset
creation time, BigQuery adds default dataset access for the following entities:
access.specialGroup: projectReaders; access.role: READER; access.specialGroup:
projectWriters; access.role: WRITER; access.specialGroup: projectOwners;
access.role: OWNER; access.userByEmail: [dataset creator email]; access.role:
OWNER; If you patch a dataset, then this field is overwritten by the patched
dataset's access field. To add entities, you must supply the entire existing
access array in addition to any new entities that you want to add.
Corresponds to the JSON property access
1851 1852 1853 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1851 def access @access end |
#creation_time ⇒ Fixnum
Output only. The time when this dataset was created, in milliseconds since the
epoch.
Corresponds to the JSON property creationTime
1857 1858 1859 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1857 def creation_time @creation_time end |
#dataset_reference ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
Corresponds to the JSON property datasetReference
1862 1863 1864 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1862 def dataset_reference @dataset_reference end |
#default_collation ⇒ String
Optional. Defines the default collation specification of future tables created
in the dataset. If a table is created in this dataset without table-level
default collation, then the table inherits the dataset default collation,
which is applied to the string fields that do not have explicit collation
specified. A change to this field affects only tables created afterwards, and
does not alter the existing tables. The following values are supported: * 'und:
ci': undetermined locale, case insensitive. * '': empty string. Default to
case-sensitive behavior.
Corresponds to the JSON property defaultCollation
1874 1875 1876 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1874 def default_collation @default_collation end |
#default_encryption_configuration ⇒ Google::Apis::BigqueryV2::EncryptionConfiguration
Configuration for Cloud KMS encryption settings.
Corresponds to the JSON property defaultEncryptionConfiguration
1879 1880 1881 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1879 def default_encryption_configuration @default_encryption_configuration end |
#default_partition_expiration_ms ⇒ Fixnum
This default partition expiration, expressed in milliseconds. When new time-
partitioned tables are created in a dataset where this property is set, the
table will inherit this value, propagated as the TimePartitioning.
expirationMs property on the new table. If you set TimePartitioning.
expirationMs explicitly when creating a table, the
defaultPartitionExpirationMs of the containing dataset is ignored. When
creating a partitioned table, if defaultPartitionExpirationMs is set, the
defaultTableExpirationMs value is ignored and the table will not be inherit a
table expiration deadline.
Corresponds to the JSON property defaultPartitionExpirationMs
1892 1893 1894 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1892 def default_partition_expiration_ms @default_partition_expiration_ms end |
#default_rounding_mode ⇒ String
Optional. Defines the default rounding mode specification of new tables
created within this dataset. During table creation, if this field is specified,
the table within this dataset will inherit the default rounding mode of the
dataset. Setting the default rounding mode on a table overrides this option.
Existing tables in the dataset are unaffected. If columns are defined during
that table creation, they will immediately inherit the table's default
rounding mode, unless otherwise specified.
Corresponds to the JSON property defaultRoundingMode
1903 1904 1905 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1903 def default_rounding_mode @default_rounding_mode end |
#default_table_expiration_ms ⇒ Fixnum
Optional. The default lifetime of all tables in the dataset, in milliseconds.
The minimum lifetime value is 3600000 milliseconds (one hour). To clear an
existing default expiration with a PATCH request, set to 0. Once this property
is set, all newly-created tables in the dataset will have an expirationTime
property set to the creation time plus the value in this property, and
changing the value will only affect new tables, not existing ones. When the
expirationTime for a given table is reached, that table will be deleted
automatically. If a table's expirationTime is modified or removed before the
table expires, or if you provide an explicit expirationTime when creating a
table, that value takes precedence over the default expiration time indicated
by this property.
Corresponds to the JSON property defaultTableExpirationMs
1918 1919 1920 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1918 def default_table_expiration_ms @default_table_expiration_ms end |
#description ⇒ String
Optional. A user-friendly description of the dataset.
Corresponds to the JSON property description
1923 1924 1925 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1923 def description @description end |
#etag ⇒ String
Output only. A hash of the resource.
Corresponds to the JSON property etag
1928 1929 1930 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1928 def etag @etag end |
#external_catalog_dataset_options ⇒ Google::Apis::BigqueryV2::ExternalCatalogDatasetOptions
Options defining open source compatible datasets living in the BigQuery
catalog. Contains metadata of open source database, schema, or namespace
represented by the current dataset.
Corresponds to the JSON property externalCatalogDatasetOptions
1935 1936 1937 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1935 def @external_catalog_dataset_options end |
#external_dataset_reference ⇒ Google::Apis::BigqueryV2::ExternalDatasetReference
Configures the access a dataset defined in an external metadata storage.
Corresponds to the JSON property externalDatasetReference
1940 1941 1942 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1940 def external_dataset_reference @external_dataset_reference end |
#friendly_name ⇒ String
Optional. A descriptive name for the dataset.
Corresponds to the JSON property friendlyName
1945 1946 1947 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1945 def friendly_name @friendly_name end |
#id ⇒ String
Output only. The fully-qualified unique name of the dataset in the format
projectId:datasetId. The dataset name without the project name is given in the
datasetId field. When creating a new dataset, leave this field blank, and
instead specify the datasetId field.
Corresponds to the JSON property id
1953 1954 1955 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1953 def id @id end |
#is_case_insensitive ⇒ Boolean Also known as: is_case_insensitive?
Optional. TRUE if the dataset and its table names are case-insensitive,
otherwise FALSE. By default, this is FALSE, which means the dataset and its
table names are case-sensitive. This field does not affect routine references.
Corresponds to the JSON property isCaseInsensitive
1960 1961 1962 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1960 def is_case_insensitive @is_case_insensitive end |
#kind ⇒ String
Output only. The resource type.
Corresponds to the JSON property kind
1966 1967 1968 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1966 def kind @kind end |
#labels ⇒ Hash<String,String>
The labels associated with this dataset. You can use these to organize and
group your datasets. You can set this property when inserting or updating a
dataset. See Creating and Updating Dataset Labels
for more information.
Corresponds to the JSON property labels
1975 1976 1977 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1975 def labels @labels end |
#last_modified_time ⇒ Fixnum
Output only. The date when this dataset was last modified, in milliseconds
since the epoch.
Corresponds to the JSON property lastModifiedTime
1981 1982 1983 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1981 def last_modified_time @last_modified_time end |
#linked_dataset_metadata ⇒ Google::Apis::BigqueryV2::LinkedDatasetMetadata
Metadata about the Linked Dataset.
Corresponds to the JSON property linkedDatasetMetadata
1986 1987 1988 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1986 def @linked_dataset_metadata end |
#linked_dataset_source ⇒ Google::Apis::BigqueryV2::LinkedDatasetSource
A dataset source type which refers to another BigQuery dataset.
Corresponds to the JSON property linkedDatasetSource
1991 1992 1993 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1991 def linked_dataset_source @linked_dataset_source end |
#location ⇒ String
The geographic location where the dataset should reside. See https://cloud.
google.com/bigquery/docs/locations for supported locations.
Corresponds to the JSON property location
1997 1998 1999 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 1997 def location @location end |
#max_time_travel_hours ⇒ Fixnum
Optional. Defines the time travel window in hours. The value can be from 48 to
168 hours (2 to 7 days). The default value is 168 hours if this is not set.
Corresponds to the JSON property maxTimeTravelHours
2003 2004 2005 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2003 def max_time_travel_hours @max_time_travel_hours end |
#resource_tags ⇒ Hash<String,String>
Optional. The tags attached to
this dataset. Tag keys are globally unique. Tag key is expected to be in the
namespaced format, for example "123456789012/environment" where 123456789012
is the ID of the parent organization or project resource for this tag key. Tag
value is expected to be the short name, for example "Production". See Tag
definitions
for more details.
Corresponds to the JSON property resourceTags
2014 2015 2016 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2014 def @resource_tags end |
#restrictions ⇒ Google::Apis::BigqueryV2::RestrictionConfig
Optional. Output only. Restriction config for all tables and dataset. If set,
restrict certain accesses on the dataset and all its tables based on the
config. See Data egress for more details.
Corresponds to the JSON property restrictions
2022 2023 2024 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2022 def restrictions @restrictions end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
2027 2028 2029 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2027 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
2033 2034 2035 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2033 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. A URL that can be used to access the resource again. You can use
this URL in Get or Update requests to the resource.
Corresponds to the JSON property selfLink
2040 2041 2042 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2040 def self_link @self_link end |
#storage_billing_model ⇒ String
Optional. Updates storage_billing_model for the dataset.
Corresponds to the JSON property storageBillingModel
2045 2046 2047 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2045 def storage_billing_model @storage_billing_model end |
#tags ⇒ Array<Google::Apis::BigqueryV2::Dataset::Tag>
Output only. Tags for the dataset. To provide tags as inputs, use the
resourceTags field.
Corresponds to the JSON property tags
2051 2052 2053 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2051 def @tags end |
#type ⇒ String
Output only. Same as type in ListFormatDataset. The type of the dataset,
one of: * DEFAULT - only accessible by owner and authorized accounts, * PUBLIC
- accessible by everyone, * LINKED - linked dataset, * EXTERNAL - dataset with
definition in external metadata catalog.
Corresponds to the JSON property
type
2059 2060 2061 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2059 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2066 def update!(**args) @access = args[:access] if args.key?(:access) @creation_time = args[:creation_time] if args.key?(:creation_time) @dataset_reference = args[:dataset_reference] if args.key?(:dataset_reference) @default_collation = args[:default_collation] if args.key?(:default_collation) @default_encryption_configuration = args[:default_encryption_configuration] if args.key?(:default_encryption_configuration) @default_partition_expiration_ms = args[:default_partition_expiration_ms] if args.key?(:default_partition_expiration_ms) @default_rounding_mode = args[:default_rounding_mode] if args.key?(:default_rounding_mode) @default_table_expiration_ms = args[:default_table_expiration_ms] if args.key?(:default_table_expiration_ms) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @external_catalog_dataset_options = args[:external_catalog_dataset_options] if args.key?(:external_catalog_dataset_options) @external_dataset_reference = args[:external_dataset_reference] if args.key?(:external_dataset_reference) @friendly_name = args[:friendly_name] if args.key?(:friendly_name) @id = args[:id] if args.key?(:id) @is_case_insensitive = args[:is_case_insensitive] if args.key?(:is_case_insensitive) @kind = args[:kind] if args.key?(:kind) @labels = args[:labels] if args.key?(:labels) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @linked_dataset_metadata = args[:linked_dataset_metadata] if args.key?(:linked_dataset_metadata) @linked_dataset_source = args[:linked_dataset_source] if args.key?(:linked_dataset_source) @location = args[:location] if args.key?(:location) @max_time_travel_hours = args[:max_time_travel_hours] if args.key?(:max_time_travel_hours) @resource_tags = args[:resource_tags] if args.key?(:resource_tags) @restrictions = args[:restrictions] if args.key?(:restrictions) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @storage_billing_model = args[:storage_billing_model] if args.key?(:storage_billing_model) @tags = args[:tags] if args.key?(:tags) @type = args[:type] if args.key?(:type) end |