Class: Google::Apis::BigqueryV2::DatasetList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Response format for a page of results when listing datasets.

Defined Under Namespace

Classes: Dataset

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatasetList

Returns a new instance of DatasetList.



2406
2407
2408
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#datasetsArray<Google::Apis::BigqueryV2::DatasetList::Dataset>

An array of the dataset resources in the project. Each resource contains basic information. For full information about a particular dataset resource, use the Datasets: get method. This property is omitted when there are no datasets in the project. Corresponds to the JSON property datasets



2379
2380
2381
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2379

def datasets
  @datasets
end

#etagString

Output only. A hash value of the results page. You can use this property to determine if the page has changed since the last request. Corresponds to the JSON property etag

Returns:

  • (String)


2385
2386
2387
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2385

def etag
  @etag
end

#kindString

Output only. The resource type. This property always returns the value " bigquery#datasetList" Corresponds to the JSON property kind

Returns:

  • (String)


2391
2392
2393
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2391

def kind
  @kind
end

#next_page_tokenString

A token that can be used to request the next results page. This property is omitted on the final results page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2397
2398
2399
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2397

def next_page_token
  @next_page_token
end

#unreachableArray<String>

A list of skipped locations that were unreachable. For more information about BigQuery locations, see: https://cloud.google.com/bigquery/docs/locations. Example: "europe-west5" Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2404
2405
2406
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2404

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2411
2412
2413
2414
2415
2416
2417
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2411

def update!(**args)
  @datasets = args[:datasets] if args.key?(:datasets)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end