Class: Google::Apis::BigqueryV2::DatasetList
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::DatasetList
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Response format for a page of results when listing datasets.
Defined Under Namespace
Classes: Dataset
Instance Attribute Summary collapse
-
#datasets ⇒ Array<Google::Apis::BigqueryV2::DatasetList::Dataset>
An array of the dataset resources in the project.
-
#etag ⇒ String
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
A token that can be used to request the next results page.
-
#unreachable ⇒ Array<String>
A list of skipped locations that were unreachable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatasetList
constructor
A new instance of DatasetList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatasetList
Returns a new instance of DatasetList.
2313 2314 2315 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#datasets ⇒ Array<Google::Apis::BigqueryV2::DatasetList::Dataset>
An array of the dataset resources in the project. Each resource contains basic
information. For full information about a particular dataset resource, use the
Datasets: get method. This property is omitted when there are no datasets in
the project.
Corresponds to the JSON property datasets
2286 2287 2288 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2286 def datasets @datasets end |
#etag ⇒ String
Output only. A hash value of the results page. You can use this property to
determine if the page has changed since the last request.
Corresponds to the JSON property etag
2292 2293 2294 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2292 def etag @etag end |
#kind ⇒ String
Output only. The resource type. This property always returns the value "
bigquery#datasetList"
Corresponds to the JSON property kind
2298 2299 2300 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2298 def kind @kind end |
#next_page_token ⇒ String
A token that can be used to request the next results page. This property is
omitted on the final results page.
Corresponds to the JSON property nextPageToken
2304 2305 2306 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2304 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
A list of skipped locations that were unreachable. For more information about
BigQuery locations, see: https://cloud.google.com/bigquery/docs/locations.
Example: "europe-west5"
Corresponds to the JSON property unreachable
2311 2312 2313 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2311 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2318 2319 2320 2321 2322 2323 2324 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2318 def update!(**args) @datasets = args[:datasets] if args.key?(:datasets) @etag = args[:etag] if args.key?(:etag) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |