Class: Google::Apis::BigqueryV2::DatasetList::Dataset
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::DatasetList::Dataset
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
A dataset resource with only a subset of fields, to be returned in a list of datasets.
Instance Attribute Summary collapse
-
#catalog_source ⇒ String
Output only.
-
#dataset_reference ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
-
#external_dataset_reference ⇒ Google::Apis::BigqueryV2::ExternalDatasetReference
Configures the access a dataset defined in an external metadata storage.
-
#friendly_name ⇒ String
An alternate name for the dataset.
-
#id ⇒ String
The fully-qualified, unique, opaque ID of the dataset.
-
#kind ⇒ String
The resource type.
-
#labels ⇒ Hash<String,String>
The labels associated with this dataset.
-
#location ⇒ String
The geographic location where the dataset resides.
-
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Dataset
constructor
A new instance of Dataset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Dataset
Returns a new instance of Dataset.
2478 2479 2480 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2478 def initialize(**args) update!(**args) end |
Instance Attribute Details
#catalog_source ⇒ String
Output only. The origin of the dataset, one of: * (Unset) - Native BigQuery
Dataset. * BIGLAKE - Dataset is backed by a namespace stored natively in
Biglake.
Corresponds to the JSON property catalogSource
2429 2430 2431 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2429 def catalog_source @catalog_source end |
#dataset_reference ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
Corresponds to the JSON property datasetReference
2434 2435 2436 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2434 def dataset_reference @dataset_reference end |
#external_dataset_reference ⇒ Google::Apis::BigqueryV2::ExternalDatasetReference
Configures the access a dataset defined in an external metadata storage.
Corresponds to the JSON property externalDatasetReference
2439 2440 2441 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2439 def external_dataset_reference @external_dataset_reference end |
#friendly_name ⇒ String
An alternate name for the dataset. The friendly name is purely decorative in
nature.
Corresponds to the JSON property friendlyName
2445 2446 2447 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2445 def friendly_name @friendly_name end |
#id ⇒ String
The fully-qualified, unique, opaque ID of the dataset.
Corresponds to the JSON property id
2450 2451 2452 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2450 def id @id end |
#kind ⇒ String
The resource type. This property always returns the value "bigquery#dataset"
Corresponds to the JSON property kind
2455 2456 2457 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2455 def kind @kind end |
#labels ⇒ Hash<String,String>
The labels associated with this dataset. You can use these to organize and
group your datasets.
Corresponds to the JSON property labels
2461 2462 2463 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2461 def labels @labels end |
#location ⇒ String
The geographic location where the dataset resides.
Corresponds to the JSON property location
2466 2467 2468 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2466 def location @location end |
#type ⇒ String
Output only. Same as type in Dataset. The type of the dataset, one of: *
DEFAULT - only accessible by owner and authorized accounts, * PUBLIC -
accessible by everyone, * LINKED - linked dataset, * EXTERNAL - dataset with
definition in external metadata catalog, * BIGLAKE_ICEBERG - a Biglake dataset
accessible through the Iceberg API, * BIGLAKE_HIVE - a Biglake dataset
accessible through the Hive API.
Corresponds to the JSON property type
2476 2477 2478 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2476 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2483 def update!(**args) @catalog_source = args[:catalog_source] if args.key?(:catalog_source) @dataset_reference = args[:dataset_reference] if args.key?(:dataset_reference) @external_dataset_reference = args[:external_dataset_reference] if args.key?(:external_dataset_reference) @friendly_name = args[:friendly_name] if args.key?(:friendly_name) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @labels = args[:labels] if args.key?(:labels) @location = args[:location] if args.key?(:location) @type = args[:type] if args.key?(:type) end |