Class: Google::Apis::BigqueryV2::DatasetList::Dataset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

A dataset resource with only a subset of fields, to be returned in a list of datasets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Dataset

Returns a new instance of Dataset.



2407
2408
2409
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#catalog_sourceString

Output only. The origin of the dataset, one of: * (Unset) - Native BigQuery Dataset. * BIGLAKE - Dataset is backed by a namespace stored natively in Biglake. Corresponds to the JSON property catalogSource

Returns:

  • (String)


2358
2359
2360
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2358

def catalog_source
  @catalog_source
end

#dataset_referenceGoogle::Apis::BigqueryV2::DatasetReference

Identifier for a dataset. Corresponds to the JSON property datasetReference



2363
2364
2365
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2363

def dataset_reference
  @dataset_reference
end

#external_dataset_referenceGoogle::Apis::BigqueryV2::ExternalDatasetReference

Configures the access a dataset defined in an external metadata storage. Corresponds to the JSON property externalDatasetReference



2368
2369
2370
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2368

def external_dataset_reference
  @external_dataset_reference
end

#friendly_nameString

An alternate name for the dataset. The friendly name is purely decorative in nature. Corresponds to the JSON property friendlyName

Returns:

  • (String)


2374
2375
2376
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2374

def friendly_name
  @friendly_name
end

#idString

The fully-qualified, unique, opaque ID of the dataset. Corresponds to the JSON property id

Returns:

  • (String)


2379
2380
2381
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2379

def id
  @id
end

#kindString

The resource type. This property always returns the value "bigquery#dataset" Corresponds to the JSON property kind

Returns:

  • (String)


2384
2385
2386
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2384

def kind
  @kind
end

#labelsHash<String,String>

The labels associated with this dataset. You can use these to organize and group your datasets. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2390
2391
2392
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2390

def labels
  @labels
end

#locationString

The geographic location where the dataset resides. Corresponds to the JSON property location

Returns:

  • (String)


2395
2396
2397
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2395

def location
  @location
end

#typeString

Output only. Same as type in Dataset. The type of the dataset, one of: * DEFAULT - only accessible by owner and authorized accounts, * PUBLIC - accessible by everyone, * LINKED - linked dataset, * EXTERNAL - dataset with definition in external metadata catalog, * BIGLAKE_ICEBERG - a Biglake dataset accessible through the Iceberg API, * BIGLAKE_HIVE - a Biglake dataset accessible through the Hive API. Corresponds to the JSON property type

Returns:

  • (String)


2405
2406
2407
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2405

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2412

def update!(**args)
  @catalog_source = args[:catalog_source] if args.key?(:catalog_source)
  @dataset_reference = args[:dataset_reference] if args.key?(:dataset_reference)
  @external_dataset_reference = args[:external_dataset_reference] if args.key?(:external_dataset_reference)
  @friendly_name = args[:friendly_name] if args.key?(:friendly_name)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @labels = args[:labels] if args.key?(:labels)
  @location = args[:location] if args.key?(:location)
  @type = args[:type] if args.key?(:type)
end