Class: Google::Apis::BigqueryV2::DatasetList::Dataset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

A dataset resource with only a subset of fields, to be returned in a list of datasets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Dataset

Returns a new instance of Dataset.



2358
2359
2360
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_referenceGoogle::Apis::BigqueryV2::DatasetReference

Identifier for a dataset. Corresponds to the JSON property datasetReference



2324
2325
2326
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2324

def dataset_reference
  @dataset_reference
end

#external_dataset_referenceGoogle::Apis::BigqueryV2::ExternalDatasetReference

Configures the access a dataset defined in an external metadata storage. Corresponds to the JSON property externalDatasetReference



2329
2330
2331
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2329

def external_dataset_reference
  @external_dataset_reference
end

#friendly_nameString

An alternate name for the dataset. The friendly name is purely decorative in nature. Corresponds to the JSON property friendlyName

Returns:

  • (String)


2335
2336
2337
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2335

def friendly_name
  @friendly_name
end

#idString

The fully-qualified, unique, opaque ID of the dataset. Corresponds to the JSON property id

Returns:

  • (String)


2340
2341
2342
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2340

def id
  @id
end

#kindString

The resource type. This property always returns the value "bigquery#dataset" Corresponds to the JSON property kind

Returns:

  • (String)


2345
2346
2347
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2345

def kind
  @kind
end

#labelsHash<String,String>

The labels associated with this dataset. You can use these to organize and group your datasets. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2351
2352
2353
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2351

def labels
  @labels
end

#locationString

The geographic location where the dataset resides. Corresponds to the JSON property location

Returns:

  • (String)


2356
2357
2358
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2356

def location
  @location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2363
2364
2365
2366
2367
2368
2369
2370
2371
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2363

def update!(**args)
  @dataset_reference = args[:dataset_reference] if args.key?(:dataset_reference)
  @external_dataset_reference = args[:external_dataset_reference] if args.key?(:external_dataset_reference)
  @friendly_name = args[:friendly_name] if args.key?(:friendly_name)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @labels = args[:labels] if args.key?(:labels)
  @location = args[:location] if args.key?(:location)
end