Class: Google::Apis::BigqueryV2::DestinationTableProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Properties for the destination table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DestinationTableProperties

Returns a new instance of DestinationTableProperties.



2461
2462
2463
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The description for the destination table. This will only be used if the destination table is newly created. If the table already exists and a value different than the current description is provided, the job will fail. Corresponds to the JSON property description

Returns:

  • (String)


2440
2441
2442
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2440

def description
  @description
end

#expiration_timeDateTime

Internal use only. Corresponds to the JSON property expirationTime

Returns:

  • (DateTime)


2445
2446
2447
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2445

def expiration_time
  @expiration_time
end

#friendly_nameString

Optional. Friendly name for the destination table. If the table already exists, it should be same as the existing friendly name. Corresponds to the JSON property friendlyName

Returns:

  • (String)


2451
2452
2453
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2451

def friendly_name
  @friendly_name
end

#labelsHash<String,String>

Optional. The labels associated with this table. You can use these to organize and group your tables. This will only be used if the destination table is newly created. If the table already exists and labels are different than the current labels are provided, the job will fail. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2459
2460
2461
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2459

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2466
2467
2468
2469
2470
2471
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2466

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @friendly_name = args[:friendly_name] if args.key?(:friendly_name)
  @labels = args[:labels] if args.key?(:labels)
end