Class: Google::Apis::BigqueryV2::DestinationTableProperties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Properties for the destination table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DestinationTableProperties

Returns a new instance of DestinationTableProperties.



2432
2433
2434
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. The description for the destination table. This will only be used if the destination table is newly created. If the table already exists and a value different than the current description is provided, the job will fail. Corresponds to the JSON property description

Returns:

  • (String)


2411
2412
2413
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2411

def description
  @description
end

#expiration_timeDateTime

Internal use only. Corresponds to the JSON property expirationTime

Returns:

  • (DateTime)


2416
2417
2418
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2416

def expiration_time
  @expiration_time
end

#friendly_nameString

Optional. Friendly name for the destination table. If the table already exists, it should be same as the existing friendly name. Corresponds to the JSON property friendlyName

Returns:

  • (String)


2422
2423
2424
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2422

def friendly_name
  @friendly_name
end

#labelsHash<String,String>

Optional. The labels associated with this table. You can use these to organize and group your tables. This will only be used if the destination table is newly created. If the table already exists and labels are different than the current labels are provided, the job will fail. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2430
2431
2432
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2430

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2437
2438
2439
2440
2441
2442
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2437

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @friendly_name = args[:friendly_name] if args.key?(:friendly_name)
  @labels = args[:labels] if args.key?(:labels)
end