Class: Google::Apis::BigqueryV2::ExplainQueryStage
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ExplainQueryStage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
A single stage of query execution.
Instance Attribute Summary collapse
-
#completed_parallel_inputs ⇒ Fixnum
Number of parallel input segments completed.
-
#compute_mode ⇒ String
Output only.
-
#compute_ms_avg ⇒ Fixnum
Milliseconds the average shard spent on CPU-bound tasks.
-
#compute_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent on CPU-bound tasks.
-
#compute_ratio_avg ⇒ Float
Relative amount of time the average shard spent on CPU-bound tasks.
-
#compute_ratio_max ⇒ Float
Relative amount of time the slowest shard spent on CPU-bound tasks.
-
#end_ms ⇒ Fixnum
Stage end time represented as milliseconds since the epoch.
-
#id ⇒ Fixnum
Unique ID for the stage within the plan.
-
#input_stages ⇒ Array<Fixnum>
IDs for stages that are inputs to this stage.
-
#name ⇒ String
Human-readable name for the stage.
-
#parallel_inputs ⇒ Fixnum
Number of parallel input segments to be processed Corresponds to the JSON property
parallelInputs. -
#read_ms_avg ⇒ Fixnum
Milliseconds the average shard spent reading input.
-
#read_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent reading input.
-
#read_ratio_avg ⇒ Float
Relative amount of time the average shard spent reading input.
-
#read_ratio_max ⇒ Float
Relative amount of time the slowest shard spent reading input.
-
#records_read ⇒ Fixnum
Number of records read into the stage.
-
#records_written ⇒ Fixnum
Number of records written by the stage.
-
#shuffle_output_bytes ⇒ Fixnum
Total number of bytes written to shuffle.
-
#shuffle_output_bytes_spilled ⇒ Fixnum
Total number of bytes written to shuffle and spilled to disk.
-
#slot_ms ⇒ Fixnum
Slot-milliseconds used by the stage.
-
#start_ms ⇒ Fixnum
Stage start time represented as milliseconds since the epoch.
-
#status ⇒ String
Current status for this stage.
-
#steps ⇒ Array<Google::Apis::BigqueryV2::ExplainQueryStep>
List of operations within the stage in dependency order (approximately chronological).
-
#wait_ms_avg ⇒ Fixnum
Milliseconds the average shard spent waiting to be scheduled.
-
#wait_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent waiting to be scheduled.
-
#wait_ratio_avg ⇒ Float
Relative amount of time the average shard spent waiting to be scheduled.
-
#wait_ratio_max ⇒ Float
Relative amount of time the slowest shard spent waiting to be scheduled.
-
#write_ms_avg ⇒ Fixnum
Milliseconds the average shard spent on writing output.
-
#write_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent on writing output.
-
#write_ratio_avg ⇒ Float
Relative amount of time the average shard spent on writing output.
-
#write_ratio_max ⇒ Float
Relative amount of time the slowest shard spent on writing output.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExplainQueryStage
constructor
A new instance of ExplainQueryStage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExplainQueryStage
Returns a new instance of ExplainQueryStage.
3111 3112 3113 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3111 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_parallel_inputs ⇒ Fixnum
Number of parallel input segments completed.
Corresponds to the JSON property completedParallelInputs
2958 2959 2960 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2958 def completed_parallel_inputs @completed_parallel_inputs end |
#compute_mode ⇒ String
Output only. Compute mode for this stage.
Corresponds to the JSON property computeMode
2963 2964 2965 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2963 def compute_mode @compute_mode end |
#compute_ms_avg ⇒ Fixnum
Milliseconds the average shard spent on CPU-bound tasks.
Corresponds to the JSON property computeMsAvg
2968 2969 2970 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2968 def compute_ms_avg @compute_ms_avg end |
#compute_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent on CPU-bound tasks.
Corresponds to the JSON property computeMsMax
2973 2974 2975 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2973 def compute_ms_max @compute_ms_max end |
#compute_ratio_avg ⇒ Float
Relative amount of time the average shard spent on CPU-bound tasks.
Corresponds to the JSON property computeRatioAvg
2978 2979 2980 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2978 def compute_ratio_avg @compute_ratio_avg end |
#compute_ratio_max ⇒ Float
Relative amount of time the slowest shard spent on CPU-bound tasks.
Corresponds to the JSON property computeRatioMax
2983 2984 2985 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2983 def compute_ratio_max @compute_ratio_max end |
#end_ms ⇒ Fixnum
Stage end time represented as milliseconds since the epoch.
Corresponds to the JSON property endMs
2988 2989 2990 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2988 def end_ms @end_ms end |
#id ⇒ Fixnum
Unique ID for the stage within the plan.
Corresponds to the JSON property id
2993 2994 2995 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2993 def id @id end |
#input_stages ⇒ Array<Fixnum>
IDs for stages that are inputs to this stage.
Corresponds to the JSON property inputStages
2998 2999 3000 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2998 def input_stages @input_stages end |
#name ⇒ String
Human-readable name for the stage.
Corresponds to the JSON property name
3003 3004 3005 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3003 def name @name end |
#parallel_inputs ⇒ Fixnum
Number of parallel input segments to be processed
Corresponds to the JSON property parallelInputs
3008 3009 3010 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3008 def parallel_inputs @parallel_inputs end |
#read_ms_avg ⇒ Fixnum
Milliseconds the average shard spent reading input.
Corresponds to the JSON property readMsAvg
3013 3014 3015 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3013 def read_ms_avg @read_ms_avg end |
#read_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent reading input.
Corresponds to the JSON property readMsMax
3018 3019 3020 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3018 def read_ms_max @read_ms_max end |
#read_ratio_avg ⇒ Float
Relative amount of time the average shard spent reading input.
Corresponds to the JSON property readRatioAvg
3023 3024 3025 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3023 def read_ratio_avg @read_ratio_avg end |
#read_ratio_max ⇒ Float
Relative amount of time the slowest shard spent reading input.
Corresponds to the JSON property readRatioMax
3028 3029 3030 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3028 def read_ratio_max @read_ratio_max end |
#records_read ⇒ Fixnum
Number of records read into the stage.
Corresponds to the JSON property recordsRead
3033 3034 3035 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3033 def records_read @records_read end |
#records_written ⇒ Fixnum
Number of records written by the stage.
Corresponds to the JSON property recordsWritten
3038 3039 3040 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3038 def records_written @records_written end |
#shuffle_output_bytes ⇒ Fixnum
Total number of bytes written to shuffle.
Corresponds to the JSON property shuffleOutputBytes
3043 3044 3045 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3043 def shuffle_output_bytes @shuffle_output_bytes end |
#shuffle_output_bytes_spilled ⇒ Fixnum
Total number of bytes written to shuffle and spilled to disk.
Corresponds to the JSON property shuffleOutputBytesSpilled
3048 3049 3050 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3048 def shuffle_output_bytes_spilled @shuffle_output_bytes_spilled end |
#slot_ms ⇒ Fixnum
Slot-milliseconds used by the stage.
Corresponds to the JSON property slotMs
3053 3054 3055 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3053 def slot_ms @slot_ms end |
#start_ms ⇒ Fixnum
Stage start time represented as milliseconds since the epoch.
Corresponds to the JSON property startMs
3058 3059 3060 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3058 def start_ms @start_ms end |
#status ⇒ String
Current status for this stage.
Corresponds to the JSON property status
3063 3064 3065 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3063 def status @status end |
#steps ⇒ Array<Google::Apis::BigqueryV2::ExplainQueryStep>
List of operations within the stage in dependency order (approximately
chronological).
Corresponds to the JSON property steps
3069 3070 3071 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3069 def steps @steps end |
#wait_ms_avg ⇒ Fixnum
Milliseconds the average shard spent waiting to be scheduled.
Corresponds to the JSON property waitMsAvg
3074 3075 3076 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3074 def wait_ms_avg @wait_ms_avg end |
#wait_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent waiting to be scheduled.
Corresponds to the JSON property waitMsMax
3079 3080 3081 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3079 def wait_ms_max @wait_ms_max end |
#wait_ratio_avg ⇒ Float
Relative amount of time the average shard spent waiting to be scheduled.
Corresponds to the JSON property waitRatioAvg
3084 3085 3086 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3084 def wait_ratio_avg @wait_ratio_avg end |
#wait_ratio_max ⇒ Float
Relative amount of time the slowest shard spent waiting to be scheduled.
Corresponds to the JSON property waitRatioMax
3089 3090 3091 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3089 def wait_ratio_max @wait_ratio_max end |
#write_ms_avg ⇒ Fixnum
Milliseconds the average shard spent on writing output.
Corresponds to the JSON property writeMsAvg
3094 3095 3096 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3094 def write_ms_avg @write_ms_avg end |
#write_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent on writing output.
Corresponds to the JSON property writeMsMax
3099 3100 3101 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3099 def write_ms_max @write_ms_max end |
#write_ratio_avg ⇒ Float
Relative amount of time the average shard spent on writing output.
Corresponds to the JSON property writeRatioAvg
3104 3105 3106 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3104 def write_ratio_avg @write_ratio_avg end |
#write_ratio_max ⇒ Float
Relative amount of time the slowest shard spent on writing output.
Corresponds to the JSON property writeRatioMax
3109 3110 3111 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3109 def write_ratio_max @write_ratio_max end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 3145 3146 3147 3148 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3116 def update!(**args) @completed_parallel_inputs = args[:completed_parallel_inputs] if args.key?(:completed_parallel_inputs) @compute_mode = args[:compute_mode] if args.key?(:compute_mode) @compute_ms_avg = args[:compute_ms_avg] if args.key?(:compute_ms_avg) @compute_ms_max = args[:compute_ms_max] if args.key?(:compute_ms_max) @compute_ratio_avg = args[:compute_ratio_avg] if args.key?(:compute_ratio_avg) @compute_ratio_max = args[:compute_ratio_max] if args.key?(:compute_ratio_max) @end_ms = args[:end_ms] if args.key?(:end_ms) @id = args[:id] if args.key?(:id) @input_stages = args[:input_stages] if args.key?(:input_stages) @name = args[:name] if args.key?(:name) @parallel_inputs = args[:parallel_inputs] if args.key?(:parallel_inputs) @read_ms_avg = args[:read_ms_avg] if args.key?(:read_ms_avg) @read_ms_max = args[:read_ms_max] if args.key?(:read_ms_max) @read_ratio_avg = args[:read_ratio_avg] if args.key?(:read_ratio_avg) @read_ratio_max = args[:read_ratio_max] if args.key?(:read_ratio_max) @records_read = args[:records_read] if args.key?(:records_read) @records_written = args[:records_written] if args.key?(:records_written) @shuffle_output_bytes = args[:shuffle_output_bytes] if args.key?(:shuffle_output_bytes) @shuffle_output_bytes_spilled = args[:shuffle_output_bytes_spilled] if args.key?(:shuffle_output_bytes_spilled) @slot_ms = args[:slot_ms] if args.key?(:slot_ms) @start_ms = args[:start_ms] if args.key?(:start_ms) @status = args[:status] if args.key?(:status) @steps = args[:steps] if args.key?(:steps) @wait_ms_avg = args[:wait_ms_avg] if args.key?(:wait_ms_avg) @wait_ms_max = args[:wait_ms_max] if args.key?(:wait_ms_max) @wait_ratio_avg = args[:wait_ratio_avg] if args.key?(:wait_ratio_avg) @wait_ratio_max = args[:wait_ratio_max] if args.key?(:wait_ratio_max) @write_ms_avg = args[:write_ms_avg] if args.key?(:write_ms_avg) @write_ms_max = args[:write_ms_max] if args.key?(:write_ms_max) @write_ratio_avg = args[:write_ratio_avg] if args.key?(:write_ratio_avg) @write_ratio_max = args[:write_ratio_max] if args.key?(:write_ratio_max) end |