Class: Google::Apis::BigqueryV2::ExplainQueryStage
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ExplainQueryStage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
A single stage of query execution.
Instance Attribute Summary collapse
-
#completed_parallel_inputs ⇒ Fixnum
Number of parallel input segments completed.
-
#compute_mode ⇒ String
Output only.
-
#compute_ms_avg ⇒ Fixnum
Milliseconds the average shard spent on CPU-bound tasks.
-
#compute_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent on CPU-bound tasks.
-
#compute_ratio_avg ⇒ Float
Relative amount of time the average shard spent on CPU-bound tasks.
-
#compute_ratio_max ⇒ Float
Relative amount of time the slowest shard spent on CPU-bound tasks.
-
#end_ms ⇒ Fixnum
Stage end time represented as milliseconds since the epoch.
-
#id ⇒ Fixnum
Unique ID for the stage within the plan.
-
#input_stages ⇒ Array<Fixnum>
IDs for stages that are inputs to this stage.
-
#name ⇒ String
Human-readable name for the stage.
-
#parallel_inputs ⇒ Fixnum
Number of parallel input segments to be processed Corresponds to the JSON property
parallelInputs. -
#read_ms_avg ⇒ Fixnum
Milliseconds the average shard spent reading input.
-
#read_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent reading input.
-
#read_ratio_avg ⇒ Float
Relative amount of time the average shard spent reading input.
-
#read_ratio_max ⇒ Float
Relative amount of time the slowest shard spent reading input.
-
#records_read ⇒ Fixnum
Number of records read into the stage.
-
#records_written ⇒ Fixnum
Number of records written by the stage.
-
#shuffle_output_bytes ⇒ Fixnum
Total number of bytes written to shuffle.
-
#shuffle_output_bytes_spilled ⇒ Fixnum
Total number of bytes written to shuffle and spilled to disk.
-
#slot_ms ⇒ Fixnum
Slot-milliseconds used by the stage.
-
#start_ms ⇒ Fixnum
Stage start time represented as milliseconds since the epoch.
-
#status ⇒ String
Current status for this stage.
-
#steps ⇒ Array<Google::Apis::BigqueryV2::ExplainQueryStep>
List of operations within the stage in dependency order (approximately chronological).
-
#wait_ms_avg ⇒ Fixnum
Milliseconds the average shard spent waiting to be scheduled.
-
#wait_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent waiting to be scheduled.
-
#wait_ratio_avg ⇒ Float
Relative amount of time the average shard spent waiting to be scheduled.
-
#wait_ratio_max ⇒ Float
Relative amount of time the slowest shard spent waiting to be scheduled.
-
#write_ms_avg ⇒ Fixnum
Milliseconds the average shard spent on writing output.
-
#write_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent on writing output.
-
#write_ratio_avg ⇒ Float
Relative amount of time the average shard spent on writing output.
-
#write_ratio_max ⇒ Float
Relative amount of time the slowest shard spent on writing output.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExplainQueryStage
constructor
A new instance of ExplainQueryStage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExplainQueryStage
Returns a new instance of ExplainQueryStage.
3105 3106 3107 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3105 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_parallel_inputs ⇒ Fixnum
Number of parallel input segments completed.
Corresponds to the JSON property completedParallelInputs
2952 2953 2954 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2952 def completed_parallel_inputs @completed_parallel_inputs end |
#compute_mode ⇒ String
Output only. Compute mode for this stage.
Corresponds to the JSON property computeMode
2957 2958 2959 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2957 def compute_mode @compute_mode end |
#compute_ms_avg ⇒ Fixnum
Milliseconds the average shard spent on CPU-bound tasks.
Corresponds to the JSON property computeMsAvg
2962 2963 2964 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2962 def compute_ms_avg @compute_ms_avg end |
#compute_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent on CPU-bound tasks.
Corresponds to the JSON property computeMsMax
2967 2968 2969 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2967 def compute_ms_max @compute_ms_max end |
#compute_ratio_avg ⇒ Float
Relative amount of time the average shard spent on CPU-bound tasks.
Corresponds to the JSON property computeRatioAvg
2972 2973 2974 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2972 def compute_ratio_avg @compute_ratio_avg end |
#compute_ratio_max ⇒ Float
Relative amount of time the slowest shard spent on CPU-bound tasks.
Corresponds to the JSON property computeRatioMax
2977 2978 2979 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2977 def compute_ratio_max @compute_ratio_max end |
#end_ms ⇒ Fixnum
Stage end time represented as milliseconds since the epoch.
Corresponds to the JSON property endMs
2982 2983 2984 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2982 def end_ms @end_ms end |
#id ⇒ Fixnum
Unique ID for the stage within the plan.
Corresponds to the JSON property id
2987 2988 2989 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2987 def id @id end |
#input_stages ⇒ Array<Fixnum>
IDs for stages that are inputs to this stage.
Corresponds to the JSON property inputStages
2992 2993 2994 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2992 def input_stages @input_stages end |
#name ⇒ String
Human-readable name for the stage.
Corresponds to the JSON property name
2997 2998 2999 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2997 def name @name end |
#parallel_inputs ⇒ Fixnum
Number of parallel input segments to be processed
Corresponds to the JSON property parallelInputs
3002 3003 3004 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3002 def parallel_inputs @parallel_inputs end |
#read_ms_avg ⇒ Fixnum
Milliseconds the average shard spent reading input.
Corresponds to the JSON property readMsAvg
3007 3008 3009 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3007 def read_ms_avg @read_ms_avg end |
#read_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent reading input.
Corresponds to the JSON property readMsMax
3012 3013 3014 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3012 def read_ms_max @read_ms_max end |
#read_ratio_avg ⇒ Float
Relative amount of time the average shard spent reading input.
Corresponds to the JSON property readRatioAvg
3017 3018 3019 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3017 def read_ratio_avg @read_ratio_avg end |
#read_ratio_max ⇒ Float
Relative amount of time the slowest shard spent reading input.
Corresponds to the JSON property readRatioMax
3022 3023 3024 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3022 def read_ratio_max @read_ratio_max end |
#records_read ⇒ Fixnum
Number of records read into the stage.
Corresponds to the JSON property recordsRead
3027 3028 3029 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3027 def records_read @records_read end |
#records_written ⇒ Fixnum
Number of records written by the stage.
Corresponds to the JSON property recordsWritten
3032 3033 3034 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3032 def records_written @records_written end |
#shuffle_output_bytes ⇒ Fixnum
Total number of bytes written to shuffle.
Corresponds to the JSON property shuffleOutputBytes
3037 3038 3039 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3037 def shuffle_output_bytes @shuffle_output_bytes end |
#shuffle_output_bytes_spilled ⇒ Fixnum
Total number of bytes written to shuffle and spilled to disk.
Corresponds to the JSON property shuffleOutputBytesSpilled
3042 3043 3044 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3042 def shuffle_output_bytes_spilled @shuffle_output_bytes_spilled end |
#slot_ms ⇒ Fixnum
Slot-milliseconds used by the stage.
Corresponds to the JSON property slotMs
3047 3048 3049 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3047 def slot_ms @slot_ms end |
#start_ms ⇒ Fixnum
Stage start time represented as milliseconds since the epoch.
Corresponds to the JSON property startMs
3052 3053 3054 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3052 def start_ms @start_ms end |
#status ⇒ String
Current status for this stage.
Corresponds to the JSON property status
3057 3058 3059 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3057 def status @status end |
#steps ⇒ Array<Google::Apis::BigqueryV2::ExplainQueryStep>
List of operations within the stage in dependency order (approximately
chronological).
Corresponds to the JSON property steps
3063 3064 3065 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3063 def steps @steps end |
#wait_ms_avg ⇒ Fixnum
Milliseconds the average shard spent waiting to be scheduled.
Corresponds to the JSON property waitMsAvg
3068 3069 3070 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3068 def wait_ms_avg @wait_ms_avg end |
#wait_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent waiting to be scheduled.
Corresponds to the JSON property waitMsMax
3073 3074 3075 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3073 def wait_ms_max @wait_ms_max end |
#wait_ratio_avg ⇒ Float
Relative amount of time the average shard spent waiting to be scheduled.
Corresponds to the JSON property waitRatioAvg
3078 3079 3080 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3078 def wait_ratio_avg @wait_ratio_avg end |
#wait_ratio_max ⇒ Float
Relative amount of time the slowest shard spent waiting to be scheduled.
Corresponds to the JSON property waitRatioMax
3083 3084 3085 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3083 def wait_ratio_max @wait_ratio_max end |
#write_ms_avg ⇒ Fixnum
Milliseconds the average shard spent on writing output.
Corresponds to the JSON property writeMsAvg
3088 3089 3090 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3088 def write_ms_avg @write_ms_avg end |
#write_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent on writing output.
Corresponds to the JSON property writeMsMax
3093 3094 3095 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3093 def write_ms_max @write_ms_max end |
#write_ratio_avg ⇒ Float
Relative amount of time the average shard spent on writing output.
Corresponds to the JSON property writeRatioAvg
3098 3099 3100 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3098 def write_ratio_avg @write_ratio_avg end |
#write_ratio_max ⇒ Float
Relative amount of time the slowest shard spent on writing output.
Corresponds to the JSON property writeRatioMax
3103 3104 3105 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3103 def write_ratio_max @write_ratio_max end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3110 3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3110 def update!(**args) @completed_parallel_inputs = args[:completed_parallel_inputs] if args.key?(:completed_parallel_inputs) @compute_mode = args[:compute_mode] if args.key?(:compute_mode) @compute_ms_avg = args[:compute_ms_avg] if args.key?(:compute_ms_avg) @compute_ms_max = args[:compute_ms_max] if args.key?(:compute_ms_max) @compute_ratio_avg = args[:compute_ratio_avg] if args.key?(:compute_ratio_avg) @compute_ratio_max = args[:compute_ratio_max] if args.key?(:compute_ratio_max) @end_ms = args[:end_ms] if args.key?(:end_ms) @id = args[:id] if args.key?(:id) @input_stages = args[:input_stages] if args.key?(:input_stages) @name = args[:name] if args.key?(:name) @parallel_inputs = args[:parallel_inputs] if args.key?(:parallel_inputs) @read_ms_avg = args[:read_ms_avg] if args.key?(:read_ms_avg) @read_ms_max = args[:read_ms_max] if args.key?(:read_ms_max) @read_ratio_avg = args[:read_ratio_avg] if args.key?(:read_ratio_avg) @read_ratio_max = args[:read_ratio_max] if args.key?(:read_ratio_max) @records_read = args[:records_read] if args.key?(:records_read) @records_written = args[:records_written] if args.key?(:records_written) @shuffle_output_bytes = args[:shuffle_output_bytes] if args.key?(:shuffle_output_bytes) @shuffle_output_bytes_spilled = args[:shuffle_output_bytes_spilled] if args.key?(:shuffle_output_bytes_spilled) @slot_ms = args[:slot_ms] if args.key?(:slot_ms) @start_ms = args[:start_ms] if args.key?(:start_ms) @status = args[:status] if args.key?(:status) @steps = args[:steps] if args.key?(:steps) @wait_ms_avg = args[:wait_ms_avg] if args.key?(:wait_ms_avg) @wait_ms_max = args[:wait_ms_max] if args.key?(:wait_ms_max) @wait_ratio_avg = args[:wait_ratio_avg] if args.key?(:wait_ratio_avg) @wait_ratio_max = args[:wait_ratio_max] if args.key?(:wait_ratio_max) @write_ms_avg = args[:write_ms_avg] if args.key?(:write_ms_avg) @write_ms_max = args[:write_ms_max] if args.key?(:write_ms_max) @write_ratio_avg = args[:write_ratio_avg] if args.key?(:write_ratio_avg) @write_ratio_max = args[:write_ratio_max] if args.key?(:write_ratio_max) end |