Class: Google::Apis::BigqueryV2::ExplainQueryStage
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ExplainQueryStage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
A single stage of query execution.
Instance Attribute Summary collapse
-
#completed_parallel_inputs ⇒ Fixnum
Number of parallel input segments completed.
-
#compute_mode ⇒ String
Output only.
-
#compute_ms_avg ⇒ Fixnum
Milliseconds the average shard spent on CPU-bound tasks.
-
#compute_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent on CPU-bound tasks.
-
#compute_ratio_avg ⇒ Float
Relative amount of time the average shard spent on CPU-bound tasks.
-
#compute_ratio_max ⇒ Float
Relative amount of time the slowest shard spent on CPU-bound tasks.
-
#end_ms ⇒ Fixnum
Stage end time represented as milliseconds since the epoch.
-
#id ⇒ Fixnum
Unique ID for the stage within the plan.
-
#input_stages ⇒ Array<Fixnum>
IDs for stages that are inputs to this stage.
-
#name ⇒ String
Human-readable name for the stage.
-
#parallel_inputs ⇒ Fixnum
Number of parallel input segments to be processed Corresponds to the JSON property
parallelInputs. -
#read_ms_avg ⇒ Fixnum
Milliseconds the average shard spent reading input.
-
#read_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent reading input.
-
#read_ratio_avg ⇒ Float
Relative amount of time the average shard spent reading input.
-
#read_ratio_max ⇒ Float
Relative amount of time the slowest shard spent reading input.
-
#records_read ⇒ Fixnum
Number of records read into the stage.
-
#records_written ⇒ Fixnum
Number of records written by the stage.
-
#shuffle_output_bytes ⇒ Fixnum
Total number of bytes written to shuffle.
-
#shuffle_output_bytes_spilled ⇒ Fixnum
Total number of bytes written to shuffle and spilled to disk.
-
#slot_ms ⇒ Fixnum
Slot-milliseconds used by the stage.
-
#start_ms ⇒ Fixnum
Stage start time represented as milliseconds since the epoch.
-
#status ⇒ String
Current status for this stage.
-
#steps ⇒ Array<Google::Apis::BigqueryV2::ExplainQueryStep>
List of operations within the stage in dependency order (approximately chronological).
-
#wait_ms_avg ⇒ Fixnum
Milliseconds the average shard spent waiting to be scheduled.
-
#wait_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent waiting to be scheduled.
-
#wait_ratio_avg ⇒ Float
Relative amount of time the average shard spent waiting to be scheduled.
-
#wait_ratio_max ⇒ Float
Relative amount of time the slowest shard spent waiting to be scheduled.
-
#write_ms_avg ⇒ Fixnum
Milliseconds the average shard spent on writing output.
-
#write_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent on writing output.
-
#write_ratio_avg ⇒ Float
Relative amount of time the average shard spent on writing output.
-
#write_ratio_max ⇒ Float
Relative amount of time the slowest shard spent on writing output.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExplainQueryStage
constructor
A new instance of ExplainQueryStage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExplainQueryStage
Returns a new instance of ExplainQueryStage.
3034 3035 3036 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3034 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_parallel_inputs ⇒ Fixnum
Number of parallel input segments completed.
Corresponds to the JSON property completedParallelInputs
2881 2882 2883 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2881 def completed_parallel_inputs @completed_parallel_inputs end |
#compute_mode ⇒ String
Output only. Compute mode for this stage.
Corresponds to the JSON property computeMode
2886 2887 2888 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2886 def compute_mode @compute_mode end |
#compute_ms_avg ⇒ Fixnum
Milliseconds the average shard spent on CPU-bound tasks.
Corresponds to the JSON property computeMsAvg
2891 2892 2893 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2891 def compute_ms_avg @compute_ms_avg end |
#compute_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent on CPU-bound tasks.
Corresponds to the JSON property computeMsMax
2896 2897 2898 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2896 def compute_ms_max @compute_ms_max end |
#compute_ratio_avg ⇒ Float
Relative amount of time the average shard spent on CPU-bound tasks.
Corresponds to the JSON property computeRatioAvg
2901 2902 2903 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2901 def compute_ratio_avg @compute_ratio_avg end |
#compute_ratio_max ⇒ Float
Relative amount of time the slowest shard spent on CPU-bound tasks.
Corresponds to the JSON property computeRatioMax
2906 2907 2908 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2906 def compute_ratio_max @compute_ratio_max end |
#end_ms ⇒ Fixnum
Stage end time represented as milliseconds since the epoch.
Corresponds to the JSON property endMs
2911 2912 2913 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2911 def end_ms @end_ms end |
#id ⇒ Fixnum
Unique ID for the stage within the plan.
Corresponds to the JSON property id
2916 2917 2918 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2916 def id @id end |
#input_stages ⇒ Array<Fixnum>
IDs for stages that are inputs to this stage.
Corresponds to the JSON property inputStages
2921 2922 2923 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2921 def input_stages @input_stages end |
#name ⇒ String
Human-readable name for the stage.
Corresponds to the JSON property name
2926 2927 2928 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2926 def name @name end |
#parallel_inputs ⇒ Fixnum
Number of parallel input segments to be processed
Corresponds to the JSON property parallelInputs
2931 2932 2933 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2931 def parallel_inputs @parallel_inputs end |
#read_ms_avg ⇒ Fixnum
Milliseconds the average shard spent reading input.
Corresponds to the JSON property readMsAvg
2936 2937 2938 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2936 def read_ms_avg @read_ms_avg end |
#read_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent reading input.
Corresponds to the JSON property readMsMax
2941 2942 2943 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2941 def read_ms_max @read_ms_max end |
#read_ratio_avg ⇒ Float
Relative amount of time the average shard spent reading input.
Corresponds to the JSON property readRatioAvg
2946 2947 2948 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2946 def read_ratio_avg @read_ratio_avg end |
#read_ratio_max ⇒ Float
Relative amount of time the slowest shard spent reading input.
Corresponds to the JSON property readRatioMax
2951 2952 2953 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2951 def read_ratio_max @read_ratio_max end |
#records_read ⇒ Fixnum
Number of records read into the stage.
Corresponds to the JSON property recordsRead
2956 2957 2958 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2956 def records_read @records_read end |
#records_written ⇒ Fixnum
Number of records written by the stage.
Corresponds to the JSON property recordsWritten
2961 2962 2963 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2961 def records_written @records_written end |
#shuffle_output_bytes ⇒ Fixnum
Total number of bytes written to shuffle.
Corresponds to the JSON property shuffleOutputBytes
2966 2967 2968 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2966 def shuffle_output_bytes @shuffle_output_bytes end |
#shuffle_output_bytes_spilled ⇒ Fixnum
Total number of bytes written to shuffle and spilled to disk.
Corresponds to the JSON property shuffleOutputBytesSpilled
2971 2972 2973 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2971 def shuffle_output_bytes_spilled @shuffle_output_bytes_spilled end |
#slot_ms ⇒ Fixnum
Slot-milliseconds used by the stage.
Corresponds to the JSON property slotMs
2976 2977 2978 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2976 def slot_ms @slot_ms end |
#start_ms ⇒ Fixnum
Stage start time represented as milliseconds since the epoch.
Corresponds to the JSON property startMs
2981 2982 2983 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2981 def start_ms @start_ms end |
#status ⇒ String
Current status for this stage.
Corresponds to the JSON property status
2986 2987 2988 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2986 def status @status end |
#steps ⇒ Array<Google::Apis::BigqueryV2::ExplainQueryStep>
List of operations within the stage in dependency order (approximately
chronological).
Corresponds to the JSON property steps
2992 2993 2994 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2992 def steps @steps end |
#wait_ms_avg ⇒ Fixnum
Milliseconds the average shard spent waiting to be scheduled.
Corresponds to the JSON property waitMsAvg
2997 2998 2999 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2997 def wait_ms_avg @wait_ms_avg end |
#wait_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent waiting to be scheduled.
Corresponds to the JSON property waitMsMax
3002 3003 3004 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3002 def wait_ms_max @wait_ms_max end |
#wait_ratio_avg ⇒ Float
Relative amount of time the average shard spent waiting to be scheduled.
Corresponds to the JSON property waitRatioAvg
3007 3008 3009 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3007 def wait_ratio_avg @wait_ratio_avg end |
#wait_ratio_max ⇒ Float
Relative amount of time the slowest shard spent waiting to be scheduled.
Corresponds to the JSON property waitRatioMax
3012 3013 3014 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3012 def wait_ratio_max @wait_ratio_max end |
#write_ms_avg ⇒ Fixnum
Milliseconds the average shard spent on writing output.
Corresponds to the JSON property writeMsAvg
3017 3018 3019 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3017 def write_ms_avg @write_ms_avg end |
#write_ms_max ⇒ Fixnum
Milliseconds the slowest shard spent on writing output.
Corresponds to the JSON property writeMsMax
3022 3023 3024 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3022 def write_ms_max @write_ms_max end |
#write_ratio_avg ⇒ Float
Relative amount of time the average shard spent on writing output.
Corresponds to the JSON property writeRatioAvg
3027 3028 3029 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3027 def write_ratio_avg @write_ratio_avg end |
#write_ratio_max ⇒ Float
Relative amount of time the slowest shard spent on writing output.
Corresponds to the JSON property writeRatioMax
3032 3033 3034 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3032 def write_ratio_max @write_ratio_max end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3039 3040 3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 3069 3070 3071 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3039 def update!(**args) @completed_parallel_inputs = args[:completed_parallel_inputs] if args.key?(:completed_parallel_inputs) @compute_mode = args[:compute_mode] if args.key?(:compute_mode) @compute_ms_avg = args[:compute_ms_avg] if args.key?(:compute_ms_avg) @compute_ms_max = args[:compute_ms_max] if args.key?(:compute_ms_max) @compute_ratio_avg = args[:compute_ratio_avg] if args.key?(:compute_ratio_avg) @compute_ratio_max = args[:compute_ratio_max] if args.key?(:compute_ratio_max) @end_ms = args[:end_ms] if args.key?(:end_ms) @id = args[:id] if args.key?(:id) @input_stages = args[:input_stages] if args.key?(:input_stages) @name = args[:name] if args.key?(:name) @parallel_inputs = args[:parallel_inputs] if args.key?(:parallel_inputs) @read_ms_avg = args[:read_ms_avg] if args.key?(:read_ms_avg) @read_ms_max = args[:read_ms_max] if args.key?(:read_ms_max) @read_ratio_avg = args[:read_ratio_avg] if args.key?(:read_ratio_avg) @read_ratio_max = args[:read_ratio_max] if args.key?(:read_ratio_max) @records_read = args[:records_read] if args.key?(:records_read) @records_written = args[:records_written] if args.key?(:records_written) @shuffle_output_bytes = args[:shuffle_output_bytes] if args.key?(:shuffle_output_bytes) @shuffle_output_bytes_spilled = args[:shuffle_output_bytes_spilled] if args.key?(:shuffle_output_bytes_spilled) @slot_ms = args[:slot_ms] if args.key?(:slot_ms) @start_ms = args[:start_ms] if args.key?(:start_ms) @status = args[:status] if args.key?(:status) @steps = args[:steps] if args.key?(:steps) @wait_ms_avg = args[:wait_ms_avg] if args.key?(:wait_ms_avg) @wait_ms_max = args[:wait_ms_max] if args.key?(:wait_ms_max) @wait_ratio_avg = args[:wait_ratio_avg] if args.key?(:wait_ratio_avg) @wait_ratio_max = args[:wait_ratio_max] if args.key?(:wait_ratio_max) @write_ms_avg = args[:write_ms_avg] if args.key?(:write_ms_avg) @write_ms_max = args[:write_ms_max] if args.key?(:write_ms_max) @write_ratio_avg = args[:write_ratio_avg] if args.key?(:write_ratio_avg) @write_ratio_max = args[:write_ratio_max] if args.key?(:write_ratio_max) end |