Class: Google::Apis::BigqueryV2::ExplainQueryStage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

A single stage of query execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExplainQueryStage

Returns a new instance of ExplainQueryStage.



3012
3013
3014
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3012

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_parallel_inputsFixnum

Number of parallel input segments completed. Corresponds to the JSON property completedParallelInputs

Returns:

  • (Fixnum)


2859
2860
2861
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2859

def completed_parallel_inputs
  @completed_parallel_inputs
end

#compute_modeString

Output only. Compute mode for this stage. Corresponds to the JSON property computeMode

Returns:

  • (String)


2864
2865
2866
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2864

def compute_mode
  @compute_mode
end

#compute_ms_avgFixnum

Milliseconds the average shard spent on CPU-bound tasks. Corresponds to the JSON property computeMsAvg

Returns:

  • (Fixnum)


2869
2870
2871
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2869

def compute_ms_avg
  @compute_ms_avg
end

#compute_ms_maxFixnum

Milliseconds the slowest shard spent on CPU-bound tasks. Corresponds to the JSON property computeMsMax

Returns:

  • (Fixnum)


2874
2875
2876
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2874

def compute_ms_max
  @compute_ms_max
end

#compute_ratio_avgFloat

Relative amount of time the average shard spent on CPU-bound tasks. Corresponds to the JSON property computeRatioAvg

Returns:

  • (Float)


2879
2880
2881
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2879

def compute_ratio_avg
  @compute_ratio_avg
end

#compute_ratio_maxFloat

Relative amount of time the slowest shard spent on CPU-bound tasks. Corresponds to the JSON property computeRatioMax

Returns:

  • (Float)


2884
2885
2886
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2884

def compute_ratio_max
  @compute_ratio_max
end

#end_msFixnum

Stage end time represented as milliseconds since the epoch. Corresponds to the JSON property endMs

Returns:

  • (Fixnum)


2889
2890
2891
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2889

def end_ms
  @end_ms
end

#idFixnum

Unique ID for the stage within the plan. Corresponds to the JSON property id

Returns:

  • (Fixnum)


2894
2895
2896
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2894

def id
  @id
end

#input_stagesArray<Fixnum>

IDs for stages that are inputs to this stage. Corresponds to the JSON property inputStages

Returns:

  • (Array<Fixnum>)


2899
2900
2901
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2899

def input_stages
  @input_stages
end

#nameString

Human-readable name for the stage. Corresponds to the JSON property name

Returns:

  • (String)


2904
2905
2906
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2904

def name
  @name
end

#parallel_inputsFixnum

Number of parallel input segments to be processed Corresponds to the JSON property parallelInputs

Returns:

  • (Fixnum)


2909
2910
2911
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2909

def parallel_inputs
  @parallel_inputs
end

#read_ms_avgFixnum

Milliseconds the average shard spent reading input. Corresponds to the JSON property readMsAvg

Returns:

  • (Fixnum)


2914
2915
2916
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2914

def read_ms_avg
  @read_ms_avg
end

#read_ms_maxFixnum

Milliseconds the slowest shard spent reading input. Corresponds to the JSON property readMsMax

Returns:

  • (Fixnum)


2919
2920
2921
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2919

def read_ms_max
  @read_ms_max
end

#read_ratio_avgFloat

Relative amount of time the average shard spent reading input. Corresponds to the JSON property readRatioAvg

Returns:

  • (Float)


2924
2925
2926
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2924

def read_ratio_avg
  @read_ratio_avg
end

#read_ratio_maxFloat

Relative amount of time the slowest shard spent reading input. Corresponds to the JSON property readRatioMax

Returns:

  • (Float)


2929
2930
2931
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2929

def read_ratio_max
  @read_ratio_max
end

#records_readFixnum

Number of records read into the stage. Corresponds to the JSON property recordsRead

Returns:

  • (Fixnum)


2934
2935
2936
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2934

def records_read
  @records_read
end

#records_writtenFixnum

Number of records written by the stage. Corresponds to the JSON property recordsWritten

Returns:

  • (Fixnum)


2939
2940
2941
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2939

def records_written
  @records_written
end

#shuffle_output_bytesFixnum

Total number of bytes written to shuffle. Corresponds to the JSON property shuffleOutputBytes

Returns:

  • (Fixnum)


2944
2945
2946
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2944

def shuffle_output_bytes
  @shuffle_output_bytes
end

#shuffle_output_bytes_spilledFixnum

Total number of bytes written to shuffle and spilled to disk. Corresponds to the JSON property shuffleOutputBytesSpilled

Returns:

  • (Fixnum)


2949
2950
2951
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2949

def shuffle_output_bytes_spilled
  @shuffle_output_bytes_spilled
end

#slot_msFixnum

Slot-milliseconds used by the stage. Corresponds to the JSON property slotMs

Returns:

  • (Fixnum)


2954
2955
2956
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2954

def slot_ms
  @slot_ms
end

#start_msFixnum

Stage start time represented as milliseconds since the epoch. Corresponds to the JSON property startMs

Returns:

  • (Fixnum)


2959
2960
2961
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2959

def start_ms
  @start_ms
end

#statusString

Current status for this stage. Corresponds to the JSON property status

Returns:

  • (String)


2964
2965
2966
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2964

def status
  @status
end

#stepsArray<Google::Apis::BigqueryV2::ExplainQueryStep>

List of operations within the stage in dependency order (approximately chronological). Corresponds to the JSON property steps



2970
2971
2972
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2970

def steps
  @steps
end

#wait_ms_avgFixnum

Milliseconds the average shard spent waiting to be scheduled. Corresponds to the JSON property waitMsAvg

Returns:

  • (Fixnum)


2975
2976
2977
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2975

def wait_ms_avg
  @wait_ms_avg
end

#wait_ms_maxFixnum

Milliseconds the slowest shard spent waiting to be scheduled. Corresponds to the JSON property waitMsMax

Returns:

  • (Fixnum)


2980
2981
2982
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2980

def wait_ms_max
  @wait_ms_max
end

#wait_ratio_avgFloat

Relative amount of time the average shard spent waiting to be scheduled. Corresponds to the JSON property waitRatioAvg

Returns:

  • (Float)


2985
2986
2987
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2985

def wait_ratio_avg
  @wait_ratio_avg
end

#wait_ratio_maxFloat

Relative amount of time the slowest shard spent waiting to be scheduled. Corresponds to the JSON property waitRatioMax

Returns:

  • (Float)


2990
2991
2992
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2990

def wait_ratio_max
  @wait_ratio_max
end

#write_ms_avgFixnum

Milliseconds the average shard spent on writing output. Corresponds to the JSON property writeMsAvg

Returns:

  • (Fixnum)


2995
2996
2997
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2995

def write_ms_avg
  @write_ms_avg
end

#write_ms_maxFixnum

Milliseconds the slowest shard spent on writing output. Corresponds to the JSON property writeMsMax

Returns:

  • (Fixnum)


3000
3001
3002
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3000

def write_ms_max
  @write_ms_max
end

#write_ratio_avgFloat

Relative amount of time the average shard spent on writing output. Corresponds to the JSON property writeRatioAvg

Returns:

  • (Float)


3005
3006
3007
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3005

def write_ratio_avg
  @write_ratio_avg
end

#write_ratio_maxFloat

Relative amount of time the slowest shard spent on writing output. Corresponds to the JSON property writeRatioMax

Returns:

  • (Float)


3010
3011
3012
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3010

def write_ratio_max
  @write_ratio_max
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
3034
3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
3046
3047
3048
3049
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3017

def update!(**args)
  @completed_parallel_inputs = args[:completed_parallel_inputs] if args.key?(:completed_parallel_inputs)
  @compute_mode = args[:compute_mode] if args.key?(:compute_mode)
  @compute_ms_avg = args[:compute_ms_avg] if args.key?(:compute_ms_avg)
  @compute_ms_max = args[:compute_ms_max] if args.key?(:compute_ms_max)
  @compute_ratio_avg = args[:compute_ratio_avg] if args.key?(:compute_ratio_avg)
  @compute_ratio_max = args[:compute_ratio_max] if args.key?(:compute_ratio_max)
  @end_ms = args[:end_ms] if args.key?(:end_ms)
  @id = args[:id] if args.key?(:id)
  @input_stages = args[:input_stages] if args.key?(:input_stages)
  @name = args[:name] if args.key?(:name)
  @parallel_inputs = args[:parallel_inputs] if args.key?(:parallel_inputs)
  @read_ms_avg = args[:read_ms_avg] if args.key?(:read_ms_avg)
  @read_ms_max = args[:read_ms_max] if args.key?(:read_ms_max)
  @read_ratio_avg = args[:read_ratio_avg] if args.key?(:read_ratio_avg)
  @read_ratio_max = args[:read_ratio_max] if args.key?(:read_ratio_max)
  @records_read = args[:records_read] if args.key?(:records_read)
  @records_written = args[:records_written] if args.key?(:records_written)
  @shuffle_output_bytes = args[:shuffle_output_bytes] if args.key?(:shuffle_output_bytes)
  @shuffle_output_bytes_spilled = args[:shuffle_output_bytes_spilled] if args.key?(:shuffle_output_bytes_spilled)
  @slot_ms = args[:slot_ms] if args.key?(:slot_ms)
  @start_ms = args[:start_ms] if args.key?(:start_ms)
  @status = args[:status] if args.key?(:status)
  @steps = args[:steps] if args.key?(:steps)
  @wait_ms_avg = args[:wait_ms_avg] if args.key?(:wait_ms_avg)
  @wait_ms_max = args[:wait_ms_max] if args.key?(:wait_ms_max)
  @wait_ratio_avg = args[:wait_ratio_avg] if args.key?(:wait_ratio_avg)
  @wait_ratio_max = args[:wait_ratio_max] if args.key?(:wait_ratio_max)
  @write_ms_avg = args[:write_ms_avg] if args.key?(:write_ms_avg)
  @write_ms_max = args[:write_ms_max] if args.key?(:write_ms_max)
  @write_ratio_avg = args[:write_ratio_avg] if args.key?(:write_ratio_avg)
  @write_ratio_max = args[:write_ratio_max] if args.key?(:write_ratio_max)
end