Class: Google::Apis::BigqueryV2::ExplainQueryStage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

A single stage of query execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExplainQueryStage

Returns a new instance of ExplainQueryStage.



2971
2972
2973
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2971

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_parallel_inputsFixnum

Number of parallel input segments completed. Corresponds to the JSON property completedParallelInputs

Returns:

  • (Fixnum)


2818
2819
2820
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2818

def completed_parallel_inputs
  @completed_parallel_inputs
end

#compute_modeString

Output only. Compute mode for this stage. Corresponds to the JSON property computeMode

Returns:

  • (String)


2823
2824
2825
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2823

def compute_mode
  @compute_mode
end

#compute_ms_avgFixnum

Milliseconds the average shard spent on CPU-bound tasks. Corresponds to the JSON property computeMsAvg

Returns:

  • (Fixnum)


2828
2829
2830
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2828

def compute_ms_avg
  @compute_ms_avg
end

#compute_ms_maxFixnum

Milliseconds the slowest shard spent on CPU-bound tasks. Corresponds to the JSON property computeMsMax

Returns:

  • (Fixnum)


2833
2834
2835
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2833

def compute_ms_max
  @compute_ms_max
end

#compute_ratio_avgFloat

Relative amount of time the average shard spent on CPU-bound tasks. Corresponds to the JSON property computeRatioAvg

Returns:

  • (Float)


2838
2839
2840
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2838

def compute_ratio_avg
  @compute_ratio_avg
end

#compute_ratio_maxFloat

Relative amount of time the slowest shard spent on CPU-bound tasks. Corresponds to the JSON property computeRatioMax

Returns:

  • (Float)


2843
2844
2845
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2843

def compute_ratio_max
  @compute_ratio_max
end

#end_msFixnum

Stage end time represented as milliseconds since the epoch. Corresponds to the JSON property endMs

Returns:

  • (Fixnum)


2848
2849
2850
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2848

def end_ms
  @end_ms
end

#idFixnum

Unique ID for the stage within the plan. Corresponds to the JSON property id

Returns:

  • (Fixnum)


2853
2854
2855
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2853

def id
  @id
end

#input_stagesArray<Fixnum>

IDs for stages that are inputs to this stage. Corresponds to the JSON property inputStages

Returns:

  • (Array<Fixnum>)


2858
2859
2860
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2858

def input_stages
  @input_stages
end

#nameString

Human-readable name for the stage. Corresponds to the JSON property name

Returns:

  • (String)


2863
2864
2865
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2863

def name
  @name
end

#parallel_inputsFixnum

Number of parallel input segments to be processed Corresponds to the JSON property parallelInputs

Returns:

  • (Fixnum)


2868
2869
2870
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2868

def parallel_inputs
  @parallel_inputs
end

#read_ms_avgFixnum

Milliseconds the average shard spent reading input. Corresponds to the JSON property readMsAvg

Returns:

  • (Fixnum)


2873
2874
2875
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2873

def read_ms_avg
  @read_ms_avg
end

#read_ms_maxFixnum

Milliseconds the slowest shard spent reading input. Corresponds to the JSON property readMsMax

Returns:

  • (Fixnum)


2878
2879
2880
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2878

def read_ms_max
  @read_ms_max
end

#read_ratio_avgFloat

Relative amount of time the average shard spent reading input. Corresponds to the JSON property readRatioAvg

Returns:

  • (Float)


2883
2884
2885
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2883

def read_ratio_avg
  @read_ratio_avg
end

#read_ratio_maxFloat

Relative amount of time the slowest shard spent reading input. Corresponds to the JSON property readRatioMax

Returns:

  • (Float)


2888
2889
2890
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2888

def read_ratio_max
  @read_ratio_max
end

#records_readFixnum

Number of records read into the stage. Corresponds to the JSON property recordsRead

Returns:

  • (Fixnum)


2893
2894
2895
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2893

def records_read
  @records_read
end

#records_writtenFixnum

Number of records written by the stage. Corresponds to the JSON property recordsWritten

Returns:

  • (Fixnum)


2898
2899
2900
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2898

def records_written
  @records_written
end

#shuffle_output_bytesFixnum

Total number of bytes written to shuffle. Corresponds to the JSON property shuffleOutputBytes

Returns:

  • (Fixnum)


2903
2904
2905
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2903

def shuffle_output_bytes
  @shuffle_output_bytes
end

#shuffle_output_bytes_spilledFixnum

Total number of bytes written to shuffle and spilled to disk. Corresponds to the JSON property shuffleOutputBytesSpilled

Returns:

  • (Fixnum)


2908
2909
2910
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2908

def shuffle_output_bytes_spilled
  @shuffle_output_bytes_spilled
end

#slot_msFixnum

Slot-milliseconds used by the stage. Corresponds to the JSON property slotMs

Returns:

  • (Fixnum)


2913
2914
2915
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2913

def slot_ms
  @slot_ms
end

#start_msFixnum

Stage start time represented as milliseconds since the epoch. Corresponds to the JSON property startMs

Returns:

  • (Fixnum)


2918
2919
2920
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2918

def start_ms
  @start_ms
end

#statusString

Current status for this stage. Corresponds to the JSON property status

Returns:

  • (String)


2923
2924
2925
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2923

def status
  @status
end

#stepsArray<Google::Apis::BigqueryV2::ExplainQueryStep>

List of operations within the stage in dependency order (approximately chronological). Corresponds to the JSON property steps



2929
2930
2931
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2929

def steps
  @steps
end

#wait_ms_avgFixnum

Milliseconds the average shard spent waiting to be scheduled. Corresponds to the JSON property waitMsAvg

Returns:

  • (Fixnum)


2934
2935
2936
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2934

def wait_ms_avg
  @wait_ms_avg
end

#wait_ms_maxFixnum

Milliseconds the slowest shard spent waiting to be scheduled. Corresponds to the JSON property waitMsMax

Returns:

  • (Fixnum)


2939
2940
2941
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2939

def wait_ms_max
  @wait_ms_max
end

#wait_ratio_avgFloat

Relative amount of time the average shard spent waiting to be scheduled. Corresponds to the JSON property waitRatioAvg

Returns:

  • (Float)


2944
2945
2946
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2944

def wait_ratio_avg
  @wait_ratio_avg
end

#wait_ratio_maxFloat

Relative amount of time the slowest shard spent waiting to be scheduled. Corresponds to the JSON property waitRatioMax

Returns:

  • (Float)


2949
2950
2951
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2949

def wait_ratio_max
  @wait_ratio_max
end

#write_ms_avgFixnum

Milliseconds the average shard spent on writing output. Corresponds to the JSON property writeMsAvg

Returns:

  • (Fixnum)


2954
2955
2956
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2954

def write_ms_avg
  @write_ms_avg
end

#write_ms_maxFixnum

Milliseconds the slowest shard spent on writing output. Corresponds to the JSON property writeMsMax

Returns:

  • (Fixnum)


2959
2960
2961
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2959

def write_ms_max
  @write_ms_max
end

#write_ratio_avgFloat

Relative amount of time the average shard spent on writing output. Corresponds to the JSON property writeRatioAvg

Returns:

  • (Float)


2964
2965
2966
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2964

def write_ratio_avg
  @write_ratio_avg
end

#write_ratio_maxFloat

Relative amount of time the slowest shard spent on writing output. Corresponds to the JSON property writeRatioMax

Returns:

  • (Float)


2969
2970
2971
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2969

def write_ratio_max
  @write_ratio_max
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
3006
3007
3008
# File 'lib/google/apis/bigquery_v2/classes.rb', line 2976

def update!(**args)
  @completed_parallel_inputs = args[:completed_parallel_inputs] if args.key?(:completed_parallel_inputs)
  @compute_mode = args[:compute_mode] if args.key?(:compute_mode)
  @compute_ms_avg = args[:compute_ms_avg] if args.key?(:compute_ms_avg)
  @compute_ms_max = args[:compute_ms_max] if args.key?(:compute_ms_max)
  @compute_ratio_avg = args[:compute_ratio_avg] if args.key?(:compute_ratio_avg)
  @compute_ratio_max = args[:compute_ratio_max] if args.key?(:compute_ratio_max)
  @end_ms = args[:end_ms] if args.key?(:end_ms)
  @id = args[:id] if args.key?(:id)
  @input_stages = args[:input_stages] if args.key?(:input_stages)
  @name = args[:name] if args.key?(:name)
  @parallel_inputs = args[:parallel_inputs] if args.key?(:parallel_inputs)
  @read_ms_avg = args[:read_ms_avg] if args.key?(:read_ms_avg)
  @read_ms_max = args[:read_ms_max] if args.key?(:read_ms_max)
  @read_ratio_avg = args[:read_ratio_avg] if args.key?(:read_ratio_avg)
  @read_ratio_max = args[:read_ratio_max] if args.key?(:read_ratio_max)
  @records_read = args[:records_read] if args.key?(:records_read)
  @records_written = args[:records_written] if args.key?(:records_written)
  @shuffle_output_bytes = args[:shuffle_output_bytes] if args.key?(:shuffle_output_bytes)
  @shuffle_output_bytes_spilled = args[:shuffle_output_bytes_spilled] if args.key?(:shuffle_output_bytes_spilled)
  @slot_ms = args[:slot_ms] if args.key?(:slot_ms)
  @start_ms = args[:start_ms] if args.key?(:start_ms)
  @status = args[:status] if args.key?(:status)
  @steps = args[:steps] if args.key?(:steps)
  @wait_ms_avg = args[:wait_ms_avg] if args.key?(:wait_ms_avg)
  @wait_ms_max = args[:wait_ms_max] if args.key?(:wait_ms_max)
  @wait_ratio_avg = args[:wait_ratio_avg] if args.key?(:wait_ratio_avg)
  @wait_ratio_max = args[:wait_ratio_max] if args.key?(:wait_ratio_max)
  @write_ms_avg = args[:write_ms_avg] if args.key?(:write_ms_avg)
  @write_ms_max = args[:write_ms_max] if args.key?(:write_ms_max)
  @write_ratio_avg = args[:write_ratio_avg] if args.key?(:write_ratio_avg)
  @write_ratio_max = args[:write_ratio_max] if args.key?(:write_ratio_max)
end