Class: Google::Apis::BigqueryV2::ExportDataStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics for the EXPORT DATA statement as part of Query Job. EXTRACT JOB statistics are populated in JobStatistics4.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportDataStatistics

Returns a new instance of ExportDataStatistics.



3078
3079
3080
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_countFixnum

Number of destination files generated in case of EXPORT DATA statement only. Corresponds to the JSON property fileCount

Returns:

  • (Fixnum)


3070
3071
3072
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3070

def file_count
  @file_count
end

#row_countFixnum

[Alpha] Number of destination rows generated in case of EXPORT DATA statement only. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


3076
3077
3078
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3076

def row_count
  @row_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3083
3084
3085
3086
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3083

def update!(**args)
  @file_count = args[:file_count] if args.key?(:file_count)
  @row_count = args[:row_count] if args.key?(:row_count)
end