Class: Google::Apis::BigqueryV2::ExternalCatalogDatasetOptions
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ExternalCatalogDatasetOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Options defining open source compatible datasets living in the BigQuery catalog. Contains metadata of open source database, schema, or namespace represented by the current dataset.
Instance Attribute Summary collapse
-
#default_storage_location_uri ⇒ String
Optional.
-
#parameters ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalCatalogDatasetOptions
constructor
A new instance of ExternalCatalogDatasetOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalCatalogDatasetOptions
Returns a new instance of ExternalCatalogDatasetOptions.
3202 3203 3204 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3202 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_storage_location_uri ⇒ String
Optional. The storage location URI for all tables in the dataset. Equivalent
to hive metastore's database locationUri. Maximum length of 1024 characters.
Corresponds to the JSON property defaultStorageLocationUri
3194 3195 3196 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3194 def default_storage_location_uri @default_storage_location_uri end |
#parameters ⇒ Hash<String,String>
Optional. A map of key value pairs defining the parameters and properties of
the open source schema. Maximum size of 2MiB.
Corresponds to the JSON property parameters
3200 3201 3202 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3200 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3207 3208 3209 3210 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3207 def update!(**args) @default_storage_location_uri = args[:default_storage_location_uri] if args.key?(:default_storage_location_uri) @parameters = args[:parameters] if args.key?(:parameters) end |