Class: Google::Apis::BigqueryV2::ExternalCatalogTableOptions
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ExternalCatalogTableOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Metadata about open source compatible table. The fields contained in these options correspond to Hive metastore's table-level properties.
Instance Attribute Summary collapse
-
#connection_id ⇒ String
Optional.
-
#parameters ⇒ Hash<String,String>
Optional.
-
#storage_descriptor ⇒ Google::Apis::BigqueryV2::StorageDescriptor
Contains information about how a table's data is stored and accessed by open source query engines.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalCatalogTableOptions
constructor
A new instance of ExternalCatalogTableOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalCatalogTableOptions
Returns a new instance of ExternalCatalogTableOptions.
3333 3334 3335 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3333 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_id ⇒ String
Optional. A connection ID that specifies the credentials to be used to read
external storage, such as Azure Blob, Cloud Storage, or Amazon S3. This
connection is needed to read the open source table from BigQuery. The
connection_id format must be either .. or projects//locations//connections/
.
Corresponds to the JSON property connectionId
3318 3319 3320 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3318 def connection_id @connection_id end |
#parameters ⇒ Hash<String,String>
Optional. A map of the key-value pairs defining the parameters and properties
of the open source table. Corresponds with Hive metastore table parameters.
Maximum size of 4MiB.
Corresponds to the JSON property parameters
3325 3326 3327 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3325 def parameters @parameters end |
#storage_descriptor ⇒ Google::Apis::BigqueryV2::StorageDescriptor
Contains information about how a table's data is stored and accessed by open
source query engines.
Corresponds to the JSON property storageDescriptor
3331 3332 3333 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3331 def storage_descriptor @storage_descriptor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3338 3339 3340 3341 3342 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3338 def update!(**args) @connection_id = args[:connection_id] if args.key?(:connection_id) @parameters = args[:parameters] if args.key?(:parameters) @storage_descriptor = args[:storage_descriptor] if args.key?(:storage_descriptor) end |