Class: Google::Apis::BigqueryV2::ExternalRuntimeOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Options for the runtime of the external system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalRuntimeOptions

Returns a new instance of ExternalRuntimeOptions.



3670
3671
3672
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_cpuFloat

Optional. Amount of CPU provisioned for a Python UDF container instance. For more information, see Configure container limits for Python UDFs Corresponds to the JSON property containerCpu

Returns:

  • (Float)


3632
3633
3634
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3632

def container_cpu
  @container_cpu
end

#container_memoryString

Optional. Amount of memory provisioned for a Python UDF container instance. Format: numberunit where unit is one of "M", "G", "Mi" and "Gi" (e.g. 1G, 512Mi). If not specified, the default value is 512Mi. For more information, see Configure container limits for Python UDFs Corresponds to the JSON property containerMemory

Returns:

  • (String)


3641
3642
3643
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3641

def container_memory
  @container_memory
end

#container_request_concurrencyFixnum

Optional. Maximum number of requests that a Python UDF instance can handle concurrently. If absent or if 0, the default concurrency value is used. For more information, see Configure container limits for Python UDFs. Corresponds to the JSON property containerRequestConcurrency

Returns:

  • (Fixnum)


3650
3651
3652
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3650

def container_request_concurrency
  @container_request_concurrency
end

#max_batching_rowsFixnum

Optional. Maximum number of rows in each batch sent to the external runtime. If absent or if 0, BigQuery dynamically decides the number of rows in a batch. Corresponds to the JSON property maxBatchingRows

Returns:

  • (Fixnum)


3656
3657
3658
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3656

def max_batching_rows
  @max_batching_rows
end

#runtime_connectionString

Optional. Fully qualified name of the connection whose service account will be used to execute the code in the container. Format: "projects/`project_id`/ locations/`location_id`/connections/`connection_id`" Corresponds to the JSON property runtimeConnection

Returns:

  • (String)


3663
3664
3665
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3663

def runtime_connection
  @runtime_connection
end

#runtime_versionString

Optional. Language runtime version. Example: python-3.11. Corresponds to the JSON property runtimeVersion

Returns:

  • (String)


3668
3669
3670
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3668

def runtime_version
  @runtime_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3675
3676
3677
3678
3679
3680
3681
3682
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3675

def update!(**args)
  @container_cpu = args[:container_cpu] if args.key?(:container_cpu)
  @container_memory = args[:container_memory] if args.key?(:container_memory)
  @container_request_concurrency = args[:container_request_concurrency] if args.key?(:container_request_concurrency)
  @max_batching_rows = args[:max_batching_rows] if args.key?(:max_batching_rows)
  @runtime_connection = args[:runtime_connection] if args.key?(:runtime_connection)
  @runtime_version = args[:runtime_version] if args.key?(:runtime_version)
end