Class: Google::Apis::BigqueryV2::ExternalRuntimeOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Options for the runtime of the external system.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalRuntimeOptions

Returns a new instance of ExternalRuntimeOptions.



3595
3596
3597
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_cpuFloat

Optional. Amount of CPU provisioned for a Python UDF container instance. For more information, see Configure container limits for Python UDFs Corresponds to the JSON property containerCpu

Returns:

  • (Float)


3560
3561
3562
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3560

def container_cpu
  @container_cpu
end

#container_memoryString

Optional. Amount of memory provisioned for a Python UDF container instance. Format: numberunit where unit is one of "M", "G", "Mi" and "Gi" (e.g. 1G, 512Mi). If not specified, the default value is 512Mi. For more information, see Configure container limits for Python UDFs Corresponds to the JSON property containerMemory

Returns:

  • (String)


3569
3570
3571
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3569

def container_memory
  @container_memory
end

#container_request_concurrencyFixnum

Optional. Maximum number of requests that a Cloud Run instance can handle concurrently. If absent or if 0, a default concurrency is used. Corresponds to the JSON property containerRequestConcurrency

Returns:

  • (Fixnum)


3575
3576
3577
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3575

def container_request_concurrency
  @container_request_concurrency
end

#max_batching_rowsFixnum

Optional. Maximum number of rows in each batch sent to the external runtime. If absent or if 0, BigQuery dynamically decides the number of rows in a batch. Corresponds to the JSON property maxBatchingRows

Returns:

  • (Fixnum)


3581
3582
3583
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3581

def max_batching_rows
  @max_batching_rows
end

#runtime_connectionString

Optional. Fully qualified name of the connection whose service account will be used to execute the code in the container. Format: "projects/`project_id`/ locations/`location_id`/connections/`connection_id`" Corresponds to the JSON property runtimeConnection

Returns:

  • (String)


3588
3589
3590
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3588

def runtime_connection
  @runtime_connection
end

#runtime_versionString

Optional. Language runtime version. Example: python-3.11. Corresponds to the JSON property runtimeVersion

Returns:

  • (String)


3593
3594
3595
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3593

def runtime_version
  @runtime_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3600
3601
3602
3603
3604
3605
3606
3607
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3600

def update!(**args)
  @container_cpu = args[:container_cpu] if args.key?(:container_cpu)
  @container_memory = args[:container_memory] if args.key?(:container_memory)
  @container_request_concurrency = args[:container_request_concurrency] if args.key?(:container_request_concurrency)
  @max_batching_rows = args[:max_batching_rows] if args.key?(:max_batching_rows)
  @runtime_connection = args[:runtime_connection] if args.key?(:runtime_connection)
  @runtime_version = args[:runtime_version] if args.key?(:runtime_version)
end