Class: Google::Apis::BigqueryV2::ExternalRuntimeOptions
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ExternalRuntimeOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Options for the runtime of the external system.
Instance Attribute Summary collapse
-
#container_cpu ⇒ Float
Optional.
-
#container_memory ⇒ String
Optional.
-
#max_batching_rows ⇒ Fixnum
Optional.
-
#runtime_connection ⇒ String
Optional.
-
#runtime_version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalRuntimeOptions
constructor
A new instance of ExternalRuntimeOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalRuntimeOptions
Returns a new instance of ExternalRuntimeOptions.
3526 3527 3528 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3526 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_cpu ⇒ Float
Optional. Amount of CPU provisioned for a Python UDF container instance. For
more information, see Configure container limits for Python UDFs
Corresponds to the JSON property containerCpu
3497 3498 3499 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3497 def container_cpu @container_cpu end |
#container_memory ⇒ String
Optional. Amount of memory provisioned for a Python UDF container instance.
Format: numberunit where unit is one of "M", "G", "Mi" and "Gi" (e.g. 1G,
512Mi). If not specified, the default value is 512Mi. For more information,
see Configure container limits for Python UDFs
Corresponds to the JSON property containerMemory
3506 3507 3508 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3506 def container_memory @container_memory end |
#max_batching_rows ⇒ Fixnum
Optional. Maximum number of rows in each batch sent to the external runtime.
If absent or if 0, BigQuery dynamically decides the number of rows in a batch.
Corresponds to the JSON property maxBatchingRows
3512 3513 3514 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3512 def max_batching_rows @max_batching_rows end |
#runtime_connection ⇒ String
Optional. Fully qualified name of the connection whose service account will be
used to execute the code in the container. Format: "projects/`project_id`/
locations/`location_id`/connections/`connection_id`"
Corresponds to the JSON property runtimeConnection
3519 3520 3521 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3519 def runtime_connection @runtime_connection end |
#runtime_version ⇒ String
Optional. Language runtime version. Example: python-3.11.
Corresponds to the JSON property runtimeVersion
3524 3525 3526 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3524 def runtime_version @runtime_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3531 3532 3533 3534 3535 3536 3537 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3531 def update!(**args) @container_cpu = args[:container_cpu] if args.key?(:container_cpu) @container_memory = args[:container_memory] if args.key?(:container_memory) @max_batching_rows = args[:max_batching_rows] if args.key?(:max_batching_rows) @runtime_connection = args[:runtime_connection] if args.key?(:runtime_connection) @runtime_version = args[:runtime_version] if args.key?(:runtime_version) end |