Class: Google::Apis::BigqueryV2::GenAiErrorStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Provides error statistics for the query job across all AI function calls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenAiErrorStats

Returns a new instance of GenAiErrorStats.



3729
3730
3731
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<String>

A list of unique errors at query level (up to 5, truncated to 100 chars) Corresponds to the JSON property errors

Returns:

  • (Array<String>)


3727
3728
3729
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3727

def errors
  @errors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3734
3735
3736
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3734

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
end