Class: Google::Apis::BigqueryV2::GenAiErrorStats
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::GenAiErrorStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Provides error statistics for the query job across all AI function calls.
Instance Attribute Summary collapse
-
#errors ⇒ Array<String>
A list of unique errors at query level (up to 5, truncated to 100 chars) Corresponds to the JSON property
errors.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenAiErrorStats
constructor
A new instance of GenAiErrorStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenAiErrorStats
Returns a new instance of GenAiErrorStats.
3729 3730 3731 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3729 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<String>
A list of unique errors at query level (up to 5, truncated to 100 chars)
Corresponds to the JSON property errors
3727 3728 3729 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3727 def errors @errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3734 3735 3736 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3734 def update!(**args) @errors = args[:errors] if args.key?(:errors) end |