Class: Google::Apis::BigqueryV2::GenAiFunctionCostOptimizationStats
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::GenAiFunctionCostOptimizationStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Provides cost optimization statistics for a GenAi function call.
Instance Attribute Summary collapse
-
#message ⇒ String
System generated message to provide insights into cost optimization state.
-
#num_cost_optimized_rows ⇒ Fixnum
Number of rows inferred via cost optimized workflow.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenAiFunctionCostOptimizationStats
constructor
A new instance of GenAiFunctionCostOptimizationStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenAiFunctionCostOptimizationStats
Returns a new instance of GenAiFunctionCostOptimizationStats.
3801 3802 3803 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3801 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ String
System generated message to provide insights into cost optimization state.
Corresponds to the JSON property message
3794 3795 3796 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3794 def @message end |
#num_cost_optimized_rows ⇒ Fixnum
Number of rows inferred via cost optimized workflow.
Corresponds to the JSON property numCostOptimizedRows
3799 3800 3801 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3799 def num_cost_optimized_rows @num_cost_optimized_rows end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3806 3807 3808 3809 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3806 def update!(**args) @message = args[:message] if args.key?(:message) @num_cost_optimized_rows = args[:num_cost_optimized_rows] if args.key?(:num_cost_optimized_rows) end |