Class: Google::Apis::BigqueryV2::GenAiFunctionErrorStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Provides error statistics for a GenAi function call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenAiFunctionErrorStats

Returns a new instance of GenAiFunctionErrorStats.



3827
3828
3829
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<String>

A list of unique errors at function level (up to 5, truncated to 100 chars). Corresponds to the JSON property errors

Returns:

  • (Array<String>)


3820
3821
3822
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3820

def errors
  @errors
end

#num_failed_rowsFixnum

Number of failed rows processed by the function Corresponds to the JSON property numFailedRows

Returns:

  • (Fixnum)


3825
3826
3827
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3825

def num_failed_rows
  @num_failed_rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3832
3833
3834
3835
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3832

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
  @num_failed_rows = args[:num_failed_rows] if args.key?(:num_failed_rows)
end