Class: Google::Apis::BigqueryV2::GenAiFunctionErrorStats
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::GenAiFunctionErrorStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Provides error statistics for a GenAi function call.
Instance Attribute Summary collapse
-
#errors ⇒ Array<String>
A list of unique errors at function level (up to 5, truncated to 100 chars).
-
#num_failed_rows ⇒ Fixnum
Number of failed rows processed by the function Corresponds to the JSON property
numFailedRows.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenAiFunctionErrorStats
constructor
A new instance of GenAiFunctionErrorStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenAiFunctionErrorStats
Returns a new instance of GenAiFunctionErrorStats.
3826 3827 3828 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3826 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<String>
A list of unique errors at function level (up to 5, truncated to 100 chars).
Corresponds to the JSON property errors
3819 3820 3821 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3819 def errors @errors end |
#num_failed_rows ⇒ Fixnum
Number of failed rows processed by the function
Corresponds to the JSON property numFailedRows
3824 3825 3826 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3824 def num_failed_rows @num_failed_rows end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3831 3832 3833 3834 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3831 def update!(**args) @errors = args[:errors] if args.key?(:errors) @num_failed_rows = args[:num_failed_rows] if args.key?(:num_failed_rows) end |