Class: Google::Apis::BigqueryV2::GeneratedExpressionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Definition of the expression used to generate the field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeneratedExpressionInfo

Returns a new instance of GeneratedExpressionInfo.



3961
3962
3963
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asynchronousBoolean Also known as: asynchronous?

Optional. Whether the column generation is done asynchronously. Corresponds to the JSON property asynchronous

Returns:

  • (Boolean)


3946
3947
3948
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3946

def asynchronous
  @asynchronous
end

#generation_expressionString

Optional. The generation expression (e.g. AI.EMBED(...)) used to generated the field. Corresponds to the JSON property generationExpression

Returns:

  • (String)


3953
3954
3955
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3953

def generation_expression
  @generation_expression
end

#storedBoolean Also known as: stored?

Optional. Whether the generated column is stored in the table. Corresponds to the JSON property stored

Returns:

  • (Boolean)


3958
3959
3960
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3958

def stored
  @stored
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3966
3967
3968
3969
3970
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3966

def update!(**args)
  @asynchronous = args[:asynchronous] if args.key?(:asynchronous)
  @generation_expression = args[:generation_expression] if args.key?(:generation_expression)
  @stored = args[:stored] if args.key?(:stored)
end