Class: Google::Apis::BigqueryV2::GeneratedExpressionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Definition of the expression used to generate the field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GeneratedExpressionInfo

Returns a new instance of GeneratedExpressionInfo.



3907
3908
3909
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asynchronousBoolean Also known as: asynchronous?

Optional. Whether the column generation is done asynchronously. Corresponds to the JSON property asynchronous

Returns:

  • (Boolean)


3892
3893
3894
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3892

def asynchronous
  @asynchronous
end

#generation_expressionString

Optional. The generation expression (e.g. AI.EMBED(...)) used to generated the field. Corresponds to the JSON property generationExpression

Returns:

  • (String)


3899
3900
3901
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3899

def generation_expression
  @generation_expression
end

#storedBoolean Also known as: stored?

Optional. Whether the generated column is stored in the table. Corresponds to the JSON property stored

Returns:

  • (Boolean)


3904
3905
3906
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3904

def stored
  @stored
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3912
3913
3914
3915
3916
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3912

def update!(**args)
  @asynchronous = args[:asynchronous] if args.key?(:asynchronous)
  @generation_expression = args[:generation_expression] if args.key?(:generation_expression)
  @stored = args[:stored] if args.key?(:stored)
end