Class: Google::Apis::BigqueryV2::GetQueryResultsResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::GetQueryResultsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Response object of GetQueryResults.
Instance Attribute Summary collapse
-
#cache_hit ⇒ Boolean
(also: #cache_hit?)
Whether the query result was fetched from the query cache.
-
#errors ⇒ Array<Google::Apis::BigqueryV2::ErrorProto>
Output only.
-
#etag ⇒ String
A hash of this response.
-
#job_complete ⇒ Boolean
(also: #job_complete?)
Whether the query has completed or not.
-
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
-
#kind ⇒ String
The resource type of the response.
-
#num_dml_affected_rows ⇒ Fixnum
Output only.
-
#page_token ⇒ String
A token used for paging results.
-
#rows ⇒ Array<Google::Apis::BigqueryV2::TableRow>
An object with as many results as can be contained within the maximum permitted reply size.
-
#schema ⇒ Google::Apis::BigqueryV2::TableSchema
Schema of a table Corresponds to the JSON property
schema. -
#total_bytes_processed ⇒ Fixnum
The total number of bytes processed for this query.
-
#total_rows ⇒ Fixnum
The total number of rows in the complete query result set, which can be more than the number of rows in this single page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetQueryResultsResponse
constructor
A new instance of GetQueryResultsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetQueryResultsResponse
Returns a new instance of GetQueryResultsResponse.
4181 4182 4183 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4181 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_hit ⇒ Boolean Also known as: cache_hit?
Whether the query result was fetched from the query cache.
Corresponds to the JSON property cacheHit
4109 4110 4111 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4109 def cache_hit @cache_hit end |
#errors ⇒ Array<Google::Apis::BigqueryV2::ErrorProto>
Output only. The first errors or warnings encountered during the running of
the job. The final message includes the number of errors that caused the
process to stop. Errors here do not necessarily mean that the job has
completed or was unsuccessful. For more information about error messages, see
Error messages.
Corresponds to the JSON property errors
4119 4120 4121 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4119 def errors @errors end |
#etag ⇒ String
A hash of this response.
Corresponds to the JSON property etag
4124 4125 4126 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4124 def etag @etag end |
#job_complete ⇒ Boolean Also known as: job_complete?
Whether the query has completed or not. If rows or totalRows are present, this
will always be true. If this is false, totalRows will not be available.
Corresponds to the JSON property jobComplete
4130 4131 4132 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4130 def job_complete @job_complete end |
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
Corresponds to the JSON property jobReference
4136 4137 4138 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4136 def job_reference @job_reference end |
#kind ⇒ String
The resource type of the response.
Corresponds to the JSON property kind
4141 4142 4143 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4141 def kind @kind end |
#num_dml_affected_rows ⇒ Fixnum
Output only. The number of rows affected by a DML statement. Present only for
DML statements INSERT, UPDATE or DELETE.
Corresponds to the JSON property numDmlAffectedRows
4147 4148 4149 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4147 def num_dml_affected_rows @num_dml_affected_rows end |
#page_token ⇒ String
A token used for paging results. When this token is non-empty, it indicates
additional results are available.
Corresponds to the JSON property pageToken
4153 4154 4155 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4153 def page_token @page_token end |
#rows ⇒ Array<Google::Apis::BigqueryV2::TableRow>
An object with as many results as can be contained within the maximum
permitted reply size. To get any additional rows, you can call GetQueryResults
and specify the jobReference returned above. Present only when the query
completes successfully. The REST-based representation of this data leverages a
series of JSON f,v objects for indicating fields and values.
Corresponds to the JSON property rows
4162 4163 4164 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4162 def rows @rows end |
#schema ⇒ Google::Apis::BigqueryV2::TableSchema
Schema of a table
Corresponds to the JSON property schema
4167 4168 4169 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4167 def schema @schema end |
#total_bytes_processed ⇒ Fixnum
The total number of bytes processed for this query.
Corresponds to the JSON property totalBytesProcessed
4172 4173 4174 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4172 def total_bytes_processed @total_bytes_processed end |
#total_rows ⇒ Fixnum
The total number of rows in the complete query result set, which can be more
than the number of rows in this single page of results. Present only when the
query completes successfully.
Corresponds to the JSON property totalRows
4179 4180 4181 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4179 def total_rows @total_rows end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4186 4187 4188 4189 4190 4191 4192 4193 4194 4195 4196 4197 4198 4199 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4186 def update!(**args) @cache_hit = args[:cache_hit] if args.key?(:cache_hit) @errors = args[:errors] if args.key?(:errors) @etag = args[:etag] if args.key?(:etag) @job_complete = args[:job_complete] if args.key?(:job_complete) @job_reference = args[:job_reference] if args.key?(:job_reference) @kind = args[:kind] if args.key?(:kind) @num_dml_affected_rows = args[:num_dml_affected_rows] if args.key?(:num_dml_affected_rows) @page_token = args[:page_token] if args.key?(:page_token) @rows = args[:rows] if args.key?(:rows) @schema = args[:schema] if args.key?(:schema) @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed) @total_rows = args[:total_rows] if args.key?(:total_rows) end |