Class: Google::Apis::BigqueryV2::GetQueryResultsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Response object of GetQueryResults.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetQueryResultsResponse

Returns a new instance of GetQueryResultsResponse.



4174
4175
4176
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4174

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_hitBoolean Also known as: cache_hit?

Whether the query result was fetched from the query cache. Corresponds to the JSON property cacheHit

Returns:

  • (Boolean)


4102
4103
4104
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4102

def cache_hit
  @cache_hit
end

#errorsArray<Google::Apis::BigqueryV2::ErrorProto>

Output only. The first errors or warnings encountered during the running of the job. The final message includes the number of errors that caused the process to stop. Errors here do not necessarily mean that the job has completed or was unsuccessful. For more information about error messages, see Error messages. Corresponds to the JSON property errors



4112
4113
4114
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4112

def errors
  @errors
end

#etagString

A hash of this response. Corresponds to the JSON property etag

Returns:

  • (String)


4117
4118
4119
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4117

def etag
  @etag
end

#job_completeBoolean Also known as: job_complete?

Whether the query has completed or not. If rows or totalRows are present, this will always be true. If this is false, totalRows will not be available. Corresponds to the JSON property jobComplete

Returns:

  • (Boolean)


4123
4124
4125
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4123

def job_complete
  @job_complete
end

#job_referenceGoogle::Apis::BigqueryV2::JobReference

A job reference is a fully qualified identifier for referring to a job. Corresponds to the JSON property jobReference



4129
4130
4131
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4129

def job_reference
  @job_reference
end

#kindString

The resource type of the response. Corresponds to the JSON property kind

Returns:

  • (String)


4134
4135
4136
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4134

def kind
  @kind
end

#num_dml_affected_rowsFixnum

Output only. The number of rows affected by a DML statement. Present only for DML statements INSERT, UPDATE or DELETE. Corresponds to the JSON property numDmlAffectedRows

Returns:

  • (Fixnum)


4140
4141
4142
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4140

def num_dml_affected_rows
  @num_dml_affected_rows
end

#page_tokenString

A token used for paging results. When this token is non-empty, it indicates additional results are available. Corresponds to the JSON property pageToken

Returns:

  • (String)


4146
4147
4148
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4146

def page_token
  @page_token
end

#rowsArray<Google::Apis::BigqueryV2::TableRow>

An object with as many results as can be contained within the maximum permitted reply size. To get any additional rows, you can call GetQueryResults and specify the jobReference returned above. Present only when the query completes successfully. The REST-based representation of this data leverages a series of JSON f,v objects for indicating fields and values. Corresponds to the JSON property rows



4155
4156
4157
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4155

def rows
  @rows
end

#schemaGoogle::Apis::BigqueryV2::TableSchema

Schema of a table Corresponds to the JSON property schema



4160
4161
4162
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4160

def schema
  @schema
end

#total_bytes_processedFixnum

The total number of bytes processed for this query. Corresponds to the JSON property totalBytesProcessed

Returns:

  • (Fixnum)


4165
4166
4167
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4165

def total_bytes_processed
  @total_bytes_processed
end

#total_rowsFixnum

The total number of rows in the complete query result set, which can be more than the number of rows in this single page of results. Present only when the query completes successfully. Corresponds to the JSON property totalRows

Returns:

  • (Fixnum)


4172
4173
4174
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4172

def total_rows
  @total_rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4179

def update!(**args)
  @cache_hit = args[:cache_hit] if args.key?(:cache_hit)
  @errors = args[:errors] if args.key?(:errors)
  @etag = args[:etag] if args.key?(:etag)
  @job_complete = args[:job_complete] if args.key?(:job_complete)
  @job_reference = args[:job_reference] if args.key?(:job_reference)
  @kind = args[:kind] if args.key?(:kind)
  @num_dml_affected_rows = args[:num_dml_affected_rows] if args.key?(:num_dml_affected_rows)
  @page_token = args[:page_token] if args.key?(:page_token)
  @rows = args[:rows] if args.key?(:rows)
  @schema = args[:schema] if args.key?(:schema)
  @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed)
  @total_rows = args[:total_rows] if args.key?(:total_rows)
end