Class: Google::Apis::BigqueryV2::GetQueryResultsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Response object of GetQueryResults.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetQueryResultsResponse

Returns a new instance of GetQueryResultsResponse.



4100
4101
4102
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_hitBoolean Also known as: cache_hit?

Whether the query result was fetched from the query cache. Corresponds to the JSON property cacheHit

Returns:

  • (Boolean)


4028
4029
4030
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4028

def cache_hit
  @cache_hit
end

#errorsArray<Google::Apis::BigqueryV2::ErrorProto>

Output only. The first errors or warnings encountered during the running of the job. The final message includes the number of errors that caused the process to stop. Errors here do not necessarily mean that the job has completed or was unsuccessful. For more information about error messages, see Error messages. Corresponds to the JSON property errors



4038
4039
4040
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4038

def errors
  @errors
end

#etagString

A hash of this response. Corresponds to the JSON property etag

Returns:

  • (String)


4043
4044
4045
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4043

def etag
  @etag
end

#job_completeBoolean Also known as: job_complete?

Whether the query has completed or not. If rows or totalRows are present, this will always be true. If this is false, totalRows will not be available. Corresponds to the JSON property jobComplete

Returns:

  • (Boolean)


4049
4050
4051
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4049

def job_complete
  @job_complete
end

#job_referenceGoogle::Apis::BigqueryV2::JobReference

A job reference is a fully qualified identifier for referring to a job. Corresponds to the JSON property jobReference



4055
4056
4057
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4055

def job_reference
  @job_reference
end

#kindString

The resource type of the response. Corresponds to the JSON property kind

Returns:

  • (String)


4060
4061
4062
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4060

def kind
  @kind
end

#num_dml_affected_rowsFixnum

Output only. The number of rows affected by a DML statement. Present only for DML statements INSERT, UPDATE or DELETE. Corresponds to the JSON property numDmlAffectedRows

Returns:

  • (Fixnum)


4066
4067
4068
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4066

def num_dml_affected_rows
  @num_dml_affected_rows
end

#page_tokenString

A token used for paging results. When this token is non-empty, it indicates additional results are available. Corresponds to the JSON property pageToken

Returns:

  • (String)


4072
4073
4074
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4072

def page_token
  @page_token
end

#rowsArray<Google::Apis::BigqueryV2::TableRow>

An object with as many results as can be contained within the maximum permitted reply size. To get any additional rows, you can call GetQueryResults and specify the jobReference returned above. Present only when the query completes successfully. The REST-based representation of this data leverages a series of JSON f,v objects for indicating fields and values. Corresponds to the JSON property rows



4081
4082
4083
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4081

def rows
  @rows
end

#schemaGoogle::Apis::BigqueryV2::TableSchema

Schema of a table Corresponds to the JSON property schema



4086
4087
4088
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4086

def schema
  @schema
end

#total_bytes_processedFixnum

The total number of bytes processed for this query. Corresponds to the JSON property totalBytesProcessed

Returns:

  • (Fixnum)


4091
4092
4093
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4091

def total_bytes_processed
  @total_bytes_processed
end

#total_rowsFixnum

The total number of rows in the complete query result set, which can be more than the number of rows in this single page of results. Present only when the query completes successfully. Corresponds to the JSON property totalRows

Returns:

  • (Fixnum)


4098
4099
4100
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4098

def total_rows
  @total_rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
4118
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4105

def update!(**args)
  @cache_hit = args[:cache_hit] if args.key?(:cache_hit)
  @errors = args[:errors] if args.key?(:errors)
  @etag = args[:etag] if args.key?(:etag)
  @job_complete = args[:job_complete] if args.key?(:job_complete)
  @job_reference = args[:job_reference] if args.key?(:job_reference)
  @kind = args[:kind] if args.key?(:kind)
  @num_dml_affected_rows = args[:num_dml_affected_rows] if args.key?(:num_dml_affected_rows)
  @page_token = args[:page_token] if args.key?(:page_token)
  @rows = args[:rows] if args.key?(:rows)
  @schema = args[:schema] if args.key?(:schema)
  @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed)
  @total_rows = args[:total_rows] if args.key?(:total_rows)
end