Class: Google::Apis::BigqueryV2::GetQueryResultsResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::GetQueryResultsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Response object of GetQueryResults.
Instance Attribute Summary collapse
-
#cache_hit ⇒ Boolean
(also: #cache_hit?)
Whether the query result was fetched from the query cache.
-
#errors ⇒ Array<Google::Apis::BigqueryV2::ErrorProto>
Output only.
-
#etag ⇒ String
A hash of this response.
-
#job_complete ⇒ Boolean
(also: #job_complete?)
Whether the query has completed or not.
-
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
-
#kind ⇒ String
The resource type of the response.
-
#num_dml_affected_rows ⇒ Fixnum
Output only.
-
#page_token ⇒ String
A token used for paging results.
-
#rows ⇒ Array<Google::Apis::BigqueryV2::TableRow>
An object with as many results as can be contained within the maximum permitted reply size.
-
#schema ⇒ Google::Apis::BigqueryV2::TableSchema
Schema of a table Corresponds to the JSON property
schema. -
#total_bytes_processed ⇒ Fixnum
The total number of bytes processed for this query.
-
#total_rows ⇒ Fixnum
The total number of rows in the complete query result set, which can be more than the number of rows in this single page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetQueryResultsResponse
constructor
A new instance of GetQueryResultsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetQueryResultsResponse
Returns a new instance of GetQueryResultsResponse.
4045 4046 4047 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_hit ⇒ Boolean Also known as: cache_hit?
Whether the query result was fetched from the query cache.
Corresponds to the JSON property cacheHit
3973 3974 3975 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3973 def cache_hit @cache_hit end |
#errors ⇒ Array<Google::Apis::BigqueryV2::ErrorProto>
Output only. The first errors or warnings encountered during the running of
the job. The final message includes the number of errors that caused the
process to stop. Errors here do not necessarily mean that the job has
completed or was unsuccessful. For more information about error messages, see
Error messages.
Corresponds to the JSON property errors
3983 3984 3985 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3983 def errors @errors end |
#etag ⇒ String
A hash of this response.
Corresponds to the JSON property etag
3988 3989 3990 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3988 def etag @etag end |
#job_complete ⇒ Boolean Also known as: job_complete?
Whether the query has completed or not. If rows or totalRows are present, this
will always be true. If this is false, totalRows will not be available.
Corresponds to the JSON property jobComplete
3994 3995 3996 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 3994 def job_complete @job_complete end |
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
Corresponds to the JSON property jobReference
4000 4001 4002 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4000 def job_reference @job_reference end |
#kind ⇒ String
The resource type of the response.
Corresponds to the JSON property kind
4005 4006 4007 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4005 def kind @kind end |
#num_dml_affected_rows ⇒ Fixnum
Output only. The number of rows affected by a DML statement. Present only for
DML statements INSERT, UPDATE or DELETE.
Corresponds to the JSON property numDmlAffectedRows
4011 4012 4013 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4011 def num_dml_affected_rows @num_dml_affected_rows end |
#page_token ⇒ String
A token used for paging results. When this token is non-empty, it indicates
additional results are available.
Corresponds to the JSON property pageToken
4017 4018 4019 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4017 def page_token @page_token end |
#rows ⇒ Array<Google::Apis::BigqueryV2::TableRow>
An object with as many results as can be contained within the maximum
permitted reply size. To get any additional rows, you can call GetQueryResults
and specify the jobReference returned above. Present only when the query
completes successfully. The REST-based representation of this data leverages a
series of JSON f,v objects for indicating fields and values.
Corresponds to the JSON property rows
4026 4027 4028 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4026 def rows @rows end |
#schema ⇒ Google::Apis::BigqueryV2::TableSchema
Schema of a table
Corresponds to the JSON property schema
4031 4032 4033 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4031 def schema @schema end |
#total_bytes_processed ⇒ Fixnum
The total number of bytes processed for this query.
Corresponds to the JSON property totalBytesProcessed
4036 4037 4038 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4036 def total_bytes_processed @total_bytes_processed end |
#total_rows ⇒ Fixnum
The total number of rows in the complete query result set, which can be more
than the number of rows in this single page of results. Present only when the
query completes successfully.
Corresponds to the JSON property totalRows
4043 4044 4045 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4043 def total_rows @total_rows end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4050 4051 4052 4053 4054 4055 4056 4057 4058 4059 4060 4061 4062 4063 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4050 def update!(**args) @cache_hit = args[:cache_hit] if args.key?(:cache_hit) @errors = args[:errors] if args.key?(:errors) @etag = args[:etag] if args.key?(:etag) @job_complete = args[:job_complete] if args.key?(:job_complete) @job_reference = args[:job_reference] if args.key?(:job_reference) @kind = args[:kind] if args.key?(:kind) @num_dml_affected_rows = args[:num_dml_affected_rows] if args.key?(:num_dml_affected_rows) @page_token = args[:page_token] if args.key?(:page_token) @rows = args[:rows] if args.key?(:rows) @schema = args[:schema] if args.key?(:schema) @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed) @total_rows = args[:total_rows] if args.key?(:total_rows) end |