Class: Google::Apis::BigqueryV2::HparamTuningTrial
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::HparamTuningTrial
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Training info of a trial in hyperparameter tuning models.
Instance Attribute Summary collapse
-
#end_time_ms ⇒ Fixnum
Ending time of the trial.
-
#error_message ⇒ String
Error message for FAILED and INFEASIBLE trial.
-
#eval_loss ⇒ Float
Loss computed on the eval data at the end of trial.
-
#evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model.
-
#hparam_tuning_evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model.
-
#hparams ⇒ Google::Apis::BigqueryV2::TrainingOptions
Options used in model training.
-
#start_time_ms ⇒ Fixnum
Starting time of the trial.
-
#status ⇒ String
The status of the trial.
-
#training_loss ⇒ Float
Loss computed on the training data at the end of trial.
-
#trial_id ⇒ Fixnum
1-based index of the trial.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HparamTuningTrial
constructor
A new instance of HparamTuningTrial.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HparamTuningTrial
Returns a new instance of HparamTuningTrial.
4597 4598 4599 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4597 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time_ms ⇒ Fixnum
Ending time of the trial.
Corresponds to the JSON property endTimeMs
4546 4547 4548 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4546 def end_time_ms @end_time_ms end |
#error_message ⇒ String
Error message for FAILED and INFEASIBLE trial.
Corresponds to the JSON property errorMessage
4551 4552 4553 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4551 def @error_message end |
#eval_loss ⇒ Float
Loss computed on the eval data at the end of trial.
Corresponds to the JSON property evalLoss
4556 4557 4558 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4556 def eval_loss @eval_loss end |
#evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model. These are either computed on all training data
or just the eval data based on whether eval data was used during training.
These are not present for imported models.
Corresponds to the JSON property evaluationMetrics
4563 4564 4565 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4563 def evaluation_metrics @evaluation_metrics end |
#hparam_tuning_evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model. These are either computed on all training data
or just the eval data based on whether eval data was used during training.
These are not present for imported models.
Corresponds to the JSON property hparamTuningEvaluationMetrics
4570 4571 4572 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4570 def hparam_tuning_evaluation_metrics @hparam_tuning_evaluation_metrics end |
#hparams ⇒ Google::Apis::BigqueryV2::TrainingOptions
Options used in model training.
Corresponds to the JSON property hparams
4575 4576 4577 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4575 def hparams @hparams end |
#start_time_ms ⇒ Fixnum
Starting time of the trial.
Corresponds to the JSON property startTimeMs
4580 4581 4582 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4580 def start_time_ms @start_time_ms end |
#status ⇒ String
The status of the trial.
Corresponds to the JSON property status
4585 4586 4587 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4585 def status @status end |
#training_loss ⇒ Float
Loss computed on the training data at the end of trial.
Corresponds to the JSON property trainingLoss
4590 4591 4592 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4590 def training_loss @training_loss end |
#trial_id ⇒ Fixnum
1-based index of the trial.
Corresponds to the JSON property trialId
4595 4596 4597 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4595 def trial_id @trial_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 4613 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4602 def update!(**args) @end_time_ms = args[:end_time_ms] if args.key?(:end_time_ms) @error_message = args[:error_message] if args.key?(:error_message) @eval_loss = args[:eval_loss] if args.key?(:eval_loss) @evaluation_metrics = args[:evaluation_metrics] if args.key?(:evaluation_metrics) @hparam_tuning_evaluation_metrics = args[:hparam_tuning_evaluation_metrics] if args.key?(:hparam_tuning_evaluation_metrics) @hparams = args[:hparams] if args.key?(:hparams) @start_time_ms = args[:start_time_ms] if args.key?(:start_time_ms) @status = args[:status] if args.key?(:status) @training_loss = args[:training_loss] if args.key?(:training_loss) @trial_id = args[:trial_id] if args.key?(:trial_id) end |