Class: Google::Apis::BigqueryV2::HparamTuningTrial
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::HparamTuningTrial
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Training info of a trial in hyperparameter tuning models.
Instance Attribute Summary collapse
-
#end_time_ms ⇒ Fixnum
Ending time of the trial.
-
#error_message ⇒ String
Error message for FAILED and INFEASIBLE trial.
-
#eval_loss ⇒ Float
Loss computed on the eval data at the end of trial.
-
#evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model.
-
#hparam_tuning_evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model.
-
#hparams ⇒ Google::Apis::BigqueryV2::TrainingOptions
Options used in model training.
-
#start_time_ms ⇒ Fixnum
Starting time of the trial.
-
#status ⇒ String
The status of the trial.
-
#training_loss ⇒ Float
Loss computed on the training data at the end of trial.
-
#trial_id ⇒ Fixnum
1-based index of the trial.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HparamTuningTrial
constructor
A new instance of HparamTuningTrial.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HparamTuningTrial
Returns a new instance of HparamTuningTrial.
4517 4518 4519 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4517 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time_ms ⇒ Fixnum
Ending time of the trial.
Corresponds to the JSON property endTimeMs
4466 4467 4468 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4466 def end_time_ms @end_time_ms end |
#error_message ⇒ String
Error message for FAILED and INFEASIBLE trial.
Corresponds to the JSON property errorMessage
4471 4472 4473 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4471 def @error_message end |
#eval_loss ⇒ Float
Loss computed on the eval data at the end of trial.
Corresponds to the JSON property evalLoss
4476 4477 4478 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4476 def eval_loss @eval_loss end |
#evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model. These are either computed on all training data
or just the eval data based on whether eval data was used during training.
These are not present for imported models.
Corresponds to the JSON property evaluationMetrics
4483 4484 4485 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4483 def evaluation_metrics @evaluation_metrics end |
#hparam_tuning_evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model. These are either computed on all training data
or just the eval data based on whether eval data was used during training.
These are not present for imported models.
Corresponds to the JSON property hparamTuningEvaluationMetrics
4490 4491 4492 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4490 def hparam_tuning_evaluation_metrics @hparam_tuning_evaluation_metrics end |
#hparams ⇒ Google::Apis::BigqueryV2::TrainingOptions
Options used in model training.
Corresponds to the JSON property hparams
4495 4496 4497 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4495 def hparams @hparams end |
#start_time_ms ⇒ Fixnum
Starting time of the trial.
Corresponds to the JSON property startTimeMs
4500 4501 4502 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4500 def start_time_ms @start_time_ms end |
#status ⇒ String
The status of the trial.
Corresponds to the JSON property status
4505 4506 4507 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4505 def status @status end |
#training_loss ⇒ Float
Loss computed on the training data at the end of trial.
Corresponds to the JSON property trainingLoss
4510 4511 4512 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4510 def training_loss @training_loss end |
#trial_id ⇒ Fixnum
1-based index of the trial.
Corresponds to the JSON property trialId
4515 4516 4517 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4515 def trial_id @trial_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 4532 4533 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4522 def update!(**args) @end_time_ms = args[:end_time_ms] if args.key?(:end_time_ms) @error_message = args[:error_message] if args.key?(:error_message) @eval_loss = args[:eval_loss] if args.key?(:eval_loss) @evaluation_metrics = args[:evaluation_metrics] if args.key?(:evaluation_metrics) @hparam_tuning_evaluation_metrics = args[:hparam_tuning_evaluation_metrics] if args.key?(:hparam_tuning_evaluation_metrics) @hparams = args[:hparams] if args.key?(:hparams) @start_time_ms = args[:start_time_ms] if args.key?(:start_time_ms) @status = args[:status] if args.key?(:status) @training_loss = args[:training_loss] if args.key?(:training_loss) @trial_id = args[:trial_id] if args.key?(:trial_id) end |