Class: Google::Apis::BigqueryV2::HparamTuningTrial
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::HparamTuningTrial
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Training info of a trial in hyperparameter tuning models.
Instance Attribute Summary collapse
-
#end_time_ms ⇒ Fixnum
Ending time of the trial.
-
#error_message ⇒ String
Error message for FAILED and INFEASIBLE trial.
-
#eval_loss ⇒ Float
Loss computed on the eval data at the end of trial.
-
#evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model.
-
#hparam_tuning_evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model.
-
#hparams ⇒ Google::Apis::BigqueryV2::TrainingOptions
Options used in model training.
-
#start_time_ms ⇒ Fixnum
Starting time of the trial.
-
#status ⇒ String
The status of the trial.
-
#training_loss ⇒ Float
Loss computed on the training data at the end of trial.
-
#trial_id ⇒ Fixnum
1-based index of the trial.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HparamTuningTrial
constructor
A new instance of HparamTuningTrial.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HparamTuningTrial
Returns a new instance of HparamTuningTrial.
4516 4517 4518 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time_ms ⇒ Fixnum
Ending time of the trial.
Corresponds to the JSON property endTimeMs
4465 4466 4467 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4465 def end_time_ms @end_time_ms end |
#error_message ⇒ String
Error message for FAILED and INFEASIBLE trial.
Corresponds to the JSON property errorMessage
4470 4471 4472 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4470 def @error_message end |
#eval_loss ⇒ Float
Loss computed on the eval data at the end of trial.
Corresponds to the JSON property evalLoss
4475 4476 4477 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4475 def eval_loss @eval_loss end |
#evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model. These are either computed on all training data
or just the eval data based on whether eval data was used during training.
These are not present for imported models.
Corresponds to the JSON property evaluationMetrics
4482 4483 4484 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4482 def evaluation_metrics @evaluation_metrics end |
#hparam_tuning_evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model. These are either computed on all training data
or just the eval data based on whether eval data was used during training.
These are not present for imported models.
Corresponds to the JSON property hparamTuningEvaluationMetrics
4489 4490 4491 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4489 def hparam_tuning_evaluation_metrics @hparam_tuning_evaluation_metrics end |
#hparams ⇒ Google::Apis::BigqueryV2::TrainingOptions
Options used in model training.
Corresponds to the JSON property hparams
4494 4495 4496 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4494 def hparams @hparams end |
#start_time_ms ⇒ Fixnum
Starting time of the trial.
Corresponds to the JSON property startTimeMs
4499 4500 4501 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4499 def start_time_ms @start_time_ms end |
#status ⇒ String
The status of the trial.
Corresponds to the JSON property status
4504 4505 4506 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4504 def status @status end |
#training_loss ⇒ Float
Loss computed on the training data at the end of trial.
Corresponds to the JSON property trainingLoss
4509 4510 4511 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4509 def training_loss @training_loss end |
#trial_id ⇒ Fixnum
1-based index of the trial.
Corresponds to the JSON property trialId
4514 4515 4516 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4514 def trial_id @trial_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 4532 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4521 def update!(**args) @end_time_ms = args[:end_time_ms] if args.key?(:end_time_ms) @error_message = args[:error_message] if args.key?(:error_message) @eval_loss = args[:eval_loss] if args.key?(:eval_loss) @evaluation_metrics = args[:evaluation_metrics] if args.key?(:evaluation_metrics) @hparam_tuning_evaluation_metrics = args[:hparam_tuning_evaluation_metrics] if args.key?(:hparam_tuning_evaluation_metrics) @hparams = args[:hparams] if args.key?(:hparams) @start_time_ms = args[:start_time_ms] if args.key?(:start_time_ms) @status = args[:status] if args.key?(:status) @training_loss = args[:training_loss] if args.key?(:training_loss) @trial_id = args[:trial_id] if args.key?(:trial_id) end |