Class: Google::Apis::BigqueryV2::HparamTuningTrial

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Training info of a trial in hyperparameter tuning models.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HparamTuningTrial

Returns a new instance of HparamTuningTrial.



4462
4463
4464
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_time_msFixnum

Ending time of the trial. Corresponds to the JSON property endTimeMs

Returns:

  • (Fixnum)


4411
4412
4413
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4411

def end_time_ms
  @end_time_ms
end

#error_messageString

Error message for FAILED and INFEASIBLE trial. Corresponds to the JSON property errorMessage

Returns:

  • (String)


4416
4417
4418
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4416

def error_message
  @error_message
end

#eval_lossFloat

Loss computed on the eval data at the end of trial. Corresponds to the JSON property evalLoss

Returns:

  • (Float)


4421
4422
4423
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4421

def eval_loss
  @eval_loss
end

#evaluation_metricsGoogle::Apis::BigqueryV2::EvaluationMetrics

Evaluation metrics of a model. These are either computed on all training data or just the eval data based on whether eval data was used during training. These are not present for imported models. Corresponds to the JSON property evaluationMetrics



4428
4429
4430
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4428

def evaluation_metrics
  @evaluation_metrics
end

#hparam_tuning_evaluation_metricsGoogle::Apis::BigqueryV2::EvaluationMetrics

Evaluation metrics of a model. These are either computed on all training data or just the eval data based on whether eval data was used during training. These are not present for imported models. Corresponds to the JSON property hparamTuningEvaluationMetrics



4435
4436
4437
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4435

def hparam_tuning_evaluation_metrics
  @hparam_tuning_evaluation_metrics
end

#hparamsGoogle::Apis::BigqueryV2::TrainingOptions

Options used in model training. Corresponds to the JSON property hparams



4440
4441
4442
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4440

def hparams
  @hparams
end

#start_time_msFixnum

Starting time of the trial. Corresponds to the JSON property startTimeMs

Returns:

  • (Fixnum)


4445
4446
4447
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4445

def start_time_ms
  @start_time_ms
end

#statusString

The status of the trial. Corresponds to the JSON property status

Returns:

  • (String)


4450
4451
4452
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4450

def status
  @status
end

#training_lossFloat

Loss computed on the training data at the end of trial. Corresponds to the JSON property trainingLoss

Returns:

  • (Float)


4455
4456
4457
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4455

def training_loss
  @training_loss
end

#trial_idFixnum

1-based index of the trial. Corresponds to the JSON property trialId

Returns:

  • (Fixnum)


4460
4461
4462
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4460

def trial_id
  @trial_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4467
4468
4469
4470
4471
4472
4473
4474
4475
4476
4477
4478
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4467

def update!(**args)
  @end_time_ms = args[:end_time_ms] if args.key?(:end_time_ms)
  @error_message = args[:error_message] if args.key?(:error_message)
  @eval_loss = args[:eval_loss] if args.key?(:eval_loss)
  @evaluation_metrics = args[:evaluation_metrics] if args.key?(:evaluation_metrics)
  @hparam_tuning_evaluation_metrics = args[:hparam_tuning_evaluation_metrics] if args.key?(:hparam_tuning_evaluation_metrics)
  @hparams = args[:hparams] if args.key?(:hparams)
  @start_time_ms = args[:start_time_ms] if args.key?(:start_time_ms)
  @status = args[:status] if args.key?(:status)
  @training_loss = args[:training_loss] if args.key?(:training_loss)
  @trial_id = args[:trial_id] if args.key?(:trial_id)
end