Class: Google::Apis::BigqueryV2::IncrementalResultStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics related to Incremental Query Results. Populated as part of JobStatistics2. This feature is not yet available.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IncrementalResultStats

Returns a new instance of IncrementalResultStats.



4583
4584
4585
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabled_reasonString

Output only. Reason why incremental query results are/were not written by the query. Corresponds to the JSON property disabledReason

Returns:

  • (String)


4544
4545
4546
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4544

def disabled_reason
  @disabled_reason
end

#disabled_reason_detailsString

Output only. Additional human-readable clarification, if available, for DisabledReason. Corresponds to the JSON property disabledReasonDetails

Returns:

  • (String)


4550
4551
4552
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4550

def disabled_reason_details
  @disabled_reason_details
end

#first_incremental_row_timeString

Output only. The time at which the first incremental result was written. If the query needed to restart internally, this only describes the final attempt. Corresponds to the JSON property firstIncrementalRowTime

Returns:

  • (String)


4556
4557
4558
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4556

def first_incremental_row_time
  @first_incremental_row_time
end

#incremental_row_countFixnum

Output only. Number of rows that were in the latest result set before query completion. Corresponds to the JSON property incrementalRowCount

Returns:

  • (Fixnum)


4562
4563
4564
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4562

def incremental_row_count
  @incremental_row_count
end

#last_incremental_row_timeString

Output only. The time at which the last incremental result was written. Does not include the final result written after query completion. Corresponds to the JSON property lastIncrementalRowTime

Returns:

  • (String)


4568
4569
4570
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4568

def last_incremental_row_time
  @last_incremental_row_time
end

#result_set_last_modify_timeString

Output only. The time at which the result table's contents were modified. May be absent if no results have been written or the query has completed. Corresponds to the JSON property resultSetLastModifyTime

Returns:

  • (String)


4574
4575
4576
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4574

def result_set_last_modify_time
  @result_set_last_modify_time
end

#result_set_last_replace_timeString

Output only. The time at which the result table's contents were completely replaced. May be absent if no results have been written or the query has completed. Corresponds to the JSON property resultSetLastReplaceTime

Returns:

  • (String)


4581
4582
4583
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4581

def result_set_last_replace_time
  @result_set_last_replace_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4588
4589
4590
4591
4592
4593
4594
4595
4596
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4588

def update!(**args)
  @disabled_reason = args[:disabled_reason] if args.key?(:disabled_reason)
  @disabled_reason_details = args[:disabled_reason_details] if args.key?(:disabled_reason_details)
  @first_incremental_row_time = args[:first_incremental_row_time] if args.key?(:first_incremental_row_time)
  @incremental_row_count = args[:incremental_row_count] if args.key?(:incremental_row_count)
  @last_incremental_row_time = args[:last_incremental_row_time] if args.key?(:last_incremental_row_time)
  @result_set_last_modify_time = args[:result_set_last_modify_time] if args.key?(:result_set_last_modify_time)
  @result_set_last_replace_time = args[:result_set_last_replace_time] if args.key?(:result_set_last_replace_time)
end