Class: Google::Apis::BigqueryV2::IncrementalResultStats
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::IncrementalResultStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Statistics related to Incremental Query Results. Populated as part of JobStatistics2. This feature is not yet available.
Instance Attribute Summary collapse
-
#disabled_reason ⇒ String
Output only.
-
#disabled_reason_details ⇒ String
Output only.
-
#first_incremental_row_time ⇒ String
Output only.
-
#incremental_row_count ⇒ Fixnum
Output only.
-
#last_incremental_row_time ⇒ String
Output only.
-
#result_set_last_modify_time ⇒ String
Output only.
-
#result_set_last_replace_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IncrementalResultStats
constructor
A new instance of IncrementalResultStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IncrementalResultStats
Returns a new instance of IncrementalResultStats.
4289 4290 4291 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disabled_reason ⇒ String
Output only. Reason why incremental query results are/were not written by the
query.
Corresponds to the JSON property disabledReason
4250 4251 4252 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4250 def disabled_reason @disabled_reason end |
#disabled_reason_details ⇒ String
Output only. Additional human-readable clarification, if available, for
DisabledReason.
Corresponds to the JSON property disabledReasonDetails
4256 4257 4258 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4256 def disabled_reason_details @disabled_reason_details end |
#first_incremental_row_time ⇒ String
Output only. The time at which the first incremental result was written. If
the query needed to restart internally, this only describes the final attempt.
Corresponds to the JSON property firstIncrementalRowTime
4262 4263 4264 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4262 def first_incremental_row_time @first_incremental_row_time end |
#incremental_row_count ⇒ Fixnum
Output only. Number of rows that were in the latest result set before query
completion.
Corresponds to the JSON property incrementalRowCount
4268 4269 4270 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4268 def incremental_row_count @incremental_row_count end |
#last_incremental_row_time ⇒ String
Output only. The time at which the last incremental result was written. Does
not include the final result written after query completion.
Corresponds to the JSON property lastIncrementalRowTime
4274 4275 4276 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4274 def last_incremental_row_time @last_incremental_row_time end |
#result_set_last_modify_time ⇒ String
Output only. The time at which the result table's contents were modified. May
be absent if no results have been written or the query has completed.
Corresponds to the JSON property resultSetLastModifyTime
4280 4281 4282 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4280 def result_set_last_modify_time @result_set_last_modify_time end |
#result_set_last_replace_time ⇒ String
Output only. The time at which the result table's contents were completely
replaced. May be absent if no results have been written or the query has
completed.
Corresponds to the JSON property resultSetLastReplaceTime
4287 4288 4289 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4287 def result_set_last_replace_time @result_set_last_replace_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4294 4295 4296 4297 4298 4299 4300 4301 4302 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4294 def update!(**args) @disabled_reason = args[:disabled_reason] if args.key?(:disabled_reason) @disabled_reason_details = args[:disabled_reason_details] if args.key?(:disabled_reason_details) @first_incremental_row_time = args[:first_incremental_row_time] if args.key?(:first_incremental_row_time) @incremental_row_count = args[:incremental_row_count] if args.key?(:incremental_row_count) @last_incremental_row_time = args[:last_incremental_row_time] if args.key?(:last_incremental_row_time) @result_set_last_modify_time = args[:result_set_last_modify_time] if args.key?(:result_set_last_modify_time) @result_set_last_replace_time = args[:result_set_last_replace_time] if args.key?(:result_set_last_replace_time) end |