Class: Google::Apis::BigqueryV2::IncrementalResultStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics related to Incremental Query Results. Populated as part of JobStatistics2. This feature is not yet available.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IncrementalResultStats

Returns a new instance of IncrementalResultStats.



4263
4264
4265
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4263

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabled_reasonString

Reason why incremental query results are/were not written by the query. Corresponds to the JSON property disabledReason

Returns:

  • (String)


4249
4250
4251
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4249

def disabled_reason
  @disabled_reason
end

#result_set_last_modify_timeString

The time at which the result table's contents were modified. May be absent if no results have been written or the query has completed. Corresponds to the JSON property resultSetLastModifyTime

Returns:

  • (String)


4255
4256
4257
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4255

def result_set_last_modify_time
  @result_set_last_modify_time
end

#result_set_last_replace_timeString

The time at which the result table's contents were completely replaced. May be absent if no results have been written or the query has completed. Corresponds to the JSON property resultSetLastReplaceTime

Returns:

  • (String)


4261
4262
4263
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4261

def result_set_last_replace_time
  @result_set_last_replace_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4268
4269
4270
4271
4272
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4268

def update!(**args)
  @disabled_reason = args[:disabled_reason] if args.key?(:disabled_reason)
  @result_set_last_modify_time = args[:result_set_last_modify_time] if args.key?(:result_set_last_modify_time)
  @result_set_last_replace_time = args[:result_set_last_replace_time] if args.key?(:result_set_last_replace_time)
end