Class: Google::Apis::BigqueryV2::IndexUnusedReason

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Reason about why no search index was used in the search query (or sub-query).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IndexUnusedReason

Returns a new instance of IndexUnusedReason.



4660
4661
4662
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4660

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#base_tableGoogle::Apis::BigqueryV2::TableReference

Specifies the base table involved in the reason that no search index was used. Corresponds to the JSON property baseTable



4643
4644
4645
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4643

def base_table
  @base_table
end

#codeString

Specifies the high-level reason for the scenario when no search index was used. Corresponds to the JSON property code

Returns:

  • (String)


4648
4649
4650
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4648

def code
  @code
end

#index_nameString

Specifies the name of the unused search index, if available. Corresponds to the JSON property indexName

Returns:

  • (String)


4653
4654
4655
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4653

def index_name
  @index_name
end

#messageString

Free form human-readable reason for the scenario when no search index was used. Corresponds to the JSON property message

Returns:

  • (String)


4658
4659
4660
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4658

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4665
4666
4667
4668
4669
4670
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4665

def update!(**args)
  @base_table = args[:base_table] if args.key?(:base_table)
  @code = args[:code] if args.key?(:code)
  @index_name = args[:index_name] if args.key?(:index_name)
  @message = args[:message] if args.key?(:message)
end