Class: Google::Apis::BigqueryV2::InsertAllTableDataRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Request for sending a single streaming insert.

Defined Under Namespace

Classes: Row

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertAllTableDataRequest

Returns a new instance of InsertAllTableDataRequest.



11244
11245
11246
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ignore_unknown_valuesBoolean Also known as: ignore_unknown_values?

Optional. Accept rows that contain values that do not match the schema. The unknown values are ignored. Default is false, which treats unknown values as errors. Corresponds to the JSON property ignoreUnknownValues

Returns:

  • (Boolean)


11206
11207
11208
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11206

def ignore_unknown_values
  @ignore_unknown_values
end

#kindString

Optional. The resource type of the response. The value is not checked at the backend. Historically, it has been set to "bigquery#tableDataInsertAllRequest" but you are not required to set it. Corresponds to the JSON property kind

Returns:

  • (String)


11214
11215
11216
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11214

def kind
  @kind
end

#rowsArray<Google::Apis::BigqueryV2::InsertAllTableDataRequest::Row>

Corresponds to the JSON property rows



11219
11220
11221
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11219

def rows
  @rows
end

#skip_invalid_rowsBoolean Also known as: skip_invalid_rows?

Optional. Insert all valid rows of a request, even if invalid rows exist. The default value is false, which causes the entire request to fail if any invalid rows exist. Corresponds to the JSON property skipInvalidRows

Returns:

  • (Boolean)


11226
11227
11228
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11226

def skip_invalid_rows
  @skip_invalid_rows
end

#template_suffixString

Optional. If specified, treats the destination table as a base template, and inserts the rows into an instance table named "destinationtemplateSuffix". BigQuery will manage creation of the instance table, using the schema of the base template table. See https://cloud.google.com/bigquery/streaming-data-into- bigquery#template-tables for considerations when working with templates tables. Corresponds to the JSON property templateSuffix

Returns:

  • (String)


11236
11237
11238
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11236

def template_suffix
  @template_suffix
end

#trace_idString

Optional. Unique request trace id. Used for debugging purposes only. It is case-sensitive, limited to up to 36 ASCII characters. A UUID is recommended. Corresponds to the JSON property traceId

Returns:

  • (String)


11242
11243
11244
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11242

def trace_id
  @trace_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11249
11250
11251
11252
11253
11254
11255
11256
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11249

def update!(**args)
  @ignore_unknown_values = args[:ignore_unknown_values] if args.key?(:ignore_unknown_values)
  @kind = args[:kind] if args.key?(:kind)
  @rows = args[:rows] if args.key?(:rows)
  @skip_invalid_rows = args[:skip_invalid_rows] if args.key?(:skip_invalid_rows)
  @template_suffix = args[:template_suffix] if args.key?(:template_suffix)
  @trace_id = args[:trace_id] if args.key?(:trace_id)
end