Class: Google::Apis::BigqueryV2::InsertAllTableDataRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::InsertAllTableDataRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Request for sending a single streaming insert.
Defined Under Namespace
Classes: Row
Instance Attribute Summary collapse
-
#ignore_unknown_values ⇒ Boolean
(also: #ignore_unknown_values?)
Optional.
-
#kind ⇒ String
Optional.
-
#rows ⇒ Array<Google::Apis::BigqueryV2::InsertAllTableDataRequest::Row>
Corresponds to the JSON property
rows. -
#skip_invalid_rows ⇒ Boolean
(also: #skip_invalid_rows?)
Optional.
-
#template_suffix ⇒ String
Optional.
-
#trace_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsertAllTableDataRequest
constructor
A new instance of InsertAllTableDataRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InsertAllTableDataRequest
Returns a new instance of InsertAllTableDataRequest.
10565 10566 10567 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ignore_unknown_values ⇒ Boolean Also known as: ignore_unknown_values?
Optional. Accept rows that contain values that do not match the schema. The
unknown values are ignored. Default is false, which treats unknown values as
errors.
Corresponds to the JSON property ignoreUnknownValues
10527 10528 10529 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10527 def ignore_unknown_values @ignore_unknown_values end |
#kind ⇒ String
Optional. The resource type of the response. The value is not checked at the
backend. Historically, it has been set to "bigquery#tableDataInsertAllRequest"
but you are not required to set it.
Corresponds to the JSON property kind
10535 10536 10537 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10535 def kind @kind end |
#rows ⇒ Array<Google::Apis::BigqueryV2::InsertAllTableDataRequest::Row>
Corresponds to the JSON property rows
10540 10541 10542 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10540 def rows @rows end |
#skip_invalid_rows ⇒ Boolean Also known as: skip_invalid_rows?
Optional. Insert all valid rows of a request, even if invalid rows exist. The
default value is false, which causes the entire request to fail if any invalid
rows exist.
Corresponds to the JSON property skipInvalidRows
10547 10548 10549 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10547 def skip_invalid_rows @skip_invalid_rows end |
#template_suffix ⇒ String
Optional. If specified, treats the destination table as a base template, and
inserts the rows into an instance table named "destinationtemplateSuffix".
BigQuery will manage creation of the instance table, using the schema of the
base template table. See https://cloud.google.com/bigquery/streaming-data-into-
bigquery#template-tables for considerations when working with templates tables.
Corresponds to the JSON property templateSuffix
10557 10558 10559 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10557 def template_suffix @template_suffix end |
#trace_id ⇒ String
Optional. Unique request trace id. Used for debugging purposes only. It is
case-sensitive, limited to up to 36 ASCII characters. A UUID is recommended.
Corresponds to the JSON property traceId
10563 10564 10565 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10563 def trace_id @trace_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10570 10571 10572 10573 10574 10575 10576 10577 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10570 def update!(**args) @ignore_unknown_values = args[:ignore_unknown_values] if args.key?(:ignore_unknown_values) @kind = args[:kind] if args.key?(:kind) @rows = args[:rows] if args.key?(:rows) @skip_invalid_rows = args[:skip_invalid_rows] if args.key?(:skip_invalid_rows) @template_suffix = args[:template_suffix] if args.key?(:template_suffix) @trace_id = args[:trace_id] if args.key?(:trace_id) end |