Class: Google::Apis::BigqueryV2::InsertAllTableDataRequest::Row

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Data for a single insertion row.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Row

Returns a new instance of Row.



11089
11090
11091
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#insert_idString

Insertion ID for best-effort deduplication. This feature is not recommended, and users seeking stronger insertion semantics are encouraged to use other mechanisms such as the BigQuery Write API. Corresponds to the JSON property insertId

Returns:

  • (String)


11082
11083
11084
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11082

def insert_id
  @insert_id
end

#jsonHash<String,Object>

Represents a single JSON object. Corresponds to the JSON property json

Returns:

  • (Hash<String,Object>)


11087
11088
11089
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11087

def json
  @json
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11094
11095
11096
11097
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11094

def update!(**args)
  @insert_id = args[:insert_id] if args.key?(:insert_id)
  @json = args[:json] if args.key?(:json)
end