Class: Google::Apis::BigqueryV2::IterationResult
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::IterationResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Information about a single iteration of the training run.
Instance Attribute Summary collapse
-
#arima_result ⇒ Google::Apis::BigqueryV2::ArimaResult
(Auto-)arima fitting result.
-
#cluster_infos ⇒ Array<Google::Apis::BigqueryV2::ClusterInfo>
Information about top clusters for clustering models.
-
#duration_ms ⇒ Fixnum
Time taken to run the iteration in milliseconds.
-
#eval_loss ⇒ Float
Loss computed on the eval data at the end of iteration.
-
#index ⇒ Fixnum
Index of the iteration, 0 based.
-
#learn_rate ⇒ Float
Learn rate used for this iteration.
-
#principal_component_infos ⇒ Array<Google::Apis::BigqueryV2::PrincipalComponentInfo>
The information of the principal components.
-
#training_loss ⇒ Float
Loss computed on the training data at the end of iteration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IterationResult
constructor
A new instance of IterationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IterationResult
Returns a new instance of IterationResult.
4845 4846 4847 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4845 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arima_result ⇒ Google::Apis::BigqueryV2::ArimaResult
(Auto-)arima fitting result. Wrap everything in ArimaResult for easier
refactoring if we want to use model-specific iteration results.
Corresponds to the JSON property arimaResult
4808 4809 4810 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4808 def arima_result @arima_result end |
#cluster_infos ⇒ Array<Google::Apis::BigqueryV2::ClusterInfo>
Information about top clusters for clustering models.
Corresponds to the JSON property clusterInfos
4813 4814 4815 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4813 def cluster_infos @cluster_infos end |
#duration_ms ⇒ Fixnum
Time taken to run the iteration in milliseconds.
Corresponds to the JSON property durationMs
4818 4819 4820 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4818 def duration_ms @duration_ms end |
#eval_loss ⇒ Float
Loss computed on the eval data at the end of iteration.
Corresponds to the JSON property evalLoss
4823 4824 4825 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4823 def eval_loss @eval_loss end |
#index ⇒ Fixnum
Index of the iteration, 0 based.
Corresponds to the JSON property index
4828 4829 4830 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4828 def index @index end |
#learn_rate ⇒ Float
Learn rate used for this iteration.
Corresponds to the JSON property learnRate
4833 4834 4835 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4833 def learn_rate @learn_rate end |
#principal_component_infos ⇒ Array<Google::Apis::BigqueryV2::PrincipalComponentInfo>
The information of the principal components.
Corresponds to the JSON property principalComponentInfos
4838 4839 4840 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4838 def principal_component_infos @principal_component_infos end |
#training_loss ⇒ Float
Loss computed on the training data at the end of iteration.
Corresponds to the JSON property trainingLoss
4843 4844 4845 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4843 def training_loss @training_loss end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4850 4851 4852 4853 4854 4855 4856 4857 4858 4859 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4850 def update!(**args) @arima_result = args[:arima_result] if args.key?(:arima_result) @cluster_infos = args[:cluster_infos] if args.key?(:cluster_infos) @duration_ms = args[:duration_ms] if args.key?(:duration_ms) @eval_loss = args[:eval_loss] if args.key?(:eval_loss) @index = args[:index] if args.key?(:index) @learn_rate = args[:learn_rate] if args.key?(:learn_rate) @principal_component_infos = args[:principal_component_infos] if args.key?(:principal_component_infos) @training_loss = args[:training_loss] if args.key?(:training_loss) end |