Class: Google::Apis::BigqueryV2::IterationResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Information about a single iteration of the training run.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IterationResult

Returns a new instance of IterationResult.



4844
4845
4846
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4844

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arima_resultGoogle::Apis::BigqueryV2::ArimaResult

(Auto-)arima fitting result. Wrap everything in ArimaResult for easier refactoring if we want to use model-specific iteration results. Corresponds to the JSON property arimaResult



4807
4808
4809
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4807

def arima_result
  @arima_result
end

#cluster_infosArray<Google::Apis::BigqueryV2::ClusterInfo>

Information about top clusters for clustering models. Corresponds to the JSON property clusterInfos



4812
4813
4814
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4812

def cluster_infos
  @cluster_infos
end

#duration_msFixnum

Time taken to run the iteration in milliseconds. Corresponds to the JSON property durationMs

Returns:

  • (Fixnum)


4817
4818
4819
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4817

def duration_ms
  @duration_ms
end

#eval_lossFloat

Loss computed on the eval data at the end of iteration. Corresponds to the JSON property evalLoss

Returns:

  • (Float)


4822
4823
4824
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4822

def eval_loss
  @eval_loss
end

#indexFixnum

Index of the iteration, 0 based. Corresponds to the JSON property index

Returns:

  • (Fixnum)


4827
4828
4829
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4827

def index
  @index
end

#learn_rateFloat

Learn rate used for this iteration. Corresponds to the JSON property learnRate

Returns:

  • (Float)


4832
4833
4834
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4832

def learn_rate
  @learn_rate
end

#principal_component_infosArray<Google::Apis::BigqueryV2::PrincipalComponentInfo>

The information of the principal components. Corresponds to the JSON property principalComponentInfos



4837
4838
4839
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4837

def principal_component_infos
  @principal_component_infos
end

#training_lossFloat

Loss computed on the training data at the end of iteration. Corresponds to the JSON property trainingLoss

Returns:

  • (Float)


4842
4843
4844
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4842

def training_loss
  @training_loss
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4849
4850
4851
4852
4853
4854
4855
4856
4857
4858
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4849

def update!(**args)
  @arima_result = args[:arima_result] if args.key?(:arima_result)
  @cluster_infos = args[:cluster_infos] if args.key?(:cluster_infos)
  @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
  @eval_loss = args[:eval_loss] if args.key?(:eval_loss)
  @index = args[:index] if args.key?(:index)
  @learn_rate = args[:learn_rate] if args.key?(:learn_rate)
  @principal_component_infos = args[:principal_component_infos] if args.key?(:principal_component_infos)
  @training_loss = args[:training_loss] if args.key?(:training_loss)
end