Class: Google::Apis::BigqueryV2::IterationResult
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::IterationResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Information about a single iteration of the training run.
Instance Attribute Summary collapse
-
#arima_result ⇒ Google::Apis::BigqueryV2::ArimaResult
(Auto-)arima fitting result.
-
#cluster_infos ⇒ Array<Google::Apis::BigqueryV2::ClusterInfo>
Information about top clusters for clustering models.
-
#duration_ms ⇒ Fixnum
Time taken to run the iteration in milliseconds.
-
#eval_loss ⇒ Float
Loss computed on the eval data at the end of iteration.
-
#index ⇒ Fixnum
Index of the iteration, 0 based.
-
#learn_rate ⇒ Float
Learn rate used for this iteration.
-
#principal_component_infos ⇒ Array<Google::Apis::BigqueryV2::PrincipalComponentInfo>
The information of the principal components.
-
#training_loss ⇒ Float
Loss computed on the training data at the end of iteration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IterationResult
constructor
A new instance of IterationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IterationResult
Returns a new instance of IterationResult.
4520 4521 4522 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4520 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arima_result ⇒ Google::Apis::BigqueryV2::ArimaResult
(Auto-)arima fitting result. Wrap everything in ArimaResult for easier
refactoring if we want to use model-specific iteration results.
Corresponds to the JSON property arimaResult
4483 4484 4485 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4483 def arima_result @arima_result end |
#cluster_infos ⇒ Array<Google::Apis::BigqueryV2::ClusterInfo>
Information about top clusters for clustering models.
Corresponds to the JSON property clusterInfos
4488 4489 4490 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4488 def cluster_infos @cluster_infos end |
#duration_ms ⇒ Fixnum
Time taken to run the iteration in milliseconds.
Corresponds to the JSON property durationMs
4493 4494 4495 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4493 def duration_ms @duration_ms end |
#eval_loss ⇒ Float
Loss computed on the eval data at the end of iteration.
Corresponds to the JSON property evalLoss
4498 4499 4500 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4498 def eval_loss @eval_loss end |
#index ⇒ Fixnum
Index of the iteration, 0 based.
Corresponds to the JSON property index
4503 4504 4505 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4503 def index @index end |
#learn_rate ⇒ Float
Learn rate used for this iteration.
Corresponds to the JSON property learnRate
4508 4509 4510 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4508 def learn_rate @learn_rate end |
#principal_component_infos ⇒ Array<Google::Apis::BigqueryV2::PrincipalComponentInfo>
The information of the principal components.
Corresponds to the JSON property principalComponentInfos
4513 4514 4515 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4513 def principal_component_infos @principal_component_infos end |
#training_loss ⇒ Float
Loss computed on the training data at the end of iteration.
Corresponds to the JSON property trainingLoss
4518 4519 4520 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4518 def training_loss @training_loss end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4525 4526 4527 4528 4529 4530 4531 4532 4533 4534 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4525 def update!(**args) @arima_result = args[:arima_result] if args.key?(:arima_result) @cluster_infos = args[:cluster_infos] if args.key?(:cluster_infos) @duration_ms = args[:duration_ms] if args.key?(:duration_ms) @eval_loss = args[:eval_loss] if args.key?(:eval_loss) @index = args[:index] if args.key?(:index) @learn_rate = args[:learn_rate] if args.key?(:learn_rate) @principal_component_infos = args[:principal_component_infos] if args.key?(:principal_component_infos) @training_loss = args[:training_loss] if args.key?(:training_loss) end |