Class: Google::Apis::BigqueryV2::Job
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Instance Attribute Summary collapse
-
#configuration ⇒ Google::Apis::BigqueryV2::JobConfiguration
Required.
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#job_creation_reason ⇒ Google::Apis::BigqueryV2::JobCreationReason
Reason about why a Job was created from a
jobs.querymethod when used withJOB_CREATION_OPTIONALJob creation mode. -
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
-
#kind ⇒ String
Output only.
-
#principal_subject ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#statistics ⇒ Google::Apis::BigqueryV2::JobStatistics
Statistics for a single job execution.
-
#status ⇒ Google::Apis::BigqueryV2::JobStatus
Output only.
-
#user_email ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Job
constructor
A new instance of Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Job
Returns a new instance of Job.
5002 5003 5004 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5002 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration ⇒ Google::Apis::BigqueryV2::JobConfiguration
Required. Describes the job configuration.
Corresponds to the JSON property configuration
4943 4944 4945 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4943 def configuration @configuration end |
#etag ⇒ String
Output only. A hash of this resource.
Corresponds to the JSON property etag
4948 4949 4950 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4948 def etag @etag end |
#id ⇒ String
Output only. Opaque ID field of the job.
Corresponds to the JSON property id
4953 4954 4955 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4953 def id @id end |
#job_creation_reason ⇒ Google::Apis::BigqueryV2::JobCreationReason
Reason about why a Job was created from a jobs.query method when used with
JOB_CREATION_OPTIONAL Job creation mode. For jobs.insert method calls it will
always be REQUESTED.
Corresponds to the JSON property jobCreationReason
4962 4963 4964 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4962 def job_creation_reason @job_creation_reason end |
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
Corresponds to the JSON property jobReference
4967 4968 4969 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4967 def job_reference @job_reference end |
#kind ⇒ String
Output only. The type of the resource.
Corresponds to the JSON property kind
4972 4973 4974 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4972 def kind @kind end |
#principal_subject ⇒ String
Output only. [Full-projection-only] String representation of identity of
requesting party. Populated for both first- and third-party identities. Only
present for APIs that support third-party identities.
Corresponds to the JSON property principal_subject
4979 4980 4981 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4979 def principal_subject @principal_subject end |
#self_link ⇒ String
Output only. A URL that can be used to access the resource again.
Corresponds to the JSON property selfLink
4984 4985 4986 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4984 def self_link @self_link end |
#statistics ⇒ Google::Apis::BigqueryV2::JobStatistics
Statistics for a single job execution.
Corresponds to the JSON property statistics
4989 4990 4991 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4989 def statistics @statistics end |
#status ⇒ Google::Apis::BigqueryV2::JobStatus
Output only. The status of this job. Examine this value when polling an
asynchronous job to see if the job is complete.
Corresponds to the JSON property status
4995 4996 4997 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4995 def status @status end |
#user_email ⇒ String
Output only. Email address of the user who ran the job.
Corresponds to the JSON property user_email
5000 5001 5002 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5000 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5007 def update!(**args) @configuration = args[:configuration] if args.key?(:configuration) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @job_creation_reason = args[:job_creation_reason] if args.key?(:job_creation_reason) @job_reference = args[:job_reference] if args.key?(:job_reference) @kind = args[:kind] if args.key?(:kind) @principal_subject = args[:principal_subject] if args.key?(:principal_subject) @self_link = args[:self_link] if args.key?(:self_link) @statistics = args[:statistics] if args.key?(:statistics) @status = args[:status] if args.key?(:status) @user_email = args[:user_email] if args.key?(:user_email) end |