Class: Google::Apis::BigqueryV2::Job
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Instance Attribute Summary collapse
-
#configuration ⇒ Google::Apis::BigqueryV2::JobConfiguration
Required.
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#job_creation_reason ⇒ Google::Apis::BigqueryV2::JobCreationReason
Reason about why a Job was created from a
jobs.querymethod when used withJOB_CREATION_OPTIONALJob creation mode. -
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
-
#kind ⇒ String
Output only.
-
#principal_subject ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#statistics ⇒ Google::Apis::BigqueryV2::JobStatistics
Statistics for a single job execution.
-
#status ⇒ Google::Apis::BigqueryV2::JobStatus
Output only.
-
#user_email ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Job
constructor
A new instance of Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Job
Returns a new instance of Job.
4927 4928 4929 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4927 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration ⇒ Google::Apis::BigqueryV2::JobConfiguration
Required. Describes the job configuration.
Corresponds to the JSON property configuration
4868 4869 4870 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4868 def configuration @configuration end |
#etag ⇒ String
Output only. A hash of this resource.
Corresponds to the JSON property etag
4873 4874 4875 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4873 def etag @etag end |
#id ⇒ String
Output only. Opaque ID field of the job.
Corresponds to the JSON property id
4878 4879 4880 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4878 def id @id end |
#job_creation_reason ⇒ Google::Apis::BigqueryV2::JobCreationReason
Reason about why a Job was created from a jobs.query method when used with
JOB_CREATION_OPTIONAL Job creation mode. For jobs.insert method calls it will
always be REQUESTED.
Corresponds to the JSON property jobCreationReason
4887 4888 4889 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4887 def job_creation_reason @job_creation_reason end |
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
Corresponds to the JSON property jobReference
4892 4893 4894 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4892 def job_reference @job_reference end |
#kind ⇒ String
Output only. The type of the resource.
Corresponds to the JSON property kind
4897 4898 4899 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4897 def kind @kind end |
#principal_subject ⇒ String
Output only. [Full-projection-only] String representation of identity of
requesting party. Populated for both first- and third-party identities. Only
present for APIs that support third-party identities.
Corresponds to the JSON property principal_subject
4904 4905 4906 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4904 def principal_subject @principal_subject end |
#self_link ⇒ String
Output only. A URL that can be used to access the resource again.
Corresponds to the JSON property selfLink
4909 4910 4911 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4909 def self_link @self_link end |
#statistics ⇒ Google::Apis::BigqueryV2::JobStatistics
Statistics for a single job execution.
Corresponds to the JSON property statistics
4914 4915 4916 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4914 def statistics @statistics end |
#status ⇒ Google::Apis::BigqueryV2::JobStatus
Output only. The status of this job. Examine this value when polling an
asynchronous job to see if the job is complete.
Corresponds to the JSON property status
4920 4921 4922 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4920 def status @status end |
#user_email ⇒ String
Output only. Email address of the user who ran the job.
Corresponds to the JSON property user_email
4925 4926 4927 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4925 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4932 4933 4934 4935 4936 4937 4938 4939 4940 4941 4942 4943 4944 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4932 def update!(**args) @configuration = args[:configuration] if args.key?(:configuration) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @job_creation_reason = args[:job_creation_reason] if args.key?(:job_creation_reason) @job_reference = args[:job_reference] if args.key?(:job_reference) @kind = args[:kind] if args.key?(:kind) @principal_subject = args[:principal_subject] if args.key?(:principal_subject) @self_link = args[:self_link] if args.key?(:self_link) @statistics = args[:statistics] if args.key?(:statistics) @status = args[:status] if args.key?(:status) @user_email = args[:user_email] if args.key?(:user_email) end |