Class: Google::Apis::BigqueryV2::JobConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobConfiguration

Returns a new instance of JobConfiguration.



5125
5126
5127
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5125

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#copyGoogle::Apis::BigqueryV2::JobConfigurationTableCopy

JobConfigurationTableCopy configures a job that copies data from one table to another. For more information on copying tables, see Copy a table. Corresponds to the JSON property copy



5056
5057
5058
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5056

def copy
  @copy
end

#dry_runBoolean Also known as: dry_run?

Optional. If set, don't actually run this job. A valid query will return a mostly empty response with some processing statistics, while an invalid query will return the same error it would if it wasn't a dry run. Behavior of non- query jobs is undefined. Corresponds to the JSON property dryRun

Returns:

  • (Boolean)


5064
5065
5066
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5064

def dry_run
  @dry_run
end

#extractGoogle::Apis::BigqueryV2::JobConfigurationExtract

JobConfigurationExtract configures a job that exports data from a BigQuery table into Google Cloud Storage. Corresponds to the JSON property extract



5071
5072
5073
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5071

def extract
  @extract
end

#job_timeout_msFixnum

Optional. Job timeout in milliseconds relative to the job creation time. If this time limit is exceeded, BigQuery attempts to stop the job, but might not always succeed in canceling it before the job completes. For example, a job that takes more than 60 seconds to complete has a better chance of being stopped than a job that takes 10 seconds to complete. Corresponds to the JSON property jobTimeoutMs

Returns:

  • (Fixnum)


5080
5081
5082
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5080

def job_timeout_ms
  @job_timeout_ms
end

#job_typeString

Output only. The type of the job. Can be QUERY, LOAD, EXTRACT, COPY or UNKNOWN. Corresponds to the JSON property jobType

Returns:

  • (String)


5085
5086
5087
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5085

def job_type
  @job_type
end

#labelsHash<String,String>

The labels associated with this job. You can use these to organize and group your jobs. Label keys and values can be no longer than 63 characters, can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label values are optional. Label keys must start with a letter and each label in the list must have a different key. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5094
5095
5096
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5094

def labels
  @labels
end

#loadGoogle::Apis::BigqueryV2::JobConfigurationLoad

JobConfigurationLoad contains the configuration properties for loading data into a destination table. Corresponds to the JSON property load



5100
5101
5102
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5100

def load
  @load
end

#max_slotsFixnum

Optional. A target limit on the rate of slot consumption by this job. If set to a value > 0, BigQuery will attempt to limit the rate of slot consumption by this job to keep it below the configured limit, even if the job is eligible for more slots based on fair scheduling. The unused slots will be available for other jobs and queries to use. Note: This feature is not yet generally available. Corresponds to the JSON property maxSlots

Returns:

  • (Fixnum)


5110
5111
5112
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5110

def max_slots
  @max_slots
end

#queryGoogle::Apis::BigqueryV2::JobConfigurationQuery

JobConfigurationQuery configures a BigQuery query job. Corresponds to the JSON property query



5115
5116
5117
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5115

def query
  @query
end

#reservationString

Optional. The reservation that job would use. User can specify a reservation to execute the job. If reservation is not set, reservation is determined based on the rules defined by the reservation assignments. The expected format is projects/project/locations/location/reservations/reservation`. Corresponds to the JSON propertyreservation`

Returns:

  • (String)


5123
5124
5125
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5123

def reservation
  @reservation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5130
5131
5132
5133
5134
5135
5136
5137
5138
5139
5140
5141
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5130

def update!(**args)
  @copy = args[:copy] if args.key?(:copy)
  @dry_run = args[:dry_run] if args.key?(:dry_run)
  @extract = args[:extract] if args.key?(:extract)
  @job_timeout_ms = args[:job_timeout_ms] if args.key?(:job_timeout_ms)
  @job_type = args[:job_type] if args.key?(:job_type)
  @labels = args[:labels] if args.key?(:labels)
  @load = args[:load] if args.key?(:load)
  @max_slots = args[:max_slots] if args.key?(:max_slots)
  @query = args[:query] if args.key?(:query)
  @reservation = args[:reservation] if args.key?(:reservation)
end