Class: Google::Apis::BigqueryV2::JobConfiguration
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobConfiguration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Instance Attribute Summary collapse
-
#copy ⇒ Google::Apis::BigqueryV2::JobConfigurationTableCopy
JobConfigurationTableCopy configures a job that copies data from one table to another.
-
#dry_run ⇒ Boolean
(also: #dry_run?)
Optional.
-
#extract ⇒ Google::Apis::BigqueryV2::JobConfigurationExtract
JobConfigurationExtract configures a job that exports data from a BigQuery table into Google Cloud Storage.
-
#job_timeout_ms ⇒ Fixnum
Optional.
-
#job_type ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
The labels associated with this job.
-
#load ⇒ Google::Apis::BigqueryV2::JobConfigurationLoad
JobConfigurationLoad contains the configuration properties for loading data into a destination table.
-
#max_slots ⇒ Fixnum
Optional.
-
#query ⇒ Google::Apis::BigqueryV2::JobConfigurationQuery
JobConfigurationQuery configures a BigQuery query job.
-
#reservation ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobConfiguration
constructor
A new instance of JobConfiguration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobConfiguration
Returns a new instance of JobConfiguration.
5050 5051 5052 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5050 def initialize(**args) update!(**args) end |
Instance Attribute Details
#copy ⇒ Google::Apis::BigqueryV2::JobConfigurationTableCopy
JobConfigurationTableCopy configures a job that copies data from one table to
another. For more information on copying tables, see Copy a table.
Corresponds to the JSON property copy
4981 4982 4983 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4981 def copy @copy end |
#dry_run ⇒ Boolean Also known as: dry_run?
Optional. If set, don't actually run this job. A valid query will return a
mostly empty response with some processing statistics, while an invalid query
will return the same error it would if it wasn't a dry run. Behavior of non-
query jobs is undefined.
Corresponds to the JSON property dryRun
4989 4990 4991 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4989 def dry_run @dry_run end |
#extract ⇒ Google::Apis::BigqueryV2::JobConfigurationExtract
JobConfigurationExtract configures a job that exports data from a BigQuery
table into Google Cloud Storage.
Corresponds to the JSON property extract
4996 4997 4998 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4996 def extract @extract end |
#job_timeout_ms ⇒ Fixnum
Optional. Job timeout in milliseconds relative to the job creation time. If
this time limit is exceeded, BigQuery attempts to stop the job, but might not
always succeed in canceling it before the job completes. For example, a job
that takes more than 60 seconds to complete has a better chance of being
stopped than a job that takes 10 seconds to complete.
Corresponds to the JSON property jobTimeoutMs
5005 5006 5007 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5005 def job_timeout_ms @job_timeout_ms end |
#job_type ⇒ String
Output only. The type of the job. Can be QUERY, LOAD, EXTRACT, COPY or UNKNOWN.
Corresponds to the JSON property jobType
5010 5011 5012 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5010 def job_type @job_type end |
#labels ⇒ Hash<String,String>
The labels associated with this job. You can use these to organize and group
your jobs. Label keys and values can be no longer than 63 characters, can only
contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. Label values are optional. Label keys
must start with a letter and each label in the list must have a different key.
Corresponds to the JSON property labels
5019 5020 5021 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5019 def labels @labels end |
#load ⇒ Google::Apis::BigqueryV2::JobConfigurationLoad
JobConfigurationLoad contains the configuration properties for loading data
into a destination table.
Corresponds to the JSON property load
5025 5026 5027 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5025 def load @load end |
#max_slots ⇒ Fixnum
Optional. A target limit on the rate of slot consumption by this job. If set
to a value > 0, BigQuery will attempt to limit the rate of slot consumption by
this job to keep it below the configured limit, even if the job is eligible
for more slots based on fair scheduling. The unused slots will be available
for other jobs and queries to use. Note: This feature is not yet generally
available.
Corresponds to the JSON property maxSlots
5035 5036 5037 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5035 def max_slots @max_slots end |
#query ⇒ Google::Apis::BigqueryV2::JobConfigurationQuery
JobConfigurationQuery configures a BigQuery query job.
Corresponds to the JSON property query
5040 5041 5042 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5040 def query @query end |
#reservation ⇒ String
Optional. The reservation that job would use. User can specify a reservation
to execute the job. If reservation is not set, reservation is determined based
on the rules defined by the reservation assignments. The expected format is
projects/project/locations/location/reservations/reservation`.
Corresponds to the JSON propertyreservation`
5048 5049 5050 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5048 def reservation @reservation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5055 def update!(**args) @copy = args[:copy] if args.key?(:copy) @dry_run = args[:dry_run] if args.key?(:dry_run) @extract = args[:extract] if args.key?(:extract) @job_timeout_ms = args[:job_timeout_ms] if args.key?(:job_timeout_ms) @job_type = args[:job_type] if args.key?(:job_type) @labels = args[:labels] if args.key?(:labels) @load = args[:load] if args.key?(:load) @max_slots = args[:max_slots] if args.key?(:max_slots) @query = args[:query] if args.key?(:query) @reservation = args[:reservation] if args.key?(:reservation) end |