Class: Google::Apis::BigqueryV2::JobConfigurationExtract

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

JobConfigurationExtract configures a job that exports data from a BigQuery table into Google Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobConfigurationExtract

Returns a new instance of JobConfigurationExtract.



5225
5226
5227
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compressionString

Optional. The compression type to use for exported files. Possible values include DEFLATE, GZIP, NONE, SNAPPY, and ZSTD. The default value is NONE. Not all compression formats are support for all file formats. DEFLATE is only supported for Avro. ZSTD is only supported for Parquet. Not applicable when extracting models. Corresponds to the JSON property compression

Returns:

  • (String)


5165
5166
5167
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5165

def compression
  @compression
end

#destination_formatString

Optional. The exported file format. Possible values include CSV, NEWLINE_DELIMITED_JSON, PARQUET, or AVRO for tables and ML_TF_SAVED_MODEL or ML_XGBOOST_BOOSTER for models. The default value for tables is CSV. Tables with nested or repeated fields cannot be exported as CSV. The default value for models is ML_TF_SAVED_MODEL. Corresponds to the JSON property destinationFormat

Returns:

  • (String)


5174
5175
5176
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5174

def destination_format
  @destination_format
end

#destination_uriString

[Pick one] DEPRECATED: Use destinationUris instead, passing only one URI as necessary. The fully-qualified Google Cloud Storage URI where the extracted table should be written. Corresponds to the JSON property destinationUri

Returns:

  • (String)


5181
5182
5183
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5181

def destination_uri
  @destination_uri
end

#destination_urisArray<String>

[Pick one] A list of fully-qualified Google Cloud Storage URIs where the extracted table should be written. Corresponds to the JSON property destinationUris

Returns:

  • (Array<String>)


5187
5188
5189
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5187

def destination_uris
  @destination_uris
end

#field_delimiterString

Optional. When extracting data in CSV format, this defines the delimiter to use between fields in the exported data. Default is ','. Not applicable when extracting models. Corresponds to the JSON property fieldDelimiter

Returns:

  • (String)


5194
5195
5196
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5194

def field_delimiter
  @field_delimiter
end

#model_extract_optionsGoogle::Apis::BigqueryV2::ModelExtractOptions

Options related to model extraction. Corresponds to the JSON property modelExtractOptions



5199
5200
5201
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5199

def model_extract_options
  @model_extract_options
end

Optional. Whether to print out a header row in the results. Default is true. Not applicable when extracting models. Corresponds to the JSON property printHeader

Returns:

  • (Boolean)


5205
5206
5207
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5205

def print_header
  @print_header
end

#source_modelGoogle::Apis::BigqueryV2::ModelReference

Id path of a model. Corresponds to the JSON property sourceModel



5211
5212
5213
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5211

def source_model
  @source_model
end

#source_tableGoogle::Apis::BigqueryV2::TableReference

A reference to the table being exported. Corresponds to the JSON property sourceTable



5216
5217
5218
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5216

def source_table
  @source_table
end

#use_avro_logical_typesBoolean Also known as: use_avro_logical_types?

Whether to use logical types when extracting to AVRO format. Not applicable when extracting models. Corresponds to the JSON property useAvroLogicalTypes

Returns:

  • (Boolean)


5222
5223
5224
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5222

def use_avro_logical_types
  @use_avro_logical_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5230

def update!(**args)
  @compression = args[:compression] if args.key?(:compression)
  @destination_format = args[:destination_format] if args.key?(:destination_format)
  @destination_uri = args[:destination_uri] if args.key?(:destination_uri)
  @destination_uris = args[:destination_uris] if args.key?(:destination_uris)
  @field_delimiter = args[:field_delimiter] if args.key?(:field_delimiter)
  @model_extract_options = args[:model_extract_options] if args.key?(:model_extract_options)
  @print_header = args[:print_header] if args.key?(:print_header)
  @source_model = args[:source_model] if args.key?(:source_model)
  @source_table = args[:source_table] if args.key?(:source_table)
  @use_avro_logical_types = args[:use_avro_logical_types] if args.key?(:use_avro_logical_types)
end