Class: Google::Apis::BigqueryV2::JobConfigurationExtract

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

JobConfigurationExtract configures a job that exports data from a BigQuery table into Google Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobConfigurationExtract

Returns a new instance of JobConfigurationExtract.



5141
5142
5143
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5141

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compressionString

Optional. The compression type to use for exported files. Possible values include DEFLATE, GZIP, NONE, SNAPPY, and ZSTD. The default value is NONE. Not all compression formats are support for all file formats. DEFLATE is only supported for Avro. ZSTD is only supported for Parquet. Not applicable when extracting models. Corresponds to the JSON property compression

Returns:

  • (String)


5081
5082
5083
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5081

def compression
  @compression
end

#destination_formatString

Optional. The exported file format. Possible values include CSV, NEWLINE_DELIMITED_JSON, PARQUET, or AVRO for tables and ML_TF_SAVED_MODEL or ML_XGBOOST_BOOSTER for models. The default value for tables is CSV. Tables with nested or repeated fields cannot be exported as CSV. The default value for models is ML_TF_SAVED_MODEL. Corresponds to the JSON property destinationFormat

Returns:

  • (String)


5090
5091
5092
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5090

def destination_format
  @destination_format
end

#destination_uriString

[Pick one] DEPRECATED: Use destinationUris instead, passing only one URI as necessary. The fully-qualified Google Cloud Storage URI where the extracted table should be written. Corresponds to the JSON property destinationUri

Returns:

  • (String)


5097
5098
5099
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5097

def destination_uri
  @destination_uri
end

#destination_urisArray<String>

[Pick one] A list of fully-qualified Google Cloud Storage URIs where the extracted table should be written. Corresponds to the JSON property destinationUris

Returns:

  • (Array<String>)


5103
5104
5105
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5103

def destination_uris
  @destination_uris
end

#field_delimiterString

Optional. When extracting data in CSV format, this defines the delimiter to use between fields in the exported data. Default is ','. Not applicable when extracting models. Corresponds to the JSON property fieldDelimiter

Returns:

  • (String)


5110
5111
5112
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5110

def field_delimiter
  @field_delimiter
end

#model_extract_optionsGoogle::Apis::BigqueryV2::ModelExtractOptions

Options related to model extraction. Corresponds to the JSON property modelExtractOptions



5115
5116
5117
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5115

def model_extract_options
  @model_extract_options
end

Optional. Whether to print out a header row in the results. Default is true. Not applicable when extracting models. Corresponds to the JSON property printHeader

Returns:

  • (Boolean)


5121
5122
5123
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5121

def print_header
  @print_header
end

#source_modelGoogle::Apis::BigqueryV2::ModelReference

Id path of a model. Corresponds to the JSON property sourceModel



5127
5128
5129
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5127

def source_model
  @source_model
end

#source_tableGoogle::Apis::BigqueryV2::TableReference

A reference to the table being exported. Corresponds to the JSON property sourceTable



5132
5133
5134
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5132

def source_table
  @source_table
end

#use_avro_logical_typesBoolean Also known as: use_avro_logical_types?

Whether to use logical types when extracting to AVRO format. Not applicable when extracting models. Corresponds to the JSON property useAvroLogicalTypes

Returns:

  • (Boolean)


5138
5139
5140
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5138

def use_avro_logical_types
  @use_avro_logical_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5146
5147
5148
5149
5150
5151
5152
5153
5154
5155
5156
5157
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5146

def update!(**args)
  @compression = args[:compression] if args.key?(:compression)
  @destination_format = args[:destination_format] if args.key?(:destination_format)
  @destination_uri = args[:destination_uri] if args.key?(:destination_uri)
  @destination_uris = args[:destination_uris] if args.key?(:destination_uris)
  @field_delimiter = args[:field_delimiter] if args.key?(:field_delimiter)
  @model_extract_options = args[:model_extract_options] if args.key?(:model_extract_options)
  @print_header = args[:print_header] if args.key?(:print_header)
  @source_model = args[:source_model] if args.key?(:source_model)
  @source_table = args[:source_table] if args.key?(:source_table)
  @use_avro_logical_types = args[:use_avro_logical_types] if args.key?(:use_avro_logical_types)
end