Class: Google::Apis::BigqueryV2::JobConfigurationExtract
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobConfigurationExtract
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
JobConfigurationExtract configures a job that exports data from a BigQuery table into Google Cloud Storage.
Instance Attribute Summary collapse
-
#compression ⇒ String
Optional.
-
#destination_format ⇒ String
Optional.
-
#destination_uri ⇒ String
[Pick one] DEPRECATED: Use destinationUris instead, passing only one URI as necessary.
-
#destination_uris ⇒ Array<String>
[Pick one] A list of fully-qualified Google Cloud Storage URIs where the extracted table should be written.
-
#field_delimiter ⇒ String
Optional.
-
#model_extract_options ⇒ Google::Apis::BigqueryV2::ModelExtractOptions
Options related to model extraction.
-
#print_header ⇒ Boolean
(also: #print_header?)
Optional.
-
#source_model ⇒ Google::Apis::BigqueryV2::ModelReference
Id path of a model.
-
#source_table ⇒ Google::Apis::BigqueryV2::TableReference
A reference to the table being exported.
-
#use_avro_logical_types ⇒ Boolean
(also: #use_avro_logical_types?)
Whether to use logical types when extracting to AVRO format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobConfigurationExtract
constructor
A new instance of JobConfigurationExtract.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobConfigurationExtract
Returns a new instance of JobConfigurationExtract.
4817 4818 4819 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4817 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compression ⇒ String
Optional. The compression type to use for exported files. Possible values
include DEFLATE, GZIP, NONE, SNAPPY, and ZSTD. The default value is NONE. Not
all compression formats are support for all file formats. DEFLATE is only
supported for Avro. ZSTD is only supported for Parquet. Not applicable when
extracting models.
Corresponds to the JSON property compression
4757 4758 4759 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4757 def compression @compression end |
#destination_format ⇒ String
Optional. The exported file format. Possible values include CSV,
NEWLINE_DELIMITED_JSON, PARQUET, or AVRO for tables and ML_TF_SAVED_MODEL or
ML_XGBOOST_BOOSTER for models. The default value for tables is CSV. Tables
with nested or repeated fields cannot be exported as CSV. The default value
for models is ML_TF_SAVED_MODEL.
Corresponds to the JSON property destinationFormat
4766 4767 4768 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4766 def destination_format @destination_format end |
#destination_uri ⇒ String
[Pick one] DEPRECATED: Use destinationUris instead, passing only one URI as
necessary. The fully-qualified Google Cloud Storage URI where the extracted
table should be written.
Corresponds to the JSON property destinationUri
4773 4774 4775 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4773 def destination_uri @destination_uri end |
#destination_uris ⇒ Array<String>
[Pick one] A list of fully-qualified Google Cloud Storage URIs where the
extracted table should be written.
Corresponds to the JSON property destinationUris
4779 4780 4781 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4779 def destination_uris @destination_uris end |
#field_delimiter ⇒ String
Optional. When extracting data in CSV format, this defines the delimiter to
use between fields in the exported data. Default is ','. Not applicable when
extracting models.
Corresponds to the JSON property fieldDelimiter
4786 4787 4788 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4786 def field_delimiter @field_delimiter end |
#model_extract_options ⇒ Google::Apis::BigqueryV2::ModelExtractOptions
Options related to model extraction.
Corresponds to the JSON property modelExtractOptions
4791 4792 4793 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4791 def @model_extract_options end |
#print_header ⇒ Boolean Also known as: print_header?
Optional. Whether to print out a header row in the results. Default is true.
Not applicable when extracting models.
Corresponds to the JSON property printHeader
4797 4798 4799 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4797 def print_header @print_header end |
#source_model ⇒ Google::Apis::BigqueryV2::ModelReference
Id path of a model.
Corresponds to the JSON property sourceModel
4803 4804 4805 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4803 def source_model @source_model end |
#source_table ⇒ Google::Apis::BigqueryV2::TableReference
A reference to the table being exported.
Corresponds to the JSON property sourceTable
4808 4809 4810 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4808 def source_table @source_table end |
#use_avro_logical_types ⇒ Boolean Also known as: use_avro_logical_types?
Whether to use logical types when extracting to AVRO format. Not applicable
when extracting models.
Corresponds to the JSON property useAvroLogicalTypes
4814 4815 4816 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4814 def use_avro_logical_types @use_avro_logical_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4822 4823 4824 4825 4826 4827 4828 4829 4830 4831 4832 4833 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 4822 def update!(**args) @compression = args[:compression] if args.key?(:compression) @destination_format = args[:destination_format] if args.key?(:destination_format) @destination_uri = args[:destination_uri] if args.key?(:destination_uri) @destination_uris = args[:destination_uris] if args.key?(:destination_uris) @field_delimiter = args[:field_delimiter] if args.key?(:field_delimiter) @model_extract_options = args[:model_extract_options] if args.key?(:model_extract_options) @print_header = args[:print_header] if args.key?(:print_header) @source_model = args[:source_model] if args.key?(:source_model) @source_table = args[:source_table] if args.key?(:source_table) @use_avro_logical_types = args[:use_avro_logical_types] if args.key?(:use_avro_logical_types) end |