Class: Google::Apis::BigqueryV2::JobConfigurationTableCopy
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobConfigurationTableCopy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
JobConfigurationTableCopy configures a job that copies data from one table to another. For more information on copying tables, see Copy a table.
Instance Attribute Summary collapse
-
#create_disposition ⇒ String
Optional.
-
#destination_encryption_configuration ⇒ Google::Apis::BigqueryV2::EncryptionConfiguration
Configuration for Cloud KMS encryption settings.
-
#destination_expiration_time ⇒ String
Optional.
-
#destination_table ⇒ Google::Apis::BigqueryV2::TableReference
[Required] The destination table.
-
#operation_type ⇒ String
Optional.
-
#source_table ⇒ Google::Apis::BigqueryV2::TableReference
[Pick one] Source table to copy.
-
#source_tables ⇒ Array<Google::Apis::BigqueryV2::TableReference>
[Pick one] Source tables to copy.
-
#write_disposition ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobConfigurationTableCopy
constructor
A new instance of JobConfigurationTableCopy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobConfigurationTableCopy
Returns a new instance of JobConfigurationTableCopy.
5878 5879 5880 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5878 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_disposition ⇒ String
Optional. Specifies whether the job is allowed to create new tables. The
following values are supported: * CREATE_IF_NEEDED: If the table does not
exist, BigQuery creates the table. * CREATE_NEVER: The table must already
exist. If it does not, a 'notFound' error is returned in the job result. The
default value is CREATE_IF_NEEDED. Creation, truncation and append actions
occur as one atomic update upon job completion.
Corresponds to the JSON property createDisposition
5832 5833 5834 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5832 def create_disposition @create_disposition end |
#destination_encryption_configuration ⇒ Google::Apis::BigqueryV2::EncryptionConfiguration
Configuration for Cloud KMS encryption settings.
Corresponds to the JSON property destinationEncryptionConfiguration
5837 5838 5839 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5837 def destination_encryption_configuration @destination_encryption_configuration end |
#destination_expiration_time ⇒ String
Optional. The time when the destination table expires. Expired tables will be
deleted and their storage reclaimed.
Corresponds to the JSON property destinationExpirationTime
5843 5844 5845 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5843 def destination_expiration_time @destination_expiration_time end |
#destination_table ⇒ Google::Apis::BigqueryV2::TableReference
[Required] The destination table.
Corresponds to the JSON property destinationTable
5848 5849 5850 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5848 def destination_table @destination_table end |
#operation_type ⇒ String
Optional. Supported operation types in table copy job.
Corresponds to the JSON property operationType
5853 5854 5855 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5853 def operation_type @operation_type end |
#source_table ⇒ Google::Apis::BigqueryV2::TableReference
[Pick one] Source table to copy.
Corresponds to the JSON property sourceTable
5858 5859 5860 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5858 def source_table @source_table end |
#source_tables ⇒ Array<Google::Apis::BigqueryV2::TableReference>
[Pick one] Source tables to copy.
Corresponds to the JSON property sourceTables
5863 5864 5865 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5863 def source_tables @source_tables end |
#write_disposition ⇒ String
Optional. Specifies the action that occurs if the destination table already
exists. The following values are supported: * WRITE_TRUNCATE: If the table
already exists, BigQuery overwrites the table data and uses the schema and
table constraints from the source table. * WRITE_APPEND: If the table already
exists, BigQuery appends the data to the table. * WRITE_EMPTY: If the table
already exists and contains data, a 'duplicate' error is returned in the job
result. The default value is WRITE_EMPTY. Each action is atomic and only
occurs if BigQuery is able to complete the job successfully. Creation,
truncation and append actions occur as one atomic update upon job completion.
Corresponds to the JSON property writeDisposition
5876 5877 5878 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5876 def write_disposition @write_disposition end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5883 5884 5885 5886 5887 5888 5889 5890 5891 5892 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5883 def update!(**args) @create_disposition = args[:create_disposition] if args.key?(:create_disposition) @destination_encryption_configuration = args[:destination_encryption_configuration] if args.key?(:destination_encryption_configuration) @destination_expiration_time = args[:destination_expiration_time] if args.key?(:destination_expiration_time) @destination_table = args[:destination_table] if args.key?(:destination_table) @operation_type = args[:operation_type] if args.key?(:operation_type) @source_table = args[:source_table] if args.key?(:source_table) @source_tables = args[:source_tables] if args.key?(:source_tables) @write_disposition = args[:write_disposition] if args.key?(:write_disposition) end |