Class: Google::Apis::BigqueryV2::JobCreationReason

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Reason about why a Job was created from a jobs.query method when used with JOB_CREATION_OPTIONAL Job creation mode. For jobs.insert method calls it will always be REQUESTED.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobCreationReason

Returns a new instance of JobCreationReason.



5638
5639
5640
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5638

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Output only. Specifies the high level reason why a Job was created. Corresponds to the JSON property code

Returns:

  • (String)


5636
5637
5638
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5636

def code
  @code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5643
5644
5645
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5643

def update!(**args)
  @code = args[:code] if args.key?(:code)
end