Class: Google::Apis::BigqueryV2::JobList::Job
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobList::Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
ListFormatJob is a partial projection of job information returned as part of a jobs.list response.
Instance Attribute Summary collapse
-
#configuration ⇒ Google::Apis::BigqueryV2::JobConfiguration
Required.
-
#error_result ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
-
#id ⇒ String
Unique opaque ID of the job.
-
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
-
#kind ⇒ String
The resource type.
-
#principal_subject ⇒ String
[Full-projection-only] String representation of identity of requesting party.
-
#state ⇒ String
Running state of the job.
-
#statistics ⇒ Google::Apis::BigqueryV2::JobStatistics
Statistics for a single job execution.
-
#status ⇒ Google::Apis::BigqueryV2::JobStatus
[Full-projection-only] Describes the status of this job.
-
#user_email ⇒ String
[Full-projection-only] Email address of the user who ran the job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Job
constructor
A new instance of Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Job
Returns a new instance of Job.
6076 6077 6078 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration ⇒ Google::Apis::BigqueryV2::JobConfiguration
Required. Describes the job configuration.
Corresponds to the JSON property configuration
6026 6027 6028 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6026 def configuration @configuration end |
#error_result ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
Corresponds to the JSON property errorResult
6031 6032 6033 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6031 def error_result @error_result end |
#id ⇒ String
Unique opaque ID of the job.
Corresponds to the JSON property id
6036 6037 6038 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6036 def id @id end |
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
Corresponds to the JSON property jobReference
6041 6042 6043 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6041 def job_reference @job_reference end |
#kind ⇒ String
The resource type.
Corresponds to the JSON property kind
6046 6047 6048 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6046 def kind @kind end |
#principal_subject ⇒ String
[Full-projection-only] String representation of identity of requesting party.
Populated for both first- and third-party identities. Only present for APIs
that support third-party identities.
Corresponds to the JSON property principal_subject
6053 6054 6055 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6053 def principal_subject @principal_subject end |
#state ⇒ String
Running state of the job. When the state is DONE, errorResult can be checked
to determine whether the job succeeded or failed.
Corresponds to the JSON property state
6059 6060 6061 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6059 def state @state end |
#statistics ⇒ Google::Apis::BigqueryV2::JobStatistics
Statistics for a single job execution.
Corresponds to the JSON property statistics
6064 6065 6066 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6064 def statistics @statistics end |
#status ⇒ Google::Apis::BigqueryV2::JobStatus
[Full-projection-only] Describes the status of this job.
Corresponds to the JSON property status
6069 6070 6071 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6069 def status @status end |
#user_email ⇒ String
[Full-projection-only] Email address of the user who ran the job.
Corresponds to the JSON property user_email
6074 6075 6076 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6074 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6081 6082 6083 6084 6085 6086 6087 6088 6089 6090 6091 6092 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6081 def update!(**args) @configuration = args[:configuration] if args.key?(:configuration) @error_result = args[:error_result] if args.key?(:error_result) @id = args[:id] if args.key?(:id) @job_reference = args[:job_reference] if args.key?(:job_reference) @kind = args[:kind] if args.key?(:kind) @principal_subject = args[:principal_subject] if args.key?(:principal_subject) @state = args[:state] if args.key?(:state) @statistics = args[:statistics] if args.key?(:statistics) @status = args[:status] if args.key?(:status) @user_email = args[:user_email] if args.key?(:user_email) end |