Class: Google::Apis::BigqueryV2::JobList::Job

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

ListFormatJob is a partial projection of job information returned as part of a jobs.list response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Job

Returns a new instance of Job.



5780
5781
5782
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configurationGoogle::Apis::BigqueryV2::JobConfiguration

Required. Describes the job configuration. Corresponds to the JSON property configuration



5730
5731
5732
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5730

def configuration
  @configuration
end

#error_resultGoogle::Apis::BigqueryV2::ErrorProto

Error details. Corresponds to the JSON property errorResult



5735
5736
5737
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5735

def error_result
  @error_result
end

#idString

Unique opaque ID of the job. Corresponds to the JSON property id

Returns:

  • (String)


5740
5741
5742
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5740

def id
  @id
end

#job_referenceGoogle::Apis::BigqueryV2::JobReference

A job reference is a fully qualified identifier for referring to a job. Corresponds to the JSON property jobReference



5745
5746
5747
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5745

def job_reference
  @job_reference
end

#kindString

The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


5750
5751
5752
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5750

def kind
  @kind
end

#principal_subjectString

[Full-projection-only] String representation of identity of requesting party. Populated for both first- and third-party identities. Only present for APIs that support third-party identities. Corresponds to the JSON property principal_subject

Returns:

  • (String)


5757
5758
5759
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5757

def principal_subject
  @principal_subject
end

#stateString

Running state of the job. When the state is DONE, errorResult can be checked to determine whether the job succeeded or failed. Corresponds to the JSON property state

Returns:

  • (String)


5763
5764
5765
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5763

def state
  @state
end

#statisticsGoogle::Apis::BigqueryV2::JobStatistics

Statistics for a single job execution. Corresponds to the JSON property statistics



5768
5769
5770
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5768

def statistics
  @statistics
end

#statusGoogle::Apis::BigqueryV2::JobStatus

[Full-projection-only] Describes the status of this job. Corresponds to the JSON property status



5773
5774
5775
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5773

def status
  @status
end

#user_emailString

[Full-projection-only] Email address of the user who ran the job. Corresponds to the JSON property user_email

Returns:

  • (String)


5778
5779
5780
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5778

def user_email
  @user_email
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5785
5786
5787
5788
5789
5790
5791
5792
5793
5794
5795
5796
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5785

def update!(**args)
  @configuration = args[:configuration] if args.key?(:configuration)
  @error_result = args[:error_result] if args.key?(:error_result)
  @id = args[:id] if args.key?(:id)
  @job_reference = args[:job_reference] if args.key?(:job_reference)
  @kind = args[:kind] if args.key?(:kind)
  @principal_subject = args[:principal_subject] if args.key?(:principal_subject)
  @state = args[:state] if args.key?(:state)
  @statistics = args[:statistics] if args.key?(:statistics)
  @status = args[:status] if args.key?(:status)
  @user_email = args[:user_email] if args.key?(:user_email)
end