Class: Google::Apis::BigqueryV2::JobList::Job
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobList::Job
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
ListFormatJob is a partial projection of job information returned as part of a jobs.list response.
Instance Attribute Summary collapse
-
#configuration ⇒ Google::Apis::BigqueryV2::JobConfiguration
Required.
-
#error_result ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
-
#id ⇒ String
Unique opaque ID of the job.
-
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
-
#kind ⇒ String
The resource type.
-
#principal_subject ⇒ String
[Full-projection-only] String representation of identity of requesting party.
-
#state ⇒ String
Running state of the job.
-
#statistics ⇒ Google::Apis::BigqueryV2::JobStatistics
Statistics for a single job execution.
-
#status ⇒ Google::Apis::BigqueryV2::JobStatus
[Full-projection-only] Describes the status of this job.
-
#user_email ⇒ String
[Full-projection-only] Email address of the user who ran the job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Job
constructor
A new instance of Job.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Job
Returns a new instance of Job.
5750 5751 5752 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration ⇒ Google::Apis::BigqueryV2::JobConfiguration
Required. Describes the job configuration.
Corresponds to the JSON property configuration
5700 5701 5702 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5700 def configuration @configuration end |
#error_result ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
Corresponds to the JSON property errorResult
5705 5706 5707 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5705 def error_result @error_result end |
#id ⇒ String
Unique opaque ID of the job.
Corresponds to the JSON property id
5710 5711 5712 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5710 def id @id end |
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
Corresponds to the JSON property jobReference
5715 5716 5717 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5715 def job_reference @job_reference end |
#kind ⇒ String
The resource type.
Corresponds to the JSON property kind
5720 5721 5722 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5720 def kind @kind end |
#principal_subject ⇒ String
[Full-projection-only] String representation of identity of requesting party.
Populated for both first- and third-party identities. Only present for APIs
that support third-party identities.
Corresponds to the JSON property principal_subject
5727 5728 5729 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5727 def principal_subject @principal_subject end |
#state ⇒ String
Running state of the job. When the state is DONE, errorResult can be checked
to determine whether the job succeeded or failed.
Corresponds to the JSON property state
5733 5734 5735 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5733 def state @state end |
#statistics ⇒ Google::Apis::BigqueryV2::JobStatistics
Statistics for a single job execution.
Corresponds to the JSON property statistics
5738 5739 5740 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5738 def statistics @statistics end |
#status ⇒ Google::Apis::BigqueryV2::JobStatus
[Full-projection-only] Describes the status of this job.
Corresponds to the JSON property status
5743 5744 5745 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5743 def status @status end |
#user_email ⇒ String
[Full-projection-only] Email address of the user who ran the job.
Corresponds to the JSON property user_email
5748 5749 5750 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5748 def user_email @user_email end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5755 def update!(**args) @configuration = args[:configuration] if args.key?(:configuration) @error_result = args[:error_result] if args.key?(:error_result) @id = args[:id] if args.key?(:id) @job_reference = args[:job_reference] if args.key?(:job_reference) @kind = args[:kind] if args.key?(:kind) @principal_subject = args[:principal_subject] if args.key?(:principal_subject) @state = args[:state] if args.key?(:state) @statistics = args[:statistics] if args.key?(:statistics) @status = args[:status] if args.key?(:status) @user_email = args[:user_email] if args.key?(:user_email) end |