Class: Google::Apis::BigqueryV2::JobStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics for a single job execution.

Defined Under Namespace

Classes: ReservationUsage

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobStatistics

Returns a new instance of JobStatistics.



6208
6209
6210
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completion_ratioFloat

Output only. [TrustedTester] Job progress (0.0 -> 1.0) for LOAD and EXTRACT jobs. Corresponds to the JSON property completionRatio

Returns:

  • (Float)


6083
6084
6085
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6083

def completion_ratio
  @completion_ratio
end

#copyGoogle::Apis::BigqueryV2::JobStatistics5

Statistics for a copy job. Corresponds to the JSON property copy



6088
6089
6090
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6088

def copy
  @copy
end

#creation_timeFixnum

Output only. Creation time of this job, in milliseconds since the epoch. This field will be present on all jobs. Corresponds to the JSON property creationTime

Returns:

  • (Fixnum)


6094
6095
6096
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6094

def creation_time
  @creation_time
end

#data_masking_statisticsGoogle::Apis::BigqueryV2::DataMaskingStatistics

Statistics for data-masking. Corresponds to the JSON property dataMaskingStatistics



6099
6100
6101
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6099

def data_masking_statistics
  @data_masking_statistics
end

#editionString

Output only. Name of edition corresponding to the reservation for this job at the time of this update. Corresponds to the JSON property edition

Returns:

  • (String)


6105
6106
6107
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6105

def edition
  @edition
end

#end_timeFixnum

Output only. End time of this job, in milliseconds since the epoch. This field will be present whenever a job is in the DONE state. Corresponds to the JSON property endTime

Returns:

  • (Fixnum)


6111
6112
6113
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6111

def end_time
  @end_time
end

#extractGoogle::Apis::BigqueryV2::JobStatistics4

Statistics for an extract job. Corresponds to the JSON property extract



6116
6117
6118
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6116

def extract
  @extract
end

#final_execution_duration_msFixnum

Output only. The duration in milliseconds of the execution of the final attempt of this job, as BigQuery may internally re-attempt to execute the job. Corresponds to the JSON property finalExecutionDurationMs

Returns:

  • (Fixnum)


6122
6123
6124
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6122

def final_execution_duration_ms
  @final_execution_duration_ms
end

#loadGoogle::Apis::BigqueryV2::JobStatistics3

Statistics for a load job. Corresponds to the JSON property load



6127
6128
6129
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6127

def load
  @load
end

#num_child_jobsFixnum

Output only. Number of child jobs executed. Corresponds to the JSON property numChildJobs

Returns:

  • (Fixnum)


6132
6133
6134
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6132

def num_child_jobs
  @num_child_jobs
end

#parent_job_idString

Output only. If this is a child job, specifies the job ID of the parent. Corresponds to the JSON property parentJobId

Returns:

  • (String)


6137
6138
6139
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6137

def parent_job_id
  @parent_job_id
end

#queryGoogle::Apis::BigqueryV2::JobStatistics2

Statistics for a query job. Corresponds to the JSON property query



6142
6143
6144
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6142

def query
  @query
end

#quota_defermentsArray<String>

Output only. Quotas which delayed this job's start time. Corresponds to the JSON property quotaDeferments

Returns:

  • (Array<String>)


6147
6148
6149
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6147

def quota_deferments
  @quota_deferments
end

#reservation_group_pathArray<String>

Output only. The reservation group path of the reservation assigned to this job. This field has a limit of 10 nested reservation groups. This is to maintain consistency between reservatins info schema and jobs info schema. The first reservation group is the root reservation group and the last is the leaf or lowest level reservation group. Corresponds to the JSON property reservationGroupPath

Returns:

  • (Array<String>)


6156
6157
6158
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6156

def reservation_group_path
  @reservation_group_path
end

#reservation_idString

Output only. Name of the primary reservation assigned to this job. Note that this could be different than reservations reported in the reservation usage field if parent reservations were used to execute this job. Corresponds to the JSON property reservation_id

Returns:

  • (String)


6169
6170
6171
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6169

def reservation_id
  @reservation_id
end

#reservation_usageArray<Google::Apis::BigqueryV2::JobStatistics::ReservationUsage>

Output only. Job resource usage breakdown by reservation. This field reported misleading information and will no longer be populated. Corresponds to the JSON property reservationUsage



6162
6163
6164
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6162

def reservation_usage
  @reservation_usage
end

#row_level_security_statisticsGoogle::Apis::BigqueryV2::RowLevelSecurityStatistics

Statistics for row-level security. Corresponds to the JSON property rowLevelSecurityStatistics



6174
6175
6176
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6174

def row_level_security_statistics
  @row_level_security_statistics
end

#script_statisticsGoogle::Apis::BigqueryV2::ScriptStatistics

Job statistics specific to the child job of a script. Corresponds to the JSON property scriptStatistics



6179
6180
6181
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6179

def script_statistics
  @script_statistics
end

#session_infoGoogle::Apis::BigqueryV2::SessionInfo

[Preview] Information related to sessions. Corresponds to the JSON property sessionInfo



6184
6185
6186
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6184

def session_info
  @session_info
end

#start_timeFixnum

Output only. Start time of this job, in milliseconds since the epoch. This field will be present when the job transitions from the PENDING state to either RUNNING or DONE. Corresponds to the JSON property startTime

Returns:

  • (Fixnum)


6191
6192
6193
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6191

def start_time
  @start_time
end

#total_bytes_processedFixnum

Output only. Total bytes processed for the job. Corresponds to the JSON property totalBytesProcessed

Returns:

  • (Fixnum)


6196
6197
6198
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6196

def total_bytes_processed
  @total_bytes_processed
end

#total_slot_msFixnum

Output only. Slot-milliseconds for the job. Corresponds to the JSON property totalSlotMs

Returns:

  • (Fixnum)


6201
6202
6203
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6201

def total_slot_ms
  @total_slot_ms
end

#transaction_infoGoogle::Apis::BigqueryV2::TransactionInfo

[Alpha] Information of a multi-statement transaction. Corresponds to the JSON property transactionInfo



6206
6207
6208
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6206

def transaction_info
  @transaction_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6213
6214
6215
6216
6217
6218
6219
6220
6221
6222
6223
6224
6225
6226
6227
6228
6229
6230
6231
6232
6233
6234
6235
6236
6237
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6213

def update!(**args)
  @completion_ratio = args[:completion_ratio] if args.key?(:completion_ratio)
  @copy = args[:copy] if args.key?(:copy)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @data_masking_statistics = args[:data_masking_statistics] if args.key?(:data_masking_statistics)
  @edition = args[:edition] if args.key?(:edition)
  @end_time = args[:end_time] if args.key?(:end_time)
  @extract = args[:extract] if args.key?(:extract)
  @final_execution_duration_ms = args[:final_execution_duration_ms] if args.key?(:final_execution_duration_ms)
  @load = args[:load] if args.key?(:load)
  @num_child_jobs = args[:num_child_jobs] if args.key?(:num_child_jobs)
  @parent_job_id = args[:parent_job_id] if args.key?(:parent_job_id)
  @query = args[:query] if args.key?(:query)
  @quota_deferments = args[:quota_deferments] if args.key?(:quota_deferments)
  @reservation_group_path = args[:reservation_group_path] if args.key?(:reservation_group_path)
  @reservation_usage = args[:reservation_usage] if args.key?(:reservation_usage)
  @reservation_id = args[:reservation_id] if args.key?(:reservation_id)
  @row_level_security_statistics = args[:row_level_security_statistics] if args.key?(:row_level_security_statistics)
  @script_statistics = args[:script_statistics] if args.key?(:script_statistics)
  @session_info = args[:session_info] if args.key?(:session_info)
  @start_time = args[:start_time] if args.key?(:start_time)
  @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed)
  @total_slot_ms = args[:total_slot_ms] if args.key?(:total_slot_ms)
  @transaction_info = args[:transaction_info] if args.key?(:transaction_info)
end