Class: Google::Apis::BigqueryV2::JobStatistics
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobStatistics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Statistics for a single job execution.
Defined Under Namespace
Classes: ReservationUsage
Instance Attribute Summary collapse
-
#completion_ratio ⇒ Float
Output only.
-
#copy ⇒ Google::Apis::BigqueryV2::JobStatistics5
Statistics for a copy job.
-
#creation_time ⇒ Fixnum
Output only.
-
#data_masking_statistics ⇒ Google::Apis::BigqueryV2::DataMaskingStatistics
Statistics for data-masking.
-
#edition ⇒ String
Output only.
-
#end_time ⇒ Fixnum
Output only.
-
#extract ⇒ Google::Apis::BigqueryV2::JobStatistics4
Statistics for an extract job.
-
#final_execution_duration_ms ⇒ Fixnum
Output only.
-
#load ⇒ Google::Apis::BigqueryV2::JobStatistics3
Statistics for a load job.
-
#num_child_jobs ⇒ Fixnum
Output only.
-
#parent_job_id ⇒ String
Output only.
-
#query ⇒ Google::Apis::BigqueryV2::JobStatistics2
Statistics for a query job.
-
#quota_deferments ⇒ Array<String>
Output only.
-
#reservation_group_path ⇒ Array<String>
Output only.
-
#reservation_id ⇒ String
Output only.
-
#reservation_usage ⇒ Array<Google::Apis::BigqueryV2::JobStatistics::ReservationUsage>
Output only.
-
#row_level_security_statistics ⇒ Google::Apis::BigqueryV2::RowLevelSecurityStatistics
Statistics for row-level security.
-
#script_statistics ⇒ Google::Apis::BigqueryV2::ScriptStatistics
Job statistics specific to the child job of a script.
-
#session_info ⇒ Google::Apis::BigqueryV2::SessionInfo
[Preview] Information related to sessions.
-
#start_time ⇒ Fixnum
Output only.
-
#total_bytes_processed ⇒ Fixnum
Output only.
-
#total_slot_ms ⇒ Fixnum
Output only.
-
#transaction_info ⇒ Google::Apis::BigqueryV2::TransactionInfo
[Alpha] Information of a multi-statement transaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobStatistics
constructor
A new instance of JobStatistics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobStatistics
Returns a new instance of JobStatistics.
5938 5939 5940 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5938 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completion_ratio ⇒ Float
Output only. [TrustedTester] Job progress (0.0 -> 1.0) for LOAD and EXTRACT
jobs.
Corresponds to the JSON property completionRatio
5813 5814 5815 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5813 def completion_ratio @completion_ratio end |
#copy ⇒ Google::Apis::BigqueryV2::JobStatistics5
Statistics for a copy job.
Corresponds to the JSON property copy
5818 5819 5820 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5818 def copy @copy end |
#creation_time ⇒ Fixnum
Output only. Creation time of this job, in milliseconds since the epoch. This
field will be present on all jobs.
Corresponds to the JSON property creationTime
5824 5825 5826 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5824 def creation_time @creation_time end |
#data_masking_statistics ⇒ Google::Apis::BigqueryV2::DataMaskingStatistics
Statistics for data-masking.
Corresponds to the JSON property dataMaskingStatistics
5829 5830 5831 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5829 def data_masking_statistics @data_masking_statistics end |
#edition ⇒ String
Output only. Name of edition corresponding to the reservation for this job at
the time of this update.
Corresponds to the JSON property edition
5835 5836 5837 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5835 def edition @edition end |
#end_time ⇒ Fixnum
Output only. End time of this job, in milliseconds since the epoch. This field
will be present whenever a job is in the DONE state.
Corresponds to the JSON property endTime
5841 5842 5843 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5841 def end_time @end_time end |
#extract ⇒ Google::Apis::BigqueryV2::JobStatistics4
Statistics for an extract job.
Corresponds to the JSON property extract
5846 5847 5848 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5846 def extract @extract end |
#final_execution_duration_ms ⇒ Fixnum
Output only. The duration in milliseconds of the execution of the final
attempt of this job, as BigQuery may internally re-attempt to execute the job.
Corresponds to the JSON property finalExecutionDurationMs
5852 5853 5854 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5852 def final_execution_duration_ms @final_execution_duration_ms end |
#load ⇒ Google::Apis::BigqueryV2::JobStatistics3
Statistics for a load job.
Corresponds to the JSON property load
5857 5858 5859 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5857 def load @load end |
#num_child_jobs ⇒ Fixnum
Output only. Number of child jobs executed.
Corresponds to the JSON property numChildJobs
5862 5863 5864 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5862 def num_child_jobs @num_child_jobs end |
#parent_job_id ⇒ String
Output only. If this is a child job, specifies the job ID of the parent.
Corresponds to the JSON property parentJobId
5867 5868 5869 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5867 def parent_job_id @parent_job_id end |
#query ⇒ Google::Apis::BigqueryV2::JobStatistics2
Statistics for a query job.
Corresponds to the JSON property query
5872 5873 5874 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5872 def query @query end |
#quota_deferments ⇒ Array<String>
Output only. Quotas which delayed this job's start time.
Corresponds to the JSON property quotaDeferments
5877 5878 5879 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5877 def quota_deferments @quota_deferments end |
#reservation_group_path ⇒ Array<String>
Output only. The reservation group path of the reservation assigned to this
job. This field has a limit of 10 nested reservation groups. This is to
maintain consistency between reservatins info schema and jobs info schema. The
first reservation group is the root reservation group and the last is the leaf
or lowest level reservation group.
Corresponds to the JSON property reservationGroupPath
5886 5887 5888 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5886 def reservation_group_path @reservation_group_path end |
#reservation_id ⇒ String
Output only. Name of the primary reservation assigned to this job. Note that
this could be different than reservations reported in the reservation usage
field if parent reservations were used to execute this job.
Corresponds to the JSON property reservation_id
5899 5900 5901 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5899 def reservation_id @reservation_id end |
#reservation_usage ⇒ Array<Google::Apis::BigqueryV2::JobStatistics::ReservationUsage>
Output only. Job resource usage breakdown by reservation. This field reported
misleading information and will no longer be populated.
Corresponds to the JSON property reservationUsage
5892 5893 5894 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5892 def reservation_usage @reservation_usage end |
#row_level_security_statistics ⇒ Google::Apis::BigqueryV2::RowLevelSecurityStatistics
Statistics for row-level security.
Corresponds to the JSON property rowLevelSecurityStatistics
5904 5905 5906 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5904 def row_level_security_statistics @row_level_security_statistics end |
#script_statistics ⇒ Google::Apis::BigqueryV2::ScriptStatistics
Job statistics specific to the child job of a script.
Corresponds to the JSON property scriptStatistics
5909 5910 5911 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5909 def script_statistics @script_statistics end |
#session_info ⇒ Google::Apis::BigqueryV2::SessionInfo
[Preview] Information related to sessions.
Corresponds to the JSON property sessionInfo
5914 5915 5916 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5914 def session_info @session_info end |
#start_time ⇒ Fixnum
Output only. Start time of this job, in milliseconds since the epoch. This
field will be present when the job transitions from the PENDING state to
either RUNNING or DONE.
Corresponds to the JSON property startTime
5921 5922 5923 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5921 def start_time @start_time end |
#total_bytes_processed ⇒ Fixnum
Output only. Total bytes processed for the job.
Corresponds to the JSON property totalBytesProcessed
5926 5927 5928 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5926 def total_bytes_processed @total_bytes_processed end |
#total_slot_ms ⇒ Fixnum
Output only. Slot-milliseconds for the job.
Corresponds to the JSON property totalSlotMs
5931 5932 5933 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5931 def total_slot_ms @total_slot_ms end |
#transaction_info ⇒ Google::Apis::BigqueryV2::TransactionInfo
[Alpha] Information of a multi-statement transaction.
Corresponds to the JSON property transactionInfo
5936 5937 5938 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5936 def transaction_info @transaction_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5943 5944 5945 5946 5947 5948 5949 5950 5951 5952 5953 5954 5955 5956 5957 5958 5959 5960 5961 5962 5963 5964 5965 5966 5967 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 5943 def update!(**args) @completion_ratio = args[:completion_ratio] if args.key?(:completion_ratio) @copy = args[:copy] if args.key?(:copy) @creation_time = args[:creation_time] if args.key?(:creation_time) @data_masking_statistics = args[:data_masking_statistics] if args.key?(:data_masking_statistics) @edition = args[:edition] if args.key?(:edition) @end_time = args[:end_time] if args.key?(:end_time) @extract = args[:extract] if args.key?(:extract) @final_execution_duration_ms = args[:final_execution_duration_ms] if args.key?(:final_execution_duration_ms) @load = args[:load] if args.key?(:load) @num_child_jobs = args[:num_child_jobs] if args.key?(:num_child_jobs) @parent_job_id = args[:parent_job_id] if args.key?(:parent_job_id) @query = args[:query] if args.key?(:query) @quota_deferments = args[:quota_deferments] if args.key?(:quota_deferments) @reservation_group_path = args[:reservation_group_path] if args.key?(:reservation_group_path) @reservation_usage = args[:reservation_usage] if args.key?(:reservation_usage) @reservation_id = args[:reservation_id] if args.key?(:reservation_id) @row_level_security_statistics = args[:row_level_security_statistics] if args.key?(:row_level_security_statistics) @script_statistics = args[:script_statistics] if args.key?(:script_statistics) @session_info = args[:session_info] if args.key?(:session_info) @start_time = args[:start_time] if args.key?(:start_time) @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed) @total_slot_ms = args[:total_slot_ms] if args.key?(:total_slot_ms) @transaction_info = args[:transaction_info] if args.key?(:transaction_info) end |