Class: Google::Apis::BigqueryV2::JobStatistics2
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobStatistics2
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Statistics for a query job.
Defined Under Namespace
Classes: ReservationUsage
Instance Attribute Summary collapse
-
#bi_engine_statistics ⇒ Google::Apis::BigqueryV2::BiEngineStatistics
Statistics for a BI Engine specific query.
-
#billing_tier ⇒ Fixnum
Output only.
-
#cache_hit ⇒ Boolean
(also: #cache_hit?)
Output only.
-
#dcl_target_dataset ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
-
#dcl_target_table ⇒ Google::Apis::BigqueryV2::TableReference
Output only.
-
#dcl_target_view ⇒ Google::Apis::BigqueryV2::TableReference
Output only.
-
#ddl_affected_row_access_policy_count ⇒ Fixnum
Output only.
-
#ddl_destination_table ⇒ Google::Apis::BigqueryV2::TableReference
Output only.
-
#ddl_operation_performed ⇒ String
Output only.
-
#ddl_target_dataset ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
-
#ddl_target_routine ⇒ Google::Apis::BigqueryV2::RoutineReference
Id path of a routine.
-
#ddl_target_row_access_policy ⇒ Google::Apis::BigqueryV2::RowAccessPolicyReference
Id path of a row access policy.
-
#ddl_target_table ⇒ Google::Apis::BigqueryV2::TableReference
Output only.
-
#dml_stats ⇒ Google::Apis::BigqueryV2::DmlStatistics
Detailed statistics for DML statements Corresponds to the JSON property
dmlStats. -
#estimated_bytes_processed ⇒ Fixnum
Output only.
-
#export_data_statistics ⇒ Google::Apis::BigqueryV2::ExportDataStatistics
Statistics for the EXPORT DATA statement as part of Query Job.
-
#external_service_costs ⇒ Array<Google::Apis::BigqueryV2::ExternalServiceCost>
Output only.
-
#gen_ai_stats ⇒ Google::Apis::BigqueryV2::GenAiStats
GenAi stats for the query job.
-
#incremental_result_stats ⇒ Google::Apis::BigqueryV2::IncrementalResultStats
Statistics related to Incremental Query Results.
-
#load_query_statistics ⇒ Google::Apis::BigqueryV2::LoadQueryStatistics
Statistics for a LOAD query.
-
#materialized_view_statistics ⇒ Google::Apis::BigqueryV2::MaterializedViewStatistics
Statistics of materialized views considered in a query job.
-
#metadata_cache_statistics ⇒ Google::Apis::BigqueryV2::MetadataCacheStatistics
Statistics for metadata caching in queried tables.
-
#ml_statistics ⇒ Google::Apis::BigqueryV2::MlStatistics
Job statistics specific to a BigQuery ML training job.
-
#model_training ⇒ Google::Apis::BigqueryV2::BigQueryModelTraining
Deprecated.
-
#model_training_current_iteration ⇒ Fixnum
Deprecated.
-
#model_training_expected_total_iteration ⇒ Fixnum
Deprecated.
-
#num_dml_affected_rows ⇒ Fixnum
Output only.
-
#performance_insights ⇒ Google::Apis::BigqueryV2::PerformanceInsights
Performance insights for the job.
-
#query_info ⇒ Google::Apis::BigqueryV2::QueryInfo
Query optimization information for a QUERY job.
-
#query_plan ⇒ Array<Google::Apis::BigqueryV2::ExplainQueryStage>
Output only.
-
#referenced_property_graphs ⇒ Array<Google::Apis::BigqueryV2::PropertyGraphReference>
Output only.
-
#referenced_routines ⇒ Array<Google::Apis::BigqueryV2::RoutineReference>
Output only.
-
#referenced_tables ⇒ Array<Google::Apis::BigqueryV2::TableReference>
Output only.
-
#reservation_usage ⇒ Array<Google::Apis::BigqueryV2::JobStatistics2::ReservationUsage>
Output only.
-
#schema ⇒ Google::Apis::BigqueryV2::TableSchema
Schema of a table Corresponds to the JSON property
schema. -
#search_statistics ⇒ Google::Apis::BigqueryV2::SearchStatistics
Statistics for a search query.
-
#spark_statistics ⇒ Google::Apis::BigqueryV2::SparkStatistics
Statistics for a BigSpark query.
-
#statement_type ⇒ String
Output only.
-
#timeline ⇒ Array<Google::Apis::BigqueryV2::QueryTimelineSample>
Output only.
-
#total_bytes_billed ⇒ Fixnum
Output only.
-
#total_bytes_processed ⇒ Fixnum
Output only.
-
#total_bytes_processed_accuracy ⇒ String
Output only.
-
#total_partitions_processed ⇒ Fixnum
Output only.
-
#total_services_sku_slot_ms ⇒ Fixnum
Output only.
-
#total_slot_ms ⇒ Fixnum
Output only.
-
#transferred_bytes ⇒ Fixnum
Output only.
-
#undeclared_query_parameters ⇒ Array<Google::Apis::BigqueryV2::QueryParameter>
Output only.
-
#vector_search_statistics ⇒ Google::Apis::BigqueryV2::VectorSearchStatistics
Statistics for a vector search query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobStatistics2
constructor
A new instance of JobStatistics2.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobStatistics2
Returns a new instance of JobStatistics2.
6760 6761 6762 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bi_engine_statistics ⇒ Google::Apis::BigqueryV2::BiEngineStatistics
Statistics for a BI Engine specific query. Populated as part of JobStatistics2
Corresponds to the JSON property biEngineStatistics
6403 6404 6405 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6403 def bi_engine_statistics @bi_engine_statistics end |
#billing_tier ⇒ Fixnum
Output only. Billing tier for the job. This is a BigQuery-specific concept
which is not related to the Google Cloud notion of "free tier". The value here
is a measure of the query's resource consumption relative to the amount of
data scanned. For on-demand queries, the limit is 100, and all queries within
this limit are billed at the standard on-demand rates. On-demand queries that
exceed this limit will fail with a billingTierLimitExceeded error.
Corresponds to the JSON property billingTier
6413 6414 6415 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6413 def billing_tier @billing_tier end |
#cache_hit ⇒ Boolean Also known as: cache_hit?
Output only. Whether the query result was fetched from the query cache.
Corresponds to the JSON property cacheHit
6418 6419 6420 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6418 def cache_hit @cache_hit end |
#dcl_target_dataset ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
Corresponds to the JSON property dclTargetDataset
6424 6425 6426 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6424 def dcl_target_dataset @dcl_target_dataset end |
#dcl_target_table ⇒ Google::Apis::BigqueryV2::TableReference
Output only. Referenced table for DCL statement.
Corresponds to the JSON property dclTargetTable
6429 6430 6431 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6429 def dcl_target_table @dcl_target_table end |
#dcl_target_view ⇒ Google::Apis::BigqueryV2::TableReference
Output only. Referenced view for DCL statement.
Corresponds to the JSON property dclTargetView
6434 6435 6436 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6434 def dcl_target_view @dcl_target_view end |
#ddl_affected_row_access_policy_count ⇒ Fixnum
Output only. The number of row access policies affected by a DDL statement.
Present only for DROP ALL ROW ACCESS POLICIES queries.
Corresponds to the JSON property ddlAffectedRowAccessPolicyCount
6440 6441 6442 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6440 def ddl_affected_row_access_policy_count @ddl_affected_row_access_policy_count end |
#ddl_destination_table ⇒ Google::Apis::BigqueryV2::TableReference
Output only. The table after rename. Present only for ALTER TABLE RENAME TO
query.
Corresponds to the JSON property ddlDestinationTable
6446 6447 6448 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6446 def ddl_destination_table @ddl_destination_table end |
#ddl_operation_performed ⇒ String
Output only. The DDL operation performed, possibly dependent on the pre-
existence of the DDL target.
Corresponds to the JSON property ddlOperationPerformed
6452 6453 6454 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6452 def ddl_operation_performed @ddl_operation_performed end |
#ddl_target_dataset ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
Corresponds to the JSON property ddlTargetDataset
6457 6458 6459 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6457 def ddl_target_dataset @ddl_target_dataset end |
#ddl_target_routine ⇒ Google::Apis::BigqueryV2::RoutineReference
Id path of a routine.
Corresponds to the JSON property ddlTargetRoutine
6462 6463 6464 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6462 def ddl_target_routine @ddl_target_routine end |
#ddl_target_row_access_policy ⇒ Google::Apis::BigqueryV2::RowAccessPolicyReference
Id path of a row access policy.
Corresponds to the JSON property ddlTargetRowAccessPolicy
6467 6468 6469 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6467 def ddl_target_row_access_policy @ddl_target_row_access_policy end |
#ddl_target_table ⇒ Google::Apis::BigqueryV2::TableReference
Output only. The DDL target table. Present only for CREATE/DROP TABLE/VIEW and
DROP ALL ROW ACCESS POLICIES queries.
Corresponds to the JSON property ddlTargetTable
6473 6474 6475 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6473 def ddl_target_table @ddl_target_table end |
#dml_stats ⇒ Google::Apis::BigqueryV2::DmlStatistics
Detailed statistics for DML statements
Corresponds to the JSON property dmlStats
6478 6479 6480 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6478 def dml_stats @dml_stats end |
#estimated_bytes_processed ⇒ Fixnum
Output only. The original estimate of bytes processed for the job.
Corresponds to the JSON property estimatedBytesProcessed
6483 6484 6485 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6483 def estimated_bytes_processed @estimated_bytes_processed end |
#export_data_statistics ⇒ Google::Apis::BigqueryV2::ExportDataStatistics
Statistics for the EXPORT DATA statement as part of Query Job. EXTRACT JOB
statistics are populated in JobStatistics4.
Corresponds to the JSON property exportDataStatistics
6489 6490 6491 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6489 def export_data_statistics @export_data_statistics end |
#external_service_costs ⇒ Array<Google::Apis::BigqueryV2::ExternalServiceCost>
Output only. Job cost breakdown as bigquery internal cost and external service
costs.
Corresponds to the JSON property externalServiceCosts
6495 6496 6497 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6495 def external_service_costs @external_service_costs end |
#gen_ai_stats ⇒ Google::Apis::BigqueryV2::GenAiStats
GenAi stats for the query job.
Corresponds to the JSON property genAiStats
6500 6501 6502 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6500 def gen_ai_stats @gen_ai_stats end |
#incremental_result_stats ⇒ Google::Apis::BigqueryV2::IncrementalResultStats
Statistics related to Incremental Query Results. Populated as part of
JobStatistics2. This feature is not yet available.
Corresponds to the JSON property incrementalResultStats
6506 6507 6508 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6506 def incremental_result_stats @incremental_result_stats end |
#load_query_statistics ⇒ Google::Apis::BigqueryV2::LoadQueryStatistics
Statistics for a LOAD query.
Corresponds to the JSON property loadQueryStatistics
6511 6512 6513 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6511 def load_query_statistics @load_query_statistics end |
#materialized_view_statistics ⇒ Google::Apis::BigqueryV2::MaterializedViewStatistics
Statistics of materialized views considered in a query job.
Corresponds to the JSON property materializedViewStatistics
6516 6517 6518 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6516 def materialized_view_statistics @materialized_view_statistics end |
#metadata_cache_statistics ⇒ Google::Apis::BigqueryV2::MetadataCacheStatistics
Statistics for metadata caching in queried tables.
Corresponds to the JSON property metadataCacheStatistics
6521 6522 6523 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6521 def @metadata_cache_statistics end |
#ml_statistics ⇒ Google::Apis::BigqueryV2::MlStatistics
Job statistics specific to a BigQuery ML training job.
Corresponds to the JSON property mlStatistics
6526 6527 6528 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6526 def ml_statistics @ml_statistics end |
#model_training ⇒ Google::Apis::BigqueryV2::BigQueryModelTraining
Deprecated.
Corresponds to the JSON property modelTraining
6531 6532 6533 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6531 def model_training @model_training end |
#model_training_current_iteration ⇒ Fixnum
Deprecated.
Corresponds to the JSON property modelTrainingCurrentIteration
6536 6537 6538 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6536 def model_training_current_iteration @model_training_current_iteration end |
#model_training_expected_total_iteration ⇒ Fixnum
Deprecated.
Corresponds to the JSON property modelTrainingExpectedTotalIteration
6541 6542 6543 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6541 def model_training_expected_total_iteration @model_training_expected_total_iteration end |
#num_dml_affected_rows ⇒ Fixnum
Output only. The number of rows affected by a DML statement. Present only for
DML statements INSERT, UPDATE or DELETE.
Corresponds to the JSON property numDmlAffectedRows
6547 6548 6549 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6547 def num_dml_affected_rows @num_dml_affected_rows end |
#performance_insights ⇒ Google::Apis::BigqueryV2::PerformanceInsights
Performance insights for the job.
Corresponds to the JSON property performanceInsights
6552 6553 6554 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6552 def performance_insights @performance_insights end |
#query_info ⇒ Google::Apis::BigqueryV2::QueryInfo
Query optimization information for a QUERY job.
Corresponds to the JSON property queryInfo
6557 6558 6559 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6557 def query_info @query_info end |
#query_plan ⇒ Array<Google::Apis::BigqueryV2::ExplainQueryStage>
Output only. Describes execution plan for the query.
Corresponds to the JSON property queryPlan
6562 6563 6564 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6562 def query_plan @query_plan end |
#referenced_property_graphs ⇒ Array<Google::Apis::BigqueryV2::PropertyGraphReference>
Output only. Referenced property graphs for the job. Queries that reference
more than 50 property graphs will not have a complete list.
Corresponds to the JSON property referencedPropertyGraphs
6568 6569 6570 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6568 def referenced_property_graphs @referenced_property_graphs end |
#referenced_routines ⇒ Array<Google::Apis::BigqueryV2::RoutineReference>
Output only. Referenced routines for the job.
Corresponds to the JSON property referencedRoutines
6573 6574 6575 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6573 def referenced_routines @referenced_routines end |
#referenced_tables ⇒ Array<Google::Apis::BigqueryV2::TableReference>
Output only. Referenced tables for the job.
Corresponds to the JSON property referencedTables
6578 6579 6580 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6578 def referenced_tables @referenced_tables end |
#reservation_usage ⇒ Array<Google::Apis::BigqueryV2::JobStatistics2::ReservationUsage>
Output only. Job resource usage breakdown by reservation. This field reported
misleading information and will no longer be populated.
Corresponds to the JSON property reservationUsage
6584 6585 6586 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6584 def reservation_usage @reservation_usage end |
#schema ⇒ Google::Apis::BigqueryV2::TableSchema
Schema of a table
Corresponds to the JSON property schema
6589 6590 6591 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6589 def schema @schema end |
#search_statistics ⇒ Google::Apis::BigqueryV2::SearchStatistics
Statistics for a search query. Populated as part of JobStatistics2.
Corresponds to the JSON property searchStatistics
6594 6595 6596 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6594 def search_statistics @search_statistics end |
#spark_statistics ⇒ Google::Apis::BigqueryV2::SparkStatistics
Statistics for a BigSpark query. Populated as part of JobStatistics2
Corresponds to the JSON property sparkStatistics
6599 6600 6601 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6599 def spark_statistics @spark_statistics end |
#statement_type ⇒ String
Output only. The type of query statement, if valid. Possible values: * SELECT
: SELECT statement. * ASSERT: ASSERT
statement. * INSERT: INSERT statement. * UPDATE:
UPDATE statement. * DELETE: DELETE
statement. * MERGE: MERGE statement. * CREATE_TABLE:
CREATE TABLE statement, without AS
SELECT. * CREATE_TABLE_AS_SELECT: CREATE TABLE AS SELECT statement. * CREATE_VIEW: CREATE VIEW statement. * CREATE_MODEL: CREATE MODEL statement. * CREATE_MATERIALIZED_VIEW:
CREATE MATERIALIZED VIEW
statement. * CREATE_FUNCTION: CREATE FUNCTION statement. * CREATE_TABLE_FUNCTION: CREATE
TABLE FUNCTION statement. *
CREATE_PROCEDURE: CREATE PROCEDURE statement. *
CREATE_ROW_ACCESS_POLICY: CREATE ROW ACCESS POLICY statement. * CREATE_SCHEMA: CREATE
SCHEMA statement. *
CREATE_SNAPSHOT_TABLE: CREATE SNAPSHOT TABLE statement. * CREATE_SEARCH_INDEX: CREATE
SEARCH INDEX statement. *
DROP_TABLE: DROP TABLE statement. *
DROP_EXTERNAL_TABLE: DROP EXTERNAL TABLE statement. * DROP_VIEW: DROP VIEW statement. * DROP_MODEL: DROP MODEL statement. * DROP_MATERIALIZED_VIEW: DROP MATERIALIZED VIEW statement. * DROP_FUNCTION :
DROP FUNCTION statement. *
DROP_TABLE_FUNCTION : DROP TABLE FUNCTION statement. * DROP_PROCEDURE: DROP PROCEDURE statement. * DROP_SEARCH_INDEX: DROP SEARCH
INDEX statement. * DROP_SCHEMA: DROP
SCHEMA statement. * DROP_SNAPSHOT_TABLE:
DROP SNAPSHOT TABLE statement.
DROP_ROW_ACCESS_POLICY:DROP [ALL] ROW ACCESS POLICY|POLICIESstatement. *ALTER_TABLE:ALTER TABLEstatement. *ALTER_VIEW:ALTER VIEWstatement. *ALTER_MATERIALIZED_VIEW:ALTER MATERIALIZED VIEWstatement. *ALTER_SCHEMA:ALTER SCHEMAstatement. *SCRIPT:SCRIPT. *TRUNCATE_TABLE:TRUNCATE TABLEstatement. *CREATE_EXTERNAL_TABLE:CREATE EXTERNAL TABLEstatement. *EXPORT_DATA:EXPORT DATAstatement. *EXPORT_MODEL:EXPORT MODELstatement. *LOAD_DATA:LOAD DATAstatement. *CALL:CALLstatement. Corresponds to the JSON propertystatementType
6692 6693 6694 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6692 def statement_type @statement_type end |
#timeline ⇒ Array<Google::Apis::BigqueryV2::QueryTimelineSample>
Output only. Describes a timeline of job execution.
Corresponds to the JSON property timeline
6697 6698 6699 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6697 def timeline @timeline end |
#total_bytes_billed ⇒ Fixnum
Output only. If the project is configured to use on-demand pricing, then this
field contains the total bytes billed for the job. If the project is
configured to use flat-rate pricing, then you are not billed for bytes and
this field is informational only.
Corresponds to the JSON property totalBytesBilled
6705 6706 6707 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6705 def total_bytes_billed @total_bytes_billed end |
#total_bytes_processed ⇒ Fixnum
Output only. Total bytes processed for the job.
Corresponds to the JSON property totalBytesProcessed
6710 6711 6712 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6710 def total_bytes_processed @total_bytes_processed end |
#total_bytes_processed_accuracy ⇒ String
Output only. For dry-run jobs, totalBytesProcessed is an estimate and this
field specifies the accuracy of the estimate. Possible values can be: UNKNOWN:
accuracy of the estimate is unknown. PRECISE: estimate is precise. LOWER_BOUND:
estimate is lower bound of what the query would cost. UPPER_BOUND: estimate
is upper bound of what the query would cost.
Corresponds to the JSON property totalBytesProcessedAccuracy
6719 6720 6721 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6719 def total_bytes_processed_accuracy @total_bytes_processed_accuracy end |
#total_partitions_processed ⇒ Fixnum
Output only. Total number of partitions processed from all partitioned tables
referenced in the job.
Corresponds to the JSON property totalPartitionsProcessed
6725 6726 6727 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6725 def total_partitions_processed @total_partitions_processed end |
#total_services_sku_slot_ms ⇒ Fixnum
Output only. Total slot milliseconds for the job that ran on external services
and billed on the services SKU. This field is only populated for jobs that
have external service costs, and is the total of the usage for costs whose
billing method is "SERVICES_SKU".
Corresponds to the JSON property totalServicesSkuSlotMs
6733 6734 6735 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6733 def total_services_sku_slot_ms @total_services_sku_slot_ms end |
#total_slot_ms ⇒ Fixnum
Output only. Slot-milliseconds for the job.
Corresponds to the JSON property totalSlotMs
6738 6739 6740 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6738 def total_slot_ms @total_slot_ms end |
#transferred_bytes ⇒ Fixnum
Output only. Total bytes transferred for BigQuery Omni queries from the remote
cloud back to Google Cloud. This tracks data movement over Google-managed
connections (like query results). It doesn't include input data read from the
external data lake (for example, S3) because that data stays within the remote
cloud.
Corresponds to the JSON property transferredBytes
6747 6748 6749 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6747 def transferred_bytes @transferred_bytes end |
#undeclared_query_parameters ⇒ Array<Google::Apis::BigqueryV2::QueryParameter>
Output only. GoogleSQL only: list of undeclared query parameters detected
during a dry run validation.
Corresponds to the JSON property undeclaredQueryParameters
6753 6754 6755 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6753 def undeclared_query_parameters @undeclared_query_parameters end |
#vector_search_statistics ⇒ Google::Apis::BigqueryV2::VectorSearchStatistics
Statistics for a vector search query. Populated as part of JobStatistics2.
Corresponds to the JSON property vectorSearchStatistics
6758 6759 6760 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6758 def vector_search_statistics @vector_search_statistics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6765 6766 6767 6768 6769 6770 6771 6772 6773 6774 6775 6776 6777 6778 6779 6780 6781 6782 6783 6784 6785 6786 6787 6788 6789 6790 6791 6792 6793 6794 6795 6796 6797 6798 6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 6811 6812 6813 6814 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6765 def update!(**args) @bi_engine_statistics = args[:bi_engine_statistics] if args.key?(:bi_engine_statistics) @billing_tier = args[:billing_tier] if args.key?(:billing_tier) @cache_hit = args[:cache_hit] if args.key?(:cache_hit) @dcl_target_dataset = args[:dcl_target_dataset] if args.key?(:dcl_target_dataset) @dcl_target_table = args[:dcl_target_table] if args.key?(:dcl_target_table) @dcl_target_view = args[:dcl_target_view] if args.key?(:dcl_target_view) @ddl_affected_row_access_policy_count = args[:ddl_affected_row_access_policy_count] if args.key?(:ddl_affected_row_access_policy_count) @ddl_destination_table = args[:ddl_destination_table] if args.key?(:ddl_destination_table) @ddl_operation_performed = args[:ddl_operation_performed] if args.key?(:ddl_operation_performed) @ddl_target_dataset = args[:ddl_target_dataset] if args.key?(:ddl_target_dataset) @ddl_target_routine = args[:ddl_target_routine] if args.key?(:ddl_target_routine) @ddl_target_row_access_policy = args[:ddl_target_row_access_policy] if args.key?(:ddl_target_row_access_policy) @ddl_target_table = args[:ddl_target_table] if args.key?(:ddl_target_table) @dml_stats = args[:dml_stats] if args.key?(:dml_stats) @estimated_bytes_processed = args[:estimated_bytes_processed] if args.key?(:estimated_bytes_processed) @export_data_statistics = args[:export_data_statistics] if args.key?(:export_data_statistics) @external_service_costs = args[:external_service_costs] if args.key?(:external_service_costs) @gen_ai_stats = args[:gen_ai_stats] if args.key?(:gen_ai_stats) @incremental_result_stats = args[:incremental_result_stats] if args.key?(:incremental_result_stats) @load_query_statistics = args[:load_query_statistics] if args.key?(:load_query_statistics) @materialized_view_statistics = args[:materialized_view_statistics] if args.key?(:materialized_view_statistics) @metadata_cache_statistics = args[:metadata_cache_statistics] if args.key?(:metadata_cache_statistics) @ml_statistics = args[:ml_statistics] if args.key?(:ml_statistics) @model_training = args[:model_training] if args.key?(:model_training) @model_training_current_iteration = args[:model_training_current_iteration] if args.key?(:model_training_current_iteration) @model_training_expected_total_iteration = args[:model_training_expected_total_iteration] if args.key?(:model_training_expected_total_iteration) @num_dml_affected_rows = args[:num_dml_affected_rows] if args.key?(:num_dml_affected_rows) @performance_insights = args[:performance_insights] if args.key?(:performance_insights) @query_info = args[:query_info] if args.key?(:query_info) @query_plan = args[:query_plan] if args.key?(:query_plan) @referenced_property_graphs = args[:referenced_property_graphs] if args.key?(:referenced_property_graphs) @referenced_routines = args[:referenced_routines] if args.key?(:referenced_routines) @referenced_tables = args[:referenced_tables] if args.key?(:referenced_tables) @reservation_usage = args[:reservation_usage] if args.key?(:reservation_usage) @schema = args[:schema] if args.key?(:schema) @search_statistics = args[:search_statistics] if args.key?(:search_statistics) @spark_statistics = args[:spark_statistics] if args.key?(:spark_statistics) @statement_type = args[:statement_type] if args.key?(:statement_type) @timeline = args[:timeline] if args.key?(:timeline) @total_bytes_billed = args[:total_bytes_billed] if args.key?(:total_bytes_billed) @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed) @total_bytes_processed_accuracy = args[:total_bytes_processed_accuracy] if args.key?(:total_bytes_processed_accuracy) @total_partitions_processed = args[:total_partitions_processed] if args.key?(:total_partitions_processed) @total_services_sku_slot_ms = args[:total_services_sku_slot_ms] if args.key?(:total_services_sku_slot_ms) @total_slot_ms = args[:total_slot_ms] if args.key?(:total_slot_ms) @transferred_bytes = args[:transferred_bytes] if args.key?(:transferred_bytes) @undeclared_query_parameters = args[:undeclared_query_parameters] if args.key?(:undeclared_query_parameters) @vector_search_statistics = args[:vector_search_statistics] if args.key?(:vector_search_statistics) end |