Class: Google::Apis::BigqueryV2::JobStatistics2

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics for a query job.

Defined Under Namespace

Classes: ReservationUsage

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobStatistics2

Returns a new instance of JobStatistics2.



6681
6682
6683
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bi_engine_statisticsGoogle::Apis::BigqueryV2::BiEngineStatistics

Statistics for a BI Engine specific query. Populated as part of JobStatistics2 Corresponds to the JSON property biEngineStatistics



6327
6328
6329
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6327

def bi_engine_statistics
  @bi_engine_statistics
end

#billing_tierFixnum

Output only. Billing tier for the job. This is a BigQuery-specific concept which is not related to the Google Cloud notion of "free tier". The value here is a measure of the query's resource consumption relative to the amount of data scanned. For on-demand queries, the limit is 100, and all queries within this limit are billed at the standard on-demand rates. On-demand queries that exceed this limit will fail with a billingTierLimitExceeded error. Corresponds to the JSON property billingTier

Returns:

  • (Fixnum)


6337
6338
6339
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6337

def billing_tier
  @billing_tier
end

#cache_hitBoolean Also known as: cache_hit?

Output only. Whether the query result was fetched from the query cache. Corresponds to the JSON property cacheHit

Returns:

  • (Boolean)


6342
6343
6344
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6342

def cache_hit
  @cache_hit
end

#dcl_target_datasetGoogle::Apis::BigqueryV2::DatasetReference

Identifier for a dataset. Corresponds to the JSON property dclTargetDataset



6348
6349
6350
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6348

def dcl_target_dataset
  @dcl_target_dataset
end

#dcl_target_tableGoogle::Apis::BigqueryV2::TableReference

Output only. Referenced table for DCL statement. Corresponds to the JSON property dclTargetTable



6353
6354
6355
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6353

def dcl_target_table
  @dcl_target_table
end

#dcl_target_viewGoogle::Apis::BigqueryV2::TableReference

Output only. Referenced view for DCL statement. Corresponds to the JSON property dclTargetView



6358
6359
6360
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6358

def dcl_target_view
  @dcl_target_view
end

#ddl_affected_row_access_policy_countFixnum

Output only. The number of row access policies affected by a DDL statement. Present only for DROP ALL ROW ACCESS POLICIES queries. Corresponds to the JSON property ddlAffectedRowAccessPolicyCount

Returns:

  • (Fixnum)


6364
6365
6366
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6364

def ddl_affected_row_access_policy_count
  @ddl_affected_row_access_policy_count
end

#ddl_destination_tableGoogle::Apis::BigqueryV2::TableReference

Output only. The table after rename. Present only for ALTER TABLE RENAME TO query. Corresponds to the JSON property ddlDestinationTable



6370
6371
6372
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6370

def ddl_destination_table
  @ddl_destination_table
end

#ddl_operation_performedString

Output only. The DDL operation performed, possibly dependent on the pre- existence of the DDL target. Corresponds to the JSON property ddlOperationPerformed

Returns:

  • (String)


6376
6377
6378
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6376

def ddl_operation_performed
  @ddl_operation_performed
end

#ddl_target_datasetGoogle::Apis::BigqueryV2::DatasetReference

Identifier for a dataset. Corresponds to the JSON property ddlTargetDataset



6381
6382
6383
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6381

def ddl_target_dataset
  @ddl_target_dataset
end

#ddl_target_routineGoogle::Apis::BigqueryV2::RoutineReference

Id path of a routine. Corresponds to the JSON property ddlTargetRoutine



6386
6387
6388
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6386

def ddl_target_routine
  @ddl_target_routine
end

#ddl_target_row_access_policyGoogle::Apis::BigqueryV2::RowAccessPolicyReference

Id path of a row access policy. Corresponds to the JSON property ddlTargetRowAccessPolicy



6391
6392
6393
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6391

def ddl_target_row_access_policy
  @ddl_target_row_access_policy
end

#ddl_target_tableGoogle::Apis::BigqueryV2::TableReference

Output only. The DDL target table. Present only for CREATE/DROP TABLE/VIEW and DROP ALL ROW ACCESS POLICIES queries. Corresponds to the JSON property ddlTargetTable



6397
6398
6399
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6397

def ddl_target_table
  @ddl_target_table
end

#dml_statsGoogle::Apis::BigqueryV2::DmlStatistics

Detailed statistics for DML statements Corresponds to the JSON property dmlStats



6402
6403
6404
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6402

def dml_stats
  @dml_stats
end

#estimated_bytes_processedFixnum

Output only. The original estimate of bytes processed for the job. Corresponds to the JSON property estimatedBytesProcessed

Returns:

  • (Fixnum)


6407
6408
6409
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6407

def estimated_bytes_processed
  @estimated_bytes_processed
end

#export_data_statisticsGoogle::Apis::BigqueryV2::ExportDataStatistics

Statistics for the EXPORT DATA statement as part of Query Job. EXTRACT JOB statistics are populated in JobStatistics4. Corresponds to the JSON property exportDataStatistics



6413
6414
6415
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6413

def export_data_statistics
  @export_data_statistics
end

#external_service_costsArray<Google::Apis::BigqueryV2::ExternalServiceCost>

Output only. Job cost breakdown as bigquery internal cost and external service costs. Corresponds to the JSON property externalServiceCosts



6419
6420
6421
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6419

def external_service_costs
  @external_service_costs
end

#gen_ai_statsGoogle::Apis::BigqueryV2::GenAiStats

GenAi stats for the query job. Corresponds to the JSON property genAiStats



6424
6425
6426
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6424

def gen_ai_stats
  @gen_ai_stats
end

#incremental_result_statsGoogle::Apis::BigqueryV2::IncrementalResultStats

Statistics related to Incremental Query Results. Populated as part of JobStatistics2. This feature is not yet available. Corresponds to the JSON property incrementalResultStats



6430
6431
6432
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6430

def incremental_result_stats
  @incremental_result_stats
end

#load_query_statisticsGoogle::Apis::BigqueryV2::LoadQueryStatistics

Statistics for a LOAD query. Corresponds to the JSON property loadQueryStatistics



6435
6436
6437
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6435

def load_query_statistics
  @load_query_statistics
end

#materialized_view_statisticsGoogle::Apis::BigqueryV2::MaterializedViewStatistics

Statistics of materialized views considered in a query job. Corresponds to the JSON property materializedViewStatistics



6440
6441
6442
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6440

def materialized_view_statistics
  @materialized_view_statistics
end

#metadata_cache_statisticsGoogle::Apis::BigqueryV2::MetadataCacheStatistics

Statistics for metadata caching in queried tables. Corresponds to the JSON property metadataCacheStatistics



6445
6446
6447
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6445

def 
  @metadata_cache_statistics
end

#ml_statisticsGoogle::Apis::BigqueryV2::MlStatistics

Job statistics specific to a BigQuery ML training job. Corresponds to the JSON property mlStatistics



6450
6451
6452
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6450

def ml_statistics
  @ml_statistics
end

#model_trainingGoogle::Apis::BigqueryV2::BigQueryModelTraining

Deprecated. Corresponds to the JSON property modelTraining



6455
6456
6457
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6455

def model_training
  @model_training
end

#model_training_current_iterationFixnum

Deprecated. Corresponds to the JSON property modelTrainingCurrentIteration

Returns:

  • (Fixnum)


6460
6461
6462
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6460

def model_training_current_iteration
  @model_training_current_iteration
end

#model_training_expected_total_iterationFixnum

Deprecated. Corresponds to the JSON property modelTrainingExpectedTotalIteration

Returns:

  • (Fixnum)


6465
6466
6467
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6465

def model_training_expected_total_iteration
  @model_training_expected_total_iteration
end

#num_dml_affected_rowsFixnum

Output only. The number of rows affected by a DML statement. Present only for DML statements INSERT, UPDATE or DELETE. Corresponds to the JSON property numDmlAffectedRows

Returns:

  • (Fixnum)


6471
6472
6473
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6471

def num_dml_affected_rows
  @num_dml_affected_rows
end

#performance_insightsGoogle::Apis::BigqueryV2::PerformanceInsights

Performance insights for the job. Corresponds to the JSON property performanceInsights



6476
6477
6478
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6476

def performance_insights
  @performance_insights
end

#query_infoGoogle::Apis::BigqueryV2::QueryInfo

Query optimization information for a QUERY job. Corresponds to the JSON property queryInfo



6481
6482
6483
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6481

def query_info
  @query_info
end

#query_planArray<Google::Apis::BigqueryV2::ExplainQueryStage>

Output only. Describes execution plan for the query. Corresponds to the JSON property queryPlan



6486
6487
6488
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6486

def query_plan
  @query_plan
end

#referenced_property_graphsArray<Google::Apis::BigqueryV2::PropertyGraphReference>

Output only. Referenced property graphs for the job. Queries that reference more than 50 property graphs will not have a complete list. Corresponds to the JSON property referencedPropertyGraphs



6492
6493
6494
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6492

def referenced_property_graphs
  @referenced_property_graphs
end

#referenced_routinesArray<Google::Apis::BigqueryV2::RoutineReference>

Output only. Referenced routines for the job. Corresponds to the JSON property referencedRoutines



6497
6498
6499
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6497

def referenced_routines
  @referenced_routines
end

#referenced_tablesArray<Google::Apis::BigqueryV2::TableReference>

Output only. Referenced tables for the job. Corresponds to the JSON property referencedTables



6502
6503
6504
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6502

def referenced_tables
  @referenced_tables
end

#reservation_usageArray<Google::Apis::BigqueryV2::JobStatistics2::ReservationUsage>

Output only. Job resource usage breakdown by reservation. This field reported misleading information and will no longer be populated. Corresponds to the JSON property reservationUsage



6508
6509
6510
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6508

def reservation_usage
  @reservation_usage
end

#schemaGoogle::Apis::BigqueryV2::TableSchema

Schema of a table Corresponds to the JSON property schema



6513
6514
6515
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6513

def schema
  @schema
end

#search_statisticsGoogle::Apis::BigqueryV2::SearchStatistics

Statistics for a search query. Populated as part of JobStatistics2. Corresponds to the JSON property searchStatistics



6518
6519
6520
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6518

def search_statistics
  @search_statistics
end

#spark_statisticsGoogle::Apis::BigqueryV2::SparkStatistics

Statistics for a BigSpark query. Populated as part of JobStatistics2 Corresponds to the JSON property sparkStatistics



6523
6524
6525
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6523

def spark_statistics
  @spark_statistics
end

#statement_typeString

Output only. The type of query statement, if valid. Possible values: * SELECT : SELECT statement. * ASSERT: ASSERT statement. * INSERT: INSERT statement. * UPDATE: UPDATE statement. * DELETE: DELETE statement. * MERGE: MERGE statement. * CREATE_TABLE: CREATE TABLE statement, without AS SELECT. * CREATE_TABLE_AS_SELECT: CREATE TABLE AS SELECT statement. * CREATE_VIEW: CREATE VIEW statement. * CREATE_MODEL: CREATE MODEL statement. * CREATE_MATERIALIZED_VIEW: CREATE MATERIALIZED VIEW statement. * CREATE_FUNCTION: CREATE FUNCTION statement. * CREATE_TABLE_FUNCTION: CREATE TABLE FUNCTION statement. * CREATE_PROCEDURE: CREATE PROCEDURE statement. * CREATE_ROW_ACCESS_POLICY: CREATE ROW ACCESS POLICY statement. * CREATE_SCHEMA: CREATE SCHEMA statement. * CREATE_SNAPSHOT_TABLE: CREATE SNAPSHOT TABLE statement. * CREATE_SEARCH_INDEX: CREATE SEARCH INDEX statement. * DROP_TABLE: DROP TABLE statement. * DROP_EXTERNAL_TABLE: DROP EXTERNAL TABLE statement. * DROP_VIEW: DROP VIEW statement. * DROP_MODEL: DROP MODEL statement. * DROP_MATERIALIZED_VIEW: DROP MATERIALIZED VIEW statement. * DROP_FUNCTION : DROP FUNCTION statement. * DROP_TABLE_FUNCTION : DROP TABLE FUNCTION statement. * DROP_PROCEDURE: DROP PROCEDURE statement. * DROP_SEARCH_INDEX: DROP SEARCH INDEX statement. * DROP_SCHEMA: DROP SCHEMA statement. * DROP_SNAPSHOT_TABLE: DROP SNAPSHOT TABLE statement.

Returns:

  • (String)


6616
6617
6618
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6616

def statement_type
  @statement_type
end

#timelineArray<Google::Apis::BigqueryV2::QueryTimelineSample>

Output only. Describes a timeline of job execution. Corresponds to the JSON property timeline



6621
6622
6623
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6621

def timeline
  @timeline
end

#total_bytes_billedFixnum

Output only. If the project is configured to use on-demand pricing, then this field contains the total bytes billed for the job. If the project is configured to use flat-rate pricing, then you are not billed for bytes and this field is informational only. Corresponds to the JSON property totalBytesBilled

Returns:

  • (Fixnum)


6629
6630
6631
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6629

def total_bytes_billed
  @total_bytes_billed
end

#total_bytes_processedFixnum

Output only. Total bytes processed for the job. Corresponds to the JSON property totalBytesProcessed

Returns:

  • (Fixnum)


6634
6635
6636
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6634

def total_bytes_processed
  @total_bytes_processed
end

#total_bytes_processed_accuracyString

Output only. For dry-run jobs, totalBytesProcessed is an estimate and this field specifies the accuracy of the estimate. Possible values can be: UNKNOWN: accuracy of the estimate is unknown. PRECISE: estimate is precise. LOWER_BOUND: estimate is lower bound of what the query would cost. UPPER_BOUND: estimate is upper bound of what the query would cost. Corresponds to the JSON property totalBytesProcessedAccuracy

Returns:

  • (String)


6643
6644
6645
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6643

def total_bytes_processed_accuracy
  @total_bytes_processed_accuracy
end

#total_partitions_processedFixnum

Output only. Total number of partitions processed from all partitioned tables referenced in the job. Corresponds to the JSON property totalPartitionsProcessed

Returns:

  • (Fixnum)


6649
6650
6651
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6649

def total_partitions_processed
  @total_partitions_processed
end

#total_services_sku_slot_msFixnum

Output only. Total slot milliseconds for the job that ran on external services and billed on the services SKU. This field is only populated for jobs that have external service costs, and is the total of the usage for costs whose billing method is "SERVICES_SKU". Corresponds to the JSON property totalServicesSkuSlotMs

Returns:

  • (Fixnum)


6657
6658
6659
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6657

def total_services_sku_slot_ms
  @total_services_sku_slot_ms
end

#total_slot_msFixnum

Output only. Slot-milliseconds for the job. Corresponds to the JSON property totalSlotMs

Returns:

  • (Fixnum)


6662
6663
6664
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6662

def total_slot_ms
  @total_slot_ms
end

#transferred_bytesFixnum

Output only. Total bytes transferred for cross-cloud queries such as Cross Cloud Transfer and CREATE TABLE AS SELECT (CTAS). Corresponds to the JSON property transferredBytes

Returns:

  • (Fixnum)


6668
6669
6670
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6668

def transferred_bytes
  @transferred_bytes
end

#undeclared_query_parametersArray<Google::Apis::BigqueryV2::QueryParameter>

Output only. GoogleSQL only: list of undeclared query parameters detected during a dry run validation. Corresponds to the JSON property undeclaredQueryParameters



6674
6675
6676
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6674

def undeclared_query_parameters
  @undeclared_query_parameters
end

#vector_search_statisticsGoogle::Apis::BigqueryV2::VectorSearchStatistics

Statistics for a vector search query. Populated as part of JobStatistics2. Corresponds to the JSON property vectorSearchStatistics



6679
6680
6681
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6679

def vector_search_statistics
  @vector_search_statistics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6686
6687
6688
6689
6690
6691
6692
6693
6694
6695
6696
6697
6698
6699
6700
6701
6702
6703
6704
6705
6706
6707
6708
6709
6710
6711
6712
6713
6714
6715
6716
6717
6718
6719
6720
6721
6722
6723
6724
6725
6726
6727
6728
6729
6730
6731
6732
6733
6734
6735
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6686

def update!(**args)
  @bi_engine_statistics = args[:bi_engine_statistics] if args.key?(:bi_engine_statistics)
  @billing_tier = args[:billing_tier] if args.key?(:billing_tier)
  @cache_hit = args[:cache_hit] if args.key?(:cache_hit)
  @dcl_target_dataset = args[:dcl_target_dataset] if args.key?(:dcl_target_dataset)
  @dcl_target_table = args[:dcl_target_table] if args.key?(:dcl_target_table)
  @dcl_target_view = args[:dcl_target_view] if args.key?(:dcl_target_view)
  @ddl_affected_row_access_policy_count = args[:ddl_affected_row_access_policy_count] if args.key?(:ddl_affected_row_access_policy_count)
  @ddl_destination_table = args[:ddl_destination_table] if args.key?(:ddl_destination_table)
  @ddl_operation_performed = args[:ddl_operation_performed] if args.key?(:ddl_operation_performed)
  @ddl_target_dataset = args[:ddl_target_dataset] if args.key?(:ddl_target_dataset)
  @ddl_target_routine = args[:ddl_target_routine] if args.key?(:ddl_target_routine)
  @ddl_target_row_access_policy = args[:ddl_target_row_access_policy] if args.key?(:ddl_target_row_access_policy)
  @ddl_target_table = args[:ddl_target_table] if args.key?(:ddl_target_table)
  @dml_stats = args[:dml_stats] if args.key?(:dml_stats)
  @estimated_bytes_processed = args[:estimated_bytes_processed] if args.key?(:estimated_bytes_processed)
  @export_data_statistics = args[:export_data_statistics] if args.key?(:export_data_statistics)
  @external_service_costs = args[:external_service_costs] if args.key?(:external_service_costs)
  @gen_ai_stats = args[:gen_ai_stats] if args.key?(:gen_ai_stats)
  @incremental_result_stats = args[:incremental_result_stats] if args.key?(:incremental_result_stats)
  @load_query_statistics = args[:load_query_statistics] if args.key?(:load_query_statistics)
  @materialized_view_statistics = args[:materialized_view_statistics] if args.key?(:materialized_view_statistics)
  @metadata_cache_statistics = args[:metadata_cache_statistics] if args.key?(:metadata_cache_statistics)
  @ml_statistics = args[:ml_statistics] if args.key?(:ml_statistics)
  @model_training = args[:model_training] if args.key?(:model_training)
  @model_training_current_iteration = args[:model_training_current_iteration] if args.key?(:model_training_current_iteration)
  @model_training_expected_total_iteration = args[:model_training_expected_total_iteration] if args.key?(:model_training_expected_total_iteration)
  @num_dml_affected_rows = args[:num_dml_affected_rows] if args.key?(:num_dml_affected_rows)
  @performance_insights = args[:performance_insights] if args.key?(:performance_insights)
  @query_info = args[:query_info] if args.key?(:query_info)
  @query_plan = args[:query_plan] if args.key?(:query_plan)
  @referenced_property_graphs = args[:referenced_property_graphs] if args.key?(:referenced_property_graphs)
  @referenced_routines = args[:referenced_routines] if args.key?(:referenced_routines)
  @referenced_tables = args[:referenced_tables] if args.key?(:referenced_tables)
  @reservation_usage = args[:reservation_usage] if args.key?(:reservation_usage)
  @schema = args[:schema] if args.key?(:schema)
  @search_statistics = args[:search_statistics] if args.key?(:search_statistics)
  @spark_statistics = args[:spark_statistics] if args.key?(:spark_statistics)
  @statement_type = args[:statement_type] if args.key?(:statement_type)
  @timeline = args[:timeline] if args.key?(:timeline)
  @total_bytes_billed = args[:total_bytes_billed] if args.key?(:total_bytes_billed)
  @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed)
  @total_bytes_processed_accuracy = args[:total_bytes_processed_accuracy] if args.key?(:total_bytes_processed_accuracy)
  @total_partitions_processed = args[:total_partitions_processed] if args.key?(:total_partitions_processed)
  @total_services_sku_slot_ms = args[:total_services_sku_slot_ms] if args.key?(:total_services_sku_slot_ms)
  @total_slot_ms = args[:total_slot_ms] if args.key?(:total_slot_ms)
  @transferred_bytes = args[:transferred_bytes] if args.key?(:transferred_bytes)
  @undeclared_query_parameters = args[:undeclared_query_parameters] if args.key?(:undeclared_query_parameters)
  @vector_search_statistics = args[:vector_search_statistics] if args.key?(:vector_search_statistics)
end