Class: Google::Apis::BigqueryV2::JobStatistics2

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics for a query job.

Defined Under Namespace

Classes: ReservationUsage

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobStatistics2

Returns a new instance of JobStatistics2.



6627
6628
6629
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6627

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bi_engine_statisticsGoogle::Apis::BigqueryV2::BiEngineStatistics

Statistics for a BI Engine specific query. Populated as part of JobStatistics2 Corresponds to the JSON property biEngineStatistics



6273
6274
6275
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6273

def bi_engine_statistics
  @bi_engine_statistics
end

#billing_tierFixnum

Output only. Billing tier for the job. This is a BigQuery-specific concept which is not related to the Google Cloud notion of "free tier". The value here is a measure of the query's resource consumption relative to the amount of data scanned. For on-demand queries, the limit is 100, and all queries within this limit are billed at the standard on-demand rates. On-demand queries that exceed this limit will fail with a billingTierLimitExceeded error. Corresponds to the JSON property billingTier

Returns:

  • (Fixnum)


6283
6284
6285
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6283

def billing_tier
  @billing_tier
end

#cache_hitBoolean Also known as: cache_hit?

Output only. Whether the query result was fetched from the query cache. Corresponds to the JSON property cacheHit

Returns:

  • (Boolean)


6288
6289
6290
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6288

def cache_hit
  @cache_hit
end

#dcl_target_datasetGoogle::Apis::BigqueryV2::DatasetReference

Identifier for a dataset. Corresponds to the JSON property dclTargetDataset



6294
6295
6296
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6294

def dcl_target_dataset
  @dcl_target_dataset
end

#dcl_target_tableGoogle::Apis::BigqueryV2::TableReference

Output only. Referenced table for DCL statement. Corresponds to the JSON property dclTargetTable



6299
6300
6301
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6299

def dcl_target_table
  @dcl_target_table
end

#dcl_target_viewGoogle::Apis::BigqueryV2::TableReference

Output only. Referenced view for DCL statement. Corresponds to the JSON property dclTargetView



6304
6305
6306
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6304

def dcl_target_view
  @dcl_target_view
end

#ddl_affected_row_access_policy_countFixnum

Output only. The number of row access policies affected by a DDL statement. Present only for DROP ALL ROW ACCESS POLICIES queries. Corresponds to the JSON property ddlAffectedRowAccessPolicyCount

Returns:

  • (Fixnum)


6310
6311
6312
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6310

def ddl_affected_row_access_policy_count
  @ddl_affected_row_access_policy_count
end

#ddl_destination_tableGoogle::Apis::BigqueryV2::TableReference

Output only. The table after rename. Present only for ALTER TABLE RENAME TO query. Corresponds to the JSON property ddlDestinationTable



6316
6317
6318
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6316

def ddl_destination_table
  @ddl_destination_table
end

#ddl_operation_performedString

Output only. The DDL operation performed, possibly dependent on the pre- existence of the DDL target. Corresponds to the JSON property ddlOperationPerformed

Returns:

  • (String)


6322
6323
6324
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6322

def ddl_operation_performed
  @ddl_operation_performed
end

#ddl_target_datasetGoogle::Apis::BigqueryV2::DatasetReference

Identifier for a dataset. Corresponds to the JSON property ddlTargetDataset



6327
6328
6329
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6327

def ddl_target_dataset
  @ddl_target_dataset
end

#ddl_target_routineGoogle::Apis::BigqueryV2::RoutineReference

Id path of a routine. Corresponds to the JSON property ddlTargetRoutine



6332
6333
6334
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6332

def ddl_target_routine
  @ddl_target_routine
end

#ddl_target_row_access_policyGoogle::Apis::BigqueryV2::RowAccessPolicyReference

Id path of a row access policy. Corresponds to the JSON property ddlTargetRowAccessPolicy



6337
6338
6339
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6337

def ddl_target_row_access_policy
  @ddl_target_row_access_policy
end

#ddl_target_tableGoogle::Apis::BigqueryV2::TableReference

Output only. The DDL target table. Present only for CREATE/DROP TABLE/VIEW and DROP ALL ROW ACCESS POLICIES queries. Corresponds to the JSON property ddlTargetTable



6343
6344
6345
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6343

def ddl_target_table
  @ddl_target_table
end

#dml_statsGoogle::Apis::BigqueryV2::DmlStatistics

Detailed statistics for DML statements Corresponds to the JSON property dmlStats



6348
6349
6350
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6348

def dml_stats
  @dml_stats
end

#estimated_bytes_processedFixnum

Output only. The original estimate of bytes processed for the job. Corresponds to the JSON property estimatedBytesProcessed

Returns:

  • (Fixnum)


6353
6354
6355
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6353

def estimated_bytes_processed
  @estimated_bytes_processed
end

#export_data_statisticsGoogle::Apis::BigqueryV2::ExportDataStatistics

Statistics for the EXPORT DATA statement as part of Query Job. EXTRACT JOB statistics are populated in JobStatistics4. Corresponds to the JSON property exportDataStatistics



6359
6360
6361
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6359

def export_data_statistics
  @export_data_statistics
end

#external_service_costsArray<Google::Apis::BigqueryV2::ExternalServiceCost>

Output only. Job cost breakdown as bigquery internal cost and external service costs. Corresponds to the JSON property externalServiceCosts



6365
6366
6367
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6365

def external_service_costs
  @external_service_costs
end

#gen_ai_statsGoogle::Apis::BigqueryV2::GenAiStats

GenAi stats for the query job. Corresponds to the JSON property genAiStats



6370
6371
6372
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6370

def gen_ai_stats
  @gen_ai_stats
end

#incremental_result_statsGoogle::Apis::BigqueryV2::IncrementalResultStats

Statistics related to Incremental Query Results. Populated as part of JobStatistics2. This feature is not yet available. Corresponds to the JSON property incrementalResultStats



6376
6377
6378
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6376

def incremental_result_stats
  @incremental_result_stats
end

#load_query_statisticsGoogle::Apis::BigqueryV2::LoadQueryStatistics

Statistics for a LOAD query. Corresponds to the JSON property loadQueryStatistics



6381
6382
6383
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6381

def load_query_statistics
  @load_query_statistics
end

#materialized_view_statisticsGoogle::Apis::BigqueryV2::MaterializedViewStatistics

Statistics of materialized views considered in a query job. Corresponds to the JSON property materializedViewStatistics



6386
6387
6388
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6386

def materialized_view_statistics
  @materialized_view_statistics
end

#metadata_cache_statisticsGoogle::Apis::BigqueryV2::MetadataCacheStatistics

Statistics for metadata caching in queried tables. Corresponds to the JSON property metadataCacheStatistics



6391
6392
6393
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6391

def 
  @metadata_cache_statistics
end

#ml_statisticsGoogle::Apis::BigqueryV2::MlStatistics

Job statistics specific to a BigQuery ML training job. Corresponds to the JSON property mlStatistics



6396
6397
6398
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6396

def ml_statistics
  @ml_statistics
end

#model_trainingGoogle::Apis::BigqueryV2::BigQueryModelTraining

Deprecated. Corresponds to the JSON property modelTraining



6401
6402
6403
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6401

def model_training
  @model_training
end

#model_training_current_iterationFixnum

Deprecated. Corresponds to the JSON property modelTrainingCurrentIteration

Returns:

  • (Fixnum)


6406
6407
6408
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6406

def model_training_current_iteration
  @model_training_current_iteration
end

#model_training_expected_total_iterationFixnum

Deprecated. Corresponds to the JSON property modelTrainingExpectedTotalIteration

Returns:

  • (Fixnum)


6411
6412
6413
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6411

def model_training_expected_total_iteration
  @model_training_expected_total_iteration
end

#num_dml_affected_rowsFixnum

Output only. The number of rows affected by a DML statement. Present only for DML statements INSERT, UPDATE or DELETE. Corresponds to the JSON property numDmlAffectedRows

Returns:

  • (Fixnum)


6417
6418
6419
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6417

def num_dml_affected_rows
  @num_dml_affected_rows
end

#performance_insightsGoogle::Apis::BigqueryV2::PerformanceInsights

Performance insights for the job. Corresponds to the JSON property performanceInsights



6422
6423
6424
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6422

def performance_insights
  @performance_insights
end

#query_infoGoogle::Apis::BigqueryV2::QueryInfo

Query optimization information for a QUERY job. Corresponds to the JSON property queryInfo



6427
6428
6429
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6427

def query_info
  @query_info
end

#query_planArray<Google::Apis::BigqueryV2::ExplainQueryStage>

Output only. Describes execution plan for the query. Corresponds to the JSON property queryPlan



6432
6433
6434
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6432

def query_plan
  @query_plan
end

#referenced_property_graphsArray<Google::Apis::BigqueryV2::PropertyGraphReference>

Output only. Referenced property graphs for the job. Queries that reference more than 50 property graphs will not have a complete list. Corresponds to the JSON property referencedPropertyGraphs



6438
6439
6440
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6438

def referenced_property_graphs
  @referenced_property_graphs
end

#referenced_routinesArray<Google::Apis::BigqueryV2::RoutineReference>

Output only. Referenced routines for the job. Corresponds to the JSON property referencedRoutines



6443
6444
6445
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6443

def referenced_routines
  @referenced_routines
end

#referenced_tablesArray<Google::Apis::BigqueryV2::TableReference>

Output only. Referenced tables for the job. Corresponds to the JSON property referencedTables



6448
6449
6450
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6448

def referenced_tables
  @referenced_tables
end

#reservation_usageArray<Google::Apis::BigqueryV2::JobStatistics2::ReservationUsage>

Output only. Job resource usage breakdown by reservation. This field reported misleading information and will no longer be populated. Corresponds to the JSON property reservationUsage



6454
6455
6456
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6454

def reservation_usage
  @reservation_usage
end

#schemaGoogle::Apis::BigqueryV2::TableSchema

Schema of a table Corresponds to the JSON property schema



6459
6460
6461
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6459

def schema
  @schema
end

#search_statisticsGoogle::Apis::BigqueryV2::SearchStatistics

Statistics for a search query. Populated as part of JobStatistics2. Corresponds to the JSON property searchStatistics



6464
6465
6466
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6464

def search_statistics
  @search_statistics
end

#spark_statisticsGoogle::Apis::BigqueryV2::SparkStatistics

Statistics for a BigSpark query. Populated as part of JobStatistics2 Corresponds to the JSON property sparkStatistics



6469
6470
6471
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6469

def spark_statistics
  @spark_statistics
end

#statement_typeString

Output only. The type of query statement, if valid. Possible values: * SELECT : SELECT statement. * ASSERT: ASSERT statement. * INSERT: INSERT statement. * UPDATE: UPDATE statement. * DELETE: DELETE statement. * MERGE: MERGE statement. * CREATE_TABLE: CREATE TABLE statement, without AS SELECT. * CREATE_TABLE_AS_SELECT: CREATE TABLE AS SELECT statement. * CREATE_VIEW: CREATE VIEW statement. * CREATE_MODEL: CREATE MODEL statement. * CREATE_MATERIALIZED_VIEW: CREATE MATERIALIZED VIEW statement. * CREATE_FUNCTION: CREATE FUNCTION statement. * CREATE_TABLE_FUNCTION: CREATE TABLE FUNCTION statement. * CREATE_PROCEDURE: CREATE PROCEDURE statement. * CREATE_ROW_ACCESS_POLICY: CREATE ROW ACCESS POLICY statement. * CREATE_SCHEMA: CREATE SCHEMA statement. * CREATE_SNAPSHOT_TABLE: CREATE SNAPSHOT TABLE statement. * CREATE_SEARCH_INDEX: CREATE SEARCH INDEX statement. * DROP_TABLE: DROP TABLE statement. * DROP_EXTERNAL_TABLE: DROP EXTERNAL TABLE statement. * DROP_VIEW: DROP VIEW statement. * DROP_MODEL: DROP MODEL statement. * DROP_MATERIALIZED_VIEW: DROP MATERIALIZED VIEW statement. * DROP_FUNCTION : DROP FUNCTION statement. * DROP_TABLE_FUNCTION : DROP TABLE FUNCTION statement. * DROP_PROCEDURE: DROP PROCEDURE statement. * DROP_SEARCH_INDEX: DROP SEARCH INDEX statement. * DROP_SCHEMA: DROP SCHEMA statement. * DROP_SNAPSHOT_TABLE: DROP SNAPSHOT TABLE statement.

Returns:

  • (String)


6562
6563
6564
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6562

def statement_type
  @statement_type
end

#timelineArray<Google::Apis::BigqueryV2::QueryTimelineSample>

Output only. Describes a timeline of job execution. Corresponds to the JSON property timeline



6567
6568
6569
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6567

def timeline
  @timeline
end

#total_bytes_billedFixnum

Output only. If the project is configured to use on-demand pricing, then this field contains the total bytes billed for the job. If the project is configured to use flat-rate pricing, then you are not billed for bytes and this field is informational only. Corresponds to the JSON property totalBytesBilled

Returns:

  • (Fixnum)


6575
6576
6577
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6575

def total_bytes_billed
  @total_bytes_billed
end

#total_bytes_processedFixnum

Output only. Total bytes processed for the job. Corresponds to the JSON property totalBytesProcessed

Returns:

  • (Fixnum)


6580
6581
6582
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6580

def total_bytes_processed
  @total_bytes_processed
end

#total_bytes_processed_accuracyString

Output only. For dry-run jobs, totalBytesProcessed is an estimate and this field specifies the accuracy of the estimate. Possible values can be: UNKNOWN: accuracy of the estimate is unknown. PRECISE: estimate is precise. LOWER_BOUND: estimate is lower bound of what the query would cost. UPPER_BOUND: estimate is upper bound of what the query would cost. Corresponds to the JSON property totalBytesProcessedAccuracy

Returns:

  • (String)


6589
6590
6591
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6589

def total_bytes_processed_accuracy
  @total_bytes_processed_accuracy
end

#total_partitions_processedFixnum

Output only. Total number of partitions processed from all partitioned tables referenced in the job. Corresponds to the JSON property totalPartitionsProcessed

Returns:

  • (Fixnum)


6595
6596
6597
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6595

def total_partitions_processed
  @total_partitions_processed
end

#total_services_sku_slot_msFixnum

Output only. Total slot milliseconds for the job that ran on external services and billed on the services SKU. This field is only populated for jobs that have external service costs, and is the total of the usage for costs whose billing method is "SERVICES_SKU". Corresponds to the JSON property totalServicesSkuSlotMs

Returns:

  • (Fixnum)


6603
6604
6605
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6603

def total_services_sku_slot_ms
  @total_services_sku_slot_ms
end

#total_slot_msFixnum

Output only. Slot-milliseconds for the job. Corresponds to the JSON property totalSlotMs

Returns:

  • (Fixnum)


6608
6609
6610
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6608

def total_slot_ms
  @total_slot_ms
end

#transferred_bytesFixnum

Output only. Total bytes transferred for cross-cloud queries such as Cross Cloud Transfer and CREATE TABLE AS SELECT (CTAS). Corresponds to the JSON property transferredBytes

Returns:

  • (Fixnum)


6614
6615
6616
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6614

def transferred_bytes
  @transferred_bytes
end

#undeclared_query_parametersArray<Google::Apis::BigqueryV2::QueryParameter>

Output only. GoogleSQL only: list of undeclared query parameters detected during a dry run validation. Corresponds to the JSON property undeclaredQueryParameters



6620
6621
6622
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6620

def undeclared_query_parameters
  @undeclared_query_parameters
end

#vector_search_statisticsGoogle::Apis::BigqueryV2::VectorSearchStatistics

Statistics for a vector search query. Populated as part of JobStatistics2. Corresponds to the JSON property vectorSearchStatistics



6625
6626
6627
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6625

def vector_search_statistics
  @vector_search_statistics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6632
6633
6634
6635
6636
6637
6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
6672
6673
6674
6675
6676
6677
6678
6679
6680
6681
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6632

def update!(**args)
  @bi_engine_statistics = args[:bi_engine_statistics] if args.key?(:bi_engine_statistics)
  @billing_tier = args[:billing_tier] if args.key?(:billing_tier)
  @cache_hit = args[:cache_hit] if args.key?(:cache_hit)
  @dcl_target_dataset = args[:dcl_target_dataset] if args.key?(:dcl_target_dataset)
  @dcl_target_table = args[:dcl_target_table] if args.key?(:dcl_target_table)
  @dcl_target_view = args[:dcl_target_view] if args.key?(:dcl_target_view)
  @ddl_affected_row_access_policy_count = args[:ddl_affected_row_access_policy_count] if args.key?(:ddl_affected_row_access_policy_count)
  @ddl_destination_table = args[:ddl_destination_table] if args.key?(:ddl_destination_table)
  @ddl_operation_performed = args[:ddl_operation_performed] if args.key?(:ddl_operation_performed)
  @ddl_target_dataset = args[:ddl_target_dataset] if args.key?(:ddl_target_dataset)
  @ddl_target_routine = args[:ddl_target_routine] if args.key?(:ddl_target_routine)
  @ddl_target_row_access_policy = args[:ddl_target_row_access_policy] if args.key?(:ddl_target_row_access_policy)
  @ddl_target_table = args[:ddl_target_table] if args.key?(:ddl_target_table)
  @dml_stats = args[:dml_stats] if args.key?(:dml_stats)
  @estimated_bytes_processed = args[:estimated_bytes_processed] if args.key?(:estimated_bytes_processed)
  @export_data_statistics = args[:export_data_statistics] if args.key?(:export_data_statistics)
  @external_service_costs = args[:external_service_costs] if args.key?(:external_service_costs)
  @gen_ai_stats = args[:gen_ai_stats] if args.key?(:gen_ai_stats)
  @incremental_result_stats = args[:incremental_result_stats] if args.key?(:incremental_result_stats)
  @load_query_statistics = args[:load_query_statistics] if args.key?(:load_query_statistics)
  @materialized_view_statistics = args[:materialized_view_statistics] if args.key?(:materialized_view_statistics)
  @metadata_cache_statistics = args[:metadata_cache_statistics] if args.key?(:metadata_cache_statistics)
  @ml_statistics = args[:ml_statistics] if args.key?(:ml_statistics)
  @model_training = args[:model_training] if args.key?(:model_training)
  @model_training_current_iteration = args[:model_training_current_iteration] if args.key?(:model_training_current_iteration)
  @model_training_expected_total_iteration = args[:model_training_expected_total_iteration] if args.key?(:model_training_expected_total_iteration)
  @num_dml_affected_rows = args[:num_dml_affected_rows] if args.key?(:num_dml_affected_rows)
  @performance_insights = args[:performance_insights] if args.key?(:performance_insights)
  @query_info = args[:query_info] if args.key?(:query_info)
  @query_plan = args[:query_plan] if args.key?(:query_plan)
  @referenced_property_graphs = args[:referenced_property_graphs] if args.key?(:referenced_property_graphs)
  @referenced_routines = args[:referenced_routines] if args.key?(:referenced_routines)
  @referenced_tables = args[:referenced_tables] if args.key?(:referenced_tables)
  @reservation_usage = args[:reservation_usage] if args.key?(:reservation_usage)
  @schema = args[:schema] if args.key?(:schema)
  @search_statistics = args[:search_statistics] if args.key?(:search_statistics)
  @spark_statistics = args[:spark_statistics] if args.key?(:spark_statistics)
  @statement_type = args[:statement_type] if args.key?(:statement_type)
  @timeline = args[:timeline] if args.key?(:timeline)
  @total_bytes_billed = args[:total_bytes_billed] if args.key?(:total_bytes_billed)
  @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed)
  @total_bytes_processed_accuracy = args[:total_bytes_processed_accuracy] if args.key?(:total_bytes_processed_accuracy)
  @total_partitions_processed = args[:total_partitions_processed] if args.key?(:total_partitions_processed)
  @total_services_sku_slot_ms = args[:total_services_sku_slot_ms] if args.key?(:total_services_sku_slot_ms)
  @total_slot_ms = args[:total_slot_ms] if args.key?(:total_slot_ms)
  @transferred_bytes = args[:transferred_bytes] if args.key?(:transferred_bytes)
  @undeclared_query_parameters = args[:undeclared_query_parameters] if args.key?(:undeclared_query_parameters)
  @vector_search_statistics = args[:vector_search_statistics] if args.key?(:vector_search_statistics)
end