Class: Google::Apis::BigqueryV2::JobStatistics2
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobStatistics2
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Statistics for a query job.
Defined Under Namespace
Classes: ReservationUsage
Instance Attribute Summary collapse
-
#bi_engine_statistics ⇒ Google::Apis::BigqueryV2::BiEngineStatistics
Statistics for a BI Engine specific query.
-
#billing_tier ⇒ Fixnum
Output only.
-
#cache_hit ⇒ Boolean
(also: #cache_hit?)
Output only.
-
#dcl_target_dataset ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
-
#dcl_target_table ⇒ Google::Apis::BigqueryV2::TableReference
Output only.
-
#dcl_target_view ⇒ Google::Apis::BigqueryV2::TableReference
Output only.
-
#ddl_affected_row_access_policy_count ⇒ Fixnum
Output only.
-
#ddl_destination_table ⇒ Google::Apis::BigqueryV2::TableReference
Output only.
-
#ddl_operation_performed ⇒ String
Output only.
-
#ddl_target_dataset ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
-
#ddl_target_routine ⇒ Google::Apis::BigqueryV2::RoutineReference
Id path of a routine.
-
#ddl_target_row_access_policy ⇒ Google::Apis::BigqueryV2::RowAccessPolicyReference
Id path of a row access policy.
-
#ddl_target_table ⇒ Google::Apis::BigqueryV2::TableReference
Output only.
-
#dml_stats ⇒ Google::Apis::BigqueryV2::DmlStatistics
Detailed statistics for DML statements Corresponds to the JSON property
dmlStats. -
#estimated_bytes_processed ⇒ Fixnum
Output only.
-
#export_data_statistics ⇒ Google::Apis::BigqueryV2::ExportDataStatistics
Statistics for the EXPORT DATA statement as part of Query Job.
-
#external_service_costs ⇒ Array<Google::Apis::BigqueryV2::ExternalServiceCost>
Output only.
-
#incremental_result_stats ⇒ Google::Apis::BigqueryV2::IncrementalResultStats
Statistics related to Incremental Query Results.
-
#load_query_statistics ⇒ Google::Apis::BigqueryV2::LoadQueryStatistics
Statistics for a LOAD query.
-
#materialized_view_statistics ⇒ Google::Apis::BigqueryV2::MaterializedViewStatistics
Statistics of materialized views considered in a query job.
-
#metadata_cache_statistics ⇒ Google::Apis::BigqueryV2::MetadataCacheStatistics
Statistics for metadata caching in queried tables.
-
#ml_statistics ⇒ Google::Apis::BigqueryV2::MlStatistics
Job statistics specific to a BigQuery ML training job.
-
#model_training ⇒ Google::Apis::BigqueryV2::BigQueryModelTraining
Deprecated.
-
#model_training_current_iteration ⇒ Fixnum
Deprecated.
-
#model_training_expected_total_iteration ⇒ Fixnum
Deprecated.
-
#num_dml_affected_rows ⇒ Fixnum
Output only.
-
#performance_insights ⇒ Google::Apis::BigqueryV2::PerformanceInsights
Performance insights for the job.
-
#query_info ⇒ Google::Apis::BigqueryV2::QueryInfo
Query optimization information for a QUERY job.
-
#query_plan ⇒ Array<Google::Apis::BigqueryV2::ExplainQueryStage>
Output only.
-
#referenced_routines ⇒ Array<Google::Apis::BigqueryV2::RoutineReference>
Output only.
-
#referenced_tables ⇒ Array<Google::Apis::BigqueryV2::TableReference>
Output only.
-
#reservation_usage ⇒ Array<Google::Apis::BigqueryV2::JobStatistics2::ReservationUsage>
Output only.
-
#schema ⇒ Google::Apis::BigqueryV2::TableSchema
Schema of a table Corresponds to the JSON property
schema. -
#search_statistics ⇒ Google::Apis::BigqueryV2::SearchStatistics
Statistics for a search query.
-
#spark_statistics ⇒ Google::Apis::BigqueryV2::SparkStatistics
Statistics for a BigSpark query.
-
#statement_type ⇒ String
Output only.
-
#timeline ⇒ Array<Google::Apis::BigqueryV2::QueryTimelineSample>
Output only.
-
#total_bytes_billed ⇒ Fixnum
Output only.
-
#total_bytes_processed ⇒ Fixnum
Output only.
-
#total_bytes_processed_accuracy ⇒ String
Output only.
-
#total_partitions_processed ⇒ Fixnum
Output only.
-
#total_services_sku_slot_ms ⇒ Fixnum
Output only.
-
#total_slot_ms ⇒ Fixnum
Output only.
-
#transferred_bytes ⇒ Fixnum
Output only.
-
#undeclared_query_parameters ⇒ Array<Google::Apis::BigqueryV2::QueryParameter>
Output only.
-
#vector_search_statistics ⇒ Google::Apis::BigqueryV2::VectorSearchStatistics
Statistics for a vector search query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobStatistics2
constructor
A new instance of JobStatistics2.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobStatistics2
Returns a new instance of JobStatistics2.
6376 6377 6378 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6376 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bi_engine_statistics ⇒ Google::Apis::BigqueryV2::BiEngineStatistics
Statistics for a BI Engine specific query. Populated as part of JobStatistics2
Corresponds to the JSON property biEngineStatistics
6033 6034 6035 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6033 def bi_engine_statistics @bi_engine_statistics end |
#billing_tier ⇒ Fixnum
Output only. Billing tier for the job. This is a BigQuery-specific concept
which is not related to the Google Cloud notion of "free tier". The value here
is a measure of the query's resource consumption relative to the amount of
data scanned. For on-demand queries, the limit is 100, and all queries within
this limit are billed at the standard on-demand rates. On-demand queries that
exceed this limit will fail with a billingTierLimitExceeded error.
Corresponds to the JSON property billingTier
6043 6044 6045 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6043 def billing_tier @billing_tier end |
#cache_hit ⇒ Boolean Also known as: cache_hit?
Output only. Whether the query result was fetched from the query cache.
Corresponds to the JSON property cacheHit
6048 6049 6050 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6048 def cache_hit @cache_hit end |
#dcl_target_dataset ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
Corresponds to the JSON property dclTargetDataset
6054 6055 6056 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6054 def dcl_target_dataset @dcl_target_dataset end |
#dcl_target_table ⇒ Google::Apis::BigqueryV2::TableReference
Output only. Referenced table for DCL statement.
Corresponds to the JSON property dclTargetTable
6059 6060 6061 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6059 def dcl_target_table @dcl_target_table end |
#dcl_target_view ⇒ Google::Apis::BigqueryV2::TableReference
Output only. Referenced view for DCL statement.
Corresponds to the JSON property dclTargetView
6064 6065 6066 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6064 def dcl_target_view @dcl_target_view end |
#ddl_affected_row_access_policy_count ⇒ Fixnum
Output only. The number of row access policies affected by a DDL statement.
Present only for DROP ALL ROW ACCESS POLICIES queries.
Corresponds to the JSON property ddlAffectedRowAccessPolicyCount
6070 6071 6072 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6070 def ddl_affected_row_access_policy_count @ddl_affected_row_access_policy_count end |
#ddl_destination_table ⇒ Google::Apis::BigqueryV2::TableReference
Output only. The table after rename. Present only for ALTER TABLE RENAME TO
query.
Corresponds to the JSON property ddlDestinationTable
6076 6077 6078 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6076 def ddl_destination_table @ddl_destination_table end |
#ddl_operation_performed ⇒ String
Output only. The DDL operation performed, possibly dependent on the pre-
existence of the DDL target.
Corresponds to the JSON property ddlOperationPerformed
6082 6083 6084 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6082 def ddl_operation_performed @ddl_operation_performed end |
#ddl_target_dataset ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
Corresponds to the JSON property ddlTargetDataset
6087 6088 6089 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6087 def ddl_target_dataset @ddl_target_dataset end |
#ddl_target_routine ⇒ Google::Apis::BigqueryV2::RoutineReference
Id path of a routine.
Corresponds to the JSON property ddlTargetRoutine
6092 6093 6094 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6092 def ddl_target_routine @ddl_target_routine end |
#ddl_target_row_access_policy ⇒ Google::Apis::BigqueryV2::RowAccessPolicyReference
Id path of a row access policy.
Corresponds to the JSON property ddlTargetRowAccessPolicy
6097 6098 6099 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6097 def ddl_target_row_access_policy @ddl_target_row_access_policy end |
#ddl_target_table ⇒ Google::Apis::BigqueryV2::TableReference
Output only. The DDL target table. Present only for CREATE/DROP TABLE/VIEW and
DROP ALL ROW ACCESS POLICIES queries.
Corresponds to the JSON property ddlTargetTable
6103 6104 6105 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6103 def ddl_target_table @ddl_target_table end |
#dml_stats ⇒ Google::Apis::BigqueryV2::DmlStatistics
Detailed statistics for DML statements
Corresponds to the JSON property dmlStats
6108 6109 6110 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6108 def dml_stats @dml_stats end |
#estimated_bytes_processed ⇒ Fixnum
Output only. The original estimate of bytes processed for the job.
Corresponds to the JSON property estimatedBytesProcessed
6113 6114 6115 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6113 def estimated_bytes_processed @estimated_bytes_processed end |
#export_data_statistics ⇒ Google::Apis::BigqueryV2::ExportDataStatistics
Statistics for the EXPORT DATA statement as part of Query Job. EXTRACT JOB
statistics are populated in JobStatistics4.
Corresponds to the JSON property exportDataStatistics
6119 6120 6121 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6119 def export_data_statistics @export_data_statistics end |
#external_service_costs ⇒ Array<Google::Apis::BigqueryV2::ExternalServiceCost>
Output only. Job cost breakdown as bigquery internal cost and external service
costs.
Corresponds to the JSON property externalServiceCosts
6125 6126 6127 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6125 def external_service_costs @external_service_costs end |
#incremental_result_stats ⇒ Google::Apis::BigqueryV2::IncrementalResultStats
Statistics related to Incremental Query Results. Populated as part of
JobStatistics2. This feature is not yet available.
Corresponds to the JSON property incrementalResultStats
6131 6132 6133 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6131 def incremental_result_stats @incremental_result_stats end |
#load_query_statistics ⇒ Google::Apis::BigqueryV2::LoadQueryStatistics
Statistics for a LOAD query.
Corresponds to the JSON property loadQueryStatistics
6136 6137 6138 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6136 def load_query_statistics @load_query_statistics end |
#materialized_view_statistics ⇒ Google::Apis::BigqueryV2::MaterializedViewStatistics
Statistics of materialized views considered in a query job.
Corresponds to the JSON property materializedViewStatistics
6141 6142 6143 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6141 def materialized_view_statistics @materialized_view_statistics end |
#metadata_cache_statistics ⇒ Google::Apis::BigqueryV2::MetadataCacheStatistics
Statistics for metadata caching in queried tables.
Corresponds to the JSON property metadataCacheStatistics
6146 6147 6148 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6146 def @metadata_cache_statistics end |
#ml_statistics ⇒ Google::Apis::BigqueryV2::MlStatistics
Job statistics specific to a BigQuery ML training job.
Corresponds to the JSON property mlStatistics
6151 6152 6153 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6151 def ml_statistics @ml_statistics end |
#model_training ⇒ Google::Apis::BigqueryV2::BigQueryModelTraining
Deprecated.
Corresponds to the JSON property modelTraining
6156 6157 6158 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6156 def model_training @model_training end |
#model_training_current_iteration ⇒ Fixnum
Deprecated.
Corresponds to the JSON property modelTrainingCurrentIteration
6161 6162 6163 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6161 def model_training_current_iteration @model_training_current_iteration end |
#model_training_expected_total_iteration ⇒ Fixnum
Deprecated.
Corresponds to the JSON property modelTrainingExpectedTotalIteration
6166 6167 6168 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6166 def model_training_expected_total_iteration @model_training_expected_total_iteration end |
#num_dml_affected_rows ⇒ Fixnum
Output only. The number of rows affected by a DML statement. Present only for
DML statements INSERT, UPDATE or DELETE.
Corresponds to the JSON property numDmlAffectedRows
6172 6173 6174 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6172 def num_dml_affected_rows @num_dml_affected_rows end |
#performance_insights ⇒ Google::Apis::BigqueryV2::PerformanceInsights
Performance insights for the job.
Corresponds to the JSON property performanceInsights
6177 6178 6179 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6177 def performance_insights @performance_insights end |
#query_info ⇒ Google::Apis::BigqueryV2::QueryInfo
Query optimization information for a QUERY job.
Corresponds to the JSON property queryInfo
6182 6183 6184 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6182 def query_info @query_info end |
#query_plan ⇒ Array<Google::Apis::BigqueryV2::ExplainQueryStage>
Output only. Describes execution plan for the query.
Corresponds to the JSON property queryPlan
6187 6188 6189 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6187 def query_plan @query_plan end |
#referenced_routines ⇒ Array<Google::Apis::BigqueryV2::RoutineReference>
Output only. Referenced routines for the job.
Corresponds to the JSON property referencedRoutines
6192 6193 6194 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6192 def referenced_routines @referenced_routines end |
#referenced_tables ⇒ Array<Google::Apis::BigqueryV2::TableReference>
Output only. Referenced tables for the job.
Corresponds to the JSON property referencedTables
6197 6198 6199 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6197 def referenced_tables @referenced_tables end |
#reservation_usage ⇒ Array<Google::Apis::BigqueryV2::JobStatistics2::ReservationUsage>
Output only. Job resource usage breakdown by reservation. This field reported
misleading information and will no longer be populated.
Corresponds to the JSON property reservationUsage
6203 6204 6205 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6203 def reservation_usage @reservation_usage end |
#schema ⇒ Google::Apis::BigqueryV2::TableSchema
Schema of a table
Corresponds to the JSON property schema
6208 6209 6210 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6208 def schema @schema end |
#search_statistics ⇒ Google::Apis::BigqueryV2::SearchStatistics
Statistics for a search query. Populated as part of JobStatistics2.
Corresponds to the JSON property searchStatistics
6213 6214 6215 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6213 def search_statistics @search_statistics end |
#spark_statistics ⇒ Google::Apis::BigqueryV2::SparkStatistics
Statistics for a BigSpark query. Populated as part of JobStatistics2
Corresponds to the JSON property sparkStatistics
6218 6219 6220 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6218 def spark_statistics @spark_statistics end |
#statement_type ⇒ String
Output only. The type of query statement, if valid. Possible values: * SELECT
: SELECT statement. * ASSERT: ASSERT
statement. * INSERT: INSERT statement. * UPDATE:
UPDATE statement. * DELETE: DELETE
statement. * MERGE: MERGE statement. * CREATE_TABLE:
CREATE TABLE statement, without AS
SELECT. * CREATE_TABLE_AS_SELECT: CREATE TABLE AS SELECT statement. * CREATE_VIEW: CREATE VIEW statement. * CREATE_MODEL: CREATE MODEL statement. * CREATE_MATERIALIZED_VIEW:
CREATE MATERIALIZED VIEW
statement. * CREATE_FUNCTION: CREATE FUNCTION statement. * CREATE_TABLE_FUNCTION: CREATE
TABLE FUNCTION statement. *
CREATE_PROCEDURE: CREATE PROCEDURE statement. *
CREATE_ROW_ACCESS_POLICY: CREATE ROW ACCESS POLICY statement. * CREATE_SCHEMA: CREATE
SCHEMA statement. *
CREATE_SNAPSHOT_TABLE: CREATE SNAPSHOT TABLE statement. * CREATE_SEARCH_INDEX: CREATE
SEARCH INDEX statement. *
DROP_TABLE: DROP TABLE statement. *
DROP_EXTERNAL_TABLE: DROP EXTERNAL TABLE statement. * DROP_VIEW: DROP VIEW statement. * DROP_MODEL: DROP MODEL statement. * DROP_MATERIALIZED_VIEW: DROP MATERIALIZED VIEW statement. * DROP_FUNCTION :
DROP FUNCTION statement. *
DROP_TABLE_FUNCTION : DROP TABLE FUNCTION statement. * DROP_PROCEDURE: DROP PROCEDURE statement. * DROP_SEARCH_INDEX: DROP SEARCH
INDEX statement. * DROP_SCHEMA: DROP
SCHEMA statement. * DROP_SNAPSHOT_TABLE:
DROP SNAPSHOT TABLE statement.
DROP_ROW_ACCESS_POLICY:DROP [ALL] ROW ACCESS POLICY|POLICIESstatement. *ALTER_TABLE:ALTER TABLEstatement. *ALTER_VIEW:ALTER VIEWstatement. *ALTER_MATERIALIZED_VIEW:ALTER MATERIALIZED VIEWstatement. *ALTER_SCHEMA:ALTER SCHEMAstatement. *SCRIPT:SCRIPT. *TRUNCATE_TABLE:TRUNCATE TABLEstatement. *CREATE_EXTERNAL_TABLE:CREATE EXTERNAL TABLEstatement. *EXPORT_DATA:EXPORT DATAstatement. *EXPORT_MODEL:EXPORT MODELstatement. *LOAD_DATA:LOAD DATAstatement. *CALL:CALLstatement. Corresponds to the JSON propertystatementType
6311 6312 6313 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6311 def statement_type @statement_type end |
#timeline ⇒ Array<Google::Apis::BigqueryV2::QueryTimelineSample>
Output only. Describes a timeline of job execution.
Corresponds to the JSON property timeline
6316 6317 6318 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6316 def timeline @timeline end |
#total_bytes_billed ⇒ Fixnum
Output only. If the project is configured to use on-demand pricing, then this
field contains the total bytes billed for the job. If the project is
configured to use flat-rate pricing, then you are not billed for bytes and
this field is informational only.
Corresponds to the JSON property totalBytesBilled
6324 6325 6326 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6324 def total_bytes_billed @total_bytes_billed end |
#total_bytes_processed ⇒ Fixnum
Output only. Total bytes processed for the job.
Corresponds to the JSON property totalBytesProcessed
6329 6330 6331 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6329 def total_bytes_processed @total_bytes_processed end |
#total_bytes_processed_accuracy ⇒ String
Output only. For dry-run jobs, totalBytesProcessed is an estimate and this
field specifies the accuracy of the estimate. Possible values can be: UNKNOWN:
accuracy of the estimate is unknown. PRECISE: estimate is precise. LOWER_BOUND:
estimate is lower bound of what the query would cost. UPPER_BOUND: estimate
is upper bound of what the query would cost.
Corresponds to the JSON property totalBytesProcessedAccuracy
6338 6339 6340 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6338 def total_bytes_processed_accuracy @total_bytes_processed_accuracy end |
#total_partitions_processed ⇒ Fixnum
Output only. Total number of partitions processed from all partitioned tables
referenced in the job.
Corresponds to the JSON property totalPartitionsProcessed
6344 6345 6346 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6344 def total_partitions_processed @total_partitions_processed end |
#total_services_sku_slot_ms ⇒ Fixnum
Output only. Total slot milliseconds for the job that ran on external services
and billed on the services SKU. This field is only populated for jobs that
have external service costs, and is the total of the usage for costs whose
billing method is "SERVICES_SKU".
Corresponds to the JSON property totalServicesSkuSlotMs
6352 6353 6354 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6352 def total_services_sku_slot_ms @total_services_sku_slot_ms end |
#total_slot_ms ⇒ Fixnum
Output only. Slot-milliseconds for the job.
Corresponds to the JSON property totalSlotMs
6357 6358 6359 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6357 def total_slot_ms @total_slot_ms end |
#transferred_bytes ⇒ Fixnum
Output only. Total bytes transferred for cross-cloud queries such as Cross
Cloud Transfer and CREATE TABLE AS SELECT (CTAS).
Corresponds to the JSON property transferredBytes
6363 6364 6365 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6363 def transferred_bytes @transferred_bytes end |
#undeclared_query_parameters ⇒ Array<Google::Apis::BigqueryV2::QueryParameter>
Output only. GoogleSQL only: list of undeclared query parameters detected
during a dry run validation.
Corresponds to the JSON property undeclaredQueryParameters
6369 6370 6371 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6369 def undeclared_query_parameters @undeclared_query_parameters end |
#vector_search_statistics ⇒ Google::Apis::BigqueryV2::VectorSearchStatistics
Statistics for a vector search query. Populated as part of JobStatistics2.
Corresponds to the JSON property vectorSearchStatistics
6374 6375 6376 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6374 def vector_search_statistics @vector_search_statistics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6381 6382 6383 6384 6385 6386 6387 6388 6389 6390 6391 6392 6393 6394 6395 6396 6397 6398 6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 6415 6416 6417 6418 6419 6420 6421 6422 6423 6424 6425 6426 6427 6428 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6381 def update!(**args) @bi_engine_statistics = args[:bi_engine_statistics] if args.key?(:bi_engine_statistics) @billing_tier = args[:billing_tier] if args.key?(:billing_tier) @cache_hit = args[:cache_hit] if args.key?(:cache_hit) @dcl_target_dataset = args[:dcl_target_dataset] if args.key?(:dcl_target_dataset) @dcl_target_table = args[:dcl_target_table] if args.key?(:dcl_target_table) @dcl_target_view = args[:dcl_target_view] if args.key?(:dcl_target_view) @ddl_affected_row_access_policy_count = args[:ddl_affected_row_access_policy_count] if args.key?(:ddl_affected_row_access_policy_count) @ddl_destination_table = args[:ddl_destination_table] if args.key?(:ddl_destination_table) @ddl_operation_performed = args[:ddl_operation_performed] if args.key?(:ddl_operation_performed) @ddl_target_dataset = args[:ddl_target_dataset] if args.key?(:ddl_target_dataset) @ddl_target_routine = args[:ddl_target_routine] if args.key?(:ddl_target_routine) @ddl_target_row_access_policy = args[:ddl_target_row_access_policy] if args.key?(:ddl_target_row_access_policy) @ddl_target_table = args[:ddl_target_table] if args.key?(:ddl_target_table) @dml_stats = args[:dml_stats] if args.key?(:dml_stats) @estimated_bytes_processed = args[:estimated_bytes_processed] if args.key?(:estimated_bytes_processed) @export_data_statistics = args[:export_data_statistics] if args.key?(:export_data_statistics) @external_service_costs = args[:external_service_costs] if args.key?(:external_service_costs) @incremental_result_stats = args[:incremental_result_stats] if args.key?(:incremental_result_stats) @load_query_statistics = args[:load_query_statistics] if args.key?(:load_query_statistics) @materialized_view_statistics = args[:materialized_view_statistics] if args.key?(:materialized_view_statistics) @metadata_cache_statistics = args[:metadata_cache_statistics] if args.key?(:metadata_cache_statistics) @ml_statistics = args[:ml_statistics] if args.key?(:ml_statistics) @model_training = args[:model_training] if args.key?(:model_training) @model_training_current_iteration = args[:model_training_current_iteration] if args.key?(:model_training_current_iteration) @model_training_expected_total_iteration = args[:model_training_expected_total_iteration] if args.key?(:model_training_expected_total_iteration) @num_dml_affected_rows = args[:num_dml_affected_rows] if args.key?(:num_dml_affected_rows) @performance_insights = args[:performance_insights] if args.key?(:performance_insights) @query_info = args[:query_info] if args.key?(:query_info) @query_plan = args[:query_plan] if args.key?(:query_plan) @referenced_routines = args[:referenced_routines] if args.key?(:referenced_routines) @referenced_tables = args[:referenced_tables] if args.key?(:referenced_tables) @reservation_usage = args[:reservation_usage] if args.key?(:reservation_usage) @schema = args[:schema] if args.key?(:schema) @search_statistics = args[:search_statistics] if args.key?(:search_statistics) @spark_statistics = args[:spark_statistics] if args.key?(:spark_statistics) @statement_type = args[:statement_type] if args.key?(:statement_type) @timeline = args[:timeline] if args.key?(:timeline) @total_bytes_billed = args[:total_bytes_billed] if args.key?(:total_bytes_billed) @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed) @total_bytes_processed_accuracy = args[:total_bytes_processed_accuracy] if args.key?(:total_bytes_processed_accuracy) @total_partitions_processed = args[:total_partitions_processed] if args.key?(:total_partitions_processed) @total_services_sku_slot_ms = args[:total_services_sku_slot_ms] if args.key?(:total_services_sku_slot_ms) @total_slot_ms = args[:total_slot_ms] if args.key?(:total_slot_ms) @transferred_bytes = args[:transferred_bytes] if args.key?(:transferred_bytes) @undeclared_query_parameters = args[:undeclared_query_parameters] if args.key?(:undeclared_query_parameters) @vector_search_statistics = args[:vector_search_statistics] if args.key?(:vector_search_statistics) end |