Class: Google::Apis::BigqueryV2::JobStatistics3
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobStatistics3
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Statistics for a load job.
Instance Attribute Summary collapse
-
#bad_records ⇒ Fixnum
Output only.
-
#input_file_bytes ⇒ Fixnum
Output only.
-
#input_files ⇒ Fixnum
Output only.
-
#output_bytes ⇒ Fixnum
Output only.
-
#output_rows ⇒ Fixnum
Output only.
-
#timeline ⇒ Array<Google::Apis::BigqueryV2::QueryTimelineSample>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobStatistics3
constructor
A new instance of JobStatistics3.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobStatistics3
Returns a new instance of JobStatistics3.
6882 6883 6884 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bad_records ⇒ Fixnum
Output only. The number of bad records encountered. Note that if the job has
failed because of more bad records encountered than the maximum allowed in the
load job configuration, then this number can be less than the total number of
bad records present in the input data.
Corresponds to the JSON property badRecords
6853 6854 6855 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6853 def bad_records @bad_records end |
#input_file_bytes ⇒ Fixnum
Output only. Number of bytes of source data in a load job.
Corresponds to the JSON property inputFileBytes
6858 6859 6860 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6858 def input_file_bytes @input_file_bytes end |
#input_files ⇒ Fixnum
Output only. Number of source files in a load job.
Corresponds to the JSON property inputFiles
6863 6864 6865 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6863 def input_files @input_files end |
#output_bytes ⇒ Fixnum
Output only. Size of the loaded data in bytes. Note that while a load job is
in the running state, this value may change.
Corresponds to the JSON property outputBytes
6869 6870 6871 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6869 def output_bytes @output_bytes end |
#output_rows ⇒ Fixnum
Output only. Number of rows imported in a load job. Note that while an import
job is in the running state, this value may change.
Corresponds to the JSON property outputRows
6875 6876 6877 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6875 def output_rows @output_rows end |
#timeline ⇒ Array<Google::Apis::BigqueryV2::QueryTimelineSample>
Output only. Describes a timeline of job execution.
Corresponds to the JSON property timeline
6880 6881 6882 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6880 def timeline @timeline end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6887 6888 6889 6890 6891 6892 6893 6894 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6887 def update!(**args) @bad_records = args[:bad_records] if args.key?(:bad_records) @input_file_bytes = args[:input_file_bytes] if args.key?(:input_file_bytes) @input_files = args[:input_files] if args.key?(:input_files) @output_bytes = args[:output_bytes] if args.key?(:output_bytes) @output_rows = args[:output_rows] if args.key?(:output_rows) @timeline = args[:timeline] if args.key?(:timeline) end |