Class: Google::Apis::BigqueryV2::JobStatistics3

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics for a load job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobStatistics3

Returns a new instance of JobStatistics3.



6808
6809
6810
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bad_recordsFixnum

Output only. The number of bad records encountered. Note that if the job has failed because of more bad records encountered than the maximum allowed in the load job configuration, then this number can be less than the total number of bad records present in the input data. Corresponds to the JSON property badRecords

Returns:

  • (Fixnum)


6779
6780
6781
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6779

def bad_records
  @bad_records
end

#input_file_bytesFixnum

Output only. Number of bytes of source data in a load job. Corresponds to the JSON property inputFileBytes

Returns:

  • (Fixnum)


6784
6785
6786
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6784

def input_file_bytes
  @input_file_bytes
end

#input_filesFixnum

Output only. Number of source files in a load job. Corresponds to the JSON property inputFiles

Returns:

  • (Fixnum)


6789
6790
6791
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6789

def input_files
  @input_files
end

#output_bytesFixnum

Output only. Size of the loaded data in bytes. Note that while a load job is in the running state, this value may change. Corresponds to the JSON property outputBytes

Returns:

  • (Fixnum)


6795
6796
6797
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6795

def output_bytes
  @output_bytes
end

#output_rowsFixnum

Output only. Number of rows imported in a load job. Note that while an import job is in the running state, this value may change. Corresponds to the JSON property outputRows

Returns:

  • (Fixnum)


6801
6802
6803
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6801

def output_rows
  @output_rows
end

#timelineArray<Google::Apis::BigqueryV2::QueryTimelineSample>

Output only. Describes a timeline of job execution. Corresponds to the JSON property timeline



6806
6807
6808
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6806

def timeline
  @timeline
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6813
6814
6815
6816
6817
6818
6819
6820
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6813

def update!(**args)
  @bad_records = args[:bad_records] if args.key?(:bad_records)
  @input_file_bytes = args[:input_file_bytes] if args.key?(:input_file_bytes)
  @input_files = args[:input_files] if args.key?(:input_files)
  @output_bytes = args[:output_bytes] if args.key?(:output_bytes)
  @output_rows = args[:output_rows] if args.key?(:output_rows)
  @timeline = args[:timeline] if args.key?(:timeline)
end