Class: Google::Apis::BigqueryV2::JobStatistics3
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobStatistics3
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Statistics for a load job.
Instance Attribute Summary collapse
-
#bad_records ⇒ Fixnum
Output only.
-
#input_file_bytes ⇒ Fixnum
Output only.
-
#input_files ⇒ Fixnum
Output only.
-
#output_bytes ⇒ Fixnum
Output only.
-
#output_rows ⇒ Fixnum
Output only.
-
#timeline ⇒ Array<Google::Apis::BigqueryV2::QueryTimelineSample>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobStatistics3
constructor
A new instance of JobStatistics3.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobStatistics3
Returns a new instance of JobStatistics3.
6466 6467 6468 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6466 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bad_records ⇒ Fixnum
Output only. The number of bad records encountered. Note that if the job has
failed because of more bad records encountered than the maximum allowed in the
load job configuration, then this number can be less than the total number of
bad records present in the input data.
Corresponds to the JSON property badRecords
6437 6438 6439 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6437 def bad_records @bad_records end |
#input_file_bytes ⇒ Fixnum
Output only. Number of bytes of source data in a load job.
Corresponds to the JSON property inputFileBytes
6442 6443 6444 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6442 def input_file_bytes @input_file_bytes end |
#input_files ⇒ Fixnum
Output only. Number of source files in a load job.
Corresponds to the JSON property inputFiles
6447 6448 6449 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6447 def input_files @input_files end |
#output_bytes ⇒ Fixnum
Output only. Size of the loaded data in bytes. Note that while a load job is
in the running state, this value may change.
Corresponds to the JSON property outputBytes
6453 6454 6455 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6453 def output_bytes @output_bytes end |
#output_rows ⇒ Fixnum
Output only. Number of rows imported in a load job. Note that while an import
job is in the running state, this value may change.
Corresponds to the JSON property outputRows
6459 6460 6461 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6459 def output_rows @output_rows end |
#timeline ⇒ Array<Google::Apis::BigqueryV2::QueryTimelineSample>
Output only. Describes a timeline of job execution.
Corresponds to the JSON property timeline
6464 6465 6466 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6464 def timeline @timeline end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6471 6472 6473 6474 6475 6476 6477 6478 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6471 def update!(**args) @bad_records = args[:bad_records] if args.key?(:bad_records) @input_file_bytes = args[:input_file_bytes] if args.key?(:input_file_bytes) @input_files = args[:input_files] if args.key?(:input_files) @output_bytes = args[:output_bytes] if args.key?(:output_bytes) @output_rows = args[:output_rows] if args.key?(:output_rows) @timeline = args[:timeline] if args.key?(:timeline) end |