Class: Google::Apis::BigqueryV2::JobStatistics4
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobStatistics4
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Statistics for an extract job.
Instance Attribute Summary collapse
-
#destination_uri_file_counts ⇒ Array<Fixnum>
Output only.
-
#input_bytes ⇒ Fixnum
Output only.
-
#timeline ⇒ Array<Google::Apis::BigqueryV2::QueryTimelineSample>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobStatistics4
constructor
A new instance of JobStatistics4.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobStatistics4
Returns a new instance of JobStatistics4.
6949 6950 6951 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6949 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_uri_file_counts ⇒ Array<Fixnum>
Output only. Number of files per destination URI or URI pattern specified in
the extract configuration. These values will be in the same order as the URIs
specified in the 'destinationUris' field.
Corresponds to the JSON property destinationUriFileCounts
6934 6935 6936 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6934 def destination_uri_file_counts @destination_uri_file_counts end |
#input_bytes ⇒ Fixnum
Output only. Number of user bytes extracted into the result. This is the byte
count as computed by BigQuery for billing purposes and doesn't have any
relationship with the number of actual result bytes extracted in the desired
format.
Corresponds to the JSON property inputBytes
6942 6943 6944 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6942 def input_bytes @input_bytes end |
#timeline ⇒ Array<Google::Apis::BigqueryV2::QueryTimelineSample>
Output only. Describes a timeline of job execution.
Corresponds to the JSON property timeline
6947 6948 6949 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6947 def timeline @timeline end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6954 6955 6956 6957 6958 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6954 def update!(**args) @destination_uri_file_counts = args[:destination_uri_file_counts] if args.key?(:destination_uri_file_counts) @input_bytes = args[:input_bytes] if args.key?(:input_bytes) @timeline = args[:timeline] if args.key?(:timeline) end |