Class: Google::Apis::BigqueryV2::JobStatistics4

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics for an extract job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobStatistics4

Returns a new instance of JobStatistics4.



6921
6922
6923
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_uri_file_countsArray<Fixnum>

Output only. Number of files per destination URI or URI pattern specified in the extract configuration. These values will be in the same order as the URIs specified in the 'destinationUris' field. Corresponds to the JSON property destinationUriFileCounts

Returns:

  • (Array<Fixnum>)


6906
6907
6908
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6906

def destination_uri_file_counts
  @destination_uri_file_counts
end

#input_bytesFixnum

Output only. Number of user bytes extracted into the result. This is the byte count as computed by BigQuery for billing purposes and doesn't have any relationship with the number of actual result bytes extracted in the desired format. Corresponds to the JSON property inputBytes

Returns:

  • (Fixnum)


6914
6915
6916
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6914

def input_bytes
  @input_bytes
end

#timelineArray<Google::Apis::BigqueryV2::QueryTimelineSample>

Output only. Describes a timeline of job execution. Corresponds to the JSON property timeline



6919
6920
6921
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6919

def timeline
  @timeline
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6926
6927
6928
6929
6930
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6926

def update!(**args)
  @destination_uri_file_counts = args[:destination_uri_file_counts] if args.key?(:destination_uri_file_counts)
  @input_bytes = args[:input_bytes] if args.key?(:input_bytes)
  @timeline = args[:timeline] if args.key?(:timeline)
end