Class: Google::Apis::BigqueryV2::JobStatistics4

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics for an extract job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobStatistics4

Returns a new instance of JobStatistics4.



6505
6506
6507
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destination_uri_file_countsArray<Fixnum>

Output only. Number of files per destination URI or URI pattern specified in the extract configuration. These values will be in the same order as the URIs specified in the 'destinationUris' field. Corresponds to the JSON property destinationUriFileCounts

Returns:

  • (Array<Fixnum>)


6490
6491
6492
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6490

def destination_uri_file_counts
  @destination_uri_file_counts
end

#input_bytesFixnum

Output only. Number of user bytes extracted into the result. This is the byte count as computed by BigQuery for billing purposes and doesn't have any relationship with the number of actual result bytes extracted in the desired format. Corresponds to the JSON property inputBytes

Returns:

  • (Fixnum)


6498
6499
6500
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6498

def input_bytes
  @input_bytes
end

#timelineArray<Google::Apis::BigqueryV2::QueryTimelineSample>

Output only. Describes a timeline of job execution. Corresponds to the JSON property timeline



6503
6504
6505
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6503

def timeline
  @timeline
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6510
6511
6512
6513
6514
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6510

def update!(**args)
  @destination_uri_file_counts = args[:destination_uri_file_counts] if args.key?(:destination_uri_file_counts)
  @input_bytes = args[:input_bytes] if args.key?(:input_bytes)
  @timeline = args[:timeline] if args.key?(:timeline)
end