Class: Google::Apis::BigqueryV2::JobStatus
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Instance Attribute Summary collapse
-
#error_result ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
-
#errors ⇒ Array<Google::Apis::BigqueryV2::ErrorProto>
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobStatus
constructor
A new instance of JobStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobStatus
Returns a new instance of JobStatus.
6981 6982 6983 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6981 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_result ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
Corresponds to the JSON property errorResult
6965 6966 6967 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6965 def error_result @error_result end |
#errors ⇒ Array<Google::Apis::BigqueryV2::ErrorProto>
Output only. The first errors encountered during the running of the job. The
final message includes the number of errors that caused the process to stop.
Errors here do not necessarily mean that the job has not completed or was
unsuccessful.
Corresponds to the JSON property errors
6973 6974 6975 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6973 def errors @errors end |
#state ⇒ String
Output only. Running state of the job. Valid states include 'PENDING', '
RUNNING', and 'DONE'.
Corresponds to the JSON property state
6979 6980 6981 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6979 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6986 6987 6988 6989 6990 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6986 def update!(**args) @error_result = args[:error_result] if args.key?(:error_result) @errors = args[:errors] if args.key?(:errors) @state = args[:state] if args.key?(:state) end |