Class: Google::Apis::BigqueryV2::JobStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobStatus

Returns a new instance of JobStatus.



6907
6908
6909
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_resultGoogle::Apis::BigqueryV2::ErrorProto

Error details. Corresponds to the JSON property errorResult



6891
6892
6893
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6891

def error_result
  @error_result
end

#errorsArray<Google::Apis::BigqueryV2::ErrorProto>

Output only. The first errors encountered during the running of the job. The final message includes the number of errors that caused the process to stop. Errors here do not necessarily mean that the job has not completed or was unsuccessful. Corresponds to the JSON property errors



6899
6900
6901
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6899

def errors
  @errors
end

#stateString

Output only. Running state of the job. Valid states include 'PENDING', ' RUNNING', and 'DONE'. Corresponds to the JSON property state

Returns:

  • (String)


6905
6906
6907
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6905

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6912
6913
6914
6915
6916
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6912

def update!(**args)
  @error_result = args[:error_result] if args.key?(:error_result)
  @errors = args[:errors] if args.key?(:errors)
  @state = args[:state] if args.key?(:state)
end