Class: Google::Apis::BigqueryV2::JobStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobStatus

Returns a new instance of JobStatus.



6848
6849
6850
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6848

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_resultGoogle::Apis::BigqueryV2::ErrorProto

Error details. Corresponds to the JSON property errorResult



6832
6833
6834
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6832

def error_result
  @error_result
end

#errorsArray<Google::Apis::BigqueryV2::ErrorProto>

Output only. The first errors encountered during the running of the job. The final message includes the number of errors that caused the process to stop. Errors here do not necessarily mean that the job has not completed or was unsuccessful. Corresponds to the JSON property errors



6840
6841
6842
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6840

def errors
  @errors
end

#stateString

Output only. Running state of the job. Valid states include 'PENDING', ' RUNNING', and 'DONE'. Corresponds to the JSON property state

Returns:

  • (String)


6846
6847
6848
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6846

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6853
6854
6855
6856
6857
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6853

def update!(**args)
  @error_result = args[:error_result] if args.key?(:error_result)
  @errors = args[:errors] if args.key?(:errors)
  @state = args[:state] if args.key?(:state)
end