Class: Google::Apis::BigqueryV2::JobStatus
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::JobStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Instance Attribute Summary collapse
-
#error_result ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
-
#errors ⇒ Array<Google::Apis::BigqueryV2::ErrorProto>
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ JobStatus
constructor
A new instance of JobStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ JobStatus
Returns a new instance of JobStatus.
6595 6596 6597 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6595 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_result ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
Corresponds to the JSON property errorResult
6579 6580 6581 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6579 def error_result @error_result end |
#errors ⇒ Array<Google::Apis::BigqueryV2::ErrorProto>
Output only. The first errors encountered during the running of the job. The
final message includes the number of errors that caused the process to stop.
Errors here do not necessarily mean that the job has not completed or was
unsuccessful.
Corresponds to the JSON property errors
6587 6588 6589 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6587 def errors @errors end |
#state ⇒ String
Output only. Running state of the job. Valid states include 'PENDING', '
RUNNING', and 'DONE'.
Corresponds to the JSON property state
6593 6594 6595 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6593 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6600 6601 6602 6603 6604 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6600 def update!(**args) @error_result = args[:error_result] if args.key?(:error_result) @errors = args[:errors] if args.key?(:errors) @state = args[:state] if args.key?(:state) end |