Class: Google::Apis::BigqueryV2::JobStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JobStatus

Returns a new instance of JobStatus.



6565
6566
6567
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_resultGoogle::Apis::BigqueryV2::ErrorProto

Error details. Corresponds to the JSON property errorResult



6549
6550
6551
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6549

def error_result
  @error_result
end

#errorsArray<Google::Apis::BigqueryV2::ErrorProto>

Output only. The first errors encountered during the running of the job. The final message includes the number of errors that caused the process to stop. Errors here do not necessarily mean that the job has not completed or was unsuccessful. Corresponds to the JSON property errors



6557
6558
6559
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6557

def errors
  @errors
end

#stateString

Output only. Running state of the job. Valid states include 'PENDING', ' RUNNING', and 'DONE'. Corresponds to the JSON property state

Returns:

  • (String)


6563
6564
6565
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6563

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6570
6571
6572
6573
6574
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6570

def update!(**args)
  @error_result = args[:error_result] if args.key?(:error_result)
  @errors = args[:errors] if args.key?(:errors)
  @state = args[:state] if args.key?(:state)
end