Class: Google::Apis::BigqueryV2::ListRowAccessPoliciesResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ListRowAccessPoliciesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Response message for the ListRowAccessPolicies method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of results.
-
#row_access_policies ⇒ Array<Google::Apis::BigqueryV2::RowAccessPolicy>
Row access policies on the requested table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRowAccessPoliciesResponse
constructor
A new instance of ListRowAccessPoliciesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRowAccessPoliciesResponse
Returns a new instance of ListRowAccessPoliciesResponse.
6764 6765 6766 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6764 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of results.
Corresponds to the JSON property nextPageToken
6757 6758 6759 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6757 def next_page_token @next_page_token end |
#row_access_policies ⇒ Array<Google::Apis::BigqueryV2::RowAccessPolicy>
Row access policies on the requested table.
Corresponds to the JSON property rowAccessPolicies
6762 6763 6764 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6762 def row_access_policies @row_access_policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6769 6770 6771 6772 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6769 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @row_access_policies = args[:row_access_policies] if args.key?(:row_access_policies) end |