Class: Google::Apis::BigqueryV2::LoadQueryStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics for a LOAD query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoadQueryStatistics

Returns a new instance of LoadQueryStatistics.



7203
7204
7205
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bad_recordsFixnum

Output only. The number of bad records encountered while processing a LOAD query. Note that if the job has failed because of more bad records encountered than the maximum allowed in the load job configuration, then this number can be less than the total number of bad records present in the input data. Corresponds to the JSON property badRecords

Returns:

  • (Fixnum)


7171
7172
7173
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7171

def bad_records
  @bad_records
end

#bytes_transferredFixnum

Output only. This field is deprecated. The number of bytes of source data copied over the network for a LOAD query. transferred_bytes has the canonical value for physical transferred bytes, which is used for BigQuery Omni billing. Corresponds to the JSON property bytesTransferred

Returns:

  • (Fixnum)


7179
7180
7181
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7179

def bytes_transferred
  @bytes_transferred
end

#input_file_bytesFixnum

Output only. Number of bytes of source data in a LOAD query. Corresponds to the JSON property inputFileBytes

Returns:

  • (Fixnum)


7184
7185
7186
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7184

def input_file_bytes
  @input_file_bytes
end

#input_filesFixnum

Output only. Number of source files in a LOAD query. Corresponds to the JSON property inputFiles

Returns:

  • (Fixnum)


7189
7190
7191
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7189

def input_files
  @input_files
end

#output_bytesFixnum

Output only. Size of the loaded data in bytes. Note that while a LOAD query is in the running state, this value may change. Corresponds to the JSON property outputBytes

Returns:

  • (Fixnum)


7195
7196
7197
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7195

def output_bytes
  @output_bytes
end

#output_rowsFixnum

Output only. Number of rows imported in a LOAD query. Note that while a LOAD query is in the running state, this value may change. Corresponds to the JSON property outputRows

Returns:

  • (Fixnum)


7201
7202
7203
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7201

def output_rows
  @output_rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7208
7209
7210
7211
7212
7213
7214
7215
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7208

def update!(**args)
  @bad_records = args[:bad_records] if args.key?(:bad_records)
  @bytes_transferred = args[:bytes_transferred] if args.key?(:bytes_transferred)
  @input_file_bytes = args[:input_file_bytes] if args.key?(:input_file_bytes)
  @input_files = args[:input_files] if args.key?(:input_files)
  @output_bytes = args[:output_bytes] if args.key?(:output_bytes)
  @output_rows = args[:output_rows] if args.key?(:output_rows)
end