Class: Google::Apis::BigqueryV2::LoadQueryStatistics
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::LoadQueryStatistics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Statistics for a LOAD query.
Instance Attribute Summary collapse
-
#bad_records ⇒ Fixnum
Output only.
-
#bytes_transferred ⇒ Fixnum
Output only.
-
#input_file_bytes ⇒ Fixnum
Output only.
-
#input_files ⇒ Fixnum
Output only.
-
#output_bytes ⇒ Fixnum
Output only.
-
#output_rows ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadQueryStatistics
constructor
A new instance of LoadQueryStatistics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadQueryStatistics
Returns a new instance of LoadQueryStatistics.
6817 6818 6819 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6817 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bad_records ⇒ Fixnum
Output only. The number of bad records encountered while processing a LOAD
query. Note that if the job has failed because of more bad records encountered
than the maximum allowed in the load job configuration, then this number can
be less than the total number of bad records present in the input data.
Corresponds to the JSON property badRecords
6785 6786 6787 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6785 def bad_records @bad_records end |
#bytes_transferred ⇒ Fixnum
Output only. This field is deprecated. The number of bytes of source data
copied over the network for a LOAD query. transferred_bytes has the
canonical value for physical transferred bytes, which is used for BigQuery
Omni billing.
Corresponds to the JSON property bytesTransferred
6793 6794 6795 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6793 def bytes_transferred @bytes_transferred end |
#input_file_bytes ⇒ Fixnum
Output only. Number of bytes of source data in a LOAD query.
Corresponds to the JSON property inputFileBytes
6798 6799 6800 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6798 def input_file_bytes @input_file_bytes end |
#input_files ⇒ Fixnum
Output only. Number of source files in a LOAD query.
Corresponds to the JSON property inputFiles
6803 6804 6805 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6803 def input_files @input_files end |
#output_bytes ⇒ Fixnum
Output only. Size of the loaded data in bytes. Note that while a LOAD query is
in the running state, this value may change.
Corresponds to the JSON property outputBytes
6809 6810 6811 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6809 def output_bytes @output_bytes end |
#output_rows ⇒ Fixnum
Output only. Number of rows imported in a LOAD query. Note that while a LOAD
query is in the running state, this value may change.
Corresponds to the JSON property outputRows
6815 6816 6817 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6815 def output_rows @output_rows end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6822 6823 6824 6825 6826 6827 6828 6829 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6822 def update!(**args) @bad_records = args[:bad_records] if args.key?(:bad_records) @bytes_transferred = args[:bytes_transferred] if args.key?(:bytes_transferred) @input_file_bytes = args[:input_file_bytes] if args.key?(:input_file_bytes) @input_files = args[:input_files] if args.key?(:input_files) @output_bytes = args[:output_bytes] if args.key?(:output_bytes) @output_rows = args[:output_rows] if args.key?(:output_rows) end |