Class: Google::Apis::BigqueryV2::MaterializedView
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::MaterializedView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
A materialized view considered for a query job.
Instance Attribute Summary collapse
-
#chosen ⇒ Boolean
(also: #chosen?)
Whether the materialized view is chosen for the query.
-
#estimated_bytes_saved ⇒ Fixnum
If present, specifies a best-effort estimation of the bytes saved by using the materialized view rather than its base tables.
-
#rejected_reason ⇒ String
If present, specifies the reason why the materialized view was not chosen for the query.
-
#table_reference ⇒ Google::Apis::BigqueryV2::TableReference
The candidate materialized view.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MaterializedView
constructor
A new instance of MaterializedView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MaterializedView
Returns a new instance of MaterializedView.
6883 6884 6885 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chosen ⇒ Boolean Also known as: chosen?
Whether the materialized view is chosen for the query. A materialized view can
be chosen to rewrite multiple parts of the same query. If a materialized view
is chosen to rewrite any part of the query, then this field is true, even if
the materialized view was not chosen to rewrite others parts.
Corresponds to the JSON property chosen
6863 6864 6865 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6863 def chosen @chosen end |
#estimated_bytes_saved ⇒ Fixnum
If present, specifies a best-effort estimation of the bytes saved by using the
materialized view rather than its base tables.
Corresponds to the JSON property estimatedBytesSaved
6870 6871 6872 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6870 def estimated_bytes_saved @estimated_bytes_saved end |
#rejected_reason ⇒ String
If present, specifies the reason why the materialized view was not chosen for
the query.
Corresponds to the JSON property rejectedReason
6876 6877 6878 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6876 def rejected_reason @rejected_reason end |
#table_reference ⇒ Google::Apis::BigqueryV2::TableReference
The candidate materialized view.
Corresponds to the JSON property tableReference
6881 6882 6883 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6881 def table_reference @table_reference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6888 6889 6890 6891 6892 6893 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 6888 def update!(**args) @chosen = args[:chosen] if args.key?(:chosen) @estimated_bytes_saved = args[:estimated_bytes_saved] if args.key?(:estimated_bytes_saved) @rejected_reason = args[:rejected_reason] if args.key?(:rejected_reason) @table_reference = args[:table_reference] if args.key?(:table_reference) end |