Class: Google::Apis::BigqueryV2::MetadataCacheStalenessInsight
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::MetadataCacheStalenessInsight
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Column Metadata Index staleness detailed infnormation.
Instance Attribute Summary collapse
-
#avg_previous_staleness_ms ⇒ String
Output only.
-
#staleness_percentage_increase ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetadataCacheStalenessInsight
constructor
A new instance of MetadataCacheStalenessInsight.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetadataCacheStalenessInsight
Returns a new instance of MetadataCacheStalenessInsight.
7405 7406 7407 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7405 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avg_previous_staleness_ms ⇒ String
Output only. Average column metadata index staleness of previous runs with the
same query hash.
Corresponds to the JSON property avgPreviousStalenessMs
7397 7398 7399 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7397 def avg_previous_staleness_ms @avg_previous_staleness_ms end |
#staleness_percentage_increase ⇒ Float
Output only. The percent increase in staleness between the current job and the
average staleness of previous jobs with the same query hash.
Corresponds to the JSON property stalenessPercentageIncrease
7403 7404 7405 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7403 def staleness_percentage_increase @staleness_percentage_increase end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7410 7411 7412 7413 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7410 def update!(**args) @avg_previous_staleness_ms = args[:avg_previous_staleness_ms] if args.key?(:avg_previous_staleness_ms) @staleness_percentage_increase = args[:staleness_percentage_increase] if args.key?(:staleness_percentage_increase) end |