Class: Google::Apis::BigqueryV2::MetadataCacheStalenessInsight
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::MetadataCacheStalenessInsight
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Column Metadata Index staleness detailed infnormation.
Instance Attribute Summary collapse
-
#avg_previous_staleness_ms ⇒ String
Output only.
-
#staleness_percentage_increase ⇒ Float
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetadataCacheStalenessInsight
constructor
A new instance of MetadataCacheStalenessInsight.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetadataCacheStalenessInsight
Returns a new instance of MetadataCacheStalenessInsight.
7331 7332 7333 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7331 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avg_previous_staleness_ms ⇒ String
Output only. Average column metadata index staleness of previous runs with the
same query hash.
Corresponds to the JSON property avgPreviousStalenessMs
7323 7324 7325 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7323 def avg_previous_staleness_ms @avg_previous_staleness_ms end |
#staleness_percentage_increase ⇒ Float
Output only. The percent increase in staleness between the current job and the
average staleness of previous jobs with the same query hash.
Corresponds to the JSON property stalenessPercentageIncrease
7329 7330 7331 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7329 def staleness_percentage_increase @staleness_percentage_increase end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7336 7337 7338 7339 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7336 def update!(**args) @avg_previous_staleness_ms = args[:avg_previous_staleness_ms] if args.key?(:avg_previous_staleness_ms) @staleness_percentage_increase = args[:staleness_percentage_increase] if args.key?(:staleness_percentage_increase) end |