Class: Google::Apis::BigqueryV2::Model
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::Model
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Instance Attribute Summary collapse
-
#best_trial_id ⇒ Fixnum
The best trial_id across all training runs.
-
#creation_time ⇒ Fixnum
Output only.
-
#default_trial_id ⇒ Fixnum
Output only.
-
#description ⇒ String
Optional.
-
#encryption_configuration ⇒ Google::Apis::BigqueryV2::EncryptionConfiguration
Configuration for Cloud KMS encryption settings.
-
#etag ⇒ String
Output only.
-
#expiration_time ⇒ Fixnum
Optional.
-
#feature_columns ⇒ Array<Google::Apis::BigqueryV2::StandardSqlField>
Output only.
-
#friendly_name ⇒ String
Optional.
-
#hparam_search_spaces ⇒ Google::Apis::BigqueryV2::HparamSearchSpaces
Hyperparameter search spaces.
-
#hparam_trials ⇒ Array<Google::Apis::BigqueryV2::HparamTuningTrial>
Output only.
-
#label_columns ⇒ Array<Google::Apis::BigqueryV2::StandardSqlField>
Output only.
-
#labels ⇒ Hash<String,String>
The labels associated with this model.
-
#last_modified_time ⇒ Fixnum
Output only.
-
#location ⇒ String
Output only.
-
#model_reference ⇒ Google::Apis::BigqueryV2::ModelReference
Id path of a model.
-
#model_type ⇒ String
Output only.
-
#optimal_trial_ids ⇒ Array<Fixnum>
Output only.
-
#remote_model_info ⇒ Google::Apis::BigqueryV2::RemoteModelInfo
Remote Model Info Corresponds to the JSON property
remoteModelInfo. -
#training_runs ⇒ Array<Google::Apis::BigqueryV2::TrainingRun>
Information for all training runs in increasing order of start_time.
-
#transform_columns ⇒ Array<Google::Apis::BigqueryV2::TransformColumn>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Model
constructor
A new instance of Model.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Model
Returns a new instance of Model.
7461 7462 7463 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#best_trial_id ⇒ Fixnum
The best trial_id across all training runs.
Corresponds to the JSON property bestTrialId
7331 7332 7333 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7331 def best_trial_id @best_trial_id end |
#creation_time ⇒ Fixnum
Output only. The time when this model was created, in millisecs since the
epoch.
Corresponds to the JSON property creationTime
7337 7338 7339 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7337 def creation_time @creation_time end |
#default_trial_id ⇒ Fixnum
Output only. The default trial_id to use in TVFs when the trial_id is not
passed in. For single-objective hyperparameter tuning models, this is the best trial ID. For multi-objective
hyperparameter tuning models, this is the
smallest trial ID among all Pareto optimal trials.
Corresponds to the JSON property defaultTrialId
7348 7349 7350 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7348 def default_trial_id @default_trial_id end |
#description ⇒ String
Optional. A user-friendly description of this model.
Corresponds to the JSON property description
7353 7354 7355 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7353 def description @description end |
#encryption_configuration ⇒ Google::Apis::BigqueryV2::EncryptionConfiguration
Configuration for Cloud KMS encryption settings.
Corresponds to the JSON property encryptionConfiguration
7358 7359 7360 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7358 def encryption_configuration @encryption_configuration end |
#etag ⇒ String
Output only. A hash of this resource.
Corresponds to the JSON property etag
7363 7364 7365 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7363 def etag @etag end |
#expiration_time ⇒ Fixnum
Optional. The time when this model expires, in milliseconds since the epoch.
If not present, the model will persist indefinitely. Expired models will be
deleted and their storage reclaimed. The defaultTableExpirationMs property of
the encapsulating dataset can be used to set a default expirationTime on newly
created models.
Corresponds to the JSON property expirationTime
7372 7373 7374 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7372 def expiration_time @expiration_time end |
#feature_columns ⇒ Array<Google::Apis::BigqueryV2::StandardSqlField>
Output only. Input feature columns for the model inference. If the model is
trained with TRANSFORM clause, these are the input of the TRANSFORM clause.
Corresponds to the JSON property featureColumns
7378 7379 7380 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7378 def feature_columns @feature_columns end |
#friendly_name ⇒ String
Optional. A descriptive name for this model.
Corresponds to the JSON property friendlyName
7383 7384 7385 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7383 def friendly_name @friendly_name end |
#hparam_search_spaces ⇒ Google::Apis::BigqueryV2::HparamSearchSpaces
Hyperparameter search spaces. These should be a subset of training_options.
Corresponds to the JSON property hparamSearchSpaces
7388 7389 7390 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7388 def hparam_search_spaces @hparam_search_spaces end |
#hparam_trials ⇒ Array<Google::Apis::BigqueryV2::HparamTuningTrial>
Output only. Trials of a hyperparameter tuning
model sorted by trial_id.
Corresponds to the JSON property hparamTrials
7395 7396 7397 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7395 def hparam_trials @hparam_trials end |
#label_columns ⇒ Array<Google::Apis::BigqueryV2::StandardSqlField>
Output only. Label columns that were used to train this model. The output of
the model will have a "predicted_" prefix to these columns.
Corresponds to the JSON property labelColumns
7401 7402 7403 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7401 def label_columns @label_columns end |
#labels ⇒ Hash<String,String>
The labels associated with this model. You can use these to organize and group
your models. Label keys and values can be no longer than 63 characters, can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. Label values are optional. Label keys
must start with a letter and each label in the list must have a different key.
Corresponds to the JSON property labels
7410 7411 7412 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7410 def labels @labels end |
#last_modified_time ⇒ Fixnum
Output only. The time when this model was last modified, in millisecs since
the epoch.
Corresponds to the JSON property lastModifiedTime
7416 7417 7418 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7416 def last_modified_time @last_modified_time end |
#location ⇒ String
Output only. The geographic location where the model resides. This value is
inherited from the dataset.
Corresponds to the JSON property location
7422 7423 7424 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7422 def location @location end |
#model_reference ⇒ Google::Apis::BigqueryV2::ModelReference
Id path of a model.
Corresponds to the JSON property modelReference
7427 7428 7429 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7427 def model_reference @model_reference end |
#model_type ⇒ String
Output only. Type of the model resource.
Corresponds to the JSON property modelType
7432 7433 7434 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7432 def model_type @model_type end |
#optimal_trial_ids ⇒ Array<Fixnum>
Output only. For single-objective hyperparameter tuning models, it only contains the best trial. For multi-objective
hyperparameter tuning models, it contains all
Pareto optimal trials sorted by trial_id.
Corresponds to the JSON property optimalTrialIds
7442 7443 7444 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7442 def optimal_trial_ids @optimal_trial_ids end |
#remote_model_info ⇒ Google::Apis::BigqueryV2::RemoteModelInfo
Remote Model Info
Corresponds to the JSON property remoteModelInfo
7447 7448 7449 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7447 def remote_model_info @remote_model_info end |
#training_runs ⇒ Array<Google::Apis::BigqueryV2::TrainingRun>
Information for all training runs in increasing order of start_time.
Corresponds to the JSON property trainingRuns
7452 7453 7454 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7452 def training_runs @training_runs end |
#transform_columns ⇒ Array<Google::Apis::BigqueryV2::TransformColumn>
Output only. This field will be populated if a TRANSFORM clause was used to
train a model. TRANSFORM clause (if used) takes feature_columns as input and
outputs transform_columns. transform_columns then are used to train the model.
Corresponds to the JSON property transformColumns
7459 7460 7461 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7459 def transform_columns @transform_columns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7466 7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7466 def update!(**args) @best_trial_id = args[:best_trial_id] if args.key?(:best_trial_id) @creation_time = args[:creation_time] if args.key?(:creation_time) @default_trial_id = args[:default_trial_id] if args.key?(:default_trial_id) @description = args[:description] if args.key?(:description) @encryption_configuration = args[:encryption_configuration] if args.key?(:encryption_configuration) @etag = args[:etag] if args.key?(:etag) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @feature_columns = args[:feature_columns] if args.key?(:feature_columns) @friendly_name = args[:friendly_name] if args.key?(:friendly_name) @hparam_search_spaces = args[:hparam_search_spaces] if args.key?(:hparam_search_spaces) @hparam_trials = args[:hparam_trials] if args.key?(:hparam_trials) @label_columns = args[:label_columns] if args.key?(:label_columns) @labels = args[:labels] if args.key?(:labels) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @location = args[:location] if args.key?(:location) @model_reference = args[:model_reference] if args.key?(:model_reference) @model_type = args[:model_type] if args.key?(:model_type) @optimal_trial_ids = args[:optimal_trial_ids] if args.key?(:optimal_trial_ids) @remote_model_info = args[:remote_model_info] if args.key?(:remote_model_info) @training_runs = args[:training_runs] if args.key?(:training_runs) @transform_columns = args[:transform_columns] if args.key?(:transform_columns) end |