Class: Google::Apis::BigqueryV2::PartitioningDefinition
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::PartitioningDefinition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
The partitioning information, which includes managed table, external table and metastore partitioned table partition information.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartitioningDefinition
constructor
A new instance of PartitioningDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartitioningDefinition
Returns a new instance of PartitioningDefinition.
7438 7439 7440 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7438 def initialize(**args) update!(**args) end |
Instance Attribute Details
#partitioned_column ⇒ Array<Google::Apis::BigqueryV2::PartitionedColumn>
Optional. Details about each partitioning column. This field is output only
for all partitioning types other than metastore partitioned tables. BigQuery
native tables only support 1 partitioning column. Other table types may
support 0, 1 or more partitioning columns. For metastore partitioned tables,
the order must match the definition order in the Hive Metastore, where it must
match the physical layout of the table. For example, CREATE TABLE a_table(id
BIGINT, name STRING) PARTITIONED BY (city STRING, state STRING). In this case
the values must be ['city', 'state'] in that order.
Corresponds to the JSON property partitionedColumn
7436 7437 7438 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7436 def partitioned_column @partitioned_column end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7443 7444 7445 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7443 def update!(**args) @partitioned_column = args[:partitioned_column] if args.key?(:partitioned_column) end |