Class: Google::Apis::BigqueryV2::PerformanceInsights

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Performance insights for the job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PerformanceInsights

Returns a new instance of PerformanceInsights.



7920
7921
7922
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7920

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#avg_previous_execution_msFixnum

Output only. Average execution ms of previous runs. Indicates the job ran slow compared to previous executions. To find previous executions, use INFORMATION_SCHEMA tables and filter jobs with same query hash. Corresponds to the JSON property avgPreviousExecutionMs

Returns:

  • (Fixnum)


7900
7901
7902
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7900

def avg_previous_execution_ms
  @avg_previous_execution_ms
end

#stage_performance_change_insightsArray<Google::Apis::BigqueryV2::StagePerformanceChangeInsight>

Output only. Query stage performance insights compared to previous runs, for diagnosing performance regression. Corresponds to the JSON property stagePerformanceChangeInsights



7906
7907
7908
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7906

def stage_performance_change_insights
  @stage_performance_change_insights
end

#stage_performance_standalone_insightsArray<Google::Apis::BigqueryV2::StagePerformanceStandaloneInsight>

Output only. Standalone query stage performance insights, for exploring potential improvements. Corresponds to the JSON property stagePerformanceStandaloneInsights



7912
7913
7914
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7912

def stage_performance_standalone_insights
  @stage_performance_standalone_insights
end

#table_change_insightsArray<Google::Apis::BigqueryV2::TableChangeInsight>

Output only. Performance insights for table-level attributes that changed compared to previous runs. Corresponds to the JSON property tableChangeInsights



7918
7919
7920
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7918

def table_change_insights
  @table_change_insights
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7925
7926
7927
7928
7929
7930
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7925

def update!(**args)
  @avg_previous_execution_ms = args[:avg_previous_execution_ms] if args.key?(:avg_previous_execution_ms)
  @stage_performance_change_insights = args[:stage_performance_change_insights] if args.key?(:stage_performance_change_insights)
  @stage_performance_standalone_insights = args[:stage_performance_standalone_insights] if args.key?(:stage_performance_standalone_insights)
  @table_change_insights = args[:table_change_insights] if args.key?(:table_change_insights)
end