Class: Google::Apis::BigqueryV2::PerformanceInsights
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::PerformanceInsights
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Performance insights for the job.
Instance Attribute Summary collapse
-
#avg_previous_execution_ms ⇒ Fixnum
Output only.
-
#stage_performance_change_insights ⇒ Array<Google::Apis::BigqueryV2::StagePerformanceChangeInsight>
Output only.
-
#stage_performance_standalone_insights ⇒ Array<Google::Apis::BigqueryV2::StagePerformanceStandaloneInsight>
Output only.
-
#table_change_insights ⇒ Array<Google::Apis::BigqueryV2::TableChangeInsight>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PerformanceInsights
constructor
A new instance of PerformanceInsights.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PerformanceInsights
Returns a new instance of PerformanceInsights.
7846 7847 7848 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7846 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avg_previous_execution_ms ⇒ Fixnum
Output only. Average execution ms of previous runs. Indicates the job ran slow
compared to previous executions. To find previous executions, use
INFORMATION_SCHEMA tables and filter jobs with same query hash.
Corresponds to the JSON property avgPreviousExecutionMs
7826 7827 7828 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7826 def avg_previous_execution_ms @avg_previous_execution_ms end |
#stage_performance_change_insights ⇒ Array<Google::Apis::BigqueryV2::StagePerformanceChangeInsight>
Output only. Query stage performance insights compared to previous runs, for
diagnosing performance regression.
Corresponds to the JSON property stagePerformanceChangeInsights
7832 7833 7834 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7832 def stage_performance_change_insights @stage_performance_change_insights end |
#stage_performance_standalone_insights ⇒ Array<Google::Apis::BigqueryV2::StagePerformanceStandaloneInsight>
Output only. Standalone query stage performance insights, for exploring
potential improvements.
Corresponds to the JSON property stagePerformanceStandaloneInsights
7838 7839 7840 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7838 def stage_performance_standalone_insights @stage_performance_standalone_insights end |
#table_change_insights ⇒ Array<Google::Apis::BigqueryV2::TableChangeInsight>
Output only. Performance insights for table-level attributes that changed
compared to previous runs.
Corresponds to the JSON property tableChangeInsights
7844 7845 7846 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7844 def table_change_insights @table_change_insights end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7851 7852 7853 7854 7855 7856 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7851 def update!(**args) @avg_previous_execution_ms = args[:avg_previous_execution_ms] if args.key?(:avg_previous_execution_ms) @stage_performance_change_insights = args[:stage_performance_change_insights] if args.key?(:stage_performance_change_insights) @stage_performance_standalone_insights = args[:stage_performance_standalone_insights] if args.key?(:stage_performance_standalone_insights) @table_change_insights = args[:table_change_insights] if args.key?(:table_change_insights) end |