Class: Google::Apis::BigqueryV2::PrivacyPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Represents privacy policy that contains the privacy requirements specified by the data owner. Currently, this is only supported on views.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivacyPolicy

Returns a new instance of PrivacyPolicy.



7922
7923
7924
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7922

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_threshold_policyGoogle::Apis::BigqueryV2::AggregationThresholdPolicy

Represents privacy policy associated with "aggregation threshold" method. Corresponds to the JSON property aggregationThresholdPolicy



7908
7909
7910
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7908

def aggregation_threshold_policy
  @aggregation_threshold_policy
end

#differential_privacy_policyGoogle::Apis::BigqueryV2::DifferentialPrivacyPolicy

Represents privacy policy associated with "differential privacy" method. Corresponds to the JSON property differentialPrivacyPolicy



7913
7914
7915
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7913

def differential_privacy_policy
  @differential_privacy_policy
end

#join_restriction_policyGoogle::Apis::BigqueryV2::JoinRestrictionPolicy

Represents privacy policy associated with "join restrictions". Join restriction gives data providers the ability to enforce joins on the ' join_allowed_columns' when data is queried from a privacy protected view. Corresponds to the JSON property joinRestrictionPolicy



7920
7921
7922
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7920

def join_restriction_policy
  @join_restriction_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7927
7928
7929
7930
7931
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7927

def update!(**args)
  @aggregation_threshold_policy = args[:aggregation_threshold_policy] if args.key?(:aggregation_threshold_policy)
  @differential_privacy_policy = args[:differential_privacy_policy] if args.key?(:differential_privacy_policy)
  @join_restriction_policy = args[:join_restriction_policy] if args.key?(:join_restriction_policy)
end