Class: Google::Apis::BigqueryV2::QueryParameterValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

The value of a query parameter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryParameterValue

Returns a new instance of QueryParameterValue.



8521
8522
8523
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#array_valuesArray<Google::Apis::BigqueryV2::QueryParameterValue>

Optional. The array values, if this is an array type. Corresponds to the JSON property arrayValues



8504
8505
8506
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8504

def array_values
  @array_values
end

#range_valueGoogle::Apis::BigqueryV2::RangeValue

Represents the value of a range. Corresponds to the JSON property rangeValue



8509
8510
8511
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8509

def range_value
  @range_value
end

#struct_valuesHash<String,Google::Apis::BigqueryV2::QueryParameterValue>

The struct field values. Corresponds to the JSON property structValues



8514
8515
8516
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8514

def struct_values
  @struct_values
end

#valueString

Optional. The value of this value, if a simple scalar type. Corresponds to the JSON property value

Returns:

  • (String)


8519
8520
8521
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8519

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8526
8527
8528
8529
8530
8531
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8526

def update!(**args)
  @array_values = args[:array_values] if args.key?(:array_values)
  @range_value = args[:range_value] if args.key?(:range_value)
  @struct_values = args[:struct_values] if args.key?(:struct_values)
  @value = args[:value] if args.key?(:value)
end