Class: Google::Apis::BigqueryV2::QueryParameterValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

The value of a query parameter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryParameterValue

Returns a new instance of QueryParameterValue.



8454
8455
8456
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8454

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#array_valuesArray<Google::Apis::BigqueryV2::QueryParameterValue>

Optional. The array values, if this is an array type. Corresponds to the JSON property arrayValues



8437
8438
8439
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8437

def array_values
  @array_values
end

#range_valueGoogle::Apis::BigqueryV2::RangeValue

Represents the value of a range. Corresponds to the JSON property rangeValue



8442
8443
8444
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8442

def range_value
  @range_value
end

#struct_valuesHash<String,Google::Apis::BigqueryV2::QueryParameterValue>

The struct field values. Corresponds to the JSON property structValues



8447
8448
8449
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8447

def struct_values
  @struct_values
end

#valueString

Optional. The value of this value, if a simple scalar type. Corresponds to the JSON property value

Returns:

  • (String)


8452
8453
8454
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8452

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8459
8460
8461
8462
8463
8464
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8459

def update!(**args)
  @array_values = args[:array_values] if args.key?(:array_values)
  @range_value = args[:range_value] if args.key?(:range_value)
  @struct_values = args[:struct_values] if args.key?(:struct_values)
  @value = args[:value] if args.key?(:value)
end