Class: Google::Apis::BigqueryV2::QueryParameterValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

The value of a query parameter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryParameterValue

Returns a new instance of QueryParameterValue.



8375
8376
8377
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#array_valuesArray<Google::Apis::BigqueryV2::QueryParameterValue>

Optional. The array values, if this is an array type. Corresponds to the JSON property arrayValues



8358
8359
8360
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8358

def array_values
  @array_values
end

#range_valueGoogle::Apis::BigqueryV2::RangeValue

Represents the value of a range. Corresponds to the JSON property rangeValue



8363
8364
8365
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8363

def range_value
  @range_value
end

#struct_valuesHash<String,Google::Apis::BigqueryV2::QueryParameterValue>

The struct field values. Corresponds to the JSON property structValues



8368
8369
8370
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8368

def struct_values
  @struct_values
end

#valueString

Optional. The value of this value, if a simple scalar type. Corresponds to the JSON property value

Returns:

  • (String)


8373
8374
8375
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8373

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8380
8381
8382
8383
8384
8385
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8380

def update!(**args)
  @array_values = args[:array_values] if args.key?(:array_values)
  @range_value = args[:range_value] if args.key?(:range_value)
  @struct_values = args[:struct_values] if args.key?(:struct_values)
  @value = args[:value] if args.key?(:value)
end