Class: Google::Apis::BigqueryV2::QueryParameterValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

The value of a query parameter.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryParameterValue

Returns a new instance of QueryParameterValue.



8001
8002
8003
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#array_valuesArray<Google::Apis::BigqueryV2::QueryParameterValue>

Optional. The array values, if this is an array type. Corresponds to the JSON property arrayValues



7984
7985
7986
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7984

def array_values
  @array_values
end

#range_valueGoogle::Apis::BigqueryV2::RangeValue

Represents the value of a range. Corresponds to the JSON property rangeValue



7989
7990
7991
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7989

def range_value
  @range_value
end

#struct_valuesHash<String,Google::Apis::BigqueryV2::QueryParameterValue>

The struct field values. Corresponds to the JSON property structValues



7994
7995
7996
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7994

def struct_values
  @struct_values
end

#valueString

Optional. The value of this value, if a simple scalar type. Corresponds to the JSON property value

Returns:

  • (String)


7999
8000
8001
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7999

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8006
8007
8008
8009
8010
8011
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8006

def update!(**args)
  @array_values = args[:array_values] if args.key?(:array_values)
  @range_value = args[:range_value] if args.key?(:range_value)
  @struct_values = args[:struct_values] if args.key?(:struct_values)
  @value = args[:value] if args.key?(:value)
end