Class: Google::Apis::BigqueryV2::QueryRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::QueryRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Describes the format of the jobs.query request.
Instance Attribute Summary collapse
-
#connection_properties ⇒ Array<Google::Apis::BigqueryV2::ConnectionProperty>
Optional.
-
#continuous ⇒ Boolean
(also: #continuous?)
[Optional] Specifies whether the query should be executed as a continuous query.
-
#create_session ⇒ Boolean
(also: #create_session?)
Optional.
-
#default_dataset ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
-
#destination_encryption_configuration ⇒ Google::Apis::BigqueryV2::EncryptionConfiguration
Configuration for Cloud KMS encryption settings.
-
#dry_run ⇒ Boolean
(also: #dry_run?)
Optional.
-
#format_options ⇒ Google::Apis::BigqueryV2::DataFormatOptions
Options for data format adjustments.
-
#job_creation_mode ⇒ String
Optional.
-
#job_timeout_ms ⇒ Fixnum
Optional.
-
#kind ⇒ String
The resource type of the request.
-
#labels ⇒ Hash<String,String>
Optional.
-
#location ⇒ String
The geographic location where the job should run.
-
#max_results ⇒ Fixnum
Optional.
-
#max_slots ⇒ Fixnum
Optional.
-
#maximum_bytes_billed ⇒ Fixnum
Optional.
-
#parameter_mode ⇒ String
GoogleSQL only.
-
#preserve_nulls ⇒ Boolean
(also: #preserve_nulls?)
This property is deprecated.
-
#query ⇒ String
Required.
-
#query_parameters ⇒ Array<Google::Apis::BigqueryV2::QueryParameter>
Query parameters for GoogleSQL queries.
-
#request_id ⇒ String
Optional.
-
#reservation ⇒ String
Optional.
-
#timeout_ms ⇒ Fixnum
Optional.
-
#use_legacy_sql ⇒ Boolean
(also: #use_legacy_sql?)
Specifies whether to use BigQuery's legacy SQL dialect for this query.
-
#use_query_cache ⇒ Boolean
(also: #use_query_cache?)
Optional.
-
#write_incremental_results ⇒ Boolean
(also: #write_incremental_results?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryRequest
constructor
A new instance of QueryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryRequest
Returns a new instance of QueryRequest.
8600 8601 8602 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_properties ⇒ Array<Google::Apis::BigqueryV2::ConnectionProperty>
Optional. Connection properties which can modify the query behavior.
Corresponds to the JSON property connectionProperties
8400 8401 8402 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8400 def connection_properties @connection_properties end |
#continuous ⇒ Boolean Also known as: continuous?
[Optional] Specifies whether the query should be executed as a continuous
query. The default value is false.
Corresponds to the JSON property continuous
8406 8407 8408 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8406 def continuous @continuous end |
#create_session ⇒ Boolean Also known as: create_session?
Optional. If true, creates a new session using a randomly generated session_id.
If false, runs query with an existing session_id passed in ConnectionProperty,
otherwise runs query in non-session mode. The session location will be set to
QueryRequest.location if it is present, otherwise it's set to the default
location based on existing routing logic.
Corresponds to the JSON property createSession
8416 8417 8418 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8416 def create_session @create_session end |
#default_dataset ⇒ Google::Apis::BigqueryV2::DatasetReference
Identifier for a dataset.
Corresponds to the JSON property defaultDataset
8422 8423 8424 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8422 def default_dataset @default_dataset end |
#destination_encryption_configuration ⇒ Google::Apis::BigqueryV2::EncryptionConfiguration
Configuration for Cloud KMS encryption settings.
Corresponds to the JSON property destinationEncryptionConfiguration
8427 8428 8429 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8427 def destination_encryption_configuration @destination_encryption_configuration end |
#dry_run ⇒ Boolean Also known as: dry_run?
Optional. If set to true, BigQuery doesn't run the job. Instead, if the query
is valid, BigQuery returns statistics about the job such as how many bytes
would be processed. If the query is invalid, an error returns. The default
value is false.
Corresponds to the JSON property dryRun
8435 8436 8437 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8435 def dry_run @dry_run end |
#format_options ⇒ Google::Apis::BigqueryV2::DataFormatOptions
Options for data format adjustments.
Corresponds to the JSON property formatOptions
8441 8442 8443 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8441 def @format_options end |
#job_creation_mode ⇒ String
Optional. If not set, jobs are always required. If set, the query request will
follow the behavior described JobCreationMode.
Corresponds to the JSON property jobCreationMode
8447 8448 8449 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8447 def job_creation_mode @job_creation_mode end |
#job_timeout_ms ⇒ Fixnum
Optional. Job timeout in milliseconds. If this time limit is exceeded,
BigQuery will attempt to stop a longer job, but may not always succeed in
canceling it before the job completes. For example, a job that takes more than
60 seconds to complete has a better chance of being stopped than a job that
takes 10 seconds to complete. This timeout applies to the query even if a job
does not need to be created.
Corresponds to the JSON property jobTimeoutMs
8457 8458 8459 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8457 def job_timeout_ms @job_timeout_ms end |
#kind ⇒ String
The resource type of the request.
Corresponds to the JSON property kind
8462 8463 8464 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8462 def kind @kind end |
#labels ⇒ Hash<String,String>
Optional. The labels associated with this query. Labels can be used to
organize and group query jobs. Label keys and values can be no longer than 63
characters, can only contain lowercase letters, numeric characters,
underscores and dashes. International characters are allowed. Label keys must
start with a letter and each label in the list must have a different key.
Corresponds to the JSON property labels
8471 8472 8473 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8471 def labels @labels end |
#location ⇒ String
The geographic location where the job should run. For more information, see
how to specify locations.
Corresponds to the JSON property location
8478 8479 8480 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8478 def location @location end |
#max_results ⇒ Fixnum
Optional. The maximum number of rows of data to return per page of results.
Setting this flag to a small value such as 1000 and then paging through
results might improve reliability when the query result set is large. In
addition to this limit, responses are also limited to 10 MB. By default, there
is no maximum row count, and only the byte limit applies.
Corresponds to the JSON property maxResults
8487 8488 8489 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8487 def max_results @max_results end |
#max_slots ⇒ Fixnum
Optional. A target limit on the rate of slot consumption by this query. If set
to a value > 0, BigQuery will attempt to limit the rate of slot consumption by
this query to keep it below the configured limit, even if the query is
eligible for more slots based on fair scheduling. The unused slots will be
available for other jobs and queries to use. Note: This feature is not yet
generally available.
Corresponds to the JSON property maxSlots
8497 8498 8499 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8497 def max_slots @max_slots end |
#maximum_bytes_billed ⇒ Fixnum
Optional. Limits the bytes billed for this query. Queries with bytes billed
above this limit will fail (without incurring a charge). If unspecified, the
project default is used.
Corresponds to the JSON property maximumBytesBilled
8504 8505 8506 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8504 def maximum_bytes_billed @maximum_bytes_billed end |
#parameter_mode ⇒ String
GoogleSQL only. Set to POSITIONAL to use positional (?) query parameters or to
NAMED to use named (@myparam) query parameters in this query.
Corresponds to the JSON property parameterMode
8510 8511 8512 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8510 def parameter_mode @parameter_mode end |
#preserve_nulls ⇒ Boolean Also known as: preserve_nulls?
This property is deprecated.
Corresponds to the JSON property preserveNulls
8515 8516 8517 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8515 def preserve_nulls @preserve_nulls end |
#query ⇒ String
Required. A query string to execute, using Google Standard SQL or legacy SQL
syntax. Example: "SELECT COUNT(f1) FROM myProjectId.myDatasetId.myTableId".
Corresponds to the JSON property query
8522 8523 8524 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8522 def query @query end |
#query_parameters ⇒ Array<Google::Apis::BigqueryV2::QueryParameter>
Query parameters for GoogleSQL queries.
Corresponds to the JSON property queryParameters
8527 8528 8529 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8527 def query_parameters @query_parameters end |
#request_id ⇒ String
Optional. A unique user provided identifier to ensure idempotent behavior for
queries. Note that this is different from the job_id. It has the following
properties: 1. It is case-sensitive, limited to up to 36 ASCII characters. A
UUID is recommended. 2. Read only queries can ignore this token since they are
nullipotent by definition. 3. For the purposes of idempotency ensured by the
request_id, a request is considered duplicate of another only if they have the
same request_id and are actually duplicates. When determining whether a
request is a duplicate of another request, all parameters in the request that
may affect the result are considered. For example, query,
connection_properties, query_parameters, use_legacy_sql are parameters that
affect the result and are considered when determining whether a request is a
duplicate, but properties like timeout_ms don't affect the result and are thus
not considered. Dry run query requests are never considered duplicate of
another request. 4. When a duplicate mutating query request is detected, it
returns: a. the results of the mutation if it completes successfully within
the timeout. b. the running operation if it is still in progress at the end of
the timeout. 5. Its lifetime is limited to 15 minutes. In other words, if two
requests are sent with the same request_id, but more than 15 minutes apart,
idempotency is not guaranteed.
Corresponds to the JSON property requestId
8550 8551 8552 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8550 def request_id @request_id end |
#reservation ⇒ String
Optional. The reservation that jobs.query request would use. User can specify
a reservation to execute the job.query. The expected format is projects/
project/locations/location/reservations/reservation`.
Corresponds to the JSON propertyreservation`
8557 8558 8559 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8557 def reservation @reservation end |
#timeout_ms ⇒ Fixnum
Optional. Optional: Specifies the maximum amount of time, in milliseconds,
that the client is willing to wait for the query to complete. By default, this
limit is 10 seconds (10,000 milliseconds). If the query is complete, the
jobComplete field in the response is true. If the query has not yet completed,
jobComplete is false. You can request a longer timeout period in the timeoutMs
field. However, the call is not guaranteed to wait for the specified timeout;
it typically returns after around 200 seconds (200,000 milliseconds), even if
the query is not complete. If jobComplete is false, you can continue to wait
for the query to complete by calling the getQueryResults method until the
jobComplete field in the getQueryResults response is true.
Corresponds to the JSON property timeoutMs
8571 8572 8573 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8571 def timeout_ms @timeout_ms end |
#use_legacy_sql ⇒ Boolean Also known as: use_legacy_sql?
Specifies whether to use BigQuery's legacy SQL dialect for this query. The
default value is true. If set to false, the query uses BigQuery's GoogleSQL. When
useLegacySql is set to false, the value of flattenResults is ignored; query
will be run as if flattenResults is false.
Corresponds to the JSON property useLegacySql
8580 8581 8582 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8580 def use_legacy_sql @use_legacy_sql end |
#use_query_cache ⇒ Boolean Also known as: use_query_cache?
Optional. Whether to look for the result in the query cache. The query cache
is a best-effort cache that will be flushed whenever tables in the query are
modified. The default value is true.
Corresponds to the JSON property useQueryCache
8588 8589 8590 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8588 def use_query_cache @use_query_cache end |
#write_incremental_results ⇒ Boolean Also known as: write_incremental_results?
Optional. This is only supported for SELECT query. If set, the query is
allowed to write results incrementally to the temporary result table. This may
incur a performance penalty. This option cannot be used with Legacy SQL. This
feature is not yet available.
Corresponds to the JSON property writeIncrementalResults
8597 8598 8599 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8597 def write_incremental_results @write_incremental_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8605 8606 8607 8608 8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8605 def update!(**args) @connection_properties = args[:connection_properties] if args.key?(:connection_properties) @continuous = args[:continuous] if args.key?(:continuous) @create_session = args[:create_session] if args.key?(:create_session) @default_dataset = args[:default_dataset] if args.key?(:default_dataset) @destination_encryption_configuration = args[:destination_encryption_configuration] if args.key?(:destination_encryption_configuration) @dry_run = args[:dry_run] if args.key?(:dry_run) @format_options = args[:format_options] if args.key?(:format_options) @job_creation_mode = args[:job_creation_mode] if args.key?(:job_creation_mode) @job_timeout_ms = args[:job_timeout_ms] if args.key?(:job_timeout_ms) @kind = args[:kind] if args.key?(:kind) @labels = args[:labels] if args.key?(:labels) @location = args[:location] if args.key?(:location) @max_results = args[:max_results] if args.key?(:max_results) @max_slots = args[:max_slots] if args.key?(:max_slots) @maximum_bytes_billed = args[:maximum_bytes_billed] if args.key?(:maximum_bytes_billed) @parameter_mode = args[:parameter_mode] if args.key?(:parameter_mode) @preserve_nulls = args[:preserve_nulls] if args.key?(:preserve_nulls) @query = args[:query] if args.key?(:query) @query_parameters = args[:query_parameters] if args.key?(:query_parameters) @request_id = args[:request_id] if args.key?(:request_id) @reservation = args[:reservation] if args.key?(:reservation) @timeout_ms = args[:timeout_ms] if args.key?(:timeout_ms) @use_legacy_sql = args[:use_legacy_sql] if args.key?(:use_legacy_sql) @use_query_cache = args[:use_query_cache] if args.key?(:use_query_cache) @write_incremental_results = args[:write_incremental_results] if args.key?(:write_incremental_results) end |