Class: Google::Apis::BigqueryV2::QueryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Describes the format of the jobs.query request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryRequest

Returns a new instance of QueryRequest.



8191
8192
8193
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_propertiesArray<Google::Apis::BigqueryV2::ConnectionProperty>

Optional. Connection properties which can modify the query behavior. Corresponds to the JSON property connectionProperties



7991
7992
7993
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7991

def connection_properties
  @connection_properties
end

#continuousBoolean Also known as: continuous?

[Optional] Specifies whether the query should be executed as a continuous query. The default value is false. Corresponds to the JSON property continuous

Returns:

  • (Boolean)


7997
7998
7999
# File 'lib/google/apis/bigquery_v2/classes.rb', line 7997

def continuous
  @continuous
end

#create_sessionBoolean Also known as: create_session?

Optional. If true, creates a new session using a randomly generated session_id. If false, runs query with an existing session_id passed in ConnectionProperty, otherwise runs query in non-session mode. The session location will be set to QueryRequest.location if it is present, otherwise it's set to the default location based on existing routing logic. Corresponds to the JSON property createSession

Returns:

  • (Boolean)


8007
8008
8009
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8007

def create_session
  @create_session
end

#default_datasetGoogle::Apis::BigqueryV2::DatasetReference

Identifier for a dataset. Corresponds to the JSON property defaultDataset



8013
8014
8015
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8013

def default_dataset
  @default_dataset
end

#destination_encryption_configurationGoogle::Apis::BigqueryV2::EncryptionConfiguration

Configuration for Cloud KMS encryption settings. Corresponds to the JSON property destinationEncryptionConfiguration



8018
8019
8020
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8018

def destination_encryption_configuration
  @destination_encryption_configuration
end

#dry_runBoolean Also known as: dry_run?

Optional. If set to true, BigQuery doesn't run the job. Instead, if the query is valid, BigQuery returns statistics about the job such as how many bytes would be processed. If the query is invalid, an error returns. The default value is false. Corresponds to the JSON property dryRun

Returns:

  • (Boolean)


8026
8027
8028
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8026

def dry_run
  @dry_run
end

#format_optionsGoogle::Apis::BigqueryV2::DataFormatOptions

Options for data format adjustments. Corresponds to the JSON property formatOptions



8032
8033
8034
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8032

def format_options
  @format_options
end

#job_creation_modeString

Optional. If not set, jobs are always required. If set, the query request will follow the behavior described JobCreationMode. Corresponds to the JSON property jobCreationMode

Returns:

  • (String)


8038
8039
8040
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8038

def job_creation_mode
  @job_creation_mode
end

#job_timeout_msFixnum

Optional. Job timeout in milliseconds. If this time limit is exceeded, BigQuery will attempt to stop a longer job, but may not always succeed in canceling it before the job completes. For example, a job that takes more than 60 seconds to complete has a better chance of being stopped than a job that takes 10 seconds to complete. This timeout applies to the query even if a job does not need to be created. Corresponds to the JSON property jobTimeoutMs

Returns:

  • (Fixnum)


8048
8049
8050
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8048

def job_timeout_ms
  @job_timeout_ms
end

#kindString

The resource type of the request. Corresponds to the JSON property kind

Returns:

  • (String)


8053
8054
8055
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8053

def kind
  @kind
end

#labelsHash<String,String>

Optional. The labels associated with this query. Labels can be used to organize and group query jobs. Label keys and values can be no longer than 63 characters, can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed. Label keys must start with a letter and each label in the list must have a different key. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


8062
8063
8064
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8062

def labels
  @labels
end

#locationString

The geographic location where the job should run. For more information, see how to specify locations. Corresponds to the JSON property location

Returns:

  • (String)


8069
8070
8071
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8069

def location
  @location
end

#max_resultsFixnum

Optional. The maximum number of rows of data to return per page of results. Setting this flag to a small value such as 1000 and then paging through results might improve reliability when the query result set is large. In addition to this limit, responses are also limited to 10 MB. By default, there is no maximum row count, and only the byte limit applies. Corresponds to the JSON property maxResults

Returns:

  • (Fixnum)


8078
8079
8080
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8078

def max_results
  @max_results
end

#max_slotsFixnum

Optional. A target limit on the rate of slot consumption by this query. If set to a value > 0, BigQuery will attempt to limit the rate of slot consumption by this query to keep it below the configured limit, even if the query is eligible for more slots based on fair scheduling. The unused slots will be available for other jobs and queries to use. Note: This feature is not yet generally available. Corresponds to the JSON property maxSlots

Returns:

  • (Fixnum)


8088
8089
8090
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8088

def max_slots
  @max_slots
end

#maximum_bytes_billedFixnum

Optional. Limits the bytes billed for this query. Queries with bytes billed above this limit will fail (without incurring a charge). If unspecified, the project default is used. Corresponds to the JSON property maximumBytesBilled

Returns:

  • (Fixnum)


8095
8096
8097
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8095

def maximum_bytes_billed
  @maximum_bytes_billed
end

#parameter_modeString

GoogleSQL only. Set to POSITIONAL to use positional (?) query parameters or to NAMED to use named (@myparam) query parameters in this query. Corresponds to the JSON property parameterMode

Returns:

  • (String)


8101
8102
8103
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8101

def parameter_mode
  @parameter_mode
end

#preserve_nullsBoolean Also known as: preserve_nulls?

This property is deprecated. Corresponds to the JSON property preserveNulls

Returns:

  • (Boolean)


8106
8107
8108
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8106

def preserve_nulls
  @preserve_nulls
end

#queryString

Required. A query string to execute, using Google Standard SQL or legacy SQL syntax. Example: "SELECT COUNT(f1) FROM myProjectId.myDatasetId.myTableId". Corresponds to the JSON property query

Returns:

  • (String)


8113
8114
8115
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8113

def query
  @query
end

#query_parametersArray<Google::Apis::BigqueryV2::QueryParameter>

Query parameters for GoogleSQL queries. Corresponds to the JSON property queryParameters



8118
8119
8120
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8118

def query_parameters
  @query_parameters
end

#request_idString

Optional. A unique user provided identifier to ensure idempotent behavior for queries. Note that this is different from the job_id. It has the following properties: 1. It is case-sensitive, limited to up to 36 ASCII characters. A UUID is recommended. 2. Read only queries can ignore this token since they are nullipotent by definition. 3. For the purposes of idempotency ensured by the request_id, a request is considered duplicate of another only if they have the same request_id and are actually duplicates. When determining whether a request is a duplicate of another request, all parameters in the request that may affect the result are considered. For example, query, connection_properties, query_parameters, use_legacy_sql are parameters that affect the result and are considered when determining whether a request is a duplicate, but properties like timeout_ms don't affect the result and are thus not considered. Dry run query requests are never considered duplicate of another request. 4. When a duplicate mutating query request is detected, it returns: a. the results of the mutation if it completes successfully within the timeout. b. the running operation if it is still in progress at the end of the timeout. 5. Its lifetime is limited to 15 minutes. In other words, if two requests are sent with the same request_id, but more than 15 minutes apart, idempotency is not guaranteed. Corresponds to the JSON property requestId

Returns:

  • (String)


8141
8142
8143
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8141

def request_id
  @request_id
end

#reservationString

Optional. The reservation that jobs.query request would use. User can specify a reservation to execute the job.query. The expected format is projects/ project/locations/location/reservations/reservation`. Corresponds to the JSON propertyreservation`

Returns:

  • (String)


8148
8149
8150
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8148

def reservation
  @reservation
end

#timeout_msFixnum

Optional. Optional: Specifies the maximum amount of time, in milliseconds, that the client is willing to wait for the query to complete. By default, this limit is 10 seconds (10,000 milliseconds). If the query is complete, the jobComplete field in the response is true. If the query has not yet completed, jobComplete is false. You can request a longer timeout period in the timeoutMs field. However, the call is not guaranteed to wait for the specified timeout; it typically returns after around 200 seconds (200,000 milliseconds), even if the query is not complete. If jobComplete is false, you can continue to wait for the query to complete by calling the getQueryResults method until the jobComplete field in the getQueryResults response is true. Corresponds to the JSON property timeoutMs

Returns:

  • (Fixnum)


8162
8163
8164
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8162

def timeout_ms
  @timeout_ms
end

#use_legacy_sqlBoolean Also known as: use_legacy_sql?

Specifies whether to use BigQuery's legacy SQL dialect for this query. The default value is true. If set to false, the query will use BigQuery's GoogleSQL: https://cloud.google.com/bigquery/sql-reference/ When useLegacySql is set to false, the value of flattenResults is ignored; query will be run as if flattenResults is false. Corresponds to the JSON property useLegacySql

Returns:

  • (Boolean)


8171
8172
8173
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8171

def use_legacy_sql
  @use_legacy_sql
end

#use_query_cacheBoolean Also known as: use_query_cache?

Optional. Whether to look for the result in the query cache. The query cache is a best-effort cache that will be flushed whenever tables in the query are modified. The default value is true. Corresponds to the JSON property useQueryCache

Returns:

  • (Boolean)


8179
8180
8181
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8179

def use_query_cache
  @use_query_cache
end

#write_incremental_resultsBoolean Also known as: write_incremental_results?

Optional. This is only supported for SELECT query. If set, the query is allowed to write results incrementally to the temporary result table. This may incur a performance penalty. This option cannot be used with Legacy SQL. This feature is not yet available. Corresponds to the JSON property writeIncrementalResults

Returns:

  • (Boolean)


8188
8189
8190
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8188

def write_incremental_results
  @write_incremental_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8196
8197
8198
8199
8200
8201
8202
8203
8204
8205
8206
8207
8208
8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8196

def update!(**args)
  @connection_properties = args[:connection_properties] if args.key?(:connection_properties)
  @continuous = args[:continuous] if args.key?(:continuous)
  @create_session = args[:create_session] if args.key?(:create_session)
  @default_dataset = args[:default_dataset] if args.key?(:default_dataset)
  @destination_encryption_configuration = args[:destination_encryption_configuration] if args.key?(:destination_encryption_configuration)
  @dry_run = args[:dry_run] if args.key?(:dry_run)
  @format_options = args[:format_options] if args.key?(:format_options)
  @job_creation_mode = args[:job_creation_mode] if args.key?(:job_creation_mode)
  @job_timeout_ms = args[:job_timeout_ms] if args.key?(:job_timeout_ms)
  @kind = args[:kind] if args.key?(:kind)
  @labels = args[:labels] if args.key?(:labels)
  @location = args[:location] if args.key?(:location)
  @max_results = args[:max_results] if args.key?(:max_results)
  @max_slots = args[:max_slots] if args.key?(:max_slots)
  @maximum_bytes_billed = args[:maximum_bytes_billed] if args.key?(:maximum_bytes_billed)
  @parameter_mode = args[:parameter_mode] if args.key?(:parameter_mode)
  @preserve_nulls = args[:preserve_nulls] if args.key?(:preserve_nulls)
  @query = args[:query] if args.key?(:query)
  @query_parameters = args[:query_parameters] if args.key?(:query_parameters)
  @request_id = args[:request_id] if args.key?(:request_id)
  @reservation = args[:reservation] if args.key?(:reservation)
  @timeout_ms = args[:timeout_ms] if args.key?(:timeout_ms)
  @use_legacy_sql = args[:use_legacy_sql] if args.key?(:use_legacy_sql)
  @use_query_cache = args[:use_query_cache] if args.key?(:use_query_cache)
  @write_incremental_results = args[:write_incremental_results] if args.key?(:write_incremental_results)
end