Class: Google::Apis::BigqueryV2::QueryResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryResponse

Returns a new instance of QueryResponse.



8392
8393
8394
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8392

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_hitBoolean Also known as: cache_hit?

Whether the query result was fetched from the query cache. Corresponds to the JSON property cacheHit

Returns:

  • (Boolean)


8262
8263
8264
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8262

def cache_hit
  @cache_hit
end

#creation_timeFixnum

Output only. Creation time of this query, in milliseconds since the epoch. This field will be present on all queries. Corresponds to the JSON property creationTime

Returns:

  • (Fixnum)


8269
8270
8271
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8269

def creation_time
  @creation_time
end

#dml_statsGoogle::Apis::BigqueryV2::DmlStatistics

Detailed statistics for DML statements Corresponds to the JSON property dmlStats



8274
8275
8276
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8274

def dml_stats
  @dml_stats
end

#end_timeFixnum

Output only. End time of this query, in milliseconds since the epoch. This field will be present whenever a query job is in the DONE state. Corresponds to the JSON property endTime

Returns:

  • (Fixnum)


8280
8281
8282
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8280

def end_time
  @end_time
end

#errorsArray<Google::Apis::BigqueryV2::ErrorProto>

Output only. The first errors or warnings encountered during the running of the job. The final message includes the number of errors that caused the process to stop. Errors here do not necessarily mean that the job has completed or was unsuccessful. For more information about error messages, see Error messages. Corresponds to the JSON property errors



8289
8290
8291
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8289

def errors
  @errors
end

#job_completeBoolean Also known as: job_complete?

Whether the query has completed or not. If rows or totalRows are present, this will always be true. If this is false, totalRows will not be available. Corresponds to the JSON property jobComplete

Returns:

  • (Boolean)


8295
8296
8297
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8295

def job_complete
  @job_complete
end

#job_creation_reasonGoogle::Apis::BigqueryV2::JobCreationReason

Reason about why a Job was created from a jobs.query method when used with JOB_CREATION_OPTIONAL Job creation mode. For jobs.insert method calls it will always be REQUESTED. Corresponds to the JSON property jobCreationReason



8305
8306
8307
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8305

def job_creation_reason
  @job_creation_reason
end

#job_referenceGoogle::Apis::BigqueryV2::JobReference

A job reference is a fully qualified identifier for referring to a job. Corresponds to the JSON property jobReference



8310
8311
8312
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8310

def job_reference
  @job_reference
end

#kindString

The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


8315
8316
8317
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8315

def kind
  @kind
end

#locationString

Output only. The geographic location of the query. For more information about BigQuery locations, see: https://cloud.google.com/bigquery/docs/locations Corresponds to the JSON property location

Returns:

  • (String)


8321
8322
8323
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8321

def location
  @location
end

#num_dml_affected_rowsFixnum

Output only. The number of rows affected by a DML statement. Present only for DML statements INSERT, UPDATE or DELETE. Corresponds to the JSON property numDmlAffectedRows

Returns:

  • (Fixnum)


8327
8328
8329
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8327

def num_dml_affected_rows
  @num_dml_affected_rows
end

#page_tokenString

A token used for paging results. A non-empty token indicates that additional results are available. To see additional results, query the jobs. getQueryResults method. For more information, see Paging through table data. Corresponds to the JSON property pageToken

Returns:

  • (String)


8336
8337
8338
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8336

def page_token
  @page_token
end

#query_idString

Auto-generated ID for the query. Corresponds to the JSON property queryId

Returns:

  • (String)


8341
8342
8343
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8341

def query_id
  @query_id
end

#rowsArray<Google::Apis::BigqueryV2::TableRow>

An object with as many results as can be contained within the maximum permitted reply size. To get any additional rows, you can call GetQueryResults and specify the jobReference returned above. Corresponds to the JSON property rows



8348
8349
8350
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8348

def rows
  @rows
end

#schemaGoogle::Apis::BigqueryV2::TableSchema

Schema of a table Corresponds to the JSON property schema



8353
8354
8355
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8353

def schema
  @schema
end

#session_infoGoogle::Apis::BigqueryV2::SessionInfo

[Preview] Information related to sessions. Corresponds to the JSON property sessionInfo



8358
8359
8360
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8358

def session_info
  @session_info
end

#start_timeFixnum

Output only. Start time of this query, in milliseconds since the epoch. This field will be present when the query job transitions from the PENDING state to either RUNNING or DONE. Corresponds to the JSON property startTime

Returns:

  • (Fixnum)


8365
8366
8367
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8365

def start_time
  @start_time
end

#total_bytes_billedFixnum

Output only. If the project is configured to use on-demand pricing, then this field contains the total bytes billed for the job. If the project is configured to use flat-rate pricing, then you are not billed for bytes and this field is informational only. Corresponds to the JSON property totalBytesBilled

Returns:

  • (Fixnum)


8373
8374
8375
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8373

def total_bytes_billed
  @total_bytes_billed
end

#total_bytes_processedFixnum

The total number of bytes processed for this query. If this query was a dry run, this is the number of bytes that would be processed if the query were run. Corresponds to the JSON property totalBytesProcessed

Returns:

  • (Fixnum)


8379
8380
8381
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8379

def total_bytes_processed
  @total_bytes_processed
end

#total_rowsFixnum

The total number of rows in the complete query result set, which can be more than the number of rows in this single page of results. Corresponds to the JSON property totalRows

Returns:

  • (Fixnum)


8385
8386
8387
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8385

def total_rows
  @total_rows
end

#total_slot_msFixnum

Output only. Number of slot ms the user is actually billed for. Corresponds to the JSON property totalSlotMs

Returns:

  • (Fixnum)


8390
8391
8392
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8390

def total_slot_ms
  @total_slot_ms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8397
8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
8410
8411
8412
8413
8414
8415
8416
8417
8418
8419
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8397

def update!(**args)
  @cache_hit = args[:cache_hit] if args.key?(:cache_hit)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @dml_stats = args[:dml_stats] if args.key?(:dml_stats)
  @end_time = args[:end_time] if args.key?(:end_time)
  @errors = args[:errors] if args.key?(:errors)
  @job_complete = args[:job_complete] if args.key?(:job_complete)
  @job_creation_reason = args[:job_creation_reason] if args.key?(:job_creation_reason)
  @job_reference = args[:job_reference] if args.key?(:job_reference)
  @kind = args[:kind] if args.key?(:kind)
  @location = args[:location] if args.key?(:location)
  @num_dml_affected_rows = args[:num_dml_affected_rows] if args.key?(:num_dml_affected_rows)
  @page_token = args[:page_token] if args.key?(:page_token)
  @query_id = args[:query_id] if args.key?(:query_id)
  @rows = args[:rows] if args.key?(:rows)
  @schema = args[:schema] if args.key?(:schema)
  @session_info = args[:session_info] if args.key?(:session_info)
  @start_time = args[:start_time] if args.key?(:start_time)
  @total_bytes_billed = args[:total_bytes_billed] if args.key?(:total_bytes_billed)
  @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed)
  @total_rows = args[:total_rows] if args.key?(:total_rows)
  @total_slot_ms = args[:total_slot_ms] if args.key?(:total_slot_ms)
end