Class: Google::Apis::BigqueryV2::QueryResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::QueryResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Instance Attribute Summary collapse
-
#cache_hit ⇒ Boolean
(also: #cache_hit?)
Whether the query result was fetched from the query cache.
-
#creation_time ⇒ Fixnum
Output only.
-
#dml_stats ⇒ Google::Apis::BigqueryV2::DmlStatistics
Detailed statistics for DML statements Corresponds to the JSON property
dmlStats. -
#end_time ⇒ Fixnum
Output only.
-
#errors ⇒ Array<Google::Apis::BigqueryV2::ErrorProto>
Output only.
-
#job_complete ⇒ Boolean
(also: #job_complete?)
Whether the query has completed or not.
-
#job_creation_reason ⇒ Google::Apis::BigqueryV2::JobCreationReason
Reason about why a Job was created from a
jobs.querymethod when used withJOB_CREATION_OPTIONALJob creation mode. -
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
-
#kind ⇒ String
The resource type.
-
#location ⇒ String
Output only.
-
#num_dml_affected_rows ⇒ Fixnum
Output only.
-
#page_token ⇒ String
A token used for paging results.
-
#query_id ⇒ String
Auto-generated ID for the query.
-
#rows ⇒ Array<Google::Apis::BigqueryV2::TableRow>
An object with as many results as can be contained within the maximum permitted reply size.
-
#schema ⇒ Google::Apis::BigqueryV2::TableSchema
Schema of a table Corresponds to the JSON property
schema. -
#session_info ⇒ Google::Apis::BigqueryV2::SessionInfo
[Preview] Information related to sessions.
-
#start_time ⇒ Fixnum
Output only.
-
#total_bytes_billed ⇒ Fixnum
Output only.
-
#total_bytes_processed ⇒ Fixnum
The total number of bytes processed for this query.
-
#total_rows ⇒ Fixnum
The total number of rows in the complete query result set, which can be more than the number of rows in this single page of results.
-
#total_slot_ms ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryResponse
constructor
A new instance of QueryResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryResponse
Returns a new instance of QueryResponse.
8362 8363 8364 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_hit ⇒ Boolean Also known as: cache_hit?
Whether the query result was fetched from the query cache.
Corresponds to the JSON property cacheHit
8232 8233 8234 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8232 def cache_hit @cache_hit end |
#creation_time ⇒ Fixnum
Output only. Creation time of this query, in milliseconds since the epoch.
This field will be present on all queries.
Corresponds to the JSON property creationTime
8239 8240 8241 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8239 def creation_time @creation_time end |
#dml_stats ⇒ Google::Apis::BigqueryV2::DmlStatistics
Detailed statistics for DML statements
Corresponds to the JSON property dmlStats
8244 8245 8246 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8244 def dml_stats @dml_stats end |
#end_time ⇒ Fixnum
Output only. End time of this query, in milliseconds since the epoch. This
field will be present whenever a query job is in the DONE state.
Corresponds to the JSON property endTime
8250 8251 8252 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8250 def end_time @end_time end |
#errors ⇒ Array<Google::Apis::BigqueryV2::ErrorProto>
Output only. The first errors or warnings encountered during the running of
the job. The final message includes the number of errors that caused the
process to stop. Errors here do not necessarily mean that the job has
completed or was unsuccessful. For more information about error messages, see
Error messages.
Corresponds to the JSON property errors
8259 8260 8261 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8259 def errors @errors end |
#job_complete ⇒ Boolean Also known as: job_complete?
Whether the query has completed or not. If rows or totalRows are present, this
will always be true. If this is false, totalRows will not be available.
Corresponds to the JSON property jobComplete
8265 8266 8267 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8265 def job_complete @job_complete end |
#job_creation_reason ⇒ Google::Apis::BigqueryV2::JobCreationReason
Reason about why a Job was created from a jobs.query method when used with
JOB_CREATION_OPTIONAL Job creation mode. For jobs.insert method calls it will
always be REQUESTED.
Corresponds to the JSON property jobCreationReason
8275 8276 8277 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8275 def job_creation_reason @job_creation_reason end |
#job_reference ⇒ Google::Apis::BigqueryV2::JobReference
A job reference is a fully qualified identifier for referring to a job.
Corresponds to the JSON property jobReference
8280 8281 8282 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8280 def job_reference @job_reference end |
#kind ⇒ String
The resource type.
Corresponds to the JSON property kind
8285 8286 8287 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8285 def kind @kind end |
#location ⇒ String
Output only. The geographic location of the query. For more information about
BigQuery locations, see: https://cloud.google.com/bigquery/docs/locations
Corresponds to the JSON property location
8291 8292 8293 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8291 def location @location end |
#num_dml_affected_rows ⇒ Fixnum
Output only. The number of rows affected by a DML statement. Present only for
DML statements INSERT, UPDATE or DELETE.
Corresponds to the JSON property numDmlAffectedRows
8297 8298 8299 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8297 def num_dml_affected_rows @num_dml_affected_rows end |
#page_token ⇒ String
A token used for paging results. A non-empty token indicates that additional
results are available. To see additional results, query the jobs.
getQueryResults method. For more information, see Paging through table
data.
Corresponds to the JSON property pageToken
8306 8307 8308 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8306 def page_token @page_token end |
#query_id ⇒ String
Auto-generated ID for the query.
Corresponds to the JSON property queryId
8311 8312 8313 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8311 def query_id @query_id end |
#rows ⇒ Array<Google::Apis::BigqueryV2::TableRow>
An object with as many results as can be contained within the maximum
permitted reply size. To get any additional rows, you can call GetQueryResults
and specify the jobReference returned above.
Corresponds to the JSON property rows
8318 8319 8320 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8318 def rows @rows end |
#schema ⇒ Google::Apis::BigqueryV2::TableSchema
Schema of a table
Corresponds to the JSON property schema
8323 8324 8325 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8323 def schema @schema end |
#session_info ⇒ Google::Apis::BigqueryV2::SessionInfo
[Preview] Information related to sessions.
Corresponds to the JSON property sessionInfo
8328 8329 8330 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8328 def session_info @session_info end |
#start_time ⇒ Fixnum
Output only. Start time of this query, in milliseconds since the epoch. This
field will be present when the query job transitions from the PENDING state to
either RUNNING or DONE.
Corresponds to the JSON property startTime
8335 8336 8337 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8335 def start_time @start_time end |
#total_bytes_billed ⇒ Fixnum
Output only. If the project is configured to use on-demand pricing, then this
field contains the total bytes billed for the job. If the project is
configured to use flat-rate pricing, then you are not billed for bytes and
this field is informational only.
Corresponds to the JSON property totalBytesBilled
8343 8344 8345 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8343 def total_bytes_billed @total_bytes_billed end |
#total_bytes_processed ⇒ Fixnum
The total number of bytes processed for this query. If this query was a dry
run, this is the number of bytes that would be processed if the query were run.
Corresponds to the JSON property totalBytesProcessed
8349 8350 8351 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8349 def total_bytes_processed @total_bytes_processed end |
#total_rows ⇒ Fixnum
The total number of rows in the complete query result set, which can be more
than the number of rows in this single page of results.
Corresponds to the JSON property totalRows
8355 8356 8357 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8355 def total_rows @total_rows end |
#total_slot_ms ⇒ Fixnum
Output only. Number of slot ms the user is actually billed for.
Corresponds to the JSON property totalSlotMs
8360 8361 8362 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8360 def total_slot_ms @total_slot_ms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8367 8368 8369 8370 8371 8372 8373 8374 8375 8376 8377 8378 8379 8380 8381 8382 8383 8384 8385 8386 8387 8388 8389 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8367 def update!(**args) @cache_hit = args[:cache_hit] if args.key?(:cache_hit) @creation_time = args[:creation_time] if args.key?(:creation_time) @dml_stats = args[:dml_stats] if args.key?(:dml_stats) @end_time = args[:end_time] if args.key?(:end_time) @errors = args[:errors] if args.key?(:errors) @job_complete = args[:job_complete] if args.key?(:job_complete) @job_creation_reason = args[:job_creation_reason] if args.key?(:job_creation_reason) @job_reference = args[:job_reference] if args.key?(:job_reference) @kind = args[:kind] if args.key?(:kind) @location = args[:location] if args.key?(:location) @num_dml_affected_rows = args[:num_dml_affected_rows] if args.key?(:num_dml_affected_rows) @page_token = args[:page_token] if args.key?(:page_token) @query_id = args[:query_id] if args.key?(:query_id) @rows = args[:rows] if args.key?(:rows) @schema = args[:schema] if args.key?(:schema) @session_info = args[:session_info] if args.key?(:session_info) @start_time = args[:start_time] if args.key?(:start_time) @total_bytes_billed = args[:total_bytes_billed] if args.key?(:total_bytes_billed) @total_bytes_processed = args[:total_bytes_processed] if args.key?(:total_bytes_processed) @total_rows = args[:total_rows] if args.key?(:total_rows) @total_slot_ms = args[:total_slot_ms] if args.key?(:total_slot_ms) end |