Class: Google::Apis::BigqueryV2::QueryTimelineSample
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::QueryTimelineSample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Summary of the state of query execution at a given time.
Instance Attribute Summary collapse
-
#active_units ⇒ Fixnum
Total number of active workers.
-
#completed_units ⇒ Fixnum
Total parallel units of work completed by this query.
-
#elapsed_ms ⇒ Fixnum
Milliseconds elapsed since the start of query execution.
-
#estimated_runnable_units ⇒ Fixnum
Units of work that can be scheduled immediately.
-
#pending_units ⇒ Fixnum
Total units of work remaining for the query.
-
#shuffle_ram_usage_ratio ⇒ Float
Total shuffle usage ratio in shuffle RAM per reservation of this query.
-
#total_slot_ms ⇒ Fixnum
Cumulative slot-ms consumed by the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryTimelineSample
constructor
A new instance of QueryTimelineSample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryTimelineSample
Returns a new instance of QueryTimelineSample.
9030 9031 9032 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9030 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_units ⇒ Fixnum
Total number of active workers. This does not correspond directly to slot
usage. This is the largest value observed since the last sample.
Corresponds to the JSON property activeUnits
8994 8995 8996 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8994 def active_units @active_units end |
#completed_units ⇒ Fixnum
Total parallel units of work completed by this query.
Corresponds to the JSON property completedUnits
8999 9000 9001 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8999 def completed_units @completed_units end |
#elapsed_ms ⇒ Fixnum
Milliseconds elapsed since the start of query execution.
Corresponds to the JSON property elapsedMs
9004 9005 9006 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9004 def elapsed_ms @elapsed_ms end |
#estimated_runnable_units ⇒ Fixnum
Units of work that can be scheduled immediately. Providing additional slots
for these units of work will accelerate the query, if no other query in the
reservation needs additional slots.
Corresponds to the JSON property estimatedRunnableUnits
9011 9012 9013 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9011 def estimated_runnable_units @estimated_runnable_units end |
#pending_units ⇒ Fixnum
Total units of work remaining for the query. This number can be revised (
increased or decreased) while the query is running.
Corresponds to the JSON property pendingUnits
9017 9018 9019 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9017 def pending_units @pending_units end |
#shuffle_ram_usage_ratio ⇒ Float
Total shuffle usage ratio in shuffle RAM per reservation of this query. This
will be provided for reservation customers only.
Corresponds to the JSON property shuffleRamUsageRatio
9023 9024 9025 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9023 def shuffle_ram_usage_ratio @shuffle_ram_usage_ratio end |
#total_slot_ms ⇒ Fixnum
Cumulative slot-ms consumed by the query.
Corresponds to the JSON property totalSlotMs
9028 9029 9030 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9028 def total_slot_ms @total_slot_ms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9035 9036 9037 9038 9039 9040 9041 9042 9043 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9035 def update!(**args) @active_units = args[:active_units] if args.key?(:active_units) @completed_units = args[:completed_units] if args.key?(:completed_units) @elapsed_ms = args[:elapsed_ms] if args.key?(:elapsed_ms) @estimated_runnable_units = args[:estimated_runnable_units] if args.key?(:estimated_runnable_units) @pending_units = args[:pending_units] if args.key?(:pending_units) @shuffle_ram_usage_ratio = args[:shuffle_ram_usage_ratio] if args.key?(:shuffle_ram_usage_ratio) @total_slot_ms = args[:total_slot_ms] if args.key?(:total_slot_ms) end |