Class: Google::Apis::BigqueryV2::QueryTimelineSample
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::QueryTimelineSample
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Summary of the state of query execution at a given time.
Instance Attribute Summary collapse
-
#active_units ⇒ Fixnum
Total number of active workers.
-
#completed_units ⇒ Fixnum
Total parallel units of work completed by this query.
-
#elapsed_ms ⇒ Fixnum
Milliseconds elapsed since the start of query execution.
-
#estimated_runnable_units ⇒ Fixnum
Units of work that can be scheduled immediately.
-
#pending_units ⇒ Fixnum
Total units of work remaining for the query.
-
#shuffle_ram_usage_ratio ⇒ Float
Total shuffle usage ratio in shuffle RAM per reservation of this query.
-
#total_slot_ms ⇒ Fixnum
Cumulative slot-ms consumed by the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryTimelineSample
constructor
A new instance of QueryTimelineSample.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryTimelineSample
Returns a new instance of QueryTimelineSample.
8961 8962 8963 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_units ⇒ Fixnum
Total number of active workers. This does not correspond directly to slot
usage. This is the largest value observed since the last sample.
Corresponds to the JSON property activeUnits
8925 8926 8927 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8925 def active_units @active_units end |
#completed_units ⇒ Fixnum
Total parallel units of work completed by this query.
Corresponds to the JSON property completedUnits
8930 8931 8932 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8930 def completed_units @completed_units end |
#elapsed_ms ⇒ Fixnum
Milliseconds elapsed since the start of query execution.
Corresponds to the JSON property elapsedMs
8935 8936 8937 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8935 def elapsed_ms @elapsed_ms end |
#estimated_runnable_units ⇒ Fixnum
Units of work that can be scheduled immediately. Providing additional slots
for these units of work will accelerate the query, if no other query in the
reservation needs additional slots.
Corresponds to the JSON property estimatedRunnableUnits
8942 8943 8944 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8942 def estimated_runnable_units @estimated_runnable_units end |
#pending_units ⇒ Fixnum
Total units of work remaining for the query. This number can be revised (
increased or decreased) while the query is running.
Corresponds to the JSON property pendingUnits
8948 8949 8950 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8948 def pending_units @pending_units end |
#shuffle_ram_usage_ratio ⇒ Float
Total shuffle usage ratio in shuffle RAM per reservation of this query. This
will be provided for reservation customers only.
Corresponds to the JSON property shuffleRamUsageRatio
8954 8955 8956 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8954 def shuffle_ram_usage_ratio @shuffle_ram_usage_ratio end |
#total_slot_ms ⇒ Fixnum
Cumulative slot-ms consumed by the query.
Corresponds to the JSON property totalSlotMs
8959 8960 8961 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8959 def total_slot_ms @total_slot_ms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8966 8967 8968 8969 8970 8971 8972 8973 8974 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8966 def update!(**args) @active_units = args[:active_units] if args.key?(:active_units) @completed_units = args[:completed_units] if args.key?(:completed_units) @elapsed_ms = args[:elapsed_ms] if args.key?(:elapsed_ms) @estimated_runnable_units = args[:estimated_runnable_units] if args.key?(:estimated_runnable_units) @pending_units = args[:pending_units] if args.key?(:pending_units) @shuffle_ram_usage_ratio = args[:shuffle_ram_usage_ratio] if args.key?(:shuffle_ram_usage_ratio) @total_slot_ms = args[:total_slot_ms] if args.key?(:total_slot_ms) end |