Class: Google::Apis::BigqueryV2::RankingMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Evaluation metrics used by weighted-ALS models specified by feedback_type= implicit.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RankingMetrics

Returns a new instance of RankingMetrics.



8565
8566
8567
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#average_rankFloat

Determines the goodness of a ranking by computing the percentile rank from the predicted confidence and dividing it by the original rank. Corresponds to the JSON property averageRank

Returns:

  • (Float)


8543
8544
8545
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8543

def average_rank
  @average_rank
end

#mean_average_precisionFloat

Calculates a precision per user for all the items by ranking them and then averages all the precisions across all the users. Corresponds to the JSON property meanAveragePrecision

Returns:

  • (Float)


8549
8550
8551
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8549

def mean_average_precision
  @mean_average_precision
end

#mean_squared_errorFloat

Similar to the mean squared error computed in regression and explicit recommendation models except instead of computing the rating directly, the output from evaluate is computed against a preference which is 1 or 0 depending on if the rating exists or not. Corresponds to the JSON property meanSquaredError

Returns:

  • (Float)


8557
8558
8559
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8557

def mean_squared_error
  @mean_squared_error
end

#normalized_discounted_cumulative_gainFloat

A metric to determine the goodness of a ranking calculated from the predicted confidence by comparing it to an ideal rank measured by the original ratings. Corresponds to the JSON property normalizedDiscountedCumulativeGain

Returns:

  • (Float)


8563
8564
8565
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8563

def normalized_discounted_cumulative_gain
  @normalized_discounted_cumulative_gain
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8570
8571
8572
8573
8574
8575
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8570

def update!(**args)
  @average_rank = args[:average_rank] if args.key?(:average_rank)
  @mean_average_precision = args[:mean_average_precision] if args.key?(:mean_average_precision)
  @mean_squared_error = args[:mean_squared_error] if args.key?(:mean_squared_error)
  @normalized_discounted_cumulative_gain = args[:normalized_discounted_cumulative_gain] if args.key?(:normalized_discounted_cumulative_gain)
end