Class: Google::Apis::BigqueryV2::RemoteFunctionOptions
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::RemoteFunctionOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Options for a remote user-defined function.
Instance Attribute Summary collapse
-
#connection ⇒ String
Fully qualified name of the user-provided connection object which holds the authentication information to send requests to the remote service.
-
#endpoint ⇒ String
Endpoint of the user-provided remote service, e.g.
-
#max_batching_rows ⇒ Fixnum
Max number of rows in each batch sent to the remote service.
-
#user_defined_context ⇒ Hash<String,String>
User-defined context as a set of key/value pairs, which will be sent as function invocation context together with batched arguments in the requests to the remote service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoteFunctionOptions
constructor
A new instance of RemoteFunctionOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoteFunctionOptions
Returns a new instance of RemoteFunctionOptions.
9247 9248 9249 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9247 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection ⇒ String
Fully qualified name of the user-provided connection object which holds the
authentication information to send requests to the remote service. Format: "
projects/`projectId`/locations/`locationId`/connections/`connectionId`"
Corresponds to the JSON property connection
9225 9226 9227 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9225 def connection @connection end |
#endpoint ⇒ String
Endpoint of the user-provided remote service, e.g. https://us-east1-
my_gcf_project.cloudfunctions.net/remote_add
Corresponds to the JSON property endpoint
9231 9232 9233 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9231 def endpoint @endpoint end |
#max_batching_rows ⇒ Fixnum
Max number of rows in each batch sent to the remote service. If absent or if 0,
BigQuery dynamically decides the number of rows in a batch.
Corresponds to the JSON property maxBatchingRows
9237 9238 9239 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9237 def max_batching_rows @max_batching_rows end |
#user_defined_context ⇒ Hash<String,String>
User-defined context as a set of key/value pairs, which will be sent as
function invocation context together with batched arguments in the requests to
the remote service. The total number of bytes of keys and values must be less
than 8KB.
Corresponds to the JSON property userDefinedContext
9245 9246 9247 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9245 def user_defined_context @user_defined_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9252 9253 9254 9255 9256 9257 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9252 def update!(**args) @connection = args[:connection] if args.key?(:connection) @endpoint = args[:endpoint] if args.key?(:endpoint) @max_batching_rows = args[:max_batching_rows] if args.key?(:max_batching_rows) @user_defined_context = args[:user_defined_context] if args.key?(:user_defined_context) end |