Class: Google::Apis::BigqueryV2::RemoteModelInfo
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::RemoteModelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Remote Model Info
Instance Attribute Summary collapse
-
#connection ⇒ String
Output only.
-
#endpoint ⇒ String
Output only.
-
#max_batching_rows ⇒ Fixnum
Output only.
-
#remote_model_version ⇒ String
Output only.
-
#remote_service_type ⇒ String
Output only.
-
#speech_recognizer ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoteModelInfo
constructor
A new instance of RemoteModelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoteModelInfo
Returns a new instance of RemoteModelInfo.
9398 9399 9400 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection ⇒ String
Output only. Fully qualified name of the user-provided connection object of
the remote model. Format: "projects/`project_id`/locations/`location_id`/
connections/`connection_id`"
Corresponds to the JSON property connection
9364 9365 9366 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9364 def connection @connection end |
#endpoint ⇒ String
Output only. The endpoint for remote model.
Corresponds to the JSON property endpoint
9369 9370 9371 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9369 def endpoint @endpoint end |
#max_batching_rows ⇒ Fixnum
Output only. Max number of rows in each batch sent to the remote service. If
unset, the number of rows in each batch is set dynamically.
Corresponds to the JSON property maxBatchingRows
9375 9376 9377 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9375 def max_batching_rows @max_batching_rows end |
#remote_model_version ⇒ String
Output only. The model version for LLM.
Corresponds to the JSON property remoteModelVersion
9380 9381 9382 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9380 def remote_model_version @remote_model_version end |
#remote_service_type ⇒ String
Output only. The remote service type for remote model.
Corresponds to the JSON property remoteServiceType
9385 9386 9387 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9385 def remote_service_type @remote_service_type end |
#speech_recognizer ⇒ String
Output only. The name of the speech recognizer to use for speech recognition.
The expected format is projects/project/locations/location/recognizers/
recognizer`. Customers can specify this field at model creation. If not
specified, a default recognizerprojects/model project/locations/global/
recognizers/_will be used. See more details at [recognizers](https://cloud.
google.com/speech-to-text/v2/docs/reference/rest/v2/projects.locations.
recognizers)
Corresponds to the JSON propertyspeechRecognizer`
9396 9397 9398 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9396 def speech_recognizer @speech_recognizer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9403 9404 9405 9406 9407 9408 9409 9410 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9403 def update!(**args) @connection = args[:connection] if args.key?(:connection) @endpoint = args[:endpoint] if args.key?(:endpoint) @max_batching_rows = args[:max_batching_rows] if args.key?(:max_batching_rows) @remote_model_version = args[:remote_model_version] if args.key?(:remote_model_version) @remote_service_type = args[:remote_service_type] if args.key?(:remote_service_type) @speech_recognizer = args[:speech_recognizer] if args.key?(:speech_recognizer) end |