Class: Google::Apis::BigqueryV2::RemoteModelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Remote Model Info

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoteModelInfo

Returns a new instance of RemoteModelInfo.



9303
9304
9305
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectionString

Output only. Fully qualified name of the user-provided connection object of the remote model. Format: "projects/`project_id`/locations/`location_id`/ connections/`connection_id`" Corresponds to the JSON property connection

Returns:

  • (String)


9269
9270
9271
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9269

def connection
  @connection
end

#endpointString

Output only. The endpoint for remote model. Corresponds to the JSON property endpoint

Returns:

  • (String)


9274
9275
9276
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9274

def endpoint
  @endpoint
end

#max_batching_rowsFixnum

Output only. Max number of rows in each batch sent to the remote service. If unset, the number of rows in each batch is set dynamically. Corresponds to the JSON property maxBatchingRows

Returns:

  • (Fixnum)


9280
9281
9282
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9280

def max_batching_rows
  @max_batching_rows
end

#remote_model_versionString

Output only. The model version for LLM. Corresponds to the JSON property remoteModelVersion

Returns:

  • (String)


9285
9286
9287
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9285

def remote_model_version
  @remote_model_version
end

#remote_service_typeString

Output only. The remote service type for remote model. Corresponds to the JSON property remoteServiceType

Returns:

  • (String)


9290
9291
9292
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9290

def remote_service_type
  @remote_service_type
end

#speech_recognizerString

Output only. The name of the speech recognizer to use for speech recognition. The expected format is projects/project/locations/location/recognizers/ recognizer`. Customers can specify this field at model creation. If not specified, a default recognizerprojects/model project/locations/global/ recognizers/_will be used. See more details at [recognizers](https://cloud. google.com/speech-to-text/v2/docs/reference/rest/v2/projects.locations. recognizers) Corresponds to the JSON propertyspeechRecognizer`

Returns:

  • (String)


9301
9302
9303
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9301

def speech_recognizer
  @speech_recognizer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9308
9309
9310
9311
9312
9313
9314
9315
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9308

def update!(**args)
  @connection = args[:connection] if args.key?(:connection)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @max_batching_rows = args[:max_batching_rows] if args.key?(:max_batching_rows)
  @remote_model_version = args[:remote_model_version] if args.key?(:remote_model_version)
  @remote_service_type = args[:remote_service_type] if args.key?(:remote_service_type)
  @speech_recognizer = args[:speech_recognizer] if args.key?(:speech_recognizer)
end