Class: Google::Apis::BigqueryV2::RemoteModelInfo
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::RemoteModelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Remote Model Info
Instance Attribute Summary collapse
-
#connection ⇒ String
Output only.
-
#endpoint ⇒ String
Output only.
-
#max_batching_rows ⇒ Fixnum
Output only.
-
#remote_model_version ⇒ String
Output only.
-
#remote_service_type ⇒ String
Output only.
-
#speech_recognizer ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoteModelInfo
constructor
A new instance of RemoteModelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoteModelInfo
Returns a new instance of RemoteModelInfo.
9113 9114 9115 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9113 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection ⇒ String
Output only. Fully qualified name of the user-provided connection object of
the remote model. Format: "projects/`project_id`/locations/`location_id`/
connections/`connection_id`"
Corresponds to the JSON property connection
9079 9080 9081 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9079 def connection @connection end |
#endpoint ⇒ String
Output only. The endpoint for remote model.
Corresponds to the JSON property endpoint
9084 9085 9086 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9084 def endpoint @endpoint end |
#max_batching_rows ⇒ Fixnum
Output only. Max number of rows in each batch sent to the remote service. If
unset, the number of rows in each batch is set dynamically.
Corresponds to the JSON property maxBatchingRows
9090 9091 9092 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9090 def max_batching_rows @max_batching_rows end |
#remote_model_version ⇒ String
Output only. The model version for LLM.
Corresponds to the JSON property remoteModelVersion
9095 9096 9097 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9095 def remote_model_version @remote_model_version end |
#remote_service_type ⇒ String
Output only. The remote service type for remote model.
Corresponds to the JSON property remoteServiceType
9100 9101 9102 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9100 def remote_service_type @remote_service_type end |
#speech_recognizer ⇒ String
Output only. The name of the speech recognizer to use for speech recognition.
The expected format is projects/project/locations/location/recognizers/
recognizer`. Customers can specify this field at model creation. If not
specified, a default recognizerprojects/model project/locations/global/
recognizers/_will be used. See more details at [recognizers](https://cloud.
google.com/speech-to-text/v2/docs/reference/rest/v2/projects.locations.
recognizers)
Corresponds to the JSON propertyspeechRecognizer`
9111 9112 9113 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9111 def speech_recognizer @speech_recognizer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9118 9119 9120 9121 9122 9123 9124 9125 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9118 def update!(**args) @connection = args[:connection] if args.key?(:connection) @endpoint = args[:endpoint] if args.key?(:endpoint) @max_batching_rows = args[:max_batching_rows] if args.key?(:max_batching_rows) @remote_model_version = args[:remote_model_version] if args.key?(:remote_model_version) @remote_service_type = args[:remote_service_type] if args.key?(:remote_service_type) @speech_recognizer = args[:speech_recognizer] if args.key?(:speech_recognizer) end |