Class: Google::Apis::BigqueryV2::RemoteModelInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Remote Model Info

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoteModelInfo

Returns a new instance of RemoteModelInfo.



9025
9026
9027
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectionString

Output only. Fully qualified name of the user-provided connection object of the remote model. Format: "projects/`project_id`/locations/`location_id`/ connections/`connection_id`" Corresponds to the JSON property connection

Returns:

  • (String)


8991
8992
8993
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8991

def connection
  @connection
end

#endpointString

Output only. The endpoint for remote model. Corresponds to the JSON property endpoint

Returns:

  • (String)


8996
8997
8998
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8996

def endpoint
  @endpoint
end

#max_batching_rowsFixnum

Output only. Max number of rows in each batch sent to the remote service. If unset, the number of rows in each batch is set dynamically. Corresponds to the JSON property maxBatchingRows

Returns:

  • (Fixnum)


9002
9003
9004
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9002

def max_batching_rows
  @max_batching_rows
end

#remote_model_versionString

Output only. The model version for LLM. Corresponds to the JSON property remoteModelVersion

Returns:

  • (String)


9007
9008
9009
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9007

def remote_model_version
  @remote_model_version
end

#remote_service_typeString

Output only. The remote service type for remote model. Corresponds to the JSON property remoteServiceType

Returns:

  • (String)


9012
9013
9014
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9012

def remote_service_type
  @remote_service_type
end

#speech_recognizerString

Output only. The name of the speech recognizer to use for speech recognition. The expected format is projects/project/locations/location/recognizers/ recognizer`. Customers can specify this field at model creation. If not specified, a default recognizerprojects/model project/locations/global/ recognizers/_will be used. See more details at [recognizers](https://cloud. google.com/speech-to-text/v2/docs/reference/rest/v2/projects.locations. recognizers) Corresponds to the JSON propertyspeechRecognizer`

Returns:

  • (String)


9023
9024
9025
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9023

def speech_recognizer
  @speech_recognizer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9030
9031
9032
9033
9034
9035
9036
9037
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9030

def update!(**args)
  @connection = args[:connection] if args.key?(:connection)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @max_batching_rows = args[:max_batching_rows] if args.key?(:max_batching_rows)
  @remote_model_version = args[:remote_model_version] if args.key?(:remote_model_version)
  @remote_service_type = args[:remote_service_type] if args.key?(:remote_service_type)
  @speech_recognizer = args[:speech_recognizer] if args.key?(:speech_recognizer)
end