Class: Google::Apis::BigqueryV2::RemoteModelInfo
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::RemoteModelInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Remote Model Info
Instance Attribute Summary collapse
-
#connection ⇒ String
Output only.
-
#endpoint ⇒ String
Output only.
-
#max_batching_rows ⇒ Fixnum
Output only.
-
#remote_model_version ⇒ String
Output only.
-
#remote_service_type ⇒ String
Output only.
-
#speech_recognizer ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoteModelInfo
constructor
A new instance of RemoteModelInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoteModelInfo
Returns a new instance of RemoteModelInfo.
8739 8740 8741 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection ⇒ String
Output only. Fully qualified name of the user-provided connection object of
the remote model. Format: "projects/`project_id`/locations/`location_id`/
connections/`connection_id`"
Corresponds to the JSON property connection
8705 8706 8707 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8705 def connection @connection end |
#endpoint ⇒ String
Output only. The endpoint for remote model.
Corresponds to the JSON property endpoint
8710 8711 8712 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8710 def endpoint @endpoint end |
#max_batching_rows ⇒ Fixnum
Output only. Max number of rows in each batch sent to the remote service. If
unset, the number of rows in each batch is set dynamically.
Corresponds to the JSON property maxBatchingRows
8716 8717 8718 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8716 def max_batching_rows @max_batching_rows end |
#remote_model_version ⇒ String
Output only. The model version for LLM.
Corresponds to the JSON property remoteModelVersion
8721 8722 8723 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8721 def remote_model_version @remote_model_version end |
#remote_service_type ⇒ String
Output only. The remote service type for remote model.
Corresponds to the JSON property remoteServiceType
8726 8727 8728 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8726 def remote_service_type @remote_service_type end |
#speech_recognizer ⇒ String
Output only. The name of the speech recognizer to use for speech recognition.
The expected format is projects/project/locations/location/recognizers/
recognizer`. Customers can specify this field at model creation. If not
specified, a default recognizerprojects/model project/locations/global/
recognizers/_will be used. See more details at [recognizers](https://cloud.
google.com/speech-to-text/v2/docs/reference/rest/v2/projects.locations.
recognizers)
Corresponds to the JSON propertyspeechRecognizer`
8737 8738 8739 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8737 def speech_recognizer @speech_recognizer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8744 8745 8746 8747 8748 8749 8750 8751 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8744 def update!(**args) @connection = args[:connection] if args.key?(:connection) @endpoint = args[:endpoint] if args.key?(:endpoint) @max_batching_rows = args[:max_batching_rows] if args.key?(:max_batching_rows) @remote_model_version = args[:remote_model_version] if args.key?(:remote_model_version) @remote_service_type = args[:remote_service_type] if args.key?(:remote_service_type) @speech_recognizer = args[:speech_recognizer] if args.key?(:speech_recognizer) end |