Class: Google::Apis::BigqueryV2::Routine
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::Routine
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
A user-defined function or a stored procedure.
Instance Attribute Summary collapse
-
#arguments ⇒ Array<Google::Apis::BigqueryV2::Argument>
Optional.
-
#build_status ⇒ Google::Apis::BigqueryV2::RoutineBuildStatus
The status of a routine build.
-
#creation_time ⇒ Fixnum
Output only.
-
#data_governance_type ⇒ String
Optional.
-
#definition_body ⇒ String
Required.
-
#description ⇒ String
Optional.
-
#determinism_level ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#external_runtime_options ⇒ Google::Apis::BigqueryV2::ExternalRuntimeOptions
Options for the runtime of the external system.
-
#imported_libraries ⇒ Array<String>
Optional.
-
#language ⇒ String
Optional.
-
#last_modified_time ⇒ Fixnum
Output only.
-
#python_options ⇒ Google::Apis::BigqueryV2::PythonOptions
Options for a user-defined Python function.
-
#remote_function_options ⇒ Google::Apis::BigqueryV2::RemoteFunctionOptions
Options for a remote user-defined function.
-
#return_table_type ⇒ Google::Apis::BigqueryV2::StandardSqlTableType
A table type Corresponds to the JSON property
returnTableType. -
#return_type ⇒ Google::Apis::BigqueryV2::StandardSqlDataType
The data type of a variable such as a function argument.
-
#routine_reference ⇒ Google::Apis::BigqueryV2::RoutineReference
Id path of a routine.
-
#routine_type ⇒ String
Required.
-
#security_mode ⇒ String
Optional.
-
#spark_options ⇒ Google::Apis::BigqueryV2::SparkOptions
Options for a user-defined Spark routine.
-
#strict_mode ⇒ Boolean
(also: #strict_mode?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Routine
constructor
A new instance of Routine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Routine
Returns a new instance of Routine.
9410 9411 9412 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9410 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arguments ⇒ Array<Google::Apis::BigqueryV2::Argument>
Optional.
Corresponds to the JSON property arguments
9275 9276 9277 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9275 def arguments @arguments end |
#build_status ⇒ Google::Apis::BigqueryV2::RoutineBuildStatus
The status of a routine build.
Corresponds to the JSON property buildStatus
9280 9281 9282 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9280 def build_status @build_status end |
#creation_time ⇒ Fixnum
Output only. The time when this routine was created, in milliseconds since the
epoch.
Corresponds to the JSON property creationTime
9286 9287 9288 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9286 def creation_time @creation_time end |
#data_governance_type ⇒ String
Optional. If set to DATA_MASKING, the function is validated and made
available as a masking function. For more information, see Create custom
masking routines.
Corresponds to the JSON property dataGovernanceType
9294 9295 9296 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9294 def data_governance_type @data_governance_type end |
#definition_body ⇒ String
Required. The body of the routine. For functions, this is the expression in
the AS clause. If language = "SQL", it is the substring inside (but
excluding) the parentheses. For example, for the function created with the
following statement: CREATE FUNCTION JoinLines(x string, y string) as (concat(
x, "\n", y)) The definition_body is concat(x, "\n", y) (\n is not replaced
with linebreak). If language="JAVASCRIPT", it is the evaluated string in the
AS clause. For example, for the function created with the following statement:
CREATE FUNCTION f() RETURNS STRING LANGUAGE js AS 'return "\n";\n' The
definition_body is return "\n";\n Note that both \n are replaced with
linebreaks. If definition_body references another routine, then that routine
must be fully qualified with its project ID.
Corresponds to the JSON property definitionBody
9309 9310 9311 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9309 def definition_body @definition_body end |
#description ⇒ String
Optional. The description of the routine, if defined.
Corresponds to the JSON property description
9314 9315 9316 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9314 def description @description end |
#determinism_level ⇒ String
Optional. The determinism level of the JavaScript UDF, if defined.
Corresponds to the JSON property determinismLevel
9319 9320 9321 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9319 def determinism_level @determinism_level end |
#etag ⇒ String
Output only. A hash of this resource.
Corresponds to the JSON property etag
9324 9325 9326 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9324 def etag @etag end |
#external_runtime_options ⇒ Google::Apis::BigqueryV2::ExternalRuntimeOptions
Options for the runtime of the external system.
Corresponds to the JSON property externalRuntimeOptions
9329 9330 9331 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9329 def @external_runtime_options end |
#imported_libraries ⇒ Array<String>
Optional. If language = "JAVASCRIPT", this field stores the path of the
imported JAVASCRIPT libraries.
Corresponds to the JSON property importedLibraries
9335 9336 9337 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9335 def imported_libraries @imported_libraries end |
#language ⇒ String
Optional. Defaults to "SQL" if remote_function_options field is absent, not
set otherwise.
Corresponds to the JSON property language
9341 9342 9343 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9341 def language @language end |
#last_modified_time ⇒ Fixnum
Output only. The time when this routine was last modified, in milliseconds
since the epoch.
Corresponds to the JSON property lastModifiedTime
9347 9348 9349 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9347 def last_modified_time @last_modified_time end |
#python_options ⇒ Google::Apis::BigqueryV2::PythonOptions
Options for a user-defined Python function.
Corresponds to the JSON property pythonOptions
9352 9353 9354 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9352 def @python_options end |
#remote_function_options ⇒ Google::Apis::BigqueryV2::RemoteFunctionOptions
Options for a remote user-defined function.
Corresponds to the JSON property remoteFunctionOptions
9357 9358 9359 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9357 def @remote_function_options end |
#return_table_type ⇒ Google::Apis::BigqueryV2::StandardSqlTableType
A table type
Corresponds to the JSON property returnTableType
9362 9363 9364 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9362 def return_table_type @return_table_type end |
#return_type ⇒ Google::Apis::BigqueryV2::StandardSqlDataType
The data type of a variable such as a function argument. Examples include: *
INT64: "typeKind": "INT64" * ARRAY: "typeKind": "ARRAY", "
arrayElementType":"typeKind": "STRING" * STRUCT>: "typeKind": "STRUCT",
"structType": "fields": [ "name": "x", "type":"typeKind": "STRING",
"name": "y", "type": "typeKind": "ARRAY", "arrayElementType": "typeKind": "
DATE" ] * RANGE: "typeKind": "RANGE", "rangeElementType":"
typeKind": "DATE"
Corresponds to the JSON property returnType
9373 9374 9375 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9373 def return_type @return_type end |
#routine_reference ⇒ Google::Apis::BigqueryV2::RoutineReference
Id path of a routine.
Corresponds to the JSON property routineReference
9378 9379 9380 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9378 def routine_reference @routine_reference end |
#routine_type ⇒ String
Required. The type of routine.
Corresponds to the JSON property routineType
9383 9384 9385 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9383 def routine_type @routine_type end |
#security_mode ⇒ String
Optional. The security mode of the routine, if defined. If not defined, the
security mode is automatically determined from the routine's configuration.
Corresponds to the JSON property securityMode
9389 9390 9391 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9389 def security_mode @security_mode end |
#spark_options ⇒ Google::Apis::BigqueryV2::SparkOptions
Options for a user-defined Spark routine.
Corresponds to the JSON property sparkOptions
9394 9395 9396 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9394 def @spark_options end |
#strict_mode ⇒ Boolean Also known as: strict_mode?
Optional. Use this option to catch many common errors. Error checking is not
exhaustive, and successfully creating a procedure doesn't guarantee that the
procedure will successfully execute at runtime. If strictMode is set to
TRUE, the procedure body is further checked for errors such as non-existent
tables or columns. The CREATE PROCEDURE statement fails if the body fails
any of these checks. If strictMode is set to FALSE, the procedure body is
checked only for syntax. For procedures that invoke themselves recursively,
specify strictMode=FALSE to avoid non-existent procedure errors during
validation. Default value is TRUE.
Corresponds to the JSON property strictMode
9407 9408 9409 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9407 def strict_mode @strict_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9415 9416 9417 9418 9419 9420 9421 9422 9423 9424 9425 9426 9427 9428 9429 9430 9431 9432 9433 9434 9435 9436 9437 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9415 def update!(**args) @arguments = args[:arguments] if args.key?(:arguments) @build_status = args[:build_status] if args.key?(:build_status) @creation_time = args[:creation_time] if args.key?(:creation_time) @data_governance_type = args[:data_governance_type] if args.key?(:data_governance_type) @definition_body = args[:definition_body] if args.key?(:definition_body) @description = args[:description] if args.key?(:description) @determinism_level = args[:determinism_level] if args.key?(:determinism_level) @etag = args[:etag] if args.key?(:etag) @external_runtime_options = args[:external_runtime_options] if args.key?(:external_runtime_options) @imported_libraries = args[:imported_libraries] if args.key?(:imported_libraries) @language = args[:language] if args.key?(:language) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @python_options = args[:python_options] if args.key?(:python_options) @remote_function_options = args[:remote_function_options] if args.key?(:remote_function_options) @return_table_type = args[:return_table_type] if args.key?(:return_table_type) @return_type = args[:return_type] if args.key?(:return_type) @routine_reference = args[:routine_reference] if args.key?(:routine_reference) @routine_type = args[:routine_type] if args.key?(:routine_type) @security_mode = args[:security_mode] if args.key?(:security_mode) @spark_options = args[:spark_options] if args.key?(:spark_options) @strict_mode = args[:strict_mode] if args.key?(:strict_mode) end |