Class: Google::Apis::BigqueryV2::Routine

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

A user-defined function or a stored procedure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Routine

Returns a new instance of Routine.



8910
8911
8912
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argumentsArray<Google::Apis::BigqueryV2::Argument>

Optional. Corresponds to the JSON property arguments



8780
8781
8782
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8780

def arguments
  @arguments
end

#creation_timeFixnum

Output only. The time when this routine was created, in milliseconds since the epoch. Corresponds to the JSON property creationTime

Returns:

  • (Fixnum)


8786
8787
8788
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8786

def creation_time
  @creation_time
end

#data_governance_typeString

Optional. If set to DATA_MASKING, the function is validated and made available as a masking function. For more information, see Create custom masking routines. Corresponds to the JSON property dataGovernanceType

Returns:

  • (String)


8794
8795
8796
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8794

def data_governance_type
  @data_governance_type
end

#definition_bodyString

Required. The body of the routine. For functions, this is the expression in the AS clause. If language = "SQL", it is the substring inside (but excluding) the parentheses. For example, for the function created with the following statement: CREATE FUNCTION JoinLines(x string, y string) as (concat( x, "\n", y)) The definition_body is concat(x, "\n", y) (\n is not replaced with linebreak). If language="JAVASCRIPT", it is the evaluated string in the AS clause. For example, for the function created with the following statement: CREATE FUNCTION f() RETURNS STRING LANGUAGE js AS 'return "\n";\n' The definition_body is return "\n";\n Note that both \n are replaced with linebreaks. If definition_body references another routine, then that routine must be fully qualified with its project ID. Corresponds to the JSON property definitionBody

Returns:

  • (String)


8809
8810
8811
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8809

def definition_body
  @definition_body
end

#descriptionString

Optional. The description of the routine, if defined. Corresponds to the JSON property description

Returns:

  • (String)


8814
8815
8816
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8814

def description
  @description
end

#determinism_levelString

Optional. The determinism level of the JavaScript UDF, if defined. Corresponds to the JSON property determinismLevel

Returns:

  • (String)


8819
8820
8821
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8819

def determinism_level
  @determinism_level
end

#etagString

Output only. A hash of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


8824
8825
8826
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8824

def etag
  @etag
end

#external_runtime_optionsGoogle::Apis::BigqueryV2::ExternalRuntimeOptions

Options for the runtime of the external system. Corresponds to the JSON property externalRuntimeOptions



8829
8830
8831
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8829

def external_runtime_options
  @external_runtime_options
end

#imported_librariesArray<String>

Optional. If language = "JAVASCRIPT", this field stores the path of the imported JAVASCRIPT libraries. Corresponds to the JSON property importedLibraries

Returns:

  • (Array<String>)


8835
8836
8837
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8835

def imported_libraries
  @imported_libraries
end

#languageString

Optional. Defaults to "SQL" if remote_function_options field is absent, not set otherwise. Corresponds to the JSON property language

Returns:

  • (String)


8841
8842
8843
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8841

def language
  @language
end

#last_modified_timeFixnum

Output only. The time when this routine was last modified, in milliseconds since the epoch. Corresponds to the JSON property lastModifiedTime

Returns:

  • (Fixnum)


8847
8848
8849
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8847

def last_modified_time
  @last_modified_time
end

#python_optionsGoogle::Apis::BigqueryV2::PythonOptions

Options for a user-defined Python function. Corresponds to the JSON property pythonOptions



8852
8853
8854
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8852

def python_options
  @python_options
end

#remote_function_optionsGoogle::Apis::BigqueryV2::RemoteFunctionOptions

Options for a remote user-defined function. Corresponds to the JSON property remoteFunctionOptions



8857
8858
8859
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8857

def remote_function_options
  @remote_function_options
end

#return_table_typeGoogle::Apis::BigqueryV2::StandardSqlTableType

A table type Corresponds to the JSON property returnTableType



8862
8863
8864
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8862

def return_table_type
  @return_table_type
end

#return_typeGoogle::Apis::BigqueryV2::StandardSqlDataType

The data type of a variable such as a function argument. Examples include: * INT64: "typeKind": "INT64" * ARRAY: "typeKind": "ARRAY", " arrayElementType":"typeKind": "STRING" * STRUCT>: "typeKind": "STRUCT", "structType": "fields": [ "name": "x", "type":"typeKind": "STRING", "name": "y", "type": "typeKind": "ARRAY", "arrayElementType": "typeKind": " DATE" ] * RANGE: "typeKind": "RANGE", "rangeElementType":" typeKind": "DATE" Corresponds to the JSON property returnType



8873
8874
8875
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8873

def return_type
  @return_type
end

#routine_referenceGoogle::Apis::BigqueryV2::RoutineReference

Id path of a routine. Corresponds to the JSON property routineReference



8878
8879
8880
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8878

def routine_reference
  @routine_reference
end

#routine_typeString

Required. The type of routine. Corresponds to the JSON property routineType

Returns:

  • (String)


8883
8884
8885
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8883

def routine_type
  @routine_type
end

#security_modeString

Optional. The security mode of the routine, if defined. If not defined, the security mode is automatically determined from the routine's configuration. Corresponds to the JSON property securityMode

Returns:

  • (String)


8889
8890
8891
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8889

def security_mode
  @security_mode
end

#spark_optionsGoogle::Apis::BigqueryV2::SparkOptions

Options for a user-defined Spark routine. Corresponds to the JSON property sparkOptions



8894
8895
8896
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8894

def spark_options
  @spark_options
end

#strict_modeBoolean Also known as: strict_mode?

Optional. Use this option to catch many common errors. Error checking is not exhaustive, and successfully creating a procedure doesn't guarantee that the procedure will successfully execute at runtime. If strictMode is set to TRUE, the procedure body is further checked for errors such as non-existent tables or columns. The CREATE PROCEDURE statement fails if the body fails any of these checks. If strictMode is set to FALSE, the procedure body is checked only for syntax. For procedures that invoke themselves recursively, specify strictMode=FALSE to avoid non-existent procedure errors during validation. Default value is TRUE. Corresponds to the JSON property strictMode

Returns:

  • (Boolean)


8907
8908
8909
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8907

def strict_mode
  @strict_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8915
8916
8917
8918
8919
8920
8921
8922
8923
8924
8925
8926
8927
8928
8929
8930
8931
8932
8933
8934
8935
8936
# File 'lib/google/apis/bigquery_v2/classes.rb', line 8915

def update!(**args)
  @arguments = args[:arguments] if args.key?(:arguments)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @data_governance_type = args[:data_governance_type] if args.key?(:data_governance_type)
  @definition_body = args[:definition_body] if args.key?(:definition_body)
  @description = args[:description] if args.key?(:description)
  @determinism_level = args[:determinism_level] if args.key?(:determinism_level)
  @etag = args[:etag] if args.key?(:etag)
  @external_runtime_options = args[:external_runtime_options] if args.key?(:external_runtime_options)
  @imported_libraries = args[:imported_libraries] if args.key?(:imported_libraries)
  @language = args[:language] if args.key?(:language)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @python_options = args[:python_options] if args.key?(:python_options)
  @remote_function_options = args[:remote_function_options] if args.key?(:remote_function_options)
  @return_table_type = args[:return_table_type] if args.key?(:return_table_type)
  @return_type = args[:return_type] if args.key?(:return_type)
  @routine_reference = args[:routine_reference] if args.key?(:routine_reference)
  @routine_type = args[:routine_type] if args.key?(:routine_type)
  @security_mode = args[:security_mode] if args.key?(:security_mode)
  @spark_options = args[:spark_options] if args.key?(:spark_options)
  @strict_mode = args[:strict_mode] if args.key?(:strict_mode)
end