Class: Google::Apis::BigqueryV2::RowAccessPolicyReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Id path of a row access policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RowAccessPolicyReference

Returns a new instance of RowAccessPolicyReference.



9431
9432
9433
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_idString

Required. The ID of the dataset containing this row access policy. Corresponds to the JSON property datasetId

Returns:

  • (String)


9412
9413
9414
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9412

def dataset_id
  @dataset_id
end

#policy_idString

Required. The ID of the row access policy. The ID must contain only letters (a- z, A-Z), numbers (0-9), or underscores (_). The maximum length is 256 characters. Corresponds to the JSON property policyId

Returns:

  • (String)


9419
9420
9421
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9419

def policy_id
  @policy_id
end

#project_idString

Required. The ID of the project containing this row access policy. Corresponds to the JSON property projectId

Returns:

  • (String)


9424
9425
9426
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9424

def project_id
  @project_id
end

#table_idString

Required. The ID of the table containing this row access policy. Corresponds to the JSON property tableId

Returns:

  • (String)


9429
9430
9431
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9429

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9436
9437
9438
9439
9440
9441
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9436

def update!(**args)
  @dataset_id = args[:dataset_id] if args.key?(:dataset_id)
  @policy_id = args[:policy_id] if args.key?(:policy_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @table_id = args[:table_id] if args.key?(:table_id)
end