Class: Google::Apis::BigqueryV2::RowAccessPolicyReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Id path of a row access policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RowAccessPolicyReference

Returns a new instance of RowAccessPolicyReference.



9094
9095
9096
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_idString

Required. The ID of the dataset containing this row access policy. Corresponds to the JSON property datasetId

Returns:

  • (String)


9075
9076
9077
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9075

def dataset_id
  @dataset_id
end

#policy_idString

Required. The ID of the row access policy. The ID must contain only letters (a- z, A-Z), numbers (0-9), or underscores (_). The maximum length is 256 characters. Corresponds to the JSON property policyId

Returns:

  • (String)


9082
9083
9084
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9082

def policy_id
  @policy_id
end

#project_idString

Required. The ID of the project containing this row access policy. Corresponds to the JSON property projectId

Returns:

  • (String)


9087
9088
9089
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9087

def project_id
  @project_id
end

#table_idString

Required. The ID of the table containing this row access policy. Corresponds to the JSON property tableId

Returns:

  • (String)


9092
9093
9094
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9092

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9099
9100
9101
9102
9103
9104
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9099

def update!(**args)
  @dataset_id = args[:dataset_id] if args.key?(:dataset_id)
  @policy_id = args[:policy_id] if args.key?(:policy_id)
  @project_id = args[:project_id] if args.key?(:project_id)
  @table_id = args[:table_id] if args.key?(:table_id)
end