Class: Google::Apis::BigqueryV2::RowAccessPolicyReference
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::RowAccessPolicyReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Id path of a row access policy.
Instance Attribute Summary collapse
-
#dataset_id ⇒ String
Required.
-
#policy_id ⇒ String
Required.
-
#project_id ⇒ String
Required.
-
#table_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RowAccessPolicyReference
constructor
A new instance of RowAccessPolicyReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RowAccessPolicyReference
Returns a new instance of RowAccessPolicyReference.
9064 9065 9066 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dataset_id ⇒ String
Required. The ID of the dataset containing this row access policy.
Corresponds to the JSON property datasetId
9045 9046 9047 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9045 def dataset_id @dataset_id end |
#policy_id ⇒ String
Required. The ID of the row access policy. The ID must contain only letters (a-
z, A-Z), numbers (0-9), or underscores (_). The maximum length is 256
characters.
Corresponds to the JSON property policyId
9052 9053 9054 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9052 def policy_id @policy_id end |
#project_id ⇒ String
Required. The ID of the project containing this row access policy.
Corresponds to the JSON property projectId
9057 9058 9059 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9057 def project_id @project_id end |
#table_id ⇒ String
Required. The ID of the table containing this row access policy.
Corresponds to the JSON property tableId
9062 9063 9064 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9062 def table_id @table_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9069 9070 9071 9072 9073 9074 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9069 def update!(**args) @dataset_id = args[:dataset_id] if args.key?(:dataset_id) @policy_id = args[:policy_id] if args.key?(:policy_id) @project_id = args[:project_id] if args.key?(:project_id) @table_id = args[:table_id] if args.key?(:table_id) end |