Class: Google::Apis::BigqueryV2::ScriptOptions
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ScriptOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Options related to script execution.
Instance Attribute Summary collapse
-
#key_result_statement ⇒ String
Determines which statement in the script represents the "key result", used to populate the schema and query results of the script job.
-
#statement_byte_budget ⇒ Fixnum
Limit on the number of bytes billed per statement.
-
#statement_timeout_ms ⇒ Fixnum
Timeout period for each statement in a script.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScriptOptions
constructor
A new instance of ScriptOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScriptOptions
Returns a new instance of ScriptOptions.
9763 9764 9765 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9763 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key_result_statement ⇒ String
Determines which statement in the script represents the "key result", used to
populate the schema and query results of the script job. Default is LAST.
Corresponds to the JSON property keyResultStatement
9750 9751 9752 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9750 def key_result_statement @key_result_statement end |
#statement_byte_budget ⇒ Fixnum
Limit on the number of bytes billed per statement. Exceeding this budget
results in an error.
Corresponds to the JSON property statementByteBudget
9756 9757 9758 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9756 def statement_byte_budget @statement_byte_budget end |
#statement_timeout_ms ⇒ Fixnum
Timeout period for each statement in a script.
Corresponds to the JSON property statementTimeoutMs
9761 9762 9763 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9761 def statement_timeout_ms @statement_timeout_ms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9768 9769 9770 9771 9772 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9768 def update!(**args) @key_result_statement = args[:key_result_statement] if args.key?(:key_result_statement) @statement_byte_budget = args[:statement_byte_budget] if args.key?(:statement_byte_budget) @statement_timeout_ms = args[:statement_timeout_ms] if args.key?(:statement_timeout_ms) end |