Class: Google::Apis::BigqueryV2::ScriptOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Options related to script execution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScriptOptions

Returns a new instance of ScriptOptions.



9694
9695
9696
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9694

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#key_result_statementString

Determines which statement in the script represents the "key result", used to populate the schema and query results of the script job. Default is LAST. Corresponds to the JSON property keyResultStatement

Returns:

  • (String)


9681
9682
9683
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9681

def key_result_statement
  @key_result_statement
end

#statement_byte_budgetFixnum

Limit on the number of bytes billed per statement. Exceeding this budget results in an error. Corresponds to the JSON property statementByteBudget

Returns:

  • (Fixnum)


9687
9688
9689
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9687

def statement_byte_budget
  @statement_byte_budget
end

#statement_timeout_msFixnum

Timeout period for each statement in a script. Corresponds to the JSON property statementTimeoutMs

Returns:

  • (Fixnum)


9692
9693
9694
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9692

def statement_timeout_ms
  @statement_timeout_ms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9699
9700
9701
9702
9703
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9699

def update!(**args)
  @key_result_statement = args[:key_result_statement] if args.key?(:key_result_statement)
  @statement_byte_budget = args[:statement_byte_budget] if args.key?(:statement_byte_budget)
  @statement_timeout_ms = args[:statement_timeout_ms] if args.key?(:statement_timeout_ms)
end