Class: Google::Apis::BigqueryV2::ScriptStatistics
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ScriptStatistics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Job statistics specific to the child job of a script.
Instance Attribute Summary collapse
-
#evaluation_kind ⇒ String
Whether this child job was a statement or expression.
-
#stack_frames ⇒ Array<Google::Apis::BigqueryV2::ScriptStackFrame>
Stack trace showing the line/column/procedure name of each frame on the stack at the point where the current evaluation happened.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScriptStatistics
constructor
A new instance of ScriptStatistics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScriptStatistics
Returns a new instance of ScriptStatistics.
9851 9852 9853 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9851 def initialize(**args) update!(**args) end |
Instance Attribute Details
#evaluation_kind ⇒ String
Whether this child job was a statement or expression.
Corresponds to the JSON property evaluationKind
9842 9843 9844 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9842 def evaluation_kind @evaluation_kind end |
#stack_frames ⇒ Array<Google::Apis::BigqueryV2::ScriptStackFrame>
Stack trace showing the line/column/procedure name of each frame on the stack
at the point where the current evaluation happened. The leaf frame is first,
the primary script is last. Never empty.
Corresponds to the JSON property stackFrames
9849 9850 9851 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9849 def stack_frames @stack_frames end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9856 9857 9858 9859 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9856 def update!(**args) @evaluation_kind = args[:evaluation_kind] if args.key?(:evaluation_kind) @stack_frames = args[:stack_frames] if args.key?(:stack_frames) end |