Class: Google::Apis::BigqueryV2::ScriptStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Job statistics specific to the child job of a script.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScriptStatistics

Returns a new instance of ScriptStatistics.



9782
9783
9784
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#evaluation_kindString

Whether this child job was a statement or expression. Corresponds to the JSON property evaluationKind

Returns:

  • (String)


9773
9774
9775
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9773

def evaluation_kind
  @evaluation_kind
end

#stack_framesArray<Google::Apis::BigqueryV2::ScriptStackFrame>

Stack trace showing the line/column/procedure name of each frame on the stack at the point where the current evaluation happened. The leaf frame is first, the primary script is last. Never empty. Corresponds to the JSON property stackFrames



9780
9781
9782
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9780

def stack_frames
  @stack_frames
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9787
9788
9789
9790
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9787

def update!(**args)
  @evaluation_kind = args[:evaluation_kind] if args.key?(:evaluation_kind)
  @stack_frames = args[:stack_frames] if args.key?(:stack_frames)
end