Class: Google::Apis::BigqueryV2::ScriptStatistics
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ScriptStatistics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Job statistics specific to the child job of a script.
Instance Attribute Summary collapse
-
#evaluation_kind ⇒ String
Whether this child job was a statement or expression.
-
#stack_frames ⇒ Array<Google::Apis::BigqueryV2::ScriptStackFrame>
Stack trace showing the line/column/procedure name of each frame on the stack at the point where the current evaluation happened.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScriptStatistics
constructor
A new instance of ScriptStatistics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScriptStatistics
Returns a new instance of ScriptStatistics.
9206 9207 9208 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#evaluation_kind ⇒ String
Whether this child job was a statement or expression.
Corresponds to the JSON property evaluationKind
9197 9198 9199 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9197 def evaluation_kind @evaluation_kind end |
#stack_frames ⇒ Array<Google::Apis::BigqueryV2::ScriptStackFrame>
Stack trace showing the line/column/procedure name of each frame on the stack
at the point where the current evaluation happened. The leaf frame is first,
the primary script is last. Never empty.
Corresponds to the JSON property stackFrames
9204 9205 9206 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9204 def stack_frames @stack_frames end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9211 9212 9213 9214 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9211 def update!(**args) @evaluation_kind = args[:evaluation_kind] if args.key?(:evaluation_kind) @stack_frames = args[:stack_frames] if args.key?(:stack_frames) end |