Class: Google::Apis::BigqueryV2::SearchStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics for a search query. Populated as part of JobStatistics2.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchStatistics

Returns a new instance of SearchStatistics.



9886
9887
9888
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9886

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#index_pruning_statsArray<Google::Apis::BigqueryV2::IndexPruningStats>

Search index pruning statistics, one for each base table that has a search index. If a base table does not have a search index or the index does not help with pruning on the base table, then there is no pruning statistics for that table. Corresponds to the JSON property indexPruningStats



9872
9873
9874
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9872

def index_pruning_stats
  @index_pruning_stats
end

#index_unused_reasonsArray<Google::Apis::BigqueryV2::IndexUnusedReason>

When indexUsageMode is UNUSED or PARTIALLY_USED, this field explains why indexes were not used in all or part of the search query. If indexUsageMode is FULLY_USED, this field is not populated. Corresponds to the JSON property indexUnusedReasons



9879
9880
9881
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9879

def index_unused_reasons
  @index_unused_reasons
end

#index_usage_modeString

Specifies the index usage mode for the query. Corresponds to the JSON property indexUsageMode

Returns:

  • (String)


9884
9885
9886
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9884

def index_usage_mode
  @index_usage_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9891
9892
9893
9894
9895
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9891

def update!(**args)
  @index_pruning_stats = args[:index_pruning_stats] if args.key?(:index_pruning_stats)
  @index_unused_reasons = args[:index_unused_reasons] if args.key?(:index_unused_reasons)
  @index_usage_mode = args[:index_usage_mode] if args.key?(:index_usage_mode)
end