Class: Google::Apis::BigqueryV2::SearchStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Statistics for a search query. Populated as part of JobStatistics2.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchStatistics

Returns a new instance of SearchStatistics.



9608
9609
9610
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9608

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#index_pruning_statsArray<Google::Apis::BigqueryV2::IndexPruningStats>

Search index pruning statistics, one for each base table that has a search index. If a base table does not have a search index or the index does not help with pruning on the base table, then there is no pruning statistics for that table. Corresponds to the JSON property indexPruningStats



9594
9595
9596
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9594

def index_pruning_stats
  @index_pruning_stats
end

#index_unused_reasonsArray<Google::Apis::BigqueryV2::IndexUnusedReason>

When indexUsageMode is UNUSED or PARTIALLY_USED, this field explains why indexes were not used in all or part of the search query. If indexUsageMode is FULLY_USED, this field is not populated. Corresponds to the JSON property indexUnusedReasons



9601
9602
9603
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9601

def index_unused_reasons
  @index_unused_reasons
end

#index_usage_modeString

Specifies the index usage mode for the query. Corresponds to the JSON property indexUsageMode

Returns:

  • (String)


9606
9607
9608
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9606

def index_usage_mode
  @index_usage_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9613
9614
9615
9616
9617
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9613

def update!(**args)
  @index_pruning_stats = args[:index_pruning_stats] if args.key?(:index_pruning_stats)
  @index_unused_reasons = args[:index_unused_reasons] if args.key?(:index_unused_reasons)
  @index_usage_mode = args[:index_usage_mode] if args.key?(:index_usage_mode)
end