Class: Google::Apis::BigqueryV2::SearchStatistics
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::SearchStatistics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Statistics for a search query. Populated as part of JobStatistics2.
Instance Attribute Summary collapse
-
#index_pruning_stats ⇒ Array<Google::Apis::BigqueryV2::IndexPruningStats>
Search index pruning statistics, one for each base table that has a search index.
-
#index_unused_reasons ⇒ Array<Google::Apis::BigqueryV2::IndexUnusedReason>
When
indexUsageModeisUNUSEDorPARTIALLY_USED, this field explains why indexes were not used in all or part of the search query. -
#index_usage_mode ⇒ String
Specifies the index usage mode for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchStatistics
constructor
A new instance of SearchStatistics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchStatistics
Returns a new instance of SearchStatistics.
9271 9272 9273 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#index_pruning_stats ⇒ Array<Google::Apis::BigqueryV2::IndexPruningStats>
Search index pruning statistics, one for each base table that has a search
index. If a base table does not have a search index or the index does not help
with pruning on the base table, then there is no pruning statistics for that
table.
Corresponds to the JSON property indexPruningStats
9257 9258 9259 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9257 def index_pruning_stats @index_pruning_stats end |
#index_unused_reasons ⇒ Array<Google::Apis::BigqueryV2::IndexUnusedReason>
When indexUsageMode is UNUSED or PARTIALLY_USED, this field explains why
indexes were not used in all or part of the search query. If indexUsageMode
is FULLY_USED, this field is not populated.
Corresponds to the JSON property indexUnusedReasons
9264 9265 9266 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9264 def index_unused_reasons @index_unused_reasons end |
#index_usage_mode ⇒ String
Specifies the index usage mode for the query.
Corresponds to the JSON property indexUsageMode
9269 9270 9271 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9269 def index_usage_mode @index_usage_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9276 9277 9278 9279 9280 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9276 def update!(**args) @index_pruning_stats = args[:index_pruning_stats] if args.key?(:index_pruning_stats) @index_unused_reasons = args[:index_unused_reasons] if args.key?(:index_unused_reasons) @index_usage_mode = args[:index_usage_mode] if args.key?(:index_usage_mode) end |