Class: Google::Apis::BigqueryV2::SerDeInfo
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::SerDeInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Serializer and deserializer information.
Instance Attribute Summary collapse
-
#name ⇒ String
Optional.
-
#parameters ⇒ Hash<String,String>
Optional.
-
#serialization_library ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SerDeInfo
constructor
A new instance of SerDeInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SerDeInfo
Returns a new instance of SerDeInfo.
9852 9853 9854 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9852 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Optional. Name of the SerDe. The maximum length is 256 characters.
Corresponds to the JSON property name
9836 9837 9838 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9836 def name @name end |
#parameters ⇒ Hash<String,String>
Optional. Key-value pairs that define the initialization parameters for the
serialization library. Maximum size 10 Kib.
Corresponds to the JSON property parameters
9842 9843 9844 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9842 def parameters @parameters end |
#serialization_library ⇒ String
Required. Specifies a fully-qualified class name of the serialization library
that is responsible for the translation of data between table representation
and the underlying low-level input and output format structures. The maximum
length is 256 characters.
Corresponds to the JSON property serializationLibrary
9850 9851 9852 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9850 def serialization_library @serialization_library end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9857 9858 9859 9860 9861 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9857 def update!(**args) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) @serialization_library = args[:serialization_library] if args.key?(:serialization_library) end |