Class: Google::Apis::BigqueryV2::SerDeInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Serializer and deserializer information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SerDeInfo

Returns a new instance of SerDeInfo.



9276
9277
9278
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9276

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Optional. Name of the SerDe. The maximum length is 256 characters. Corresponds to the JSON property name

Returns:

  • (String)


9260
9261
9262
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9260

def name
  @name
end

#parametersHash<String,String>

Optional. Key-value pairs that define the initialization parameters for the serialization library. Maximum size 10 Kib. Corresponds to the JSON property parameters

Returns:

  • (Hash<String,String>)


9266
9267
9268
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9266

def parameters
  @parameters
end

#serialization_libraryString

Required. Specifies a fully-qualified class name of the serialization library that is responsible for the translation of data between table representation and the underlying low-level input and output format structures. The maximum length is 256 characters. Corresponds to the JSON property serializationLibrary

Returns:

  • (String)


9274
9275
9276
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9274

def serialization_library
  @serialization_library
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9281
9282
9283
9284
9285
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9281

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @serialization_library = args[:serialization_library] if args.key?(:serialization_library)
end