Class: Google::Apis::BigqueryV2::SnapshotDefinition
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::SnapshotDefinition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Information about base table and snapshot time of the snapshot.
Instance Attribute Summary collapse
-
#base_table_reference ⇒ Google::Apis::BigqueryV2::TableReference
Required.
-
#snapshot_time ⇒ DateTime
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotDefinition
constructor
A new instance of SnapshotDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotDefinition
Returns a new instance of SnapshotDefinition.
9970 9971 9972 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9970 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_table_reference ⇒ Google::Apis::BigqueryV2::TableReference
Required. Reference describing the ID of the table that was snapshot.
Corresponds to the JSON property baseTableReference
9962 9963 9964 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9962 def base_table_reference @base_table_reference end |
#snapshot_time ⇒ DateTime
Required. The time at which the base table was snapshot. This value is
reported in the JSON response using RFC3339 format.
Corresponds to the JSON property snapshotTime
9968 9969 9970 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9968 def snapshot_time @snapshot_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9975 9976 9977 9978 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9975 def update!(**args) @base_table_reference = args[:base_table_reference] if args.key?(:base_table_reference) @snapshot_time = args[:snapshot_time] if args.key?(:snapshot_time) end |