Class: Google::Apis::BigqueryV2::SparkOptions
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::SparkOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Options for a user-defined Spark routine.
Instance Attribute Summary collapse
-
#archive_uris ⇒ Array<String>
Archive files to be extracted into the working directory of each executor.
-
#connection ⇒ String
Fully qualified name of the user-provided Spark connection object.
-
#container_image ⇒ String
Custom container image for the runtime environment.
-
#file_uris ⇒ Array<String>
Files to be placed in the working directory of each executor.
-
#jar_uris ⇒ Array<String>
JARs to include on the driver and executor CLASSPATH.
-
#main_class ⇒ String
The fully qualified name of a class in jar_uris, for example, com.example.
-
#main_file_uri ⇒ String
The main file/jar URI of the Spark application.
-
#properties ⇒ Hash<String,String>
Configuration properties as a set of key/value pairs, which will be passed on to the Spark application.
-
#py_file_uris ⇒ Array<String>
Python files to be placed on the PYTHONPATH for PySpark application.
-
#runtime_version ⇒ String
Runtime version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SparkOptions
constructor
A new instance of SparkOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SparkOptions
Returns a new instance of SparkOptions.
10147 10148 10149 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_uris ⇒ Array<String>
Archive files to be extracted into the working directory of each executor. For
more information about Apache Spark, see Apache Spark.
Corresponds to the JSON property archiveUris
10084 10085 10086 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10084 def archive_uris @archive_uris end |
#connection ⇒ String
Fully qualified name of the user-provided Spark connection object. Format: "
projects/`project_id`/locations/`location_id`/connections/`connection_id`"
Corresponds to the JSON property connection
10090 10091 10092 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10090 def connection @connection end |
#container_image ⇒ String
Custom container image for the runtime environment.
Corresponds to the JSON property containerImage
10095 10096 10097 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10095 def container_image @container_image end |
#file_uris ⇒ Array<String>
Files to be placed in the working directory of each executor. For more
information about Apache Spark, see Apache Spark.
Corresponds to the JSON property fileUris
10102 10103 10104 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10102 def file_uris @file_uris end |
#jar_uris ⇒ Array<String>
JARs to include on the driver and executor CLASSPATH. For more information
about Apache Spark, see Apache Spark.
Corresponds to the JSON property jarUris
10109 10110 10111 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10109 def jar_uris @jar_uris end |
#main_class ⇒ String
The fully qualified name of a class in jar_uris, for example, com.example.
wordcount. Exactly one of main_class and main_jar_uri field should be set for
Java/Scala language type.
Corresponds to the JSON property mainClass
10116 10117 10118 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10116 def main_class @main_class end |
#main_file_uri ⇒ String
The main file/jar URI of the Spark application. Exactly one of the
definition_body field and the main_file_uri field must be set for Python.
Exactly one of main_class and main_file_uri field should be set for Java/Scala
language type.
Corresponds to the JSON property mainFileUri
10124 10125 10126 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10124 def main_file_uri @main_file_uri end |
#properties ⇒ Hash<String,String>
Configuration properties as a set of key/value pairs, which will be passed on
to the Spark application. For more information, see Apache Spark and the procedure option list.
Corresponds to the JSON property properties
10133 10134 10135 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10133 def properties @properties end |
#py_file_uris ⇒ Array<String>
Python files to be placed on the PYTHONPATH for PySpark application. Supported
file types: .py, .egg, and .zip. For more information about Apache Spark,
see Apache Spark.
Corresponds to the JSON property pyFileUris
10140 10141 10142 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10140 def py_file_uris @py_file_uris end |
#runtime_version ⇒ String
Runtime version. If not specified, the default runtime version is used.
Corresponds to the JSON property runtimeVersion
10145 10146 10147 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10145 def runtime_version @runtime_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10152 10153 10154 10155 10156 10157 10158 10159 10160 10161 10162 10163 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10152 def update!(**args) @archive_uris = args[:archive_uris] if args.key?(:archive_uris) @connection = args[:connection] if args.key?(:connection) @container_image = args[:container_image] if args.key?(:container_image) @file_uris = args[:file_uris] if args.key?(:file_uris) @jar_uris = args[:jar_uris] if args.key?(:jar_uris) @main_class = args[:main_class] if args.key?(:main_class) @main_file_uri = args[:main_file_uri] if args.key?(:main_file_uri) @properties = args[:properties] if args.key?(:properties) @py_file_uris = args[:py_file_uris] if args.key?(:py_file_uris) @runtime_version = args[:runtime_version] if args.key?(:runtime_version) end |