Class: Google::Apis::BigqueryV2::StandardSqlDataType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

The data type of a variable such as a function argument. Examples include: * INT64: "typeKind": "INT64" * ARRAY: "typeKind": "ARRAY", " arrayElementType":"typeKind": "STRING" * STRUCT>: "typeKind": "STRUCT", "structType": "fields": [ "name": "x", "type":"typeKind": "STRING", "name": "y", "type": "typeKind": "ARRAY", "arrayElementType": "typeKind": " DATE" ] * RANGE: "typeKind": "RANGE", "rangeElementType":" typeKind": "DATE"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StandardSqlDataType

Returns a new instance of StandardSqlDataType.



9736
9737
9738
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#array_element_typeGoogle::Apis::BigqueryV2::StandardSqlDataType

The data type of a variable such as a function argument. Examples include: * INT64: "typeKind": "INT64" * ARRAY: "typeKind": "ARRAY", " arrayElementType":"typeKind": "STRING" * STRUCT>: "typeKind": "STRUCT", "structType": "fields": [ "name": "x", "type":"typeKind": "STRING", "name": "y", "type": "typeKind": "ARRAY", "arrayElementType": "typeKind": " DATE" ] * RANGE: "typeKind": "RANGE", "rangeElementType":" typeKind": "DATE" Corresponds to the JSON property arrayElementType



9712
9713
9714
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9712

def array_element_type
  @array_element_type
end

#range_element_typeGoogle::Apis::BigqueryV2::StandardSqlDataType

The data type of a variable such as a function argument. Examples include: * INT64: "typeKind": "INT64" * ARRAY: "typeKind": "ARRAY", " arrayElementType":"typeKind": "STRING" * STRUCT>: "typeKind": "STRUCT", "structType": "fields": [ "name": "x", "type":"typeKind": "STRING", "name": "y", "type": "typeKind": "ARRAY", "arrayElementType": "typeKind": " DATE" ] * RANGE: "typeKind": "RANGE", "rangeElementType":" typeKind": "DATE" Corresponds to the JSON property rangeElementType



9723
9724
9725
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9723

def range_element_type
  @range_element_type
end

#struct_typeGoogle::Apis::BigqueryV2::StandardSqlStructType

The representation of a SQL STRUCT type. Corresponds to the JSON property structType



9728
9729
9730
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9728

def struct_type
  @struct_type
end

#type_kindString

Required. The top level type of this field. Can be any GoogleSQL data type (e. g., "INT64", "DATE", "ARRAY"). Corresponds to the JSON property typeKind

Returns:

  • (String)


9734
9735
9736
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9734

def type_kind
  @type_kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9741
9742
9743
9744
9745
9746
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9741

def update!(**args)
  @array_element_type = args[:array_element_type] if args.key?(:array_element_type)
  @range_element_type = args[:range_element_type] if args.key?(:range_element_type)
  @struct_type = args[:struct_type] if args.key?(:struct_type)
  @type_kind = args[:type_kind] if args.key?(:type_kind)
end