Class: Google::Apis::BigqueryV2::StorageDescriptor
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::StorageDescriptor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Contains information about how a table's data is stored and accessed by open source query engines.
Instance Attribute Summary collapse
-
#input_format ⇒ String
Optional.
-
#location_uri ⇒ String
Optional.
-
#output_format ⇒ String
Optional.
-
#serde_info ⇒ Google::Apis::BigqueryV2::SerDeInfo
Serializer and deserializer information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDescriptor
constructor
A new instance of StorageDescriptor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDescriptor
Returns a new instance of StorageDescriptor.
10395 10396 10397 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#input_format ⇒ String
Optional. Specifies the fully qualified class name of the InputFormat (e.g. "
org.apache.hadoop.hive.ql.io.orc.OrcInputFormat"). The maximum length is 128
characters.
Corresponds to the JSON property inputFormat
10374 10375 10376 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10374 def input_format @input_format end |
#location_uri ⇒ String
Optional. The physical location of the table (e.g. gs://spark-dataproc-data/
pangea-data/case_sensitive/ or gs://spark-dataproc-data/pangea-data/*). The
maximum length is 2056 bytes.
Corresponds to the JSON property locationUri
10381 10382 10383 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10381 def location_uri @location_uri end |
#output_format ⇒ String
Optional. Specifies the fully qualified class name of the OutputFormat (e.g. "
org.apache.hadoop.hive.ql.io.orc.OrcOutputFormat"). The maximum length is 128
characters.
Corresponds to the JSON property outputFormat
10388 10389 10390 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10388 def output_format @output_format end |
#serde_info ⇒ Google::Apis::BigqueryV2::SerDeInfo
Serializer and deserializer information.
Corresponds to the JSON property serdeInfo
10393 10394 10395 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10393 def serde_info @serde_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10400 10401 10402 10403 10404 10405 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10400 def update!(**args) @input_format = args[:input_format] if args.key?(:input_format) @location_uri = args[:location_uri] if args.key?(:location_uri) @output_format = args[:output_format] if args.key?(:output_format) @serde_info = args[:serde_info] if args.key?(:serde_info) end |