Class: Google::Apis::BigqueryV2::StorageDescriptor
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::StorageDescriptor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Contains information about how a table's data is stored and accessed by open source query engines.
Instance Attribute Summary collapse
-
#input_format ⇒ String
Optional.
-
#location_uri ⇒ String
Optional.
-
#output_format ⇒ String
Optional.
-
#serde_info ⇒ Google::Apis::BigqueryV2::SerDeInfo
Serializer and deserializer information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StorageDescriptor
constructor
A new instance of StorageDescriptor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StorageDescriptor
Returns a new instance of StorageDescriptor.
10274 10275 10276 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10274 def initialize(**args) update!(**args) end |
Instance Attribute Details
#input_format ⇒ String
Optional. Specifies the fully qualified class name of the InputFormat (e.g. "
org.apache.hadoop.hive.ql.io.orc.OrcInputFormat"). The maximum length is 128
characters.
Corresponds to the JSON property inputFormat
10253 10254 10255 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10253 def input_format @input_format end |
#location_uri ⇒ String
Optional. The physical location of the table (e.g. gs://spark-dataproc-data/
pangea-data/case_sensitive/ or gs://spark-dataproc-data/pangea-data/*). The
maximum length is 2056 bytes.
Corresponds to the JSON property locationUri
10260 10261 10262 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10260 def location_uri @location_uri end |
#output_format ⇒ String
Optional. Specifies the fully qualified class name of the OutputFormat (e.g. "
org.apache.hadoop.hive.ql.io.orc.OrcOutputFormat"). The maximum length is 128
characters.
Corresponds to the JSON property outputFormat
10267 10268 10269 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10267 def output_format @output_format end |
#serde_info ⇒ Google::Apis::BigqueryV2::SerDeInfo
Serializer and deserializer information.
Corresponds to the JSON property serdeInfo
10272 10273 10274 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10272 def serde_info @serde_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10279 10280 10281 10282 10283 10284 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10279 def update!(**args) @input_format = args[:input_format] if args.key?(:input_format) @location_uri = args[:location_uri] if args.key?(:location_uri) @output_format = args[:output_format] if args.key?(:output_format) @serde_info = args[:serde_info] if args.key?(:serde_info) end |