Class: Google::Apis::BigqueryV2::StoredColumnsUnusedReason
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::StoredColumnsUnusedReason
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
If the stored column was not used, explain why.
Instance Attribute Summary collapse
-
#code ⇒ String
Specifies the high-level reason for the unused scenario, each reason must have a code associated.
-
#message ⇒ String
Specifies the detailed description for the scenario.
-
#uncovered_columns ⇒ Array<String>
Specifies which columns were not covered by the stored columns for the specified code up to 20 columns.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoredColumnsUnusedReason
constructor
A new instance of StoredColumnsUnusedReason.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoredColumnsUnusedReason
Returns a new instance of StoredColumnsUnusedReason.
9884 9885 9886 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Specifies the high-level reason for the unused scenario, each reason must have
a code associated.
Corresponds to the JSON property code
9870 9871 9872 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9870 def code @code end |
#message ⇒ String
Specifies the detailed description for the scenario.
Corresponds to the JSON property message
9875 9876 9877 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9875 def @message end |
#uncovered_columns ⇒ Array<String>
Specifies which columns were not covered by the stored columns for the
specified code up to 20 columns. This is populated when the code is
STORED_COLUMNS_COVER_INSUFFICIENT and BASE_TABLE_HAS_CLS.
Corresponds to the JSON property uncoveredColumns
9882 9883 9884 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9882 def uncovered_columns @uncovered_columns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9889 9890 9891 9892 9893 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9889 def update!(**args) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @uncovered_columns = args[:uncovered_columns] if args.key?(:uncovered_columns) end |