Class: Google::Apis::BigqueryV2::StoredColumnsUsage
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::StoredColumnsUsage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Indicates the stored columns usage in the query.
Instance Attribute Summary collapse
-
#base_table ⇒ Google::Apis::BigqueryV2::TableReference
Specifies the base table.
-
#is_query_accelerated ⇒ Boolean
(also: #is_query_accelerated?)
Specifies whether the query was accelerated with stored columns.
-
#stored_columns_unused_reasons ⇒ Array<Google::Apis::BigqueryV2::StoredColumnsUnusedReason>
If stored columns were not used, explain why.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoredColumnsUsage
constructor
A new instance of StoredColumnsUsage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoredColumnsUsage
Returns a new instance of StoredColumnsUsage.
10253 10254 10255 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10253 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_table ⇒ Google::Apis::BigqueryV2::TableReference
Specifies the base table.
Corresponds to the JSON property baseTable
10240 10241 10242 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10240 def base_table @base_table end |
#is_query_accelerated ⇒ Boolean Also known as: is_query_accelerated?
Specifies whether the query was accelerated with stored columns.
Corresponds to the JSON property isQueryAccelerated
10245 10246 10247 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10245 def is_query_accelerated @is_query_accelerated end |
#stored_columns_unused_reasons ⇒ Array<Google::Apis::BigqueryV2::StoredColumnsUnusedReason>
If stored columns were not used, explain why.
Corresponds to the JSON property storedColumnsUnusedReasons
10251 10252 10253 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10251 def stored_columns_unused_reasons @stored_columns_unused_reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10258 10259 10260 10261 10262 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10258 def update!(**args) @base_table = args[:base_table] if args.key?(:base_table) @is_query_accelerated = args[:is_query_accelerated] if args.key?(:is_query_accelerated) @stored_columns_unused_reasons = args[:stored_columns_unused_reasons] if args.key?(:stored_columns_unused_reasons) end |