Class: Google::Apis::BigqueryV2::StoredColumnsUsage
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::StoredColumnsUsage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Indicates the stored columns usage in the query.
Instance Attribute Summary collapse
-
#base_table ⇒ Google::Apis::BigqueryV2::TableReference
Specifies the base table.
-
#is_query_accelerated ⇒ Boolean
(also: #is_query_accelerated?)
Specifies whether the query was accelerated with stored columns.
-
#stored_columns_unused_reasons ⇒ Array<Google::Apis::BigqueryV2::StoredColumnsUnusedReason>
If stored columns were not used, explain why.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoredColumnsUsage
constructor
A new instance of StoredColumnsUsage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoredColumnsUsage
Returns a new instance of StoredColumnsUsage.
9916 9917 9918 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_table ⇒ Google::Apis::BigqueryV2::TableReference
Specifies the base table.
Corresponds to the JSON property baseTable
9903 9904 9905 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9903 def base_table @base_table end |
#is_query_accelerated ⇒ Boolean Also known as: is_query_accelerated?
Specifies whether the query was accelerated with stored columns.
Corresponds to the JSON property isQueryAccelerated
9908 9909 9910 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9908 def is_query_accelerated @is_query_accelerated end |
#stored_columns_unused_reasons ⇒ Array<Google::Apis::BigqueryV2::StoredColumnsUnusedReason>
If stored columns were not used, explain why.
Corresponds to the JSON property storedColumnsUnusedReasons
9914 9915 9916 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9914 def stored_columns_unused_reasons @stored_columns_unused_reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9921 9922 9923 9924 9925 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9921 def update!(**args) @base_table = args[:base_table] if args.key?(:base_table) @is_query_accelerated = args[:is_query_accelerated] if args.key?(:is_query_accelerated) @stored_columns_unused_reasons = args[:stored_columns_unused_reasons] if args.key?(:stored_columns_unused_reasons) end |