Class: Google::Apis::BigqueryV2::StoredColumnsUsage
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::StoredColumnsUsage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Indicates the stored columns usage in the query.
Instance Attribute Summary collapse
-
#base_table ⇒ Google::Apis::BigqueryV2::TableReference
Specifies the base table.
-
#is_query_accelerated ⇒ Boolean
(also: #is_query_accelerated?)
Specifies whether the query was accelerated with stored columns.
-
#stored_columns_unused_reasons ⇒ Array<Google::Apis::BigqueryV2::StoredColumnsUnusedReason>
If stored columns were not used, explain why.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoredColumnsUsage
constructor
A new instance of StoredColumnsUsage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoredColumnsUsage
Returns a new instance of StoredColumnsUsage.
9886 9887 9888 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9886 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_table ⇒ Google::Apis::BigqueryV2::TableReference
Specifies the base table.
Corresponds to the JSON property baseTable
9873 9874 9875 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9873 def base_table @base_table end |
#is_query_accelerated ⇒ Boolean Also known as: is_query_accelerated?
Specifies whether the query was accelerated with stored columns.
Corresponds to the JSON property isQueryAccelerated
9878 9879 9880 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9878 def is_query_accelerated @is_query_accelerated end |
#stored_columns_unused_reasons ⇒ Array<Google::Apis::BigqueryV2::StoredColumnsUnusedReason>
If stored columns were not used, explain why.
Corresponds to the JSON property storedColumnsUnusedReasons
9884 9885 9886 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9884 def stored_columns_unused_reasons @stored_columns_unused_reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9891 9892 9893 9894 9895 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9891 def update!(**args) @base_table = args[:base_table] if args.key?(:base_table) @is_query_accelerated = args[:is_query_accelerated] if args.key?(:is_query_accelerated) @stored_columns_unused_reasons = args[:stored_columns_unused_reasons] if args.key?(:stored_columns_unused_reasons) end |