Class: Google::Apis::BigqueryV2::Streamingbuffer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Streamingbuffer

Returns a new instance of Streamingbuffer.



10565
10566
10567
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#estimated_bytesFixnum

Output only. A lower-bound estimate of the number of bytes currently in the streaming buffer. Corresponds to the JSON property estimatedBytes

Returns:

  • (Fixnum)


10551
10552
10553
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10551

def estimated_bytes
  @estimated_bytes
end

#estimated_rowsFixnum

Output only. A lower-bound estimate of the number of rows currently in the streaming buffer. Corresponds to the JSON property estimatedRows

Returns:

  • (Fixnum)


10557
10558
10559
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10557

def estimated_rows
  @estimated_rows
end

#oldest_entry_timeFixnum

Output only. Contains the timestamp of the oldest entry in the streaming buffer, in milliseconds since the epoch, if the streaming buffer is available. Corresponds to the JSON property oldestEntryTime

Returns:

  • (Fixnum)


10563
10564
10565
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10563

def oldest_entry_time
  @oldest_entry_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10570
10571
10572
10573
10574
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10570

def update!(**args)
  @estimated_bytes = args[:estimated_bytes] if args.key?(:estimated_bytes)
  @estimated_rows = args[:estimated_rows] if args.key?(:estimated_rows)
  @oldest_entry_time = args[:oldest_entry_time] if args.key?(:oldest_entry_time)
end