Class: Google::Apis::BigqueryV2::Streamingbuffer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Streamingbuffer

Returns a new instance of Streamingbuffer.



10380
10381
10382
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#estimated_bytesFixnum

Output only. A lower-bound estimate of the number of bytes currently in the streaming buffer. Corresponds to the JSON property estimatedBytes

Returns:

  • (Fixnum)


10366
10367
10368
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10366

def estimated_bytes
  @estimated_bytes
end

#estimated_rowsFixnum

Output only. A lower-bound estimate of the number of rows currently in the streaming buffer. Corresponds to the JSON property estimatedRows

Returns:

  • (Fixnum)


10372
10373
10374
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10372

def estimated_rows
  @estimated_rows
end

#oldest_entry_timeFixnum

Output only. Contains the timestamp of the oldest entry in the streaming buffer, in milliseconds since the epoch, if the streaming buffer is available. Corresponds to the JSON property oldestEntryTime

Returns:

  • (Fixnum)


10378
10379
10380
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10378

def oldest_entry_time
  @oldest_entry_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10385
10386
10387
10388
10389
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10385

def update!(**args)
  @estimated_bytes = args[:estimated_bytes] if args.key?(:estimated_bytes)
  @estimated_rows = args[:estimated_rows] if args.key?(:estimated_rows)
  @oldest_entry_time = args[:oldest_entry_time] if args.key?(:oldest_entry_time)
end