Class: Google::Apis::BigqueryV2::Streamingbuffer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Streamingbuffer

Returns a new instance of Streamingbuffer.



10287
10288
10289
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10287

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#estimated_bytesFixnum

Output only. A lower-bound estimate of the number of bytes currently in the streaming buffer. Corresponds to the JSON property estimatedBytes

Returns:

  • (Fixnum)


10273
10274
10275
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10273

def estimated_bytes
  @estimated_bytes
end

#estimated_rowsFixnum

Output only. A lower-bound estimate of the number of rows currently in the streaming buffer. Corresponds to the JSON property estimatedRows

Returns:

  • (Fixnum)


10279
10280
10281
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10279

def estimated_rows
  @estimated_rows
end

#oldest_entry_timeFixnum

Output only. Contains the timestamp of the oldest entry in the streaming buffer, in milliseconds since the epoch, if the streaming buffer is available. Corresponds to the JSON property oldestEntryTime

Returns:

  • (Fixnum)


10285
10286
10287
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10285

def oldest_entry_time
  @oldest_entry_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10292
10293
10294
10295
10296
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10292

def update!(**args)
  @estimated_bytes = args[:estimated_bytes] if args.key?(:estimated_bytes)
  @estimated_rows = args[:estimated_rows] if args.key?(:estimated_rows)
  @oldest_entry_time = args[:oldest_entry_time] if args.key?(:oldest_entry_time)
end