Class: Google::Apis::BigqueryV2::Table
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::Table
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Instance Attribute Summary collapse
-
#biglake_configuration ⇒ Google::Apis::BigqueryV2::BigLakeConfiguration
Configuration for BigQuery tables for Apache Iceberg (formerly BigLake managed tables.) Corresponds to the JSON property
biglakeConfiguration. -
#clone_definition ⇒ Google::Apis::BigqueryV2::CloneDefinition
Information about base table and clone time of a table clone.
-
#clustering ⇒ Google::Apis::BigqueryV2::Clustering
Configures table clustering.
-
#creation_time ⇒ Fixnum
Output only.
-
#default_collation ⇒ String
Optional.
-
#default_rounding_mode ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#encryption_configuration ⇒ Google::Apis::BigqueryV2::EncryptionConfiguration
Configuration for Cloud KMS encryption settings.
-
#etag ⇒ String
Output only.
-
#expiration_time ⇒ Fixnum
Optional.
-
#external_catalog_table_options ⇒ Google::Apis::BigqueryV2::ExternalCatalogTableOptions
Metadata about open source compatible table.
-
#external_data_configuration ⇒ Google::Apis::BigqueryV2::ExternalDataConfiguration
Optional.
-
#friendly_name ⇒ String
Optional.
-
#id ⇒ String
Output only.
-
#kind ⇒ String
The type of resource ID.
-
#labels ⇒ Hash<String,String>
The labels associated with this table.
-
#last_modified_time ⇒ Fixnum
Output only.
-
#location ⇒ String
Output only.
-
#managed_table_type ⇒ String
Optional.
-
#materialized_view ⇒ Google::Apis::BigqueryV2::MaterializedViewDefinition
Definition and configuration of a materialized view.
-
#materialized_view_status ⇒ Google::Apis::BigqueryV2::MaterializedViewStatus
Status of a materialized view.
-
#max_staleness ⇒ String
Optional.
-
#model ⇒ Google::Apis::BigqueryV2::ModelDefinition
Deprecated.
-
#num_active_logical_bytes ⇒ Fixnum
Output only.
-
#num_active_physical_bytes ⇒ Fixnum
Output only.
-
#num_bytes ⇒ Fixnum
Output only.
-
#num_current_physical_bytes ⇒ Fixnum
Output only.
-
#num_long_term_bytes ⇒ Fixnum
Output only.
-
#num_long_term_logical_bytes ⇒ Fixnum
Output only.
-
#num_long_term_physical_bytes ⇒ Fixnum
Output only.
-
#num_partitions ⇒ Fixnum
Output only.
-
#num_physical_bytes ⇒ Fixnum
Output only.
-
#num_rows ⇒ Fixnum
Output only.
-
#num_time_travel_physical_bytes ⇒ Fixnum
Output only.
-
#num_total_logical_bytes ⇒ Fixnum
Output only.
-
#num_total_physical_bytes ⇒ Fixnum
Output only.
-
#partition_definition ⇒ Google::Apis::BigqueryV2::PartitioningDefinition
The partitioning information, which includes managed table, external table and metastore partitioned table partition information.
-
#range_partitioning ⇒ Google::Apis::BigqueryV2::RangePartitioning
If specified, configures range partitioning for this table.
-
#replicas ⇒ Array<Google::Apis::BigqueryV2::TableReference>
Optional.
-
#require_partition_filter ⇒ Boolean
(also: #require_partition_filter?)
Optional.
-
#resource_tags ⇒ Hash<String,String>
[Optional] The tags associated with this table.
-
#restrictions ⇒ Google::Apis::BigqueryV2::RestrictionConfig
Optional.
-
#schema ⇒ Google::Apis::BigqueryV2::TableSchema
Schema of a table Corresponds to the JSON property
schema. -
#self_link ⇒ String
Output only.
-
#snapshot_definition ⇒ Google::Apis::BigqueryV2::SnapshotDefinition
Information about base table and snapshot time of the snapshot.
-
#streaming_buffer ⇒ Google::Apis::BigqueryV2::Streamingbuffer
Output only.
-
#table_constraints ⇒ Google::Apis::BigqueryV2::TableConstraints
The TableConstraints defines the primary key and foreign key.
-
#table_reference ⇒ Google::Apis::BigqueryV2::TableReference
Required.
-
#table_replication_info ⇒ Google::Apis::BigqueryV2::TableReplicationInfo
Replication info of a table created using
AS REPLICADDL like:CREATE MATERIALIZED VIEW mv1 AS REPLICA OF src_mvCorresponds to the JSON propertytableReplicationInfo. -
#time_partitioning ⇒ Google::Apis::BigqueryV2::TimePartitioning
If specified, configures time-based partitioning for this table.
-
#type ⇒ String
Output only.
-
#view ⇒ Google::Apis::BigqueryV2::ViewDefinition
Describes the definition of a logical view.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Table
constructor
A new instance of Table.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Table
Returns a new instance of Table.
10305 10306 10307 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#biglake_configuration ⇒ Google::Apis::BigqueryV2::BigLakeConfiguration
Configuration for BigQuery tables for Apache Iceberg (formerly BigLake managed
tables.)
Corresponds to the JSON property biglakeConfiguration
9984 9985 9986 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9984 def biglake_configuration @biglake_configuration end |
#clone_definition ⇒ Google::Apis::BigqueryV2::CloneDefinition
Information about base table and clone time of a table clone.
Corresponds to the JSON property cloneDefinition
9989 9990 9991 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9989 def clone_definition @clone_definition end |
#clustering ⇒ Google::Apis::BigqueryV2::Clustering
Configures table clustering.
Corresponds to the JSON property clustering
9994 9995 9996 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 9994 def clustering @clustering end |
#creation_time ⇒ Fixnum
Output only. The time when this table was created, in milliseconds since the
epoch.
Corresponds to the JSON property creationTime
10000 10001 10002 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10000 def creation_time @creation_time end |
#default_collation ⇒ String
Optional. Defines the default collation specification of new STRING fields in
the table. During table creation or update, if a STRING field is added to this
table without explicit collation specified, then the table inherits the table
default collation. A change to this field affects only fields added afterwards,
and does not alter the existing fields. The following values are supported: *
'und:ci': undetermined locale, case insensitive. * '': empty string. Default
to case-sensitive behavior.
Corresponds to the JSON property defaultCollation
10011 10012 10013 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10011 def default_collation @default_collation end |
#default_rounding_mode ⇒ String
Optional. Defines the default rounding mode specification of new decimal
fields (NUMERIC OR BIGNUMERIC) in the table. During table creation or update,
if a decimal field is added to this table without an explicit rounding mode
specified, then the field inherits the table default rounding mode. Changing
this field doesn't affect existing fields.
Corresponds to the JSON property defaultRoundingMode
10020 10021 10022 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10020 def default_rounding_mode @default_rounding_mode end |
#description ⇒ String
Optional. A user-friendly description of this table.
Corresponds to the JSON property description
10025 10026 10027 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10025 def description @description end |
#encryption_configuration ⇒ Google::Apis::BigqueryV2::EncryptionConfiguration
Configuration for Cloud KMS encryption settings.
Corresponds to the JSON property encryptionConfiguration
10030 10031 10032 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10030 def encryption_configuration @encryption_configuration end |
#etag ⇒ String
Output only. A hash of this resource.
Corresponds to the JSON property etag
10035 10036 10037 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10035 def etag @etag end |
#expiration_time ⇒ Fixnum
Optional. The time when this table expires, in milliseconds since the epoch.
If not present, the table will persist indefinitely. Expired tables will be
deleted and their storage reclaimed. The defaultTableExpirationMs property of
the encapsulating dataset can be used to set a default expirationTime on newly
created tables.
Corresponds to the JSON property expirationTime
10044 10045 10046 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10044 def expiration_time @expiration_time end |
#external_catalog_table_options ⇒ Google::Apis::BigqueryV2::ExternalCatalogTableOptions
Metadata about open source compatible table. The fields contained in these
options correspond to Hive metastore's table-level properties.
Corresponds to the JSON property externalCatalogTableOptions
10050 10051 10052 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10050 def @external_catalog_table_options end |
#external_data_configuration ⇒ Google::Apis::BigqueryV2::ExternalDataConfiguration
Optional. Describes the data format, location, and other properties of a table
stored outside of BigQuery. By defining these properties, the data source can
then be queried as if it were a standard BigQuery table.
Corresponds to the JSON property externalDataConfiguration
10057 10058 10059 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10057 def external_data_configuration @external_data_configuration end |
#friendly_name ⇒ String
Optional. A descriptive name for this table.
Corresponds to the JSON property friendlyName
10062 10063 10064 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10062 def friendly_name @friendly_name end |
#id ⇒ String
Output only. An opaque ID uniquely identifying the table.
Corresponds to the JSON property id
10067 10068 10069 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10067 def id @id end |
#kind ⇒ String
The type of resource ID.
Corresponds to the JSON property kind
10072 10073 10074 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10072 def kind @kind end |
#labels ⇒ Hash<String,String>
The labels associated with this table. You can use these to organize and group
your tables. Label keys and values can be no longer than 63 characters, can
only contain lowercase letters, numeric characters, underscores and dashes.
International characters are allowed. Label values are optional. Label keys
must start with a letter and each label in the list must have a different key.
Corresponds to the JSON property labels
10081 10082 10083 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10081 def labels @labels end |
#last_modified_time ⇒ Fixnum
Output only. The time when this table was last modified, in milliseconds since
the epoch.
Corresponds to the JSON property lastModifiedTime
10087 10088 10089 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10087 def last_modified_time @last_modified_time end |
#location ⇒ String
Output only. The geographic location where the table resides. This value is
inherited from the dataset.
Corresponds to the JSON property location
10093 10094 10095 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10093 def location @location end |
#managed_table_type ⇒ String
Optional. If set, overrides the default managed table type configured in the
dataset.
Corresponds to the JSON property managedTableType
10099 10100 10101 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10099 def managed_table_type @managed_table_type end |
#materialized_view ⇒ Google::Apis::BigqueryV2::MaterializedViewDefinition
Definition and configuration of a materialized view.
Corresponds to the JSON property materializedView
10104 10105 10106 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10104 def materialized_view @materialized_view end |
#materialized_view_status ⇒ Google::Apis::BigqueryV2::MaterializedViewStatus
Status of a materialized view. The last refresh timestamp status is omitted
here, but is present in the MaterializedViewDefinition message.
Corresponds to the JSON property materializedViewStatus
10110 10111 10112 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10110 def materialized_view_status @materialized_view_status end |
#max_staleness ⇒ String
Optional. The maximum staleness of data that could be returned when the table (
or stale MV) is queried. Staleness encoded as a string encoding of sql
IntervalValue type.
Corresponds to the JSON property maxStaleness
10117 10118 10119 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10117 def max_staleness @max_staleness end |
#model ⇒ Google::Apis::BigqueryV2::ModelDefinition
Deprecated.
Corresponds to the JSON property model
10122 10123 10124 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10122 def model @model end |
#num_active_logical_bytes ⇒ Fixnum
Output only. Number of logical bytes that are less than 90 days old.
Corresponds to the JSON property numActiveLogicalBytes
10127 10128 10129 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10127 def num_active_logical_bytes @num_active_logical_bytes end |
#num_active_physical_bytes ⇒ Fixnum
Output only. Number of physical bytes less than 90 days old. This data is not
kept in real time, and might be delayed by a few seconds to a few minutes.
Corresponds to the JSON property numActivePhysicalBytes
10133 10134 10135 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10133 def num_active_physical_bytes @num_active_physical_bytes end |
#num_bytes ⇒ Fixnum
Output only. The size of this table in logical bytes, excluding any data in
the streaming buffer.
Corresponds to the JSON property numBytes
10139 10140 10141 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10139 def num_bytes @num_bytes end |
#num_current_physical_bytes ⇒ Fixnum
Output only. Number of physical bytes used by current live data storage. This
data is not kept in real time, and might be delayed by a few seconds to a few
minutes.
Corresponds to the JSON property numCurrentPhysicalBytes
10146 10147 10148 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10146 def num_current_physical_bytes @num_current_physical_bytes end |
#num_long_term_bytes ⇒ Fixnum
Output only. The number of logical bytes in the table that are considered "
long-term storage".
Corresponds to the JSON property numLongTermBytes
10152 10153 10154 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10152 def num_long_term_bytes @num_long_term_bytes end |
#num_long_term_logical_bytes ⇒ Fixnum
Output only. Number of logical bytes that are more than 90 days old.
Corresponds to the JSON property numLongTermLogicalBytes
10157 10158 10159 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10157 def num_long_term_logical_bytes @num_long_term_logical_bytes end |
#num_long_term_physical_bytes ⇒ Fixnum
Output only. Number of physical bytes more than 90 days old. This data is not
kept in real time, and might be delayed by a few seconds to a few minutes.
Corresponds to the JSON property numLongTermPhysicalBytes
10163 10164 10165 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10163 def num_long_term_physical_bytes @num_long_term_physical_bytes end |
#num_partitions ⇒ Fixnum
Output only. The number of partitions present in the table or materialized
view. This data is not kept in real time, and might be delayed by a few
seconds to a few minutes.
Corresponds to the JSON property numPartitions
10170 10171 10172 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10170 def num_partitions @num_partitions end |
#num_physical_bytes ⇒ Fixnum
Output only. The physical size of this table in bytes. This includes storage
used for time travel.
Corresponds to the JSON property numPhysicalBytes
10176 10177 10178 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10176 def num_physical_bytes @num_physical_bytes end |
#num_rows ⇒ Fixnum
Output only. The number of rows of data in this table, excluding any data in
the streaming buffer.
Corresponds to the JSON property numRows
10182 10183 10184 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10182 def num_rows @num_rows end |
#num_time_travel_physical_bytes ⇒ Fixnum
Output only. Number of physical bytes used by time travel storage (deleted or
changed data). This data is not kept in real time, and might be delayed by a
few seconds to a few minutes.
Corresponds to the JSON property numTimeTravelPhysicalBytes
10189 10190 10191 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10189 def num_time_travel_physical_bytes @num_time_travel_physical_bytes end |
#num_total_logical_bytes ⇒ Fixnum
Output only. Total number of logical bytes in the table or materialized view.
Corresponds to the JSON property numTotalLogicalBytes
10194 10195 10196 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10194 def num_total_logical_bytes @num_total_logical_bytes end |
#num_total_physical_bytes ⇒ Fixnum
Output only. The physical size of this table in bytes. This also includes
storage used for time travel. This data is not kept in real time, and might be
delayed by a few seconds to a few minutes.
Corresponds to the JSON property numTotalPhysicalBytes
10201 10202 10203 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10201 def num_total_physical_bytes @num_total_physical_bytes end |
#partition_definition ⇒ Google::Apis::BigqueryV2::PartitioningDefinition
The partitioning information, which includes managed table, external table and
metastore partitioned table partition information.
Corresponds to the JSON property partitionDefinition
10207 10208 10209 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10207 def partition_definition @partition_definition end |
#range_partitioning ⇒ Google::Apis::BigqueryV2::RangePartitioning
If specified, configures range partitioning for this table.
Corresponds to the JSON property rangePartitioning
10212 10213 10214 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10212 def range_partitioning @range_partitioning end |
#replicas ⇒ Array<Google::Apis::BigqueryV2::TableReference>
Optional. Output only. Table references of all replicas currently active on
the table.
Corresponds to the JSON property replicas
10218 10219 10220 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10218 def replicas @replicas end |
#require_partition_filter ⇒ Boolean Also known as: require_partition_filter?
Optional. If set to true, queries over this table require a partition filter
that can be used for partition elimination to be specified.
Corresponds to the JSON property requirePartitionFilter
10224 10225 10226 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10224 def require_partition_filter @require_partition_filter end |
#resource_tags ⇒ Hash<String,String>
[Optional] The tags associated with this table. Tag keys are globally unique.
See additional information on tags. An object containing a list of "key": value pairs.
The key is the namespaced friendly name of the tag key, e.g. "12345/
environment" where 12345 is parent id. The value is the friendly short name of
the tag value, e.g. "production".
Corresponds to the JSON property resourceTags
10235 10236 10237 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10235 def @resource_tags end |
#restrictions ⇒ Google::Apis::BigqueryV2::RestrictionConfig
Optional. Output only. Restriction config for table. If set, restrict certain
accesses on the table based on the config. See Data egress for more
details.
Corresponds to the JSON property restrictions
10243 10244 10245 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10243 def restrictions @restrictions end |
#schema ⇒ Google::Apis::BigqueryV2::TableSchema
Schema of a table
Corresponds to the JSON property schema
10248 10249 10250 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10248 def schema @schema end |
#self_link ⇒ String
Output only. A URL that can be used to access this resource again.
Corresponds to the JSON property selfLink
10253 10254 10255 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10253 def self_link @self_link end |
#snapshot_definition ⇒ Google::Apis::BigqueryV2::SnapshotDefinition
Information about base table and snapshot time of the snapshot.
Corresponds to the JSON property snapshotDefinition
10258 10259 10260 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10258 def snapshot_definition @snapshot_definition end |
#streaming_buffer ⇒ Google::Apis::BigqueryV2::Streamingbuffer
Output only. Contains information regarding this table's streaming buffer, if
one is present. This field will be absent if the table is not being streamed
to or if there is no data in the streaming buffer.
Corresponds to the JSON property streamingBuffer
10265 10266 10267 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10265 def streaming_buffer @streaming_buffer end |
#table_constraints ⇒ Google::Apis::BigqueryV2::TableConstraints
The TableConstraints defines the primary key and foreign key.
Corresponds to the JSON property tableConstraints
10270 10271 10272 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10270 def table_constraints @table_constraints end |
#table_reference ⇒ Google::Apis::BigqueryV2::TableReference
Required. Reference describing the ID of this table.
Corresponds to the JSON property tableReference
10275 10276 10277 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10275 def table_reference @table_reference end |
#table_replication_info ⇒ Google::Apis::BigqueryV2::TableReplicationInfo
Replication info of a table created using AS REPLICA DDL like: CREATE
MATERIALIZED VIEW mv1 AS REPLICA OF src_mv
Corresponds to the JSON property tableReplicationInfo
10281 10282 10283 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10281 def table_replication_info @table_replication_info end |
#time_partitioning ⇒ Google::Apis::BigqueryV2::TimePartitioning
If specified, configures time-based partitioning for this table.
Corresponds to the JSON property timePartitioning
10286 10287 10288 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10286 def time_partitioning @time_partitioning end |
#type ⇒ String
Output only. Describes the table type. The following values are supported: *
TABLE: A normal BigQuery table. * VIEW: A virtual table defined by a SQL
query. * EXTERNAL: A table that references data stored in an external
storage system, such as Google Cloud Storage. * MATERIALIZED_VIEW: A
precomputed view defined by a SQL query. * SNAPSHOT: An immutable BigQuery
table that preserves the contents of a base table at a particular time. See
additional information on table snapshots. The default value is TABLE.
Corresponds to the JSON property type
10298 10299 10300 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10298 def type @type end |
#view ⇒ Google::Apis::BigqueryV2::ViewDefinition
Describes the definition of a logical view.
Corresponds to the JSON property view
10303 10304 10305 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10303 def view @view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10310 10311 10312 10313 10314 10315 10316 10317 10318 10319 10320 10321 10322 10323 10324 10325 10326 10327 10328 10329 10330 10331 10332 10333 10334 10335 10336 10337 10338 10339 10340 10341 10342 10343 10344 10345 10346 10347 10348 10349 10350 10351 10352 10353 10354 10355 10356 10357 10358 10359 10360 10361 10362 10363 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10310 def update!(**args) @biglake_configuration = args[:biglake_configuration] if args.key?(:biglake_configuration) @clone_definition = args[:clone_definition] if args.key?(:clone_definition) @clustering = args[:clustering] if args.key?(:clustering) @creation_time = args[:creation_time] if args.key?(:creation_time) @default_collation = args[:default_collation] if args.key?(:default_collation) @default_rounding_mode = args[:default_rounding_mode] if args.key?(:default_rounding_mode) @description = args[:description] if args.key?(:description) @encryption_configuration = args[:encryption_configuration] if args.key?(:encryption_configuration) @etag = args[:etag] if args.key?(:etag) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @external_catalog_table_options = args[:external_catalog_table_options] if args.key?(:external_catalog_table_options) @external_data_configuration = args[:external_data_configuration] if args.key?(:external_data_configuration) @friendly_name = args[:friendly_name] if args.key?(:friendly_name) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @labels = args[:labels] if args.key?(:labels) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @location = args[:location] if args.key?(:location) @managed_table_type = args[:managed_table_type] if args.key?(:managed_table_type) @materialized_view = args[:materialized_view] if args.key?(:materialized_view) @materialized_view_status = args[:materialized_view_status] if args.key?(:materialized_view_status) @max_staleness = args[:max_staleness] if args.key?(:max_staleness) @model = args[:model] if args.key?(:model) @num_active_logical_bytes = args[:num_active_logical_bytes] if args.key?(:num_active_logical_bytes) @num_active_physical_bytes = args[:num_active_physical_bytes] if args.key?(:num_active_physical_bytes) @num_bytes = args[:num_bytes] if args.key?(:num_bytes) @num_current_physical_bytes = args[:num_current_physical_bytes] if args.key?(:num_current_physical_bytes) @num_long_term_bytes = args[:num_long_term_bytes] if args.key?(:num_long_term_bytes) @num_long_term_logical_bytes = args[:num_long_term_logical_bytes] if args.key?(:num_long_term_logical_bytes) @num_long_term_physical_bytes = args[:num_long_term_physical_bytes] if args.key?(:num_long_term_physical_bytes) @num_partitions = args[:num_partitions] if args.key?(:num_partitions) @num_physical_bytes = args[:num_physical_bytes] if args.key?(:num_physical_bytes) @num_rows = args[:num_rows] if args.key?(:num_rows) @num_time_travel_physical_bytes = args[:num_time_travel_physical_bytes] if args.key?(:num_time_travel_physical_bytes) @num_total_logical_bytes = args[:num_total_logical_bytes] if args.key?(:num_total_logical_bytes) @num_total_physical_bytes = args[:num_total_physical_bytes] if args.key?(:num_total_physical_bytes) @partition_definition = args[:partition_definition] if args.key?(:partition_definition) @range_partitioning = args[:range_partitioning] if args.key?(:range_partitioning) @replicas = args[:replicas] if args.key?(:replicas) @require_partition_filter = args[:require_partition_filter] if args.key?(:require_partition_filter) @resource_tags = args[:resource_tags] if args.key?(:resource_tags) @restrictions = args[:restrictions] if args.key?(:restrictions) @schema = args[:schema] if args.key?(:schema) @self_link = args[:self_link] if args.key?(:self_link) @snapshot_definition = args[:snapshot_definition] if args.key?(:snapshot_definition) @streaming_buffer = args[:streaming_buffer] if args.key?(:streaming_buffer) @table_constraints = args[:table_constraints] if args.key?(:table_constraints) @table_reference = args[:table_reference] if args.key?(:table_reference) @table_replication_info = args[:table_replication_info] if args.key?(:table_replication_info) @time_partitioning = args[:time_partitioning] if args.key?(:time_partitioning) @type = args[:type] if args.key?(:type) @view = args[:view] if args.key?(:view) end |