Class: Google::Apis::BigqueryV2::TableChangeInsight

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Table-level performance insights compared to previous runs. These insights don' t apply to specific query stages, rather they apply to the whole table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TableChangeInsight

Returns a new instance of TableChangeInsight.



10862
10863
10864
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metadata_cache_not_used_but_used_previouslyBoolean Also known as: metadata_cache_not_used_but_used_previously?

Output only. True if the table's column metadata index was not used in the current job, but was used in a previous job with the same query hash. Corresponds to the JSON property metadataCacheNotUsedButUsedPreviously

Returns:

  • (Boolean)


10849
10850
10851
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10849

def 
  @metadata_cache_not_used_but_used_previously
end

#metadata_cache_staleness_insightGoogle::Apis::BigqueryV2::MetadataCacheStalenessInsight

Column Metadata Index staleness detailed infnormation. Corresponds to the JSON property metadataCacheStalenessInsight



10855
10856
10857
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10855

def 
  @metadata_cache_staleness_insight
end

#table_referenceGoogle::Apis::BigqueryV2::TableReference

Output only. The table that was queried. Corresponds to the JSON property tableReference



10860
10861
10862
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10860

def table_reference
  @table_reference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10867
10868
10869
10870
10871
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10867

def update!(**args)
  @metadata_cache_not_used_but_used_previously = args[:metadata_cache_not_used_but_used_previously] if args.key?(:metadata_cache_not_used_but_used_previously)
  @metadata_cache_staleness_insight = args[:metadata_cache_staleness_insight] if args.key?(:metadata_cache_staleness_insight)
  @table_reference = args[:table_reference] if args.key?(:table_reference)
end