Class: Google::Apis::BigqueryV2::TableFieldSchema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

A field in TableSchema

Defined Under Namespace

Classes: Categories, DataGovernanceTagsInfo, PolicyTags, RangeElementType

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TableFieldSchema

Returns a new instance of TableFieldSchema.



11351
11352
11353
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesGoogle::Apis::BigqueryV2::TableFieldSchema::Categories

Deprecated. Corresponds to the JSON property categories



11204
11205
11206
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11204

def categories
  @categories
end

#collationString

Optional. Field collation can be set only when the type of field is STRING. The following values are supported: * 'und:ci': undetermined locale, case insensitive. * '': empty string. Default to case-sensitive behavior. Corresponds to the JSON property collation

Returns:

  • (String)


11211
11212
11213
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11211

def collation
  @collation
end

#data_governance_tags_infoGoogle::Apis::BigqueryV2::TableFieldSchema::DataGovernanceTagsInfo

Optional. Specifies the data governance tags on this field. This field works with other column-level security fields as follows: - Precedence: If a data governance tag is attached to a column, it takes precedence over the policy tag attached to the column. However, if a data policy is attached to a column, it takes precedence over the data governance tag. - Patching behavior (how this field behaves during a Table.patch schema update): - Unset: If the data_governance_tags_info field is omitted from the update request, the existing tags on the column are preserved. - Empty Field: To clear data governance tags from a column, send the data_governance_tags_info field as an empty object. This will remove all tags from the column. - Updating tags: To replace existing tag, send the field with the new tag. Corresponds to the JSON property dataGovernanceTagsInfo



11226
11227
11228
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11226

def data_governance_tags_info
  @data_governance_tags_info
end

#data_policiesArray<Google::Apis::BigqueryV2::DataPolicyOption>

Optional. Data policies attached to this field, used for field-level access control. Corresponds to the JSON property dataPolicies



11232
11233
11234
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11232

def data_policies
  @data_policies
end

#data_policy_listGoogle::Apis::BigqueryV2::DataPolicyList

A list of data policy options. For more information, see Mask data by applying data policies to a column. Corresponds to the JSON property dataPolicyList



11239
11240
11241
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11239

def data_policy_list
  @data_policy_list
end

#default_value_expressionString

Optional. A SQL expression to specify the default value for this field. Corresponds to the JSON property defaultValueExpression

Returns:

  • (String)


11245
11246
11247
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11245

def default_value_expression
  @default_value_expression
end

#descriptionString

Optional. The field description. The maximum length is 1,024 characters. Corresponds to the JSON property description

Returns:

  • (String)


11250
11251
11252
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11250

def description
  @description
end

#fieldsArray<Google::Apis::BigqueryV2::TableFieldSchema>

Optional. Describes the nested schema fields if the type property is set to RECORD. Corresponds to the JSON property fields



11256
11257
11258
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11256

def fields
  @fields
end

#foreign_type_definitionString

Optional. Definition of the foreign data type. Only valid for top-level schema fields (not nested fields). If the type is FOREIGN, this field is required. Corresponds to the JSON property foreignTypeDefinition

Returns:

  • (String)


11262
11263
11264
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11262

def foreign_type_definition
  @foreign_type_definition
end

#generated_columnGoogle::Apis::BigqueryV2::GeneratedColumn

Optional. Definition of how values are generated for the field. Only valid for top-level schema fields (not nested fields). Corresponds to the JSON property generatedColumn



11268
11269
11270
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11268

def generated_column
  @generated_column
end

#max_lengthFixnum

Optional. Maximum length of values of this field for STRINGS or BYTES. If max_length is not specified, no maximum length constraint is imposed on this field. If type = "STRING", then max_length represents the maximum UTF-8 length of strings in this field. If type = "BYTES", then max_length represents the maximum number of bytes in this field. It is invalid to set this field if type ≠ "STRING" and ≠ "BYTES". Corresponds to the JSON property maxLength

Returns:

  • (Fixnum)


11278
11279
11280
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11278

def max_length
  @max_length
end

#modeString

Optional. The field mode. Possible values include NULLABLE, REQUIRED and REPEATED. The default value is NULLABLE. Corresponds to the JSON property mode

Returns:

  • (String)


11284
11285
11286
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11284

def mode
  @mode
end

#nameString

Required. The field name. The name must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_), and must start with a letter or underscore. The maximum length is 300 characters. Corresponds to the JSON property name

Returns:

  • (String)


11291
11292
11293
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11291

def name
  @name
end

#policy_tagsGoogle::Apis::BigqueryV2::TableFieldSchema::PolicyTags

Optional. The policy tags attached to this field, used for field-level access control. If not set, defaults to empty policy_tags. Corresponds to the JSON property policyTags



11297
11298
11299
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11297

def policy_tags
  @policy_tags
end

#precisionFixnum

Optional. Precision (maximum number of total digits in base 10) and scale ( maximum number of digits in the fractional part in base 10) constraints for values of this field for NUMERIC or BIGNUMERIC. It is invalid to set precision or scale if type ≠ "NUMERIC" and ≠ "BIGNUMERIC". If precision and scale are not specified, no value range constraint is imposed on this field insofar as values are permitted by the type. Values of this NUMERIC or BIGNUMERIC field must be in this range when: * Precision (P) and scale (S) are specified: [-10P- S + 10-S, 10P-S - 10-S] * Precision (P) is specified but not scale (and thus scale is interpreted to be equal to zero): [-10P + 1, 10P - 1]. Acceptable values for precision and scale if both are specified: * If type = "NUMERIC": 1 ≤ precision - scale ≤ 29 and 0 ≤ scale ≤ 9. * If type = "BIGNUMERIC": 1 ≤ precision - scale ≤ 38 and 0 ≤ scale ≤ 38. Acceptable values for precision if only precision is specified but not scale (and thus scale is interpreted to be equal to zero): * If type = "NUMERIC": 1 ≤ precision ≤ 29. * If type = " BIGNUMERIC": 1 ≤ precision ≤ 38. If scale is specified but not precision, then it is invalid. Corresponds to the JSON property precision

Returns:

  • (Fixnum)


11317
11318
11319
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11317

def precision
  @precision
end

#range_element_typeGoogle::Apis::BigqueryV2::TableFieldSchema::RangeElementType

Represents the type of a field element. Corresponds to the JSON property rangeElementType



11322
11323
11324
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11322

def range_element_type
  @range_element_type
end

#rounding_modeString

Optional. Specifies the rounding mode to be used when storing values of NUMERIC and BIGNUMERIC type. Corresponds to the JSON property roundingMode

Returns:

  • (String)


11328
11329
11330
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11328

def rounding_mode
  @rounding_mode
end

#scaleFixnum

Optional. See documentation for precision. Corresponds to the JSON property scale

Returns:

  • (Fixnum)


11333
11334
11335
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11333

def scale
  @scale
end

#timestamp_precisionFixnum

Optional. Precision (maximum number of total digits in base 10) for seconds of TIMESTAMP type. Possible values include: * 6 (Default, for TIMESTAMP type with microsecond precision) * 12 (For TIMESTAMP type with picosecond precision) Corresponds to the JSON property timestampPrecision

Returns:

  • (Fixnum)


11340
11341
11342
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11340

def timestamp_precision
  @timestamp_precision
end

#typeString

Required. The field data type. Possible values include: * STRING * BYTES * INTEGER (or INT64) * FLOAT (or FLOAT64) * BOOLEAN (or BOOL) * TIMESTAMP * DATE

  • TIME * DATETIME * GEOGRAPHY * NUMERIC * BIGNUMERIC * JSON * RECORD (or STRUCT) * RANGE Use of RECORD/STRUCT indicates that the field contains a nested schema. Corresponds to the JSON property type

Returns:

  • (String)


11349
11350
11351
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11349

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11356
11357
11358
11359
11360
11361
11362
11363
11364
11365
11366
11367
11368
11369
11370
11371
11372
11373
11374
11375
11376
11377
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11356

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @collation = args[:collation] if args.key?(:collation)
  @data_governance_tags_info = args[:data_governance_tags_info] if args.key?(:data_governance_tags_info)
  @data_policies = args[:data_policies] if args.key?(:data_policies)
  @data_policy_list = args[:data_policy_list] if args.key?(:data_policy_list)
  @default_value_expression = args[:default_value_expression] if args.key?(:default_value_expression)
  @description = args[:description] if args.key?(:description)
  @fields = args[:fields] if args.key?(:fields)
  @foreign_type_definition = args[:foreign_type_definition] if args.key?(:foreign_type_definition)
  @generated_column = args[:generated_column] if args.key?(:generated_column)
  @max_length = args[:max_length] if args.key?(:max_length)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @policy_tags = args[:policy_tags] if args.key?(:policy_tags)
  @precision = args[:precision] if args.key?(:precision)
  @range_element_type = args[:range_element_type] if args.key?(:range_element_type)
  @rounding_mode = args[:rounding_mode] if args.key?(:rounding_mode)
  @scale = args[:scale] if args.key?(:scale)
  @timestamp_precision = args[:timestamp_precision] if args.key?(:timestamp_precision)
  @type = args[:type] if args.key?(:type)
end