Class: Google::Apis::BigqueryV2::TableList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Partial projection of the metadata for a given table in a list response.

Defined Under Namespace

Classes: Table

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TableList

Returns a new instance of TableList.



10944
10945
10946
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

A hash of this page of results. Corresponds to the JSON property etag

Returns:

  • (String)


10922
10923
10924
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10922

def etag
  @etag
end

#kindString

The type of list. Corresponds to the JSON property kind

Returns:

  • (String)


10927
10928
10929
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10927

def kind
  @kind
end

#next_page_tokenString

A token to request the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10932
10933
10934
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10932

def next_page_token
  @next_page_token
end

#tablesArray<Google::Apis::BigqueryV2::TableList::Table>

Tables in the requested dataset. Corresponds to the JSON property tables



10937
10938
10939
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10937

def tables
  @tables
end

#total_itemsFixnum

The total number of tables in the dataset. Corresponds to the JSON property totalItems

Returns:

  • (Fixnum)


10942
10943
10944
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10942

def total_items
  @total_items
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10949
10950
10951
10952
10953
10954
10955
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10949

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @tables = args[:tables] if args.key?(:tables)
  @total_items = args[:total_items] if args.key?(:total_items)
end