Class: Google::Apis::BigqueryV2::TableList::Table
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::TableList::Table
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Defined Under Namespace
Classes: View
Instance Attribute Summary collapse
-
#clustering ⇒ Google::Apis::BigqueryV2::Clustering
Configures table clustering.
-
#creation_time ⇒ Fixnum
Output only.
-
#expiration_time ⇒ Fixnum
The time when this table expires, in milliseconds since the epoch.
-
#friendly_name ⇒ String
The user-friendly name for this table.
-
#id ⇒ String
An opaque ID of the table.
-
#kind ⇒ String
The resource type.
-
#labels ⇒ Hash<String,String>
The labels associated with this table.
-
#range_partitioning ⇒ Google::Apis::BigqueryV2::RangePartitioning
The range partitioning for this table.
-
#require_partition_filter ⇒ Boolean
(also: #require_partition_filter?)
Optional.
-
#table_reference ⇒ Google::Apis::BigqueryV2::TableReference
A reference uniquely identifying table.
-
#time_partitioning ⇒ Google::Apis::BigqueryV2::TimePartitioning
The time-based partitioning for this table.
-
#type ⇒ String
The type of table.
-
#view ⇒ Google::Apis::BigqueryV2::TableList::Table::View
Information about a logical view.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Table
constructor
A new instance of Table.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Table
Returns a new instance of Table.
11779 11780 11781 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11779 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clustering ⇒ Google::Apis::BigqueryV2::Clustering
Configures table clustering.
Corresponds to the JSON property clustering
11711 11712 11713 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11711 def clustering @clustering end |
#creation_time ⇒ Fixnum
Output only. The time when this table was created, in milliseconds since the
epoch.
Corresponds to the JSON property creationTime
11717 11718 11719 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11717 def creation_time @creation_time end |
#expiration_time ⇒ Fixnum
The time when this table expires, in milliseconds since the epoch. If not
present, the table will persist indefinitely. Expired tables will be deleted
and their storage reclaimed.
Corresponds to the JSON property expirationTime
11724 11725 11726 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11724 def expiration_time @expiration_time end |
#friendly_name ⇒ String
The user-friendly name for this table.
Corresponds to the JSON property friendlyName
11729 11730 11731 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11729 def friendly_name @friendly_name end |
#id ⇒ String
An opaque ID of the table.
Corresponds to the JSON property id
11734 11735 11736 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11734 def id @id end |
#kind ⇒ String
The resource type.
Corresponds to the JSON property kind
11739 11740 11741 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11739 def kind @kind end |
#labels ⇒ Hash<String,String>
The labels associated with this table. You can use these to organize and group
your tables.
Corresponds to the JSON property labels
11745 11746 11747 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11745 def labels @labels end |
#range_partitioning ⇒ Google::Apis::BigqueryV2::RangePartitioning
The range partitioning for this table.
Corresponds to the JSON property rangePartitioning
11750 11751 11752 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11750 def range_partitioning @range_partitioning end |
#require_partition_filter ⇒ Boolean Also known as: require_partition_filter?
Optional. If set to true, queries including this table must specify a
partition filter. This filter is used for partition elimination.
Corresponds to the JSON property requirePartitionFilter
11756 11757 11758 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11756 def require_partition_filter @require_partition_filter end |
#table_reference ⇒ Google::Apis::BigqueryV2::TableReference
A reference uniquely identifying table.
Corresponds to the JSON property tableReference
11762 11763 11764 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11762 def table_reference @table_reference end |
#time_partitioning ⇒ Google::Apis::BigqueryV2::TimePartitioning
The time-based partitioning for this table.
Corresponds to the JSON property timePartitioning
11767 11768 11769 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11767 def time_partitioning @time_partitioning end |
#type ⇒ String
The type of table.
Corresponds to the JSON property type
11772 11773 11774 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11772 def type @type end |
#view ⇒ Google::Apis::BigqueryV2::TableList::Table::View
Information about a logical view.
Corresponds to the JSON property view
11777 11778 11779 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11777 def view @view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11784 11785 11786 11787 11788 11789 11790 11791 11792 11793 11794 11795 11796 11797 11798 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11784 def update!(**args) @clustering = args[:clustering] if args.key?(:clustering) @creation_time = args[:creation_time] if args.key?(:creation_time) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @friendly_name = args[:friendly_name] if args.key?(:friendly_name) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @labels = args[:labels] if args.key?(:labels) @range_partitioning = args[:range_partitioning] if args.key?(:range_partitioning) @require_partition_filter = args[:require_partition_filter] if args.key?(:require_partition_filter) @table_reference = args[:table_reference] if args.key?(:table_reference) @time_partitioning = args[:time_partitioning] if args.key?(:time_partitioning) @type = args[:type] if args.key?(:type) @view = args[:view] if args.key?(:view) end |