Class: Google::Apis::BigqueryV2::TableList::Table

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Defined Under Namespace

Classes: View

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Table

Returns a new instance of Table.



11589
11590
11591
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusteringGoogle::Apis::BigqueryV2::Clustering

Configures table clustering. Corresponds to the JSON property clustering



11521
11522
11523
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11521

def clustering
  @clustering
end

#creation_timeFixnum

Output only. The time when this table was created, in milliseconds since the epoch. Corresponds to the JSON property creationTime

Returns:

  • (Fixnum)


11527
11528
11529
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11527

def creation_time
  @creation_time
end

#expiration_timeFixnum

The time when this table expires, in milliseconds since the epoch. If not present, the table will persist indefinitely. Expired tables will be deleted and their storage reclaimed. Corresponds to the JSON property expirationTime

Returns:

  • (Fixnum)


11534
11535
11536
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11534

def expiration_time
  @expiration_time
end

#friendly_nameString

The user-friendly name for this table. Corresponds to the JSON property friendlyName

Returns:

  • (String)


11539
11540
11541
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11539

def friendly_name
  @friendly_name
end

#idString

An opaque ID of the table. Corresponds to the JSON property id

Returns:

  • (String)


11544
11545
11546
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11544

def id
  @id
end

#kindString

The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


11549
11550
11551
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11549

def kind
  @kind
end

#labelsHash<String,String>

The labels associated with this table. You can use these to organize and group your tables. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


11555
11556
11557
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11555

def labels
  @labels
end

#range_partitioningGoogle::Apis::BigqueryV2::RangePartitioning

The range partitioning for this table. Corresponds to the JSON property rangePartitioning



11560
11561
11562
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11560

def range_partitioning
  @range_partitioning
end

#require_partition_filterBoolean Also known as: require_partition_filter?

Optional. If set to true, queries including this table must specify a partition filter. This filter is used for partition elimination. Corresponds to the JSON property requirePartitionFilter

Returns:

  • (Boolean)


11566
11567
11568
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11566

def require_partition_filter
  @require_partition_filter
end

#table_referenceGoogle::Apis::BigqueryV2::TableReference

A reference uniquely identifying table. Corresponds to the JSON property tableReference



11572
11573
11574
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11572

def table_reference
  @table_reference
end

#time_partitioningGoogle::Apis::BigqueryV2::TimePartitioning

The time-based partitioning for this table. Corresponds to the JSON property timePartitioning



11577
11578
11579
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11577

def time_partitioning
  @time_partitioning
end

#typeString

The type of table. Corresponds to the JSON property type

Returns:

  • (String)


11582
11583
11584
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11582

def type
  @type
end

#viewGoogle::Apis::BigqueryV2::TableList::Table::View

Information about a logical view. Corresponds to the JSON property view



11587
11588
11589
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11587

def view
  @view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11594
11595
11596
11597
11598
11599
11600
11601
11602
11603
11604
11605
11606
11607
11608
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11594

def update!(**args)
  @clustering = args[:clustering] if args.key?(:clustering)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @friendly_name = args[:friendly_name] if args.key?(:friendly_name)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @labels = args[:labels] if args.key?(:labels)
  @range_partitioning = args[:range_partitioning] if args.key?(:range_partitioning)
  @require_partition_filter = args[:require_partition_filter] if args.key?(:require_partition_filter)
  @table_reference = args[:table_reference] if args.key?(:table_reference)
  @time_partitioning = args[:time_partitioning] if args.key?(:time_partitioning)
  @type = args[:type] if args.key?(:type)
  @view = args[:view] if args.key?(:view)
end