Class: Google::Apis::BigqueryV2::TableList::Table
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::TableList::Table
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Defined Under Namespace
Classes: View
Instance Attribute Summary collapse
-
#clustering ⇒ Google::Apis::BigqueryV2::Clustering
Configures table clustering.
-
#creation_time ⇒ Fixnum
Output only.
-
#expiration_time ⇒ Fixnum
The time when this table expires, in milliseconds since the epoch.
-
#friendly_name ⇒ String
The user-friendly name for this table.
-
#id ⇒ String
An opaque ID of the table.
-
#kind ⇒ String
The resource type.
-
#labels ⇒ Hash<String,String>
The labels associated with this table.
-
#range_partitioning ⇒ Google::Apis::BigqueryV2::RangePartitioning
The range partitioning for this table.
-
#require_partition_filter ⇒ Boolean
(also: #require_partition_filter?)
Optional.
-
#table_reference ⇒ Google::Apis::BigqueryV2::TableReference
A reference uniquely identifying table.
-
#time_partitioning ⇒ Google::Apis::BigqueryV2::TimePartitioning
The time-based partitioning for this table.
-
#type ⇒ String
The type of table.
-
#view ⇒ Google::Apis::BigqueryV2::TableList::Table::View
Information about a logical view.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Table
constructor
A new instance of Table.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Table
Returns a new instance of Table.
11406 11407 11408 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11406 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clustering ⇒ Google::Apis::BigqueryV2::Clustering
Configures table clustering.
Corresponds to the JSON property clustering
11338 11339 11340 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11338 def clustering @clustering end |
#creation_time ⇒ Fixnum
Output only. The time when this table was created, in milliseconds since the
epoch.
Corresponds to the JSON property creationTime
11344 11345 11346 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11344 def creation_time @creation_time end |
#expiration_time ⇒ Fixnum
The time when this table expires, in milliseconds since the epoch. If not
present, the table will persist indefinitely. Expired tables will be deleted
and their storage reclaimed.
Corresponds to the JSON property expirationTime
11351 11352 11353 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11351 def expiration_time @expiration_time end |
#friendly_name ⇒ String
The user-friendly name for this table.
Corresponds to the JSON property friendlyName
11356 11357 11358 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11356 def friendly_name @friendly_name end |
#id ⇒ String
An opaque ID of the table.
Corresponds to the JSON property id
11361 11362 11363 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11361 def id @id end |
#kind ⇒ String
The resource type.
Corresponds to the JSON property kind
11366 11367 11368 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11366 def kind @kind end |
#labels ⇒ Hash<String,String>
The labels associated with this table. You can use these to organize and group
your tables.
Corresponds to the JSON property labels
11372 11373 11374 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11372 def labels @labels end |
#range_partitioning ⇒ Google::Apis::BigqueryV2::RangePartitioning
The range partitioning for this table.
Corresponds to the JSON property rangePartitioning
11377 11378 11379 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11377 def range_partitioning @range_partitioning end |
#require_partition_filter ⇒ Boolean Also known as: require_partition_filter?
Optional. If set to true, queries including this table must specify a
partition filter. This filter is used for partition elimination.
Corresponds to the JSON property requirePartitionFilter
11383 11384 11385 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11383 def require_partition_filter @require_partition_filter end |
#table_reference ⇒ Google::Apis::BigqueryV2::TableReference
A reference uniquely identifying table.
Corresponds to the JSON property tableReference
11389 11390 11391 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11389 def table_reference @table_reference end |
#time_partitioning ⇒ Google::Apis::BigqueryV2::TimePartitioning
The time-based partitioning for this table.
Corresponds to the JSON property timePartitioning
11394 11395 11396 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11394 def time_partitioning @time_partitioning end |
#type ⇒ String
The type of table.
Corresponds to the JSON property type
11399 11400 11401 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11399 def type @type end |
#view ⇒ Google::Apis::BigqueryV2::TableList::Table::View
Information about a logical view.
Corresponds to the JSON property view
11404 11405 11406 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11404 def view @view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11411 def update!(**args) @clustering = args[:clustering] if args.key?(:clustering) @creation_time = args[:creation_time] if args.key?(:creation_time) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @friendly_name = args[:friendly_name] if args.key?(:friendly_name) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @labels = args[:labels] if args.key?(:labels) @range_partitioning = args[:range_partitioning] if args.key?(:range_partitioning) @require_partition_filter = args[:require_partition_filter] if args.key?(:require_partition_filter) @table_reference = args[:table_reference] if args.key?(:table_reference) @time_partitioning = args[:time_partitioning] if args.key?(:time_partitioning) @type = args[:type] if args.key?(:type) @view = args[:view] if args.key?(:view) end |