Class: Google::Apis::BigqueryV2::TableList::Table
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::TableList::Table
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Defined Under Namespace
Classes: View
Instance Attribute Summary collapse
-
#clustering ⇒ Google::Apis::BigqueryV2::Clustering
Configures table clustering.
-
#creation_time ⇒ Fixnum
Output only.
-
#expiration_time ⇒ Fixnum
The time when this table expires, in milliseconds since the epoch.
-
#friendly_name ⇒ String
The user-friendly name for this table.
-
#id ⇒ String
An opaque ID of the table.
-
#kind ⇒ String
The resource type.
-
#labels ⇒ Hash<String,String>
The labels associated with this table.
-
#range_partitioning ⇒ Google::Apis::BigqueryV2::RangePartitioning
The range partitioning for this table.
-
#require_partition_filter ⇒ Boolean
(also: #require_partition_filter?)
Optional.
-
#table_reference ⇒ Google::Apis::BigqueryV2::TableReference
A reference uniquely identifying table.
-
#time_partitioning ⇒ Google::Apis::BigqueryV2::TimePartitioning
The time-based partitioning for this table.
-
#type ⇒ String
The type of table.
-
#view ⇒ Google::Apis::BigqueryV2::TableList::Table::View
Information about a logical view.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Table
constructor
A new instance of Table.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Table
Returns a new instance of Table.
11032 11033 11034 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11032 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clustering ⇒ Google::Apis::BigqueryV2::Clustering
Configures table clustering.
Corresponds to the JSON property clustering
10964 10965 10966 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10964 def clustering @clustering end |
#creation_time ⇒ Fixnum
Output only. The time when this table was created, in milliseconds since the
epoch.
Corresponds to the JSON property creationTime
10970 10971 10972 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10970 def creation_time @creation_time end |
#expiration_time ⇒ Fixnum
The time when this table expires, in milliseconds since the epoch. If not
present, the table will persist indefinitely. Expired tables will be deleted
and their storage reclaimed.
Corresponds to the JSON property expirationTime
10977 10978 10979 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10977 def expiration_time @expiration_time end |
#friendly_name ⇒ String
The user-friendly name for this table.
Corresponds to the JSON property friendlyName
10982 10983 10984 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10982 def friendly_name @friendly_name end |
#id ⇒ String
An opaque ID of the table.
Corresponds to the JSON property id
10987 10988 10989 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10987 def id @id end |
#kind ⇒ String
The resource type.
Corresponds to the JSON property kind
10992 10993 10994 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10992 def kind @kind end |
#labels ⇒ Hash<String,String>
The labels associated with this table. You can use these to organize and group
your tables.
Corresponds to the JSON property labels
10998 10999 11000 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 10998 def labels @labels end |
#range_partitioning ⇒ Google::Apis::BigqueryV2::RangePartitioning
The range partitioning for this table.
Corresponds to the JSON property rangePartitioning
11003 11004 11005 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11003 def range_partitioning @range_partitioning end |
#require_partition_filter ⇒ Boolean Also known as: require_partition_filter?
Optional. If set to true, queries including this table must specify a
partition filter. This filter is used for partition elimination.
Corresponds to the JSON property requirePartitionFilter
11009 11010 11011 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11009 def require_partition_filter @require_partition_filter end |
#table_reference ⇒ Google::Apis::BigqueryV2::TableReference
A reference uniquely identifying table.
Corresponds to the JSON property tableReference
11015 11016 11017 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11015 def table_reference @table_reference end |
#time_partitioning ⇒ Google::Apis::BigqueryV2::TimePartitioning
The time-based partitioning for this table.
Corresponds to the JSON property timePartitioning
11020 11021 11022 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11020 def time_partitioning @time_partitioning end |
#type ⇒ String
The type of table.
Corresponds to the JSON property type
11025 11026 11027 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11025 def type @type end |
#view ⇒ Google::Apis::BigqueryV2::TableList::Table::View
Information about a logical view.
Corresponds to the JSON property view
11030 11031 11032 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11030 def view @view end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11037 11038 11039 11040 11041 11042 11043 11044 11045 11046 11047 11048 11049 11050 11051 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11037 def update!(**args) @clustering = args[:clustering] if args.key?(:clustering) @creation_time = args[:creation_time] if args.key?(:creation_time) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @friendly_name = args[:friendly_name] if args.key?(:friendly_name) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @labels = args[:labels] if args.key?(:labels) @range_partitioning = args[:range_partitioning] if args.key?(:range_partitioning) @require_partition_filter = args[:require_partition_filter] if args.key?(:require_partition_filter) @table_reference = args[:table_reference] if args.key?(:table_reference) @time_partitioning = args[:time_partitioning] if args.key?(:time_partitioning) @type = args[:type] if args.key?(:type) @view = args[:view] if args.key?(:view) end |