Class: Google::Apis::BigqueryV2::TableMetadataCacheUsage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Table level detail on the usage of metadata caching. Only set for Metadata caching eligible tables referenced in the query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TableMetadataCacheUsage

Returns a new instance of TableMetadataCacheUsage.



11797
11798
11799
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11797

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explanationString

Free form human-readable reason metadata caching was unused for the job. Corresponds to the JSON property explanation

Returns:

  • (String)


11768
11769
11770
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11768

def explanation
  @explanation
end

#pruning_statsGoogle::Apis::BigqueryV2::PruningStats

The column metadata index pruning statistics. Corresponds to the JSON property pruningStats



11773
11774
11775
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11773

def pruning_stats
  @pruning_stats
end

#stalenessString

Duration since last refresh as of this job for managed tables (indicates metadata cache staleness as seen by this job). Corresponds to the JSON property staleness

Returns:

  • (String)


11779
11780
11781
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11779

def staleness
  @staleness
end

#table_referenceGoogle::Apis::BigqueryV2::TableReference

Metadata caching eligible table referenced in the query. Corresponds to the JSON property tableReference



11784
11785
11786
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11784

def table_reference
  @table_reference
end

#table_typeString

Table type. Corresponds to the JSON property tableType

Returns:

  • (String)


11790
11791
11792
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11790

def table_type
  @table_type
end

#unused_reasonString

Reason for not using metadata caching for the table. Corresponds to the JSON property unusedReason

Returns:

  • (String)


11795
11796
11797
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11795

def unused_reason
  @unused_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11802
11803
11804
11805
11806
11807
11808
11809
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11802

def update!(**args)
  @explanation = args[:explanation] if args.key?(:explanation)
  @pruning_stats = args[:pruning_stats] if args.key?(:pruning_stats)
  @staleness = args[:staleness] if args.key?(:staleness)
  @table_reference = args[:table_reference] if args.key?(:table_reference)
  @table_type = args[:table_type] if args.key?(:table_type)
  @unused_reason = args[:unused_reason] if args.key?(:unused_reason)
end