Class: Google::Apis::BigqueryV2::TableMetadataCacheUsage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Table level detail on the usage of metadata caching. Only set for Metadata caching eligible tables referenced in the query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TableMetadataCacheUsage

Returns a new instance of TableMetadataCacheUsage.



11493
11494
11495
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11493

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explanationString

Free form human-readable reason metadata caching was unused for the job. Corresponds to the JSON property explanation

Returns:

  • (String)


11464
11465
11466
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11464

def explanation
  @explanation
end

#pruning_statsGoogle::Apis::BigqueryV2::PruningStats

The column metadata index pruning statistics. Corresponds to the JSON property pruningStats



11469
11470
11471
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11469

def pruning_stats
  @pruning_stats
end

#stalenessString

Duration since last refresh as of this job for managed tables (indicates metadata cache staleness as seen by this job). Corresponds to the JSON property staleness

Returns:

  • (String)


11475
11476
11477
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11475

def staleness
  @staleness
end

#table_referenceGoogle::Apis::BigqueryV2::TableReference

Metadata caching eligible table referenced in the query. Corresponds to the JSON property tableReference



11480
11481
11482
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11480

def table_reference
  @table_reference
end

#table_typeString

Table type. Corresponds to the JSON property tableType

Returns:

  • (String)


11486
11487
11488
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11486

def table_type
  @table_type
end

#unused_reasonString

Reason for not using metadata caching for the table. Corresponds to the JSON property unusedReason

Returns:

  • (String)


11491
11492
11493
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11491

def unused_reason
  @unused_reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11498
11499
11500
11501
11502
11503
11504
11505
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11498

def update!(**args)
  @explanation = args[:explanation] if args.key?(:explanation)
  @pruning_stats = args[:pruning_stats] if args.key?(:pruning_stats)
  @staleness = args[:staleness] if args.key?(:staleness)
  @table_reference = args[:table_reference] if args.key?(:table_reference)
  @table_type = args[:table_type] if args.key?(:table_type)
  @unused_reason = args[:unused_reason] if args.key?(:unused_reason)
end