Class: Google::Apis::BigqueryV2::TableReplicationInfo
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::TableReplicationInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Replication info of a table created using AS REPLICA DDL like: CREATE
MATERIALIZED VIEW mv1 AS REPLICA OF src_mv
Instance Attribute Summary collapse
-
#replicated_source_last_refresh_time ⇒ Fixnum
Optional.
-
#replication_error ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
-
#replication_interval_ms ⇒ Fixnum
Optional.
-
#replication_status ⇒ String
Optional.
-
#source_table ⇒ Google::Apis::BigqueryV2::TableReference
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TableReplicationInfo
constructor
A new instance of TableReplicationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TableReplicationInfo
Returns a new instance of TableReplicationInfo.
11760 11761 11762 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#replicated_source_last_refresh_time ⇒ Fixnum
Optional. Output only. If source is a materialized view, this field signifies
the last refresh time of the source.
Corresponds to the JSON property replicatedSourceLastRefreshTime
11736 11737 11738 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11736 def replicated_source_last_refresh_time @replicated_source_last_refresh_time end |
#replication_error ⇒ Google::Apis::BigqueryV2::ErrorProto
Error details.
Corresponds to the JSON property replicationError
11741 11742 11743 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11741 def replication_error @replication_error end |
#replication_interval_ms ⇒ Fixnum
Optional. Specifies the interval at which the source table is polled for
updates. It's Optional. If not specified, default replication interval would
be applied.
Corresponds to the JSON property replicationIntervalMs
11748 11749 11750 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11748 def replication_interval_ms @replication_interval_ms end |
#replication_status ⇒ String
Optional. Output only. Replication status of configured replication.
Corresponds to the JSON property replicationStatus
11753 11754 11755 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11753 def replication_status @replication_status end |
#source_table ⇒ Google::Apis::BigqueryV2::TableReference
Required. Source table reference that is replicated.
Corresponds to the JSON property sourceTable
11758 11759 11760 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11758 def source_table @source_table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11765 11766 11767 11768 11769 11770 11771 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11765 def update!(**args) @replicated_source_last_refresh_time = args[:replicated_source_last_refresh_time] if args.key?(:replicated_source_last_refresh_time) @replication_error = args[:replication_error] if args.key?(:replication_error) @replication_interval_ms = args[:replication_interval_ms] if args.key?(:replication_interval_ms) @replication_status = args[:replication_status] if args.key?(:replication_status) @source_table = args[:source_table] if args.key?(:source_table) end |