Class: Google::Apis::BigqueryV2::TableReplicationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Replication info of a table created using AS REPLICA DDL like: CREATE MATERIALIZED VIEW mv1 AS REPLICA OF src_mv

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TableReplicationInfo

Returns a new instance of TableReplicationInfo.



11233
11234
11235
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11233

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#replicated_source_last_refresh_timeFixnum

Optional. Output only. If source is a materialized view, this field signifies the last refresh time of the source. Corresponds to the JSON property replicatedSourceLastRefreshTime

Returns:

  • (Fixnum)


11209
11210
11211
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11209

def replicated_source_last_refresh_time
  @replicated_source_last_refresh_time
end

#replication_errorGoogle::Apis::BigqueryV2::ErrorProto

Error details. Corresponds to the JSON property replicationError



11214
11215
11216
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11214

def replication_error
  @replication_error
end

#replication_interval_msFixnum

Optional. Specifies the interval at which the source table is polled for updates. It's Optional. If not specified, default replication interval would be applied. Corresponds to the JSON property replicationIntervalMs

Returns:

  • (Fixnum)


11221
11222
11223
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11221

def replication_interval_ms
  @replication_interval_ms
end

#replication_statusString

Optional. Output only. Replication status of configured replication. Corresponds to the JSON property replicationStatus

Returns:

  • (String)


11226
11227
11228
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11226

def replication_status
  @replication_status
end

#source_tableGoogle::Apis::BigqueryV2::TableReference

Required. Source table reference that is replicated. Corresponds to the JSON property sourceTable



11231
11232
11233
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11231

def source_table
  @source_table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11238
11239
11240
11241
11242
11243
11244
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11238

def update!(**args)
  @replicated_source_last_refresh_time = args[:replicated_source_last_refresh_time] if args.key?(:replicated_source_last_refresh_time)
  @replication_error = args[:replication_error] if args.key?(:replication_error)
  @replication_interval_ms = args[:replication_interval_ms] if args.key?(:replication_interval_ms)
  @replication_status = args[:replication_status] if args.key?(:replication_status)
  @source_table = args[:source_table] if args.key?(:source_table)
end