Class: Google::Apis::BigqueryV2::TableReplicationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Replication info of a table created using AS REPLICA DDL like: CREATE MATERIALIZED VIEW mv1 AS REPLICA OF src_mv

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TableReplicationInfo

Returns a new instance of TableReplicationInfo.



11203
11204
11205
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#replicated_source_last_refresh_timeFixnum

Optional. Output only. If source is a materialized view, this field signifies the last refresh time of the source. Corresponds to the JSON property replicatedSourceLastRefreshTime

Returns:

  • (Fixnum)


11179
11180
11181
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11179

def replicated_source_last_refresh_time
  @replicated_source_last_refresh_time
end

#replication_errorGoogle::Apis::BigqueryV2::ErrorProto

Error details. Corresponds to the JSON property replicationError



11184
11185
11186
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11184

def replication_error
  @replication_error
end

#replication_interval_msFixnum

Optional. Specifies the interval at which the source table is polled for updates. It's Optional. If not specified, default replication interval would be applied. Corresponds to the JSON property replicationIntervalMs

Returns:

  • (Fixnum)


11191
11192
11193
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11191

def replication_interval_ms
  @replication_interval_ms
end

#replication_statusString

Optional. Output only. Replication status of configured replication. Corresponds to the JSON property replicationStatus

Returns:

  • (String)


11196
11197
11198
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11196

def replication_status
  @replication_status
end

#source_tableGoogle::Apis::BigqueryV2::TableReference

Required. Source table reference that is replicated. Corresponds to the JSON property sourceTable



11201
11202
11203
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11201

def source_table
  @source_table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11208
11209
11210
11211
11212
11213
11214
# File 'lib/google/apis/bigquery_v2/classes.rb', line 11208

def update!(**args)
  @replicated_source_last_refresh_time = args[:replicated_source_last_refresh_time] if args.key?(:replicated_source_last_refresh_time)
  @replication_error = args[:replication_error] if args.key?(:replication_error)
  @replication_interval_ms = args[:replication_interval_ms] if args.key?(:replication_interval_ms)
  @replication_status = args[:replication_status] if args.key?(:replication_status)
  @source_table = args[:source_table] if args.key?(:source_table)
end