Class: Google::Apis::BigqueryV2::TrainingOptions
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::TrainingOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Options used in model training.
Instance Attribute Summary collapse
-
#activation_fn ⇒ String
Activation function of the neural nets.
-
#adjust_step_changes ⇒ Boolean
(also: #adjust_step_changes?)
If true, detect step changes and make data adjustment in the input time series.
-
#approx_global_feature_contrib ⇒ Boolean
(also: #approx_global_feature_contrib?)
Whether to use approximate feature contribution method in XGBoost model explanation for global explain.
-
#auto_arima ⇒ Boolean
(also: #auto_arima?)
Whether to enable auto ARIMA or not.
-
#auto_arima_max_order ⇒ Fixnum
The max value of the sum of non-seasonal p and q.
-
#auto_arima_min_order ⇒ Fixnum
The min value of the sum of non-seasonal p and q.
-
#auto_class_weights ⇒ Boolean
(also: #auto_class_weights?)
Whether to calculate class weights automatically based on the popularity of each label.
-
#batch_size ⇒ Fixnum
Batch size for dnn models.
-
#booster_type ⇒ String
Booster type for boosted tree models.
-
#budget_hours ⇒ Float
Budget in hours for AutoML training.
-
#calculate_p_values ⇒ Boolean
(also: #calculate_p_values?)
Whether or not p-value test should be computed for this model.
-
#category_encoding_method ⇒ String
Categorical feature encoding method.
-
#clean_spikes_and_dips ⇒ Boolean
(also: #clean_spikes_and_dips?)
If true, clean spikes and dips in the input time series.
-
#color_space ⇒ String
Enums for color space, used for processing images in Object Table.
-
#colsample_bylevel ⇒ Float
Subsample ratio of columns for each level for boosted tree models.
-
#colsample_bynode ⇒ Float
Subsample ratio of columns for each node(split) for boosted tree models.
-
#colsample_bytree ⇒ Float
Subsample ratio of columns when constructing each tree for boosted tree models.
-
#contribution_metric ⇒ String
The contribution metric.
-
#dart_normalize_type ⇒ String
Type of normalization algorithm for boosted tree models using dart booster.
-
#data_frequency ⇒ String
The data frequency of a time series.
-
#data_split_column ⇒ String
The column to split data with.
-
#data_split_eval_fraction ⇒ Float
The fraction of evaluation data over the whole input data.
-
#data_split_method ⇒ String
The data split type for training and evaluation, e.g.
-
#decompose_time_series ⇒ Boolean
(also: #decompose_time_series?)
If true, perform decompose time series and save the results.
-
#dimension_id_columns ⇒ Array<String>
Optional.
-
#distance_type ⇒ String
Distance type for clustering models.
-
#dropout ⇒ Float
Dropout probability for dnn models.
-
#early_stop ⇒ Boolean
(also: #early_stop?)
Whether to stop early when the loss doesn't improve significantly any more ( compared to min_relative_progress).
-
#enable_global_explain ⇒ Boolean
(also: #enable_global_explain?)
If true, enable global explanation during training.
-
#endpoint_idle_ttl ⇒ String
The idle TTL of the endpoint before the resources get destroyed.
-
#feedback_type ⇒ String
Feedback type that specifies which algorithm to run for matrix factorization.
-
#fit_intercept ⇒ Boolean
(also: #fit_intercept?)
Whether the model should include intercept during model training.
-
#forecast_limit_lower_bound ⇒ Float
The forecast limit lower bound that was used during ARIMA model training with limits.
-
#forecast_limit_upper_bound ⇒ Float
The forecast limit upper bound that was used during ARIMA model training with limits.
-
#hidden_units ⇒ Array<Fixnum>
Hidden units for dnn models.
-
#holiday_region ⇒ String
The geographical region based on which the holidays are considered in time series modeling.
-
#holiday_regions ⇒ Array<String>
A list of geographical regions that are used for time series modeling.
-
#horizon ⇒ Fixnum
The number of periods ahead that need to be forecasted.
-
#hparam_tuning_objectives ⇒ Array<String>
The target evaluation metrics to optimize the hyperparameters for.
-
#hugging_face_model_id ⇒ String
The id of a Hugging Face model.
-
#include_drift ⇒ Boolean
(also: #include_drift?)
Include drift when fitting an ARIMA model.
-
#initial_learn_rate ⇒ Float
Specifies the initial learning rate for the line search learn rate strategy.
-
#input_label_columns ⇒ Array<String>
Name of input label columns in training data.
-
#instance_weight_column ⇒ String
Name of the instance weight column for training data.
-
#integrated_gradients_num_steps ⇒ Fixnum
Number of integral steps for the integrated gradients explain method.
-
#is_test_column ⇒ String
Name of the column used to determine the rows corresponding to control and test.
-
#item_column ⇒ String
Item column specified for matrix factorization models.
-
#kmeans_initialization_column ⇒ String
The column used to provide the initial centroids for kmeans algorithm when kmeans_initialization_method is CUSTOM.
-
#kmeans_initialization_method ⇒ String
The method used to initialize the centroids for kmeans algorithm.
-
#l1_reg_activation ⇒ Float
L1 regularization coefficient to activations.
-
#l1_regularization ⇒ Float
L1 regularization coefficient.
-
#l2_regularization ⇒ Float
L2 regularization coefficient.
-
#label_class_weights ⇒ Hash<String,Float>
Weights associated with each label class, for rebalancing the training data.
-
#learn_rate ⇒ Float
Learning rate in training.
-
#learn_rate_strategy ⇒ String
The strategy to determine learn rate for the current iteration.
-
#loss_type ⇒ String
Type of loss function used during training run.
-
#machine_type ⇒ String
The type of the machine used to deploy and serve the model.
-
#max_iterations ⇒ Fixnum
The maximum number of iterations in training.
-
#max_parallel_trials ⇒ Fixnum
Maximum number of trials to run in parallel.
-
#max_replica_count ⇒ Fixnum
The maximum number of machine replicas that will be deployed on an endpoint.
-
#max_time_series_length ⇒ Fixnum
The maximum number of time points in a time series that can be used in modeling the trend component of the time series.
-
#max_tree_depth ⇒ Fixnum
Maximum depth of a tree for boosted tree models.
-
#min_apriori_support ⇒ Float
The apriori support minimum.
-
#min_relative_progress ⇒ Float
When early_stop is true, stops training when accuracy improvement is less than 'min_relative_progress'.
-
#min_replica_count ⇒ Fixnum
The minimum number of machine replicas that will be always deployed on an endpoint.
-
#min_split_loss ⇒ Float
Minimum split loss for boosted tree models.
-
#min_time_series_length ⇒ Fixnum
The minimum number of time points in a time series that are used in modeling the trend component of the time series.
-
#min_tree_child_weight ⇒ Fixnum
Minimum sum of instance weight needed in a child for boosted tree models.
-
#model_garden_model_name ⇒ String
The name of a Vertex model garden publisher model.
-
#model_registry ⇒ String
The model registry.
-
#model_uri ⇒ String
Google Cloud Storage URI from which the model was imported.
-
#non_seasonal_order ⇒ Google::Apis::BigqueryV2::ArimaOrder
Arima order, can be used for both non-seasonal and seasonal parts.
-
#num_clusters ⇒ Fixnum
Number of clusters for clustering models.
-
#num_factors ⇒ Fixnum
Num factors specified for matrix factorization models.
-
#num_parallel_tree ⇒ Fixnum
Number of parallel trees constructed during each iteration for boosted tree models.
-
#num_principal_components ⇒ Fixnum
Number of principal components to keep in the PCA model.
-
#num_trials ⇒ Fixnum
Number of trials to run this hyperparameter tuning job.
-
#optimization_strategy ⇒ String
Optimization strategy for training linear regression models.
-
#optimizer ⇒ String
Optimizer used for training the neural nets.
-
#pca_explained_variance_ratio ⇒ Float
The minimum ratio of cumulative explained variance that needs to be given by the PCA model.
-
#pca_solver ⇒ String
The solver for PCA.
-
#reservation_affinity_key ⇒ String
Corresponds to the label key of a reservation resource used by Vertex AI.
-
#reservation_affinity_type ⇒ String
Specifies the reservation affinity type used to configure a Vertex AI resource.
-
#reservation_affinity_values ⇒ Array<String>
Corresponds to the label values of a reservation resource used by Vertex AI.
-
#sampled_shapley_num_paths ⇒ Fixnum
Number of paths for the sampled Shapley explain method.
-
#scale_features ⇒ Boolean
(also: #scale_features?)
If true, scale the feature values by dividing the feature standard deviation.
-
#standardize_features ⇒ Boolean
(also: #standardize_features?)
Whether to standardize numerical features.
-
#subsample ⇒ Float
Subsample fraction of the training data to grow tree to prevent overfitting for boosted tree models.
-
#tf_version ⇒ String
Based on the selected TF version, the corresponding docker image is used to train external models.
-
#time_series_data_column ⇒ String
Column to be designated as time series data for ARIMA model.
-
#time_series_id_column ⇒ String
The time series id column that was used during ARIMA model training.
-
#time_series_id_columns ⇒ Array<String>
The time series id columns that were used during ARIMA model training.
-
#time_series_length_fraction ⇒ Float
The fraction of the interpolated length of the time series that's used to model the time series trend component.
-
#time_series_timestamp_column ⇒ String
Column to be designated as time series timestamp for ARIMA model.
-
#tree_method ⇒ String
Tree construction algorithm for boosted tree models.
-
#trend_smoothing_window_size ⇒ Fixnum
Smoothing window size for the trend component.
-
#user_column ⇒ String
User column specified for matrix factorization models.
-
#vertex_ai_model_version_aliases ⇒ Array<String>
The version aliases to apply in Vertex AI model registry.
-
#wals_alpha ⇒ Float
Hyperparameter for matrix factoration when implicit feedback type is specified.
-
#warm_start ⇒ Boolean
(also: #warm_start?)
Whether to train a model from the last checkpoint.
-
#xgboost_version ⇒ String
User-selected XGBoost versions for training of XGBoost models.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TrainingOptions
constructor
A new instance of TrainingOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TrainingOptions
Returns a new instance of TrainingOptions.
12800 12801 12802 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12800 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_fn ⇒ String
Activation function of the neural nets.
Corresponds to the JSON property activationFn
12219 12220 12221 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12219 def activation_fn @activation_fn end |
#adjust_step_changes ⇒ Boolean Also known as: adjust_step_changes?
If true, detect step changes and make data adjustment in the input time series.
Corresponds to the JSON property adjustStepChanges
12224 12225 12226 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12224 def adjust_step_changes @adjust_step_changes end |
#approx_global_feature_contrib ⇒ Boolean Also known as: approx_global_feature_contrib?
Whether to use approximate feature contribution method in XGBoost model
explanation for global explain.
Corresponds to the JSON property approxGlobalFeatureContrib
12231 12232 12233 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12231 def approx_global_feature_contrib @approx_global_feature_contrib end |
#auto_arima ⇒ Boolean Also known as: auto_arima?
Whether to enable auto ARIMA or not.
Corresponds to the JSON property autoArima
12237 12238 12239 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12237 def auto_arima @auto_arima end |
#auto_arima_max_order ⇒ Fixnum
The max value of the sum of non-seasonal p and q.
Corresponds to the JSON property autoArimaMaxOrder
12243 12244 12245 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12243 def auto_arima_max_order @auto_arima_max_order end |
#auto_arima_min_order ⇒ Fixnum
The min value of the sum of non-seasonal p and q.
Corresponds to the JSON property autoArimaMinOrder
12248 12249 12250 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12248 def auto_arima_min_order @auto_arima_min_order end |
#auto_class_weights ⇒ Boolean Also known as: auto_class_weights?
Whether to calculate class weights automatically based on the popularity of
each label.
Corresponds to the JSON property autoClassWeights
12254 12255 12256 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12254 def auto_class_weights @auto_class_weights end |
#batch_size ⇒ Fixnum
Batch size for dnn models.
Corresponds to the JSON property batchSize
12260 12261 12262 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12260 def batch_size @batch_size end |
#booster_type ⇒ String
Booster type for boosted tree models.
Corresponds to the JSON property boosterType
12265 12266 12267 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12265 def booster_type @booster_type end |
#budget_hours ⇒ Float
Budget in hours for AutoML training.
Corresponds to the JSON property budgetHours
12270 12271 12272 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12270 def budget_hours @budget_hours end |
#calculate_p_values ⇒ Boolean Also known as: calculate_p_values?
Whether or not p-value test should be computed for this model. Only available
for linear and logistic regression models.
Corresponds to the JSON property calculatePValues
12276 12277 12278 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12276 def calculate_p_values @calculate_p_values end |
#category_encoding_method ⇒ String
Categorical feature encoding method.
Corresponds to the JSON property categoryEncodingMethod
12282 12283 12284 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12282 def category_encoding_method @category_encoding_method end |
#clean_spikes_and_dips ⇒ Boolean Also known as: clean_spikes_and_dips?
If true, clean spikes and dips in the input time series.
Corresponds to the JSON property cleanSpikesAndDips
12287 12288 12289 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12287 def clean_spikes_and_dips @clean_spikes_and_dips end |
#color_space ⇒ String
Enums for color space, used for processing images in Object Table. See more
details at https://www.tensorflow.org/io/tutorials/colorspace.
Corresponds to the JSON property colorSpace
12294 12295 12296 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12294 def color_space @color_space end |
#colsample_bylevel ⇒ Float
Subsample ratio of columns for each level for boosted tree models.
Corresponds to the JSON property colsampleBylevel
12299 12300 12301 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12299 def colsample_bylevel @colsample_bylevel end |
#colsample_bynode ⇒ Float
Subsample ratio of columns for each node(split) for boosted tree models.
Corresponds to the JSON property colsampleBynode
12304 12305 12306 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12304 def colsample_bynode @colsample_bynode end |
#colsample_bytree ⇒ Float
Subsample ratio of columns when constructing each tree for boosted tree models.
Corresponds to the JSON property colsampleBytree
12309 12310 12311 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12309 def colsample_bytree @colsample_bytree end |
#contribution_metric ⇒ String
The contribution metric. Applies to contribution analysis models. Allowed
formats supported are for summable and summable ratio contribution metrics.
These include expressions such as SUM(x) or SUM(x)/SUM(y), where x and y
are column names from the base table.
Corresponds to the JSON property contributionMetric
12317 12318 12319 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12317 def contribution_metric @contribution_metric end |
#dart_normalize_type ⇒ String
Type of normalization algorithm for boosted tree models using dart booster.
Corresponds to the JSON property dartNormalizeType
12322 12323 12324 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12322 def dart_normalize_type @dart_normalize_type end |
#data_frequency ⇒ String
The data frequency of a time series.
Corresponds to the JSON property dataFrequency
12327 12328 12329 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12327 def data_frequency @data_frequency end |
#data_split_column ⇒ String
The column to split data with. This column won't be used as a feature. 1. When
data_split_method is CUSTOM, the corresponding column should be boolean. The
rows with true value tag are eval data, and the false are training data. 2.
When data_split_method is SEQ, the first DATA_SPLIT_EVAL_FRACTION rows (from
smallest to largest) in the corresponding column are used as training data,
and the rest are eval data. It respects the order in Orderable data types:
https://cloud.google.com/bigquery/docs/reference/standard-sql/data-types#
data_type_properties
Corresponds to the JSON property dataSplitColumn
12339 12340 12341 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12339 def data_split_column @data_split_column end |
#data_split_eval_fraction ⇒ Float
The fraction of evaluation data over the whole input data. The rest of data
will be used as training data. The format should be double. Accurate to two
decimal places. Default value is 0.2.
Corresponds to the JSON property dataSplitEvalFraction
12346 12347 12348 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12346 def data_split_eval_fraction @data_split_eval_fraction end |
#data_split_method ⇒ String
The data split type for training and evaluation, e.g. RANDOM.
Corresponds to the JSON property dataSplitMethod
12351 12352 12353 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12351 def data_split_method @data_split_method end |
#decompose_time_series ⇒ Boolean Also known as: decompose_time_series?
If true, perform decompose time series and save the results.
Corresponds to the JSON property decomposeTimeSeries
12356 12357 12358 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12356 def decompose_time_series @decompose_time_series end |
#dimension_id_columns ⇒ Array<String>
Optional. Names of the columns to slice on. Applies to contribution analysis
models.
Corresponds to the JSON property dimensionIdColumns
12363 12364 12365 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12363 def dimension_id_columns @dimension_id_columns end |
#distance_type ⇒ String
Distance type for clustering models.
Corresponds to the JSON property distanceType
12368 12369 12370 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12368 def distance_type @distance_type end |
#dropout ⇒ Float
Dropout probability for dnn models.
Corresponds to the JSON property dropout
12373 12374 12375 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12373 def dropout @dropout end |
#early_stop ⇒ Boolean Also known as: early_stop?
Whether to stop early when the loss doesn't improve significantly any more (
compared to min_relative_progress). Used only for iterative training
algorithms.
Corresponds to the JSON property earlyStop
12380 12381 12382 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12380 def early_stop @early_stop end |
#enable_global_explain ⇒ Boolean Also known as: enable_global_explain?
If true, enable global explanation during training.
Corresponds to the JSON property enableGlobalExplain
12386 12387 12388 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12386 def enable_global_explain @enable_global_explain end |
#endpoint_idle_ttl ⇒ String
The idle TTL of the endpoint before the resources get destroyed. The default
value is 6.5 hours.
Corresponds to the JSON property endpointIdleTtl
12393 12394 12395 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12393 def endpoint_idle_ttl @endpoint_idle_ttl end |
#feedback_type ⇒ String
Feedback type that specifies which algorithm to run for matrix factorization.
Corresponds to the JSON property feedbackType
12398 12399 12400 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12398 def feedback_type @feedback_type end |
#fit_intercept ⇒ Boolean Also known as: fit_intercept?
Whether the model should include intercept during model training.
Corresponds to the JSON property fitIntercept
12403 12404 12405 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12403 def fit_intercept @fit_intercept end |
#forecast_limit_lower_bound ⇒ Float
The forecast limit lower bound that was used during ARIMA model training with
limits. To see more details of the algorithm: https://otexts.com/fpp2/limits.
html
Corresponds to the JSON property forecastLimitLowerBound
12411 12412 12413 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12411 def forecast_limit_lower_bound @forecast_limit_lower_bound end |
#forecast_limit_upper_bound ⇒ Float
The forecast limit upper bound that was used during ARIMA model training with
limits.
Corresponds to the JSON property forecastLimitUpperBound
12417 12418 12419 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12417 def forecast_limit_upper_bound @forecast_limit_upper_bound end |
#hidden_units ⇒ Array<Fixnum>
Hidden units for dnn models.
Corresponds to the JSON property hiddenUnits
12422 12423 12424 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12422 def hidden_units @hidden_units end |
#holiday_region ⇒ String
The geographical region based on which the holidays are considered in time
series modeling. If a valid value is specified, then holiday effects modeling
is enabled.
Corresponds to the JSON property holidayRegion
12429 12430 12431 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12429 def holiday_region @holiday_region end |
#holiday_regions ⇒ Array<String>
A list of geographical regions that are used for time series modeling.
Corresponds to the JSON property holidayRegions
12434 12435 12436 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12434 def holiday_regions @holiday_regions end |
#horizon ⇒ Fixnum
The number of periods ahead that need to be forecasted.
Corresponds to the JSON property horizon
12439 12440 12441 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12439 def horizon @horizon end |
#hparam_tuning_objectives ⇒ Array<String>
The target evaluation metrics to optimize the hyperparameters for.
Corresponds to the JSON property hparamTuningObjectives
12444 12445 12446 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12444 def hparam_tuning_objectives @hparam_tuning_objectives end |
#hugging_face_model_id ⇒ String
The id of a Hugging Face model. For example, google/gemma-2-2b-it.
Corresponds to the JSON property huggingFaceModelId
12449 12450 12451 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12449 def hugging_face_model_id @hugging_face_model_id end |
#include_drift ⇒ Boolean Also known as: include_drift?
Include drift when fitting an ARIMA model.
Corresponds to the JSON property includeDrift
12454 12455 12456 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12454 def include_drift @include_drift end |
#initial_learn_rate ⇒ Float
Specifies the initial learning rate for the line search learn rate strategy.
Corresponds to the JSON property initialLearnRate
12460 12461 12462 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12460 def initial_learn_rate @initial_learn_rate end |
#input_label_columns ⇒ Array<String>
Name of input label columns in training data.
Corresponds to the JSON property inputLabelColumns
12465 12466 12467 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12465 def input_label_columns @input_label_columns end |
#instance_weight_column ⇒ String
Name of the instance weight column for training data. This column isn't be
used as a feature.
Corresponds to the JSON property instanceWeightColumn
12471 12472 12473 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12471 def instance_weight_column @instance_weight_column end |
#integrated_gradients_num_steps ⇒ Fixnum
Number of integral steps for the integrated gradients explain method.
Corresponds to the JSON property integratedGradientsNumSteps
12476 12477 12478 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12476 def integrated_gradients_num_steps @integrated_gradients_num_steps end |
#is_test_column ⇒ String
Name of the column used to determine the rows corresponding to control and
test. Applies to contribution analysis models.
Corresponds to the JSON property isTestColumn
12482 12483 12484 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12482 def is_test_column @is_test_column end |
#item_column ⇒ String
Item column specified for matrix factorization models.
Corresponds to the JSON property itemColumn
12487 12488 12489 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12487 def item_column @item_column end |
#kmeans_initialization_column ⇒ String
The column used to provide the initial centroids for kmeans algorithm when
kmeans_initialization_method is CUSTOM.
Corresponds to the JSON property kmeansInitializationColumn
12493 12494 12495 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12493 def kmeans_initialization_column @kmeans_initialization_column end |
#kmeans_initialization_method ⇒ String
The method used to initialize the centroids for kmeans algorithm.
Corresponds to the JSON property kmeansInitializationMethod
12498 12499 12500 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12498 def kmeans_initialization_method @kmeans_initialization_method end |
#l1_reg_activation ⇒ Float
L1 regularization coefficient to activations.
Corresponds to the JSON property l1RegActivation
12503 12504 12505 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12503 def l1_reg_activation @l1_reg_activation end |
#l1_regularization ⇒ Float
L1 regularization coefficient.
Corresponds to the JSON property l1Regularization
12508 12509 12510 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12508 def l1_regularization @l1_regularization end |
#l2_regularization ⇒ Float
L2 regularization coefficient.
Corresponds to the JSON property l2Regularization
12513 12514 12515 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12513 def l2_regularization @l2_regularization end |
#label_class_weights ⇒ Hash<String,Float>
Weights associated with each label class, for rebalancing the training data.
Only applicable for classification models.
Corresponds to the JSON property labelClassWeights
12519 12520 12521 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12519 def label_class_weights @label_class_weights end |
#learn_rate ⇒ Float
Learning rate in training. Used only for iterative training algorithms.
Corresponds to the JSON property learnRate
12524 12525 12526 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12524 def learn_rate @learn_rate end |
#learn_rate_strategy ⇒ String
The strategy to determine learn rate for the current iteration.
Corresponds to the JSON property learnRateStrategy
12529 12530 12531 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12529 def learn_rate_strategy @learn_rate_strategy end |
#loss_type ⇒ String
Type of loss function used during training run.
Corresponds to the JSON property lossType
12534 12535 12536 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12534 def loss_type @loss_type end |
#machine_type ⇒ String
The type of the machine used to deploy and serve the model.
Corresponds to the JSON property machineType
12539 12540 12541 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12539 def machine_type @machine_type end |
#max_iterations ⇒ Fixnum
The maximum number of iterations in training. Used only for iterative training
algorithms.
Corresponds to the JSON property maxIterations
12545 12546 12547 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12545 def max_iterations @max_iterations end |
#max_parallel_trials ⇒ Fixnum
Maximum number of trials to run in parallel.
Corresponds to the JSON property maxParallelTrials
12550 12551 12552 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12550 def max_parallel_trials @max_parallel_trials end |
#max_replica_count ⇒ Fixnum
The maximum number of machine replicas that will be deployed on an endpoint.
The default value is equal to min_replica_count.
Corresponds to the JSON property maxReplicaCount
12556 12557 12558 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12556 def max_replica_count @max_replica_count end |
#max_time_series_length ⇒ Fixnum
The maximum number of time points in a time series that can be used in
modeling the trend component of the time series. Don't use this option with
the timeSeriesLengthFraction or minTimeSeriesLength options.
Corresponds to the JSON property maxTimeSeriesLength
12563 12564 12565 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12563 def max_time_series_length @max_time_series_length end |
#max_tree_depth ⇒ Fixnum
Maximum depth of a tree for boosted tree models.
Corresponds to the JSON property maxTreeDepth
12568 12569 12570 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12568 def max_tree_depth @max_tree_depth end |
#min_apriori_support ⇒ Float
The apriori support minimum. Applies to contribution analysis models.
Corresponds to the JSON property minAprioriSupport
12573 12574 12575 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12573 def min_apriori_support @min_apriori_support end |
#min_relative_progress ⇒ Float
When early_stop is true, stops training when accuracy improvement is less than
'min_relative_progress'. Used only for iterative training algorithms.
Corresponds to the JSON property minRelativeProgress
12579 12580 12581 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12579 def min_relative_progress @min_relative_progress end |
#min_replica_count ⇒ Fixnum
The minimum number of machine replicas that will be always deployed on an
endpoint. This value must be greater than or equal to 1. The default value is
1.
Corresponds to the JSON property minReplicaCount
12586 12587 12588 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12586 def min_replica_count @min_replica_count end |
#min_split_loss ⇒ Float
Minimum split loss for boosted tree models.
Corresponds to the JSON property minSplitLoss
12591 12592 12593 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12591 def min_split_loss @min_split_loss end |
#min_time_series_length ⇒ Fixnum
The minimum number of time points in a time series that are used in modeling
the trend component of the time series. If you use this option you must also
set the timeSeriesLengthFraction option. This training option ensures that
enough time points are available when you use timeSeriesLengthFraction in
trend modeling. This is particularly important when forecasting multiple time
series in a single query using timeSeriesIdColumn. If the total number of
time points is less than the minTimeSeriesLength value, then the query uses
all available time points.
Corresponds to the JSON property minTimeSeriesLength
12603 12604 12605 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12603 def min_time_series_length @min_time_series_length end |
#min_tree_child_weight ⇒ Fixnum
Minimum sum of instance weight needed in a child for boosted tree models.
Corresponds to the JSON property minTreeChildWeight
12608 12609 12610 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12608 def min_tree_child_weight @min_tree_child_weight end |
#model_garden_model_name ⇒ String
The name of a Vertex model garden publisher model. Format is publishers/
publisher/models/model@optional_version_id`.
Corresponds to the JSON propertymodelGardenModelName`
12614 12615 12616 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12614 def model_garden_model_name @model_garden_model_name end |
#model_registry ⇒ String
The model registry.
Corresponds to the JSON property modelRegistry
12619 12620 12621 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12619 def model_registry @model_registry end |
#model_uri ⇒ String
Google Cloud Storage URI from which the model was imported. Only applicable
for imported models.
Corresponds to the JSON property modelUri
12625 12626 12627 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12625 def model_uri @model_uri end |
#non_seasonal_order ⇒ Google::Apis::BigqueryV2::ArimaOrder
Arima order, can be used for both non-seasonal and seasonal parts.
Corresponds to the JSON property nonSeasonalOrder
12630 12631 12632 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12630 def non_seasonal_order @non_seasonal_order end |
#num_clusters ⇒ Fixnum
Number of clusters for clustering models.
Corresponds to the JSON property numClusters
12635 12636 12637 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12635 def num_clusters @num_clusters end |
#num_factors ⇒ Fixnum
Num factors specified for matrix factorization models.
Corresponds to the JSON property numFactors
12640 12641 12642 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12640 def num_factors @num_factors end |
#num_parallel_tree ⇒ Fixnum
Number of parallel trees constructed during each iteration for boosted tree
models.
Corresponds to the JSON property numParallelTree
12646 12647 12648 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12646 def num_parallel_tree @num_parallel_tree end |
#num_principal_components ⇒ Fixnum
Number of principal components to keep in the PCA model. Must be <= the number
of features.
Corresponds to the JSON property numPrincipalComponents
12652 12653 12654 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12652 def num_principal_components @num_principal_components end |
#num_trials ⇒ Fixnum
Number of trials to run this hyperparameter tuning job.
Corresponds to the JSON property numTrials
12657 12658 12659 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12657 def num_trials @num_trials end |
#optimization_strategy ⇒ String
Optimization strategy for training linear regression models.
Corresponds to the JSON property optimizationStrategy
12662 12663 12664 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12662 def optimization_strategy @optimization_strategy end |
#optimizer ⇒ String
Optimizer used for training the neural nets.
Corresponds to the JSON property optimizer
12667 12668 12669 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12667 def optimizer @optimizer end |
#pca_explained_variance_ratio ⇒ Float
The minimum ratio of cumulative explained variance that needs to be given by
the PCA model.
Corresponds to the JSON property pcaExplainedVarianceRatio
12673 12674 12675 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12673 def pca_explained_variance_ratio @pca_explained_variance_ratio end |
#pca_solver ⇒ String
The solver for PCA.
Corresponds to the JSON property pcaSolver
12678 12679 12680 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12678 def pca_solver @pca_solver end |
#reservation_affinity_key ⇒ String
Corresponds to the label key of a reservation resource used by Vertex AI. To
target a SPECIFIC_RESERVATION by name, use compute.googleapis.com/reservation-
name as the key and specify the name of your reservation as its value.
Corresponds to the JSON property reservationAffinityKey
12685 12686 12687 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12685 def reservation_affinity_key @reservation_affinity_key end |
#reservation_affinity_type ⇒ String
Specifies the reservation affinity type used to configure a Vertex AI resource.
The default value is NO_RESERVATION.
Corresponds to the JSON property reservationAffinityType
12691 12692 12693 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12691 def reservation_affinity_type @reservation_affinity_type end |
#reservation_affinity_values ⇒ Array<String>
Corresponds to the label values of a reservation resource used by Vertex AI.
This must be the full resource name of the reservation or reservation block.
Corresponds to the JSON property reservationAffinityValues
12697 12698 12699 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12697 def reservation_affinity_values @reservation_affinity_values end |
#sampled_shapley_num_paths ⇒ Fixnum
Number of paths for the sampled Shapley explain method.
Corresponds to the JSON property sampledShapleyNumPaths
12702 12703 12704 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12702 def sampled_shapley_num_paths @sampled_shapley_num_paths end |
#scale_features ⇒ Boolean Also known as: scale_features?
If true, scale the feature values by dividing the feature standard deviation.
Currently only apply to PCA.
Corresponds to the JSON property scaleFeatures
12708 12709 12710 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12708 def scale_features @scale_features end |
#standardize_features ⇒ Boolean Also known as: standardize_features?
Whether to standardize numerical features. Default to true.
Corresponds to the JSON property standardizeFeatures
12714 12715 12716 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12714 def standardize_features @standardize_features end |
#subsample ⇒ Float
Subsample fraction of the training data to grow tree to prevent overfitting
for boosted tree models.
Corresponds to the JSON property subsample
12721 12722 12723 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12721 def subsample @subsample end |
#tf_version ⇒ String
Based on the selected TF version, the corresponding docker image is used to
train external models.
Corresponds to the JSON property tfVersion
12727 12728 12729 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12727 def tf_version @tf_version end |
#time_series_data_column ⇒ String
Column to be designated as time series data for ARIMA model.
Corresponds to the JSON property timeSeriesDataColumn
12732 12733 12734 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12732 def time_series_data_column @time_series_data_column end |
#time_series_id_column ⇒ String
The time series id column that was used during ARIMA model training.
Corresponds to the JSON property timeSeriesIdColumn
12737 12738 12739 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12737 def time_series_id_column @time_series_id_column end |
#time_series_id_columns ⇒ Array<String>
The time series id columns that were used during ARIMA model training.
Corresponds to the JSON property timeSeriesIdColumns
12742 12743 12744 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12742 def time_series_id_columns @time_series_id_columns end |
#time_series_length_fraction ⇒ Float
The fraction of the interpolated length of the time series that's used to
model the time series trend component. All of the time points of the time
series are used to model the non-trend component. This training option
accelerates modeling training without sacrificing much forecasting accuracy.
You can use this option with minTimeSeriesLength but not with
maxTimeSeriesLength.
Corresponds to the JSON property timeSeriesLengthFraction
12752 12753 12754 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12752 def time_series_length_fraction @time_series_length_fraction end |
#time_series_timestamp_column ⇒ String
Column to be designated as time series timestamp for ARIMA model.
Corresponds to the JSON property timeSeriesTimestampColumn
12757 12758 12759 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12757 def @time_series_timestamp_column end |
#tree_method ⇒ String
Tree construction algorithm for boosted tree models.
Corresponds to the JSON property treeMethod
12762 12763 12764 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12762 def tree_method @tree_method end |
#trend_smoothing_window_size ⇒ Fixnum
Smoothing window size for the trend component. When a positive value is
specified, a center moving average smoothing is applied on the history trend.
When the smoothing window is out of the boundary at the beginning or the end
of the trend, the first element or the last element is padded to fill the
smoothing window before the average is applied.
Corresponds to the JSON property trendSmoothingWindowSize
12771 12772 12773 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12771 def trend_smoothing_window_size @trend_smoothing_window_size end |
#user_column ⇒ String
User column specified for matrix factorization models.
Corresponds to the JSON property userColumn
12776 12777 12778 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12776 def user_column @user_column end |
#vertex_ai_model_version_aliases ⇒ Array<String>
The version aliases to apply in Vertex AI model registry. Always overwrite if
the version aliases exists in a existing model.
Corresponds to the JSON property vertexAiModelVersionAliases
12782 12783 12784 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12782 def vertex_ai_model_version_aliases @vertex_ai_model_version_aliases end |
#wals_alpha ⇒ Float
Hyperparameter for matrix factoration when implicit feedback type is specified.
Corresponds to the JSON property walsAlpha
12787 12788 12789 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12787 def wals_alpha @wals_alpha end |
#warm_start ⇒ Boolean Also known as: warm_start?
Whether to train a model from the last checkpoint.
Corresponds to the JSON property warmStart
12792 12793 12794 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12792 def warm_start @warm_start end |
#xgboost_version ⇒ String
User-selected XGBoost versions for training of XGBoost models.
Corresponds to the JSON property xgboostVersion
12798 12799 12800 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12798 def xgboost_version @xgboost_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12805 12806 12807 12808 12809 12810 12811 12812 12813 12814 12815 12816 12817 12818 12819 12820 12821 12822 12823 12824 12825 12826 12827 12828 12829 12830 12831 12832 12833 12834 12835 12836 12837 12838 12839 12840 12841 12842 12843 12844 12845 12846 12847 12848 12849 12850 12851 12852 12853 12854 12855 12856 12857 12858 12859 12860 12861 12862 12863 12864 12865 12866 12867 12868 12869 12870 12871 12872 12873 12874 12875 12876 12877 12878 12879 12880 12881 12882 12883 12884 12885 12886 12887 12888 12889 12890 12891 12892 12893 12894 12895 12896 12897 12898 12899 12900 12901 12902 12903 12904 12905 12906 12907 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12805 def update!(**args) @activation_fn = args[:activation_fn] if args.key?(:activation_fn) @adjust_step_changes = args[:adjust_step_changes] if args.key?(:adjust_step_changes) @approx_global_feature_contrib = args[:approx_global_feature_contrib] if args.key?(:approx_global_feature_contrib) @auto_arima = args[:auto_arima] if args.key?(:auto_arima) @auto_arima_max_order = args[:auto_arima_max_order] if args.key?(:auto_arima_max_order) @auto_arima_min_order = args[:auto_arima_min_order] if args.key?(:auto_arima_min_order) @auto_class_weights = args[:auto_class_weights] if args.key?(:auto_class_weights) @batch_size = args[:batch_size] if args.key?(:batch_size) @booster_type = args[:booster_type] if args.key?(:booster_type) @budget_hours = args[:budget_hours] if args.key?(:budget_hours) @calculate_p_values = args[:calculate_p_values] if args.key?(:calculate_p_values) @category_encoding_method = args[:category_encoding_method] if args.key?(:category_encoding_method) @clean_spikes_and_dips = args[:clean_spikes_and_dips] if args.key?(:clean_spikes_and_dips) @color_space = args[:color_space] if args.key?(:color_space) @colsample_bylevel = args[:colsample_bylevel] if args.key?(:colsample_bylevel) @colsample_bynode = args[:colsample_bynode] if args.key?(:colsample_bynode) @colsample_bytree = args[:colsample_bytree] if args.key?(:colsample_bytree) @contribution_metric = args[:contribution_metric] if args.key?(:contribution_metric) @dart_normalize_type = args[:dart_normalize_type] if args.key?(:dart_normalize_type) @data_frequency = args[:data_frequency] if args.key?(:data_frequency) @data_split_column = args[:data_split_column] if args.key?(:data_split_column) @data_split_eval_fraction = args[:data_split_eval_fraction] if args.key?(:data_split_eval_fraction) @data_split_method = args[:data_split_method] if args.key?(:data_split_method) @decompose_time_series = args[:decompose_time_series] if args.key?(:decompose_time_series) @dimension_id_columns = args[:dimension_id_columns] if args.key?(:dimension_id_columns) @distance_type = args[:distance_type] if args.key?(:distance_type) @dropout = args[:dropout] if args.key?(:dropout) @early_stop = args[:early_stop] if args.key?(:early_stop) @enable_global_explain = args[:enable_global_explain] if args.key?(:enable_global_explain) @endpoint_idle_ttl = args[:endpoint_idle_ttl] if args.key?(:endpoint_idle_ttl) @feedback_type = args[:feedback_type] if args.key?(:feedback_type) @fit_intercept = args[:fit_intercept] if args.key?(:fit_intercept) @forecast_limit_lower_bound = args[:forecast_limit_lower_bound] if args.key?(:forecast_limit_lower_bound) @forecast_limit_upper_bound = args[:forecast_limit_upper_bound] if args.key?(:forecast_limit_upper_bound) @hidden_units = args[:hidden_units] if args.key?(:hidden_units) @holiday_region = args[:holiday_region] if args.key?(:holiday_region) @holiday_regions = args[:holiday_regions] if args.key?(:holiday_regions) @horizon = args[:horizon] if args.key?(:horizon) @hparam_tuning_objectives = args[:hparam_tuning_objectives] if args.key?(:hparam_tuning_objectives) @hugging_face_model_id = args[:hugging_face_model_id] if args.key?(:hugging_face_model_id) @include_drift = args[:include_drift] if args.key?(:include_drift) @initial_learn_rate = args[:initial_learn_rate] if args.key?(:initial_learn_rate) @input_label_columns = args[:input_label_columns] if args.key?(:input_label_columns) @instance_weight_column = args[:instance_weight_column] if args.key?(:instance_weight_column) @integrated_gradients_num_steps = args[:integrated_gradients_num_steps] if args.key?(:integrated_gradients_num_steps) @is_test_column = args[:is_test_column] if args.key?(:is_test_column) @item_column = args[:item_column] if args.key?(:item_column) @kmeans_initialization_column = args[:kmeans_initialization_column] if args.key?(:kmeans_initialization_column) @kmeans_initialization_method = args[:kmeans_initialization_method] if args.key?(:kmeans_initialization_method) @l1_reg_activation = args[:l1_reg_activation] if args.key?(:l1_reg_activation) @l1_regularization = args[:l1_regularization] if args.key?(:l1_regularization) @l2_regularization = args[:l2_regularization] if args.key?(:l2_regularization) @label_class_weights = args[:label_class_weights] if args.key?(:label_class_weights) @learn_rate = args[:learn_rate] if args.key?(:learn_rate) @learn_rate_strategy = args[:learn_rate_strategy] if args.key?(:learn_rate_strategy) @loss_type = args[:loss_type] if args.key?(:loss_type) @machine_type = args[:machine_type] if args.key?(:machine_type) @max_iterations = args[:max_iterations] if args.key?(:max_iterations) @max_parallel_trials = args[:max_parallel_trials] if args.key?(:max_parallel_trials) @max_replica_count = args[:max_replica_count] if args.key?(:max_replica_count) @max_time_series_length = args[:max_time_series_length] if args.key?(:max_time_series_length) @max_tree_depth = args[:max_tree_depth] if args.key?(:max_tree_depth) @min_apriori_support = args[:min_apriori_support] if args.key?(:min_apriori_support) @min_relative_progress = args[:min_relative_progress] if args.key?(:min_relative_progress) @min_replica_count = args[:min_replica_count] if args.key?(:min_replica_count) @min_split_loss = args[:min_split_loss] if args.key?(:min_split_loss) @min_time_series_length = args[:min_time_series_length] if args.key?(:min_time_series_length) @min_tree_child_weight = args[:min_tree_child_weight] if args.key?(:min_tree_child_weight) @model_garden_model_name = args[:model_garden_model_name] if args.key?(:model_garden_model_name) @model_registry = args[:model_registry] if args.key?(:model_registry) @model_uri = args[:model_uri] if args.key?(:model_uri) @non_seasonal_order = args[:non_seasonal_order] if args.key?(:non_seasonal_order) @num_clusters = args[:num_clusters] if args.key?(:num_clusters) @num_factors = args[:num_factors] if args.key?(:num_factors) @num_parallel_tree = args[:num_parallel_tree] if args.key?(:num_parallel_tree) @num_principal_components = args[:num_principal_components] if args.key?(:num_principal_components) @num_trials = args[:num_trials] if args.key?(:num_trials) @optimization_strategy = args[:optimization_strategy] if args.key?(:optimization_strategy) @optimizer = args[:optimizer] if args.key?(:optimizer) @pca_explained_variance_ratio = args[:pca_explained_variance_ratio] if args.key?(:pca_explained_variance_ratio) @pca_solver = args[:pca_solver] if args.key?(:pca_solver) @reservation_affinity_key = args[:reservation_affinity_key] if args.key?(:reservation_affinity_key) @reservation_affinity_type = args[:reservation_affinity_type] if args.key?(:reservation_affinity_type) @reservation_affinity_values = args[:reservation_affinity_values] if args.key?(:reservation_affinity_values) @sampled_shapley_num_paths = args[:sampled_shapley_num_paths] if args.key?(:sampled_shapley_num_paths) @scale_features = args[:scale_features] if args.key?(:scale_features) @standardize_features = args[:standardize_features] if args.key?(:standardize_features) @subsample = args[:subsample] if args.key?(:subsample) @tf_version = args[:tf_version] if args.key?(:tf_version) @time_series_data_column = args[:time_series_data_column] if args.key?(:time_series_data_column) @time_series_id_column = args[:time_series_id_column] if args.key?(:time_series_id_column) @time_series_id_columns = args[:time_series_id_columns] if args.key?(:time_series_id_columns) @time_series_length_fraction = args[:time_series_length_fraction] if args.key?(:time_series_length_fraction) @time_series_timestamp_column = args[:time_series_timestamp_column] if args.key?(:time_series_timestamp_column) @tree_method = args[:tree_method] if args.key?(:tree_method) @trend_smoothing_window_size = args[:trend_smoothing_window_size] if args.key?(:trend_smoothing_window_size) @user_column = args[:user_column] if args.key?(:user_column) @vertex_ai_model_version_aliases = args[:vertex_ai_model_version_aliases] if args.key?(:vertex_ai_model_version_aliases) @wals_alpha = args[:wals_alpha] if args.key?(:wals_alpha) @warm_start = args[:warm_start] if args.key?(:warm_start) @xgboost_version = args[:xgboost_version] if args.key?(:xgboost_version) end |