Class: Google::Apis::BigqueryV2::TrainingRun

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Information about a single training query run for the model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TrainingRun

Returns a new instance of TrainingRun.



12669
12670
12671
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#class_level_global_explanationsArray<Google::Apis::BigqueryV2::GlobalExplanation>

Output only. Global explanation contains the explanation of top features on the class level. Applies to classification models only. Corresponds to the JSON property classLevelGlobalExplanations



12617
12618
12619
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12617

def class_level_global_explanations
  @class_level_global_explanations
end

#data_split_resultGoogle::Apis::BigqueryV2::DataSplitResult

Data split result. This contains references to the training and evaluation data tables that were used to train the model. Corresponds to the JSON property dataSplitResult



12623
12624
12625
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12623

def data_split_result
  @data_split_result
end

#evaluation_metricsGoogle::Apis::BigqueryV2::EvaluationMetrics

Evaluation metrics of a model. These are either computed on all training data or just the eval data based on whether eval data was used during training. These are not present for imported models. Corresponds to the JSON property evaluationMetrics



12630
12631
12632
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12630

def evaluation_metrics
  @evaluation_metrics
end

#model_level_global_explanationGoogle::Apis::BigqueryV2::GlobalExplanation

Global explanations containing the top most important features after training. Corresponds to the JSON property modelLevelGlobalExplanation



12635
12636
12637
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12635

def model_level_global_explanation
  @model_level_global_explanation
end

#resultsArray<Google::Apis::BigqueryV2::IterationResult>

Output only. Output of each iteration run, results.size() <= max_iterations. Corresponds to the JSON property results



12640
12641
12642
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12640

def results
  @results
end

#start_timeString

Output only. The start time of this training run. Corresponds to the JSON property startTime

Returns:

  • (String)


12645
12646
12647
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12645

def start_time
  @start_time
end

#training_optionsGoogle::Apis::BigqueryV2::TrainingOptions

Options used in model training. Corresponds to the JSON property trainingOptions



12650
12651
12652
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12650

def training_options
  @training_options
end

#training_start_timeFixnum

Output only. The start time of this training run, in milliseconds since epoch. Corresponds to the JSON property trainingStartTime

Returns:

  • (Fixnum)


12655
12656
12657
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12655

def training_start_time
  @training_start_time
end

#vertex_ai_model_idString

The model id in the Vertex AI Model Registry for this training run. Corresponds to the JSON property vertexAiModelId

Returns:

  • (String)


12661
12662
12663
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12661

def vertex_ai_model_id
  @vertex_ai_model_id
end

#vertex_ai_model_versionString

Output only. The model version in the Vertex AI Model Registry for this training run. Corresponds to the JSON property vertexAiModelVersion

Returns:

  • (String)


12667
12668
12669
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12667

def vertex_ai_model_version
  @vertex_ai_model_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12674
12675
12676
12677
12678
12679
12680
12681
12682
12683
12684
12685
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12674

def update!(**args)
  @class_level_global_explanations = args[:class_level_global_explanations] if args.key?(:class_level_global_explanations)
  @data_split_result = args[:data_split_result] if args.key?(:data_split_result)
  @evaluation_metrics = args[:evaluation_metrics] if args.key?(:evaluation_metrics)
  @model_level_global_explanation = args[:model_level_global_explanation] if args.key?(:model_level_global_explanation)
  @results = args[:results] if args.key?(:results)
  @start_time = args[:start_time] if args.key?(:start_time)
  @training_options = args[:training_options] if args.key?(:training_options)
  @training_start_time = args[:training_start_time] if args.key?(:training_start_time)
  @vertex_ai_model_id = args[:vertex_ai_model_id] if args.key?(:vertex_ai_model_id)
  @vertex_ai_model_version = args[:vertex_ai_model_version] if args.key?(:vertex_ai_model_version)
end