Class: Google::Apis::BigqueryV2::TrainingRun
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::TrainingRun
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Information about a single training query run for the model.
Instance Attribute Summary collapse
-
#class_level_global_explanations ⇒ Array<Google::Apis::BigqueryV2::GlobalExplanation>
Output only.
-
#data_split_result ⇒ Google::Apis::BigqueryV2::DataSplitResult
Data split result.
-
#evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model.
-
#model_level_global_explanation ⇒ Google::Apis::BigqueryV2::GlobalExplanation
Global explanations containing the top most important features after training.
-
#results ⇒ Array<Google::Apis::BigqueryV2::IterationResult>
Output only.
-
#start_time ⇒ String
Output only.
-
#training_options ⇒ Google::Apis::BigqueryV2::TrainingOptions
Options used in model training.
-
#training_start_time ⇒ Fixnum
Output only.
-
#vertex_ai_model_id ⇒ String
The model id in the Vertex AI Model Registry for this training run.
-
#vertex_ai_model_version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TrainingRun
constructor
A new instance of TrainingRun.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TrainingRun
Returns a new instance of TrainingRun.
12107 12108 12109 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#class_level_global_explanations ⇒ Array<Google::Apis::BigqueryV2::GlobalExplanation>
Output only. Global explanation contains the explanation of top features on
the class level. Applies to classification models only.
Corresponds to the JSON property classLevelGlobalExplanations
12055 12056 12057 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12055 def class_level_global_explanations @class_level_global_explanations end |
#data_split_result ⇒ Google::Apis::BigqueryV2::DataSplitResult
Data split result. This contains references to the training and evaluation
data tables that were used to train the model.
Corresponds to the JSON property dataSplitResult
12061 12062 12063 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12061 def data_split_result @data_split_result end |
#evaluation_metrics ⇒ Google::Apis::BigqueryV2::EvaluationMetrics
Evaluation metrics of a model. These are either computed on all training data
or just the eval data based on whether eval data was used during training.
These are not present for imported models.
Corresponds to the JSON property evaluationMetrics
12068 12069 12070 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12068 def evaluation_metrics @evaluation_metrics end |
#model_level_global_explanation ⇒ Google::Apis::BigqueryV2::GlobalExplanation
Global explanations containing the top most important features after training.
Corresponds to the JSON property modelLevelGlobalExplanation
12073 12074 12075 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12073 def model_level_global_explanation @model_level_global_explanation end |
#results ⇒ Array<Google::Apis::BigqueryV2::IterationResult>
Output only. Output of each iteration run, results.size() <= max_iterations.
Corresponds to the JSON property results
12078 12079 12080 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12078 def results @results end |
#start_time ⇒ String
Output only. The start time of this training run.
Corresponds to the JSON property startTime
12083 12084 12085 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12083 def start_time @start_time end |
#training_options ⇒ Google::Apis::BigqueryV2::TrainingOptions
Options used in model training.
Corresponds to the JSON property trainingOptions
12088 12089 12090 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12088 def @training_options end |
#training_start_time ⇒ Fixnum
Output only. The start time of this training run, in milliseconds since epoch.
Corresponds to the JSON property trainingStartTime
12093 12094 12095 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12093 def training_start_time @training_start_time end |
#vertex_ai_model_id ⇒ String
The model id in the Vertex AI Model Registry for this training run.
Corresponds to the JSON property vertexAiModelId
12099 12100 12101 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12099 def vertex_ai_model_id @vertex_ai_model_id end |
#vertex_ai_model_version ⇒ String
Output only. The model version in the Vertex AI Model Registry for this training run.
Corresponds to the JSON property vertexAiModelVersion
12105 12106 12107 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12105 def vertex_ai_model_version @vertex_ai_model_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 12123 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12112 def update!(**args) @class_level_global_explanations = args[:class_level_global_explanations] if args.key?(:class_level_global_explanations) @data_split_result = args[:data_split_result] if args.key?(:data_split_result) @evaluation_metrics = args[:evaluation_metrics] if args.key?(:evaluation_metrics) @model_level_global_explanation = args[:model_level_global_explanation] if args.key?(:model_level_global_explanation) @results = args[:results] if args.key?(:results) @start_time = args[:start_time] if args.key?(:start_time) @training_options = args[:training_options] if args.key?(:training_options) @training_start_time = args[:training_start_time] if args.key?(:training_start_time) @vertex_ai_model_id = args[:vertex_ai_model_id] if args.key?(:vertex_ai_model_id) @vertex_ai_model_version = args[:vertex_ai_model_version] if args.key?(:vertex_ai_model_version) end |