Class: Google::Apis::BigqueryV2::VectorSearchStatistics
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::VectorSearchStatistics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Statistics for a vector search query. Populated as part of JobStatistics2.
Instance Attribute Summary collapse
-
#index_unused_reasons ⇒ Array<Google::Apis::BigqueryV2::IndexUnusedReason>
When
indexUsageModeisUNUSEDorPARTIALLY_USED, this field explains why indexes were not used in all or part of the vector search query. -
#index_usage_mode ⇒ String
Specifies the index usage mode for the query.
-
#stored_columns_usages ⇒ Array<Google::Apis::BigqueryV2::StoredColumnsUsage>
Specifies the usage of stored columns in the query when stored columns are used in the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VectorSearchStatistics
constructor
A new instance of VectorSearchStatistics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VectorSearchStatistics
Returns a new instance of VectorSearchStatistics.
12258 12259 12260 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12258 def initialize(**args) update!(**args) end |
Instance Attribute Details
#index_unused_reasons ⇒ Array<Google::Apis::BigqueryV2::IndexUnusedReason>
When indexUsageMode is UNUSED or PARTIALLY_USED, this field explains why
indexes were not used in all or part of the vector search query. If
indexUsageMode is FULLY_USED, this field is not populated.
Corresponds to the JSON property indexUnusedReasons
12245 12246 12247 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12245 def index_unused_reasons @index_unused_reasons end |
#index_usage_mode ⇒ String
Specifies the index usage mode for the query.
Corresponds to the JSON property indexUsageMode
12250 12251 12252 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12250 def index_usage_mode @index_usage_mode end |
#stored_columns_usages ⇒ Array<Google::Apis::BigqueryV2::StoredColumnsUsage>
Specifies the usage of stored columns in the query when stored columns are
used in the query.
Corresponds to the JSON property storedColumnsUsages
12256 12257 12258 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12256 def stored_columns_usages @stored_columns_usages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12263 12264 12265 12266 12267 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12263 def update!(**args) @index_unused_reasons = args[:index_unused_reasons] if args.key?(:index_unused_reasons) @index_usage_mode = args[:index_usage_mode] if args.key?(:index_usage_mode) @stored_columns_usages = args[:stored_columns_usages] if args.key?(:stored_columns_usages) end |