Class: Google::Apis::BigqueryV2::ViewDefinition
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ViewDefinition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Describes the definition of a logical view.
Instance Attribute Summary collapse
-
#foreign_definitions ⇒ Array<Google::Apis::BigqueryV2::ForeignViewDefinition>
Optional.
-
#privacy_policy ⇒ Google::Apis::BigqueryV2::PrivacyPolicy
Represents privacy policy that contains the privacy requirements specified by the data owner.
-
#query ⇒ String
Required.
-
#use_explicit_column_names ⇒ Boolean
(also: #use_explicit_column_names?)
True if the column names are explicitly specified.
-
#use_legacy_sql ⇒ Boolean
(also: #use_legacy_sql?)
Specifies whether to use BigQuery's legacy SQL for this view.
-
#user_defined_function_resources ⇒ Array<Google::Apis::BigqueryV2::UserDefinedFunctionResource>
Describes user-defined function resources used in the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ViewDefinition
constructor
A new instance of ViewDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ViewDefinition
Returns a new instance of ViewDefinition.
12990 12991 12992 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#foreign_definitions ⇒ Array<Google::Apis::BigqueryV2::ForeignViewDefinition>
Optional. Foreign view representations.
Corresponds to the JSON property foreignDefinitions
12955 12956 12957 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12955 def foreign_definitions @foreign_definitions end |
#privacy_policy ⇒ Google::Apis::BigqueryV2::PrivacyPolicy
Represents privacy policy that contains the privacy requirements specified by
the data owner. Currently, this is only supported on views.
Corresponds to the JSON property privacyPolicy
12961 12962 12963 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12961 def privacy_policy @privacy_policy end |
#query ⇒ String
Required. A query that BigQuery executes when the view is referenced.
Corresponds to the JSON property query
12966 12967 12968 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12966 def query @query end |
#use_explicit_column_names ⇒ Boolean Also known as: use_explicit_column_names?
True if the column names are explicitly specified. For example by using the '
CREATE VIEW v(c1, c2) AS ...' syntax. Can only be set for GoogleSQL views.
Corresponds to the JSON property useExplicitColumnNames
12972 12973 12974 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12972 def use_explicit_column_names @use_explicit_column_names end |
#use_legacy_sql ⇒ Boolean Also known as: use_legacy_sql?
Specifies whether to use BigQuery's legacy SQL for this view. The default
value is true. If set to false, the view uses BigQuery's GoogleSQL. Queries and views that
reference this view must use the same flag value. A wrapper is used here
because the default value is True.
Corresponds to the JSON property useLegacySql
12982 12983 12984 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12982 def use_legacy_sql @use_legacy_sql end |
#user_defined_function_resources ⇒ Array<Google::Apis::BigqueryV2::UserDefinedFunctionResource>
Describes user-defined function resources used in the query.
Corresponds to the JSON property userDefinedFunctionResources
12988 12989 12990 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12988 def user_defined_function_resources @user_defined_function_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12995 12996 12997 12998 12999 13000 13001 13002 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12995 def update!(**args) @foreign_definitions = args[:foreign_definitions] if args.key?(:foreign_definitions) @privacy_policy = args[:privacy_policy] if args.key?(:privacy_policy) @query = args[:query] if args.key?(:query) @use_explicit_column_names = args[:use_explicit_column_names] if args.key?(:use_explicit_column_names) @use_legacy_sql = args[:use_legacy_sql] if args.key?(:use_legacy_sql) @user_defined_function_resources = args[:user_defined_function_resources] if args.key?(:user_defined_function_resources) end |