Class: Google::Apis::BigqueryV2::ViewDefinition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb

Overview

Describes the definition of a logical view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ViewDefinition

Returns a new instance of ViewDefinition.



12869
12870
12871
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12869

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#foreign_definitionsArray<Google::Apis::BigqueryV2::ForeignViewDefinition>

Optional. Foreign view representations. Corresponds to the JSON property foreignDefinitions



12834
12835
12836
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12834

def foreign_definitions
  @foreign_definitions
end

#privacy_policyGoogle::Apis::BigqueryV2::PrivacyPolicy

Represents privacy policy that contains the privacy requirements specified by the data owner. Currently, this is only supported on views. Corresponds to the JSON property privacyPolicy



12840
12841
12842
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12840

def privacy_policy
  @privacy_policy
end

#queryString

Required. A query that BigQuery executes when the view is referenced. Corresponds to the JSON property query

Returns:

  • (String)


12845
12846
12847
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12845

def query
  @query
end

#use_explicit_column_namesBoolean Also known as: use_explicit_column_names?

True if the column names are explicitly specified. For example by using the ' CREATE VIEW v(c1, c2) AS ...' syntax. Can only be set for GoogleSQL views. Corresponds to the JSON property useExplicitColumnNames

Returns:

  • (Boolean)


12851
12852
12853
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12851

def use_explicit_column_names
  @use_explicit_column_names
end

#use_legacy_sqlBoolean Also known as: use_legacy_sql?

Specifies whether to use BigQuery's legacy SQL for this view. The default value is true. If set to false, the view uses BigQuery's GoogleSQL. Queries and views that reference this view must use the same flag value. A wrapper is used here because the default value is True. Corresponds to the JSON property useLegacySql

Returns:

  • (Boolean)


12861
12862
12863
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12861

def use_legacy_sql
  @use_legacy_sql
end

#user_defined_function_resourcesArray<Google::Apis::BigqueryV2::UserDefinedFunctionResource>

Describes user-defined function resources used in the query. Corresponds to the JSON property userDefinedFunctionResources



12867
12868
12869
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12867

def user_defined_function_resources
  @user_defined_function_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12874
12875
12876
12877
12878
12879
12880
12881
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12874

def update!(**args)
  @foreign_definitions = args[:foreign_definitions] if args.key?(:foreign_definitions)
  @privacy_policy = args[:privacy_policy] if args.key?(:privacy_policy)
  @query = args[:query] if args.key?(:query)
  @use_explicit_column_names = args[:use_explicit_column_names] if args.key?(:use_explicit_column_names)
  @use_legacy_sql = args[:use_legacy_sql] if args.key?(:use_legacy_sql)
  @user_defined_function_resources = args[:user_defined_function_resources] if args.key?(:user_defined_function_resources)
end