Class: Google::Apis::BigqueryV2::ViewDefinition
- Inherits:
-
Object
- Object
- Google::Apis::BigqueryV2::ViewDefinition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigquery_v2/classes.rb,
lib/google/apis/bigquery_v2/representations.rb,
lib/google/apis/bigquery_v2/representations.rb
Overview
Describes the definition of a logical view.
Instance Attribute Summary collapse
-
#foreign_definitions ⇒ Array<Google::Apis::BigqueryV2::ForeignViewDefinition>
Optional.
-
#privacy_policy ⇒ Google::Apis::BigqueryV2::PrivacyPolicy
Represents privacy policy that contains the privacy requirements specified by the data owner.
-
#query ⇒ String
Required.
-
#use_explicit_column_names ⇒ Boolean
(also: #use_explicit_column_names?)
True if the column names are explicitly specified.
-
#use_legacy_sql ⇒ Boolean
(also: #use_legacy_sql?)
Specifies whether to use BigQuery's legacy SQL for this view.
-
#user_defined_function_resources ⇒ Array<Google::Apis::BigqueryV2::UserDefinedFunctionResource>
Describes user-defined function resources used in the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ViewDefinition
constructor
A new instance of ViewDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ViewDefinition
Returns a new instance of ViewDefinition.
12342 12343 12344 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12342 def initialize(**args) update!(**args) end |
Instance Attribute Details
#foreign_definitions ⇒ Array<Google::Apis::BigqueryV2::ForeignViewDefinition>
Optional. Foreign view representations.
Corresponds to the JSON property foreignDefinitions
12307 12308 12309 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12307 def foreign_definitions @foreign_definitions end |
#privacy_policy ⇒ Google::Apis::BigqueryV2::PrivacyPolicy
Represents privacy policy that contains the privacy requirements specified by
the data owner. Currently, this is only supported on views.
Corresponds to the JSON property privacyPolicy
12313 12314 12315 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12313 def privacy_policy @privacy_policy end |
#query ⇒ String
Required. A query that BigQuery executes when the view is referenced.
Corresponds to the JSON property query
12318 12319 12320 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12318 def query @query end |
#use_explicit_column_names ⇒ Boolean Also known as: use_explicit_column_names?
True if the column names are explicitly specified. For example by using the '
CREATE VIEW v(c1, c2) AS ...' syntax. Can only be set for GoogleSQL views.
Corresponds to the JSON property useExplicitColumnNames
12324 12325 12326 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12324 def use_explicit_column_names @use_explicit_column_names end |
#use_legacy_sql ⇒ Boolean Also known as: use_legacy_sql?
Specifies whether to use BigQuery's legacy SQL for this view. The default
value is true. If set to false, the view uses BigQuery's GoogleSQL. Queries and views that
reference this view must use the same flag value. A wrapper is used here
because the default value is True.
Corresponds to the JSON property useLegacySql
12334 12335 12336 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12334 def use_legacy_sql @use_legacy_sql end |
#user_defined_function_resources ⇒ Array<Google::Apis::BigqueryV2::UserDefinedFunctionResource>
Describes user-defined function resources used in the query.
Corresponds to the JSON property userDefinedFunctionResources
12340 12341 12342 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12340 def user_defined_function_resources @user_defined_function_resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12347 12348 12349 12350 12351 12352 12353 12354 |
# File 'lib/google/apis/bigquery_v2/classes.rb', line 12347 def update!(**args) @foreign_definitions = args[:foreign_definitions] if args.key?(:foreign_definitions) @privacy_policy = args[:privacy_policy] if args.key?(:privacy_policy) @query = args[:query] if args.key?(:query) @use_explicit_column_names = args[:use_explicit_column_names] if args.key?(:use_explicit_column_names) @use_legacy_sql = args[:use_legacy_sql] if args.key?(:use_legacy_sql) @user_defined_function_resources = args[:user_defined_function_resources] if args.key?(:user_defined_function_resources) end |